# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .goa_driver_tiny_response_response_body import GoaDriverTinyResponseResponseBody
from .vehicle_with_gateway_tiny_response_response_body import VehicleWithGatewayTinyResponseResponseBody
from .workflow_dvir_object_response_body import WorkflowDvirObjectResponseBody


class WorkflowDvirSubmittedResponseObjectResponseBody(UniversalBaseModel):
    """
    Details specific to DVIR Submitted.
    """

    driver: typing.Optional[GoaDriverTinyResponseResponseBody] = None
    dvir: typing.Optional[WorkflowDvirObjectResponseBody] = None
    vehicle: typing.Optional[VehicleWithGatewayTinyResponseResponseBody] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
