# This file was auto-generated by Fern from our API Definition.

import typing

StreamWorkOrdersRequestWorkOrderStatusesItem = typing.Union[
    typing.Literal[
        "Assigned",
        "Cancelled",
        "Closed",
        "Completed",
        "In Progress",
        "On Hold",
        "Open",
        "Pending Approval",
        "Pending Parts",
    ],
    typing.Any,
]
