# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class DriverAppSettingsGamificationConfigTinyObjectResponseBody(UniversalBaseModel):
    """
    Gamification configuration for the Driver App.
    """

    anonymize_driver_names: typing_extensions.Annotated[
        typing.Optional[bool],
        FieldMetadata(alias="anonymizeDriverNames"),
        pydantic.Field(
            alias="anonymizeDriverNames",
            description="Hide the names of other drivers when viewing the driver leaderboard in the mobile app.",
        ),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
