# This file was auto-generated by Fern from our API Definition.

import typing

VehicleSensorConfigurationAreaResponseBodyPosition = typing.Union[typing.Literal["back", "front", "middle"], typing.Any]
