# This file was auto-generated by Fern from our API Definition.

import typing

HealthResponseResponseBodyHealthStatus = typing.Union[
    typing.Literal["dataPending", "healthy", "needsAttention", "needsReplacement"], typing.Any
]
