# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .forms_geofence_object_response_body_entry_type import FormsGeofenceObjectResponseBodyEntryType


class FormsGeofenceObjectResponseBody(UniversalBaseModel):
    """
    Tracked or untracked (i.e. manually entered) geofence object.
    """

    address: typing.Optional[str] = pydantic.Field(default=None)
    """
    Address of the geofence. Included if 'entryType' is `tracked`.
    """

    entry_type: typing_extensions.Annotated[
        FormsGeofenceObjectResponseBodyEntryType,
        FieldMetadata(alias="entryType"),
        pydantic.Field(
            alias="entryType", description="The type of entry for the geofence.  Valid values: `tracked`, `untracked`"
        ),
    ]
    external_ids: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, str]],
        FieldMetadata(alias="externalIds"),
        pydantic.Field(alias="externalIds", description="A map of external ids"),
    ] = None
    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    ID of the tracked geofence. Included if 'entryType' is `tracked`.
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Name of an untracked (i.e. manually entered) geofence.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
