# This file was auto-generated by Fern from our API Definition.

import typing

CarbCtcVehicleHistoryObjectResponseBodyTestResult = typing.Union[
    typing.Literal["pass", "fail", "error", "unknown"], typing.Any
]
