# This file was auto-generated by Fern from our API Definition.

import typing

DeviceRecoveryRecoverAssetRequestBodyMissingReason = typing.Union[
    typing.Literal["MISPLACED", "STOLEN", "NOT_SURE"], typing.Any
]
