# This file was auto-generated by Fern from our API Definition.

import typing

WorkOrdersPatchWorkOrdersRequestBodyPriority = typing.Union[
    typing.Literal["High", "Low", "Medium", "Urgent"], typing.Any
]
