# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .goa_attribute_tiny_response_body import GoaAttributeTinyResponseBody
from .goa_tag_tiny_response_response_body import GoaTagTinyResponseResponseBody


class DetectionLogAssetObjectResponseBody(UniversalBaseModel):
    """
    Asset that the detection is tied to. Always returned.
    """

    attributes: typing.Optional[typing.List[GoaAttributeTinyResponseBody]] = pydantic.Field(default=None)
    """
    List of attributes associated with the entity
    """

    id: str = pydantic.Field()
    """
    Unique ID for the asset object that is reporting the detection. Always returned.
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Name for the asset object that is reporting the safety event. Only returned when includeAsset is set to true
    """

    tags: typing.Optional[typing.List[GoaTagTinyResponseResponseBody]] = pydantic.Field(default=None)
    """
    Tags for the asset associated with the safety event. Only returned when includeAsset is set to true
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
