# This file was auto-generated by Fern from our API Definition.

import typing

V1VisionStepResultsItemCaliperFilterPolarity = typing.Union[
    typing.Literal["LIGHT TO DARK", "DARK TO LIGHT"], typing.Any
]
