# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class FormsCheckBoxesValueObjectResponseBody(UniversalBaseModel):
    """
    The value of a check boxes form input field.
    """

    value: typing.List[str] = pydantic.Field()
    """
    List of selected options.
    """

    value_ids: typing_extensions.Annotated[
        typing.List[str],
        FieldMetadata(alias="valueIds"),
        pydantic.Field(alias="valueIds", description="List of selected option IDs."),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
