# This file was auto-generated by Fern from our API Definition.

import typing

RouteEventResponseResponseBodyEventType = typing.Union[
    typing.Literal[
        "stopArrived",
        "stopCompleted",
        "stopEnRoute",
        "stopSkipped",
        "stopTaskCompleted",
        "stopTaskSkipped",
        "stopEtaUpdated",
        "unspecified",
    ],
    typing.Any,
]
