# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .assets_location_link_config_address_details_object_response_body import (
    AssetsLocationLinkConfigAddressDetailsObjectResponseBody,
)
from .goa_tag_tiny_response_response_body import GoaTagTinyResponseResponseBody


class AssetsLocationLinkResponseConfigObjectResponseBody(UniversalBaseModel):
    """
    Configuration details specific to the 'By Asset' Live Sharing Link.
    """

    asset_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="assetId"),
        pydantic.Field(alias="assetId", description="Unique assets ID that Live Sharing Link will show."),
    ] = None
    location: typing.Optional[AssetsLocationLinkConfigAddressDetailsObjectResponseBody] = None
    tags: typing.Optional[typing.List[GoaTagTinyResponseResponseBody]] = pydantic.Field(default=None)
    """
    The list of [tags](https://kb.samsara.com/hc/en-us/articles/360026674631-Using-Tags-and-Tag-Nesting) associated with assets for Live Sharing Link. Only populated if the link is configured for by tags instead of by asset ID.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
