# This file was auto-generated by Fern from our API Definition.

import typing

UsDriverRulesetOverrideRestbreak = typing.Union[
    typing.Literal["Property (off-duty/sleeper)", "California Mealbreak (off-duty/sleeper)", "None"], typing.Any
]
