# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class HarshBrakeSensitivityGForceSettingsObjectResponseBody(UniversalBaseModel):
    """
    The harsh brake sensitivity settings.
    """

    heavy_duty: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="heavyDuty"),
        pydantic.Field(alias="heavyDuty", description="Harsh brake sensitivity settings for heavy duty vehicle."),
    ] = None
    light_duty: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="lightDuty"),
        pydantic.Field(alias="lightDuty", description="Harsh brake sensitivity settings for light duty vehicle."),
    ] = None
    passenger: typing.Optional[str] = pydantic.Field(default=None)
    """
    Harsh brake sensitivity settings for passenger car.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
