# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .v_1_vision_step_results import V1VisionStepResults


class V1VisionRunByCameraResponseInspectionResults(UniversalBaseModel):
    capture_at_ms: typing_extensions.Annotated[
        typing.Optional[float], FieldMetadata(alias="captureAtMs"), pydantic.Field(alias="captureAtMs")
    ] = None
    result: typing.Optional[str] = None
    step_results: typing_extensions.Annotated[
        typing.Optional[V1VisionStepResults], FieldMetadata(alias="stepResults"), pydantic.Field(alias="stepResults")
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
