# This file was auto-generated by Fern from our API Definition.

import typing

FormSubmissionRequestTableCellObjectRequestBodyType = typing.Union[
    typing.Literal["number", "text", "multiple_choice", "check_boxes", "datetime", "person"], typing.Any
]
