# This file was auto-generated by Fern from our API Definition.

import typing

TimeRangeObjectRequestBodyDaysOfWeekItem = typing.Union[
    typing.Literal["FRIDAY", "MONDAY", "SATURDAY", "SUNDAY", "THURSDAY", "TUESDAY", "WEDNESDAY"], typing.Any
]
