# This file was auto-generated by Fern from our API Definition.

import typing

UsDriverRulesetOverrideUsStateToOverride = typing.Union[
    typing.Literal["", "AK", "CA", "FL", "NE", "NC", "OK", "OR", "SC", "TX", "WI"], typing.Any
]
