# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class FunctionScheduleEntryResponseBody(UniversalBaseModel):
    """
    A single schedule entry defining when a Function runs.
    """

    days_of_week: typing_extensions.Annotated[
        typing.List[bool],
        FieldMetadata(alias="daysOfWeek"),
        pydantic.Field(
            alias="daysOfWeek", description="Days of the week this entry applies to (7 elements, index 0 = Sunday)."
        ),
    ]
    time_since_midnight_ms: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="timeSinceMidnightMs"),
        pydantic.Field(
            alias="timeSinceMidnightMs", description="Time since midnight in milliseconds when the function runs."
        ),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
