# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .alert_object_workforce_camera_device_response_body import AlertObjectWorkforceCameraDeviceResponseBody


class CameraStreamIssueResponseBody(UniversalBaseModel):
    """
    Details specific to Camera Stream Issue.
    """

    camera_device: typing_extensions.Annotated[
        typing.Optional[AlertObjectWorkforceCameraDeviceResponseBody],
        FieldMetadata(alias="cameraDevice"),
        pydantic.Field(alias="cameraDevice"),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
