# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .forms_media_record_object_response_body import FormsMediaRecordObjectResponseBody


class FormsMediaValueObjectResponseBody(UniversalBaseModel):
    """
    The value of a media form input field.
    """

    media_list: typing_extensions.Annotated[
        typing.List[FormsMediaRecordObjectResponseBody],
        FieldMetadata(alias="mediaList"),
        pydantic.Field(alias="mediaList", description="List of forms media record objects."),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
