# This file was auto-generated by Fern from our API Definition.

import typing

MediaObjectResponseBodyStatus = typing.Union[
    typing.Literal["available", "invalid", "pending", "failed", "unavailable"], typing.Any
]
