# This file was auto-generated by Fern from our API Definition.

import typing

WorkflowDvirObjectResponseBodyType = typing.Union[
    typing.Literal["preTrip", "postTrip", "mechanic", "unspecified"], typing.Any
]
