# This file was auto-generated by Fern from our API Definition.

import typing

UpdateEngineImmobilizerRelayStateRequestBodyRequestBodyId = typing.Union[typing.Literal["relay1", "relay2"], typing.Any]
