# This file was auto-generated by Fern from our API Definition.

import typing

from .vehicle_stats_fault_codes_oem_trouble_code import VehicleStatsFaultCodesOemTroubleCode

VehicleStatsFaultCodesOemTroubleCodes = typing.List[VehicleStatsFaultCodesOemTroubleCode]
