# This file was auto-generated by Fern from our API Definition.

import typing

HealthResponseResponseBodyRecommendedAction = typing.Union[
    typing.Literal[
        "recommendedActionAgHealthy",
        "recommendedActionAgLowDeviceBatteryAG45",
        "recommendedActionAgLowDeviceBatteryAG46",
        "recommendedActionAgLowDeviceBatteryAG51",
        "recommendedActionAgLowDeviceBatteryPoweredAG",
        "recommendedActionAgNoGpsSignal",
        "recommendedActionAgNotDetected",
        "recommendedActionAgUnplugged",
        "recommendedActionBLEDataPending",
        "recommendedActionBLEHealthy",
        "recommendedActionBLELowBattery",
        "recommendedActionBLENotDetected",
        "recommendedActionCcHealthy",
        "recommendedActionCcLowUptime",
        "recommendedActionCcMediaInputUptime",
        "recommendedActionCcNotDetected",
        "recommendedActionCmCameraMisaligned",
        "recommendedActionCmHealthy",
        "recommendedActionCmInactive",
        "recommendedActionCmInwardCameraObstruction",
        "recommendedActionCmIrregularRecording",
        "recommendedActionCmLowUptime",
        "recommendedActionCmNewlyInstalledDevice",
        "recommendedActionCmNotDetected",
        "recommendedActionCmOutwardCameraObstruction",
        "recommendedActionCmRecordingTimeRequired",
        "recommendedActionCmVgUnplugged",
        "recommendedActionGatewayNewlyInstalledDevice",
        "recommendedActionHealthy",
        "recommendedActionLowBatteryVoltage",
        "recommendedActionOemNotReporting",
        "recommendedActionVehicleOff",
        "recommendedActionVgHealthy",
        "recommendedActionVgMissingEldDiagnostics",
        "recommendedActionVgMissingEldDiagnosticsExchangeSubmitted",
        "recommendedActionVgMissingEldDiagnosticsHardwareExchanged",
        "recommendedActionVgMissingEldDiagnosticsNoExchangeSubmitted",
        "recommendedActionVgMissingVin",
        "recommendedActionVgNeedsReplacement",
        "recommendedActionVgNotDetected",
        "recommendedActionVgVgUnplugged",
        "unknown",
    ],
    typing.Any,
]
