# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class InvoiceScanFileRequestBody(UniversalBaseModel):
    """
    Invoice file object
    """

    base_64_content: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="base64Content"),
        pydantic.Field(alias="base64Content", description="Base64 encoded file content. Maximum decoded size: 10MB."),
    ]
    content_type: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="contentType"),
        pydantic.Field(
            alias="contentType",
            description="MIME type of the file. Supported types: application/pdf, image/jpeg, image/png.",
        ),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
