# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .update_vehicle_request_aux_input_type_1 import UpdateVehicleRequestAuxInputType1
    from .update_vehicle_request_aux_input_type_10 import UpdateVehicleRequestAuxInputType10
    from .update_vehicle_request_aux_input_type_11 import UpdateVehicleRequestAuxInputType11
    from .update_vehicle_request_aux_input_type_12 import UpdateVehicleRequestAuxInputType12
    from .update_vehicle_request_aux_input_type_13 import UpdateVehicleRequestAuxInputType13
    from .update_vehicle_request_aux_input_type_2 import UpdateVehicleRequestAuxInputType2
    from .update_vehicle_request_aux_input_type_3 import UpdateVehicleRequestAuxInputType3
    from .update_vehicle_request_aux_input_type_4 import UpdateVehicleRequestAuxInputType4
    from .update_vehicle_request_aux_input_type_5 import UpdateVehicleRequestAuxInputType5
    from .update_vehicle_request_aux_input_type_6 import UpdateVehicleRequestAuxInputType6
    from .update_vehicle_request_aux_input_type_7 import UpdateVehicleRequestAuxInputType7
    from .update_vehicle_request_aux_input_type_8 import UpdateVehicleRequestAuxInputType8
    from .update_vehicle_request_aux_input_type_9 import UpdateVehicleRequestAuxInputType9
    from .update_vehicle_request_harsh_acceleration_setting_type import UpdateVehicleRequestHarshAccelerationSettingType
_dynamic_imports: typing.Dict[str, str] = {
    "UpdateVehicleRequestAuxInputType1": ".update_vehicle_request_aux_input_type_1",
    "UpdateVehicleRequestAuxInputType10": ".update_vehicle_request_aux_input_type_10",
    "UpdateVehicleRequestAuxInputType11": ".update_vehicle_request_aux_input_type_11",
    "UpdateVehicleRequestAuxInputType12": ".update_vehicle_request_aux_input_type_12",
    "UpdateVehicleRequestAuxInputType13": ".update_vehicle_request_aux_input_type_13",
    "UpdateVehicleRequestAuxInputType2": ".update_vehicle_request_aux_input_type_2",
    "UpdateVehicleRequestAuxInputType3": ".update_vehicle_request_aux_input_type_3",
    "UpdateVehicleRequestAuxInputType4": ".update_vehicle_request_aux_input_type_4",
    "UpdateVehicleRequestAuxInputType5": ".update_vehicle_request_aux_input_type_5",
    "UpdateVehicleRequestAuxInputType6": ".update_vehicle_request_aux_input_type_6",
    "UpdateVehicleRequestAuxInputType7": ".update_vehicle_request_aux_input_type_7",
    "UpdateVehicleRequestAuxInputType8": ".update_vehicle_request_aux_input_type_8",
    "UpdateVehicleRequestAuxInputType9": ".update_vehicle_request_aux_input_type_9",
    "UpdateVehicleRequestHarshAccelerationSettingType": ".update_vehicle_request_harsh_acceleration_setting_type",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "UpdateVehicleRequestAuxInputType1",
    "UpdateVehicleRequestAuxInputType10",
    "UpdateVehicleRequestAuxInputType11",
    "UpdateVehicleRequestAuxInputType12",
    "UpdateVehicleRequestAuxInputType13",
    "UpdateVehicleRequestAuxInputType2",
    "UpdateVehicleRequestAuxInputType3",
    "UpdateVehicleRequestAuxInputType4",
    "UpdateVehicleRequestAuxInputType5",
    "UpdateVehicleRequestAuxInputType6",
    "UpdateVehicleRequestAuxInputType7",
    "UpdateVehicleRequestAuxInputType8",
    "UpdateVehicleRequestAuxInputType9",
    "UpdateVehicleRequestHarshAccelerationSettingType",
]
