# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class QrCodeResponseObjectResponseBody(UniversalBaseModel):
    """
    A single document.
    """

    driver_id: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="driverId"),
        pydantic.Field(alias="driverId", description="ID for the driver the QR code belongs to."),
    ]
    qr_code_link: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="qrCodeLink"),
        pydantic.Field(
            alias="qrCodeLink",
            description="URL link to the driver assignment QR code. Included if a QR code has been created for the driver.",
        ),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
