# This file was auto-generated by Fern from our API Definition.

import typing

SafetyScoreBehaviorObjectResponseBodyBehaviorType = typing.Union[
    typing.Literal[
        "acceleration",
        "braking",
        "crash",
        "defensiveDriving",
        "didNotYield",
        "distractedDrivingAutomatic",
        "distractedDrivingManual",
        "drowsy",
        "eatingDrinking",
        "followingDistance",
        "followingDistanceModerate",
        "followingDistanceSevere",
        "forwardCollisionWarning",
        "harshTurn",
        "laneDeparture",
        "lateResponse",
        "mobileUsage",
        "nearCollision",
        "noSeatbelt",
        "obstructedCamera",
        "ranRedLight",
        "rollingStop",
        "smoking",
        "speedingManual",
        "unknown",
    ],
    typing.Any,
]
