# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .parent_tag_name import ParentTagName
from .tagged_object_id import TaggedObjectId


class ParentTag(UniversalBaseModel):
    """
    If this tag is part a hierarchical tag tree, this is the parent tag, otherwise this will be omitted.
    """

    id: TaggedObjectId
    name: typing.Optional[ParentTagName] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
