# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .work_order_money_object_response_body_currency import WorkOrderMoneyObjectResponseBodyCurrency


class WorkOrderMoneyObjectResponseBody(UniversalBaseModel):
    """
    A specified amount of money.
    """

    amount: str = pydantic.Field()
    """
    Amount of the currency.
    """

    currency: WorkOrderMoneyObjectResponseBodyCurrency = pydantic.Field()
    """
    Type of the currency. We currently only support usd.  Valid values: `usd`
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
