# This file was auto-generated by Fern from our API Definition.

import typing

DefectTypesResponseDataResponseBodySeverity = typing.Union[
    typing.Literal["major", "minor", "notApplicable"], typing.Any
]
