# This file was auto-generated by Fern from our API Definition.

import typing

DeviceRecoveryRecoverAssetRequestBodyRecoveryStatus = typing.Union[typing.Literal["YES", "NO", "NOT_SURE"], typing.Any]
