# This file was auto-generated by Fern from our API Definition.

import typing

PatchSafetyEventsDismissalReasonBodyRequestBodyCode = typing.Union[
    typing.Literal["incorrect", "minorEvent", "other"], typing.Any
]
