# This file was auto-generated by Fern from our API Definition.

import typing

QualificationRecordRequestFieldInputObjectRequestBodyType = typing.Union[
    typing.Literal["number", "text", "multiple_choice", "check_boxes", "datetime", "table", "media", "signature"],
    typing.Any,
]
