# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class FunctionEffectsResponseBody(UniversalBaseModel):
    """
    Computed effects of the Function configuration.
    """

    next_scheduled_at_time: typing_extensions.Annotated[
        typing.Optional[dt.datetime],
        FieldMetadata(alias="nextScheduledAtTime"),
        pydantic.Field(
            alias="nextScheduledAtTime",
            description="RFC 3339 timestamp of the next scheduled run. Omitted if no schedule is set.",
        ),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
