# This file was auto-generated by Fern from our API Definition.

import typing

FormsFieldDefinitionObjectResponseBodyAllowedAssetTypesItem = typing.Union[
    typing.Literal["vehicle", "trailer", "equipment", "unpoweredAsset"], typing.Any
]
