# This file was auto-generated by Fern from our API Definition.

import typing

RouteStopDetailsObjectResponseBodyOperation = typing.Union[typing.Literal["stop arrived", "stop departed"], typing.Any]
