# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class HubCapacityObjectResponseBody(UniversalBaseModel):
    """
    Hub capacity object
    """

    created_at: typing_extensions.Annotated[
        dt.datetime,
        FieldMetadata(alias="createdAt"),
        pydantic.Field(alias="createdAt", description="Creation timestamp"),
    ]
    hub_id: typing_extensions.Annotated[
        str, FieldMetadata(alias="hubId"), pydantic.Field(alias="hubId", description="Hub identifier")
    ]
    id: str = pydantic.Field()
    """
    Capacity identifier
    """

    name: str = pydantic.Field()
    """
    Capacity name
    """

    unit: str = pydantic.Field()
    """
    Unit of measurement
    """

    updated_at: typing_extensions.Annotated[
        dt.datetime,
        FieldMetadata(alias="updatedAt"),
        pydantic.Field(alias="updatedAt", description="Last update timestamp"),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
