# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .work_order_money_object_response_body import WorkOrderMoneyObjectResponseBody


class WorkOrderUnallocatedLaborObjectResponseBody(UniversalBaseModel):
    """
    Unallocated labor from time entries not associated with any service task.
    """

    cost: WorkOrderMoneyObjectResponseBody
    time_minutes: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="timeMinutes"),
        pydantic.Field(alias="timeMinutes", description="The total unallocated labor time in minutes."),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
