# This file was auto-generated by Fern from our API Definition.

import typing

AddressAddressTypesItem = typing.Union[
    typing.Literal[
        "yard",
        "shortHaul",
        "workforceSite",
        "riskZone",
        "industrialSite",
        "alertsOnly",
        "agricultureSource",
        "avoidanceZone",
        "knownGPSJammingZone",
        "authorizedZone",
        "unauthorizedZone",
        "vendor",
        "inventory",
    ],
    typing.Any,
]
