# This file was auto-generated by Fern from our API Definition.

import typing

TachographActivityState = typing.Union[
    typing.Literal["BREAK/REST", "WORK", "AVAILABILITY", "DRIVING", "UNKNOWN"], typing.Any
]
