# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class V1MachineHistoryResponseVibrations(UniversalBaseModel):
    x: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="X"), pydantic.Field(alias="X")] = None
    y: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="Y"), pydantic.Field(alias="Y")] = None
    z: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="Z"), pydantic.Field(alias="Z")] = None
    time: typing.Optional[int] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
