# This file was auto-generated by Fern from our API Definition.

import typing

ReportRunObjectResponseBodyStatus = typing.Union[
    typing.Literal["complete", "pending", "failed", "canceled", "unknown"], typing.Any
]
