# This file was auto-generated by Fern from our API Definition.

import typing

WorkOrderAttachmentObjectResponseBodyProcessingStatus = typing.Union[
    typing.Literal["unknown", "processing", "finished"], typing.Any
]
