# This file was auto-generated by Fern from our API Definition.

import typing

DriverEldRulesetShift = typing.Union[
    typing.Literal["US Interstate Property", "US Interstate Passenger", "Texas Intrastate"], typing.Any
]
