# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .fuel_volume_response_body import FuelVolumeResponseBody
from .vehicle_with_gateway_tiny_response_response_body import VehicleWithGatewayTinyResponseResponseBody
from .workflow_address_event_with_geofence_object_response_body import (
    WorkflowAddressEventWithGeofenceObjectResponseBody,
)


class WorkflowGeofenceEventResponseObjectResponseBody(UniversalBaseModel):
    address: typing.Optional[WorkflowAddressEventWithGeofenceObjectResponseBody] = None
    fuel_volume: typing_extensions.Annotated[
        typing.Optional[FuelVolumeResponseBody], FieldMetadata(alias="fuelVolume"), pydantic.Field(alias="fuelVolume")
    ] = None
    vehicle: typing.Optional[VehicleWithGatewayTinyResponseResponseBody] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
