# This file was auto-generated by Fern from our API Definition.

import typing

SafetyEventsV2PatchSafetyEventsV2BatchRequestBodyContextLabelsToAddItem = typing.Union[
    typing.Literal[
        "Congested",
        "Construction",
        "Coupling/Uncoupling",
        "Cyclist/Motorcyclist",
        "Defensive",
        "Fog",
        "Improper Seat Belt",
        "Light Traffic",
        "Moderate Traffic",
        "Moderately Drowsy",
        "Mounted Phone",
        "Night",
        "Parking Lot",
        "Passenger Mobile Usage",
        "Passenger Sleeping",
        "Passengers",
        "Pedestrians",
        "Raining",
        "Sensitive Media",
        "Slightly Drowsy",
        "Snowing",
        "Snowy Road",
        "Speed Sign Verified",
        "Very Drowsy",
        "Wet Road",
    ],
    typing.Any,
]
