# This file was auto-generated by Fern from our API Definition.

import typing

ReportColumnsObjectResponseBodyDataType = typing.Union[
    typing.Literal["string", "float", "integer", "timestamp", "unknown"], typing.Any
]
