# This file was auto-generated by Fern from our API Definition.

import typing

GetEquipmentStatsFeedRequestTypesItem = typing.Union[
    typing.Literal[
        "gatewayEngineStates",
        "obdEngineStates",
        "fuelPercents",
        "engineRpm",
        "gatewayEngineSeconds",
        "obdEngineSeconds",
        "gatewayJ1939EngineSeconds",
        "gpsOdometerMeters",
        "gps",
        "engineTotalIdleTimeMinutes",
    ],
    typing.Any,
]
