# This file was auto-generated by Fern from our API Definition.

import typing

TrainingAssignmentNearDueDateTriggerDetailsObjectRequestBodyConditionUnits = typing.Union[
    typing.Literal["DAYS", "WEEKS"], typing.Any
]
