# This file was auto-generated by Fern from our API Definition.

import typing

IssuesPatchIssueRequestBodyStatus = typing.Union[
    typing.Literal["open", "inProgress", "resolved", "dismissed"], typing.Any
]
