# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .function_code_package_response_body_status import FunctionCodePackageResponseBodyStatus


class FunctionCodePackageResponseBody(UniversalBaseModel):
    """
    Code package status for the Function.
    """

    download_get_url: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="downloadGetUrl"),
        pydantic.Field(
            alias="downloadGetUrl",
            description="A presigned GET URL for downloading the function's current code package. Present only when code has been uploaded.",
        ),
    ] = None
    status: FunctionCodePackageResponseBodyStatus = pydantic.Field()
    """
    Status of the code package.  Valid values: `unknown`, `pendingUpload`, `uploaded`, `deployed`
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
