# This file was auto-generated by Fern from our API Definition.

import typing

CarbCtcVehicleObjectResponseBodyTestStatus = typing.Union[
    typing.Literal["notScheduled", "scheduled", "inProgress", "awaitingResult", "pass", "fail", "error", "unknown"],
    typing.Any,
]
