# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .patch_safety_events_response_item_response_body import PatchSafetyEventsResponseItemResponseBody


class SafetyEventsV2PatchSafetyEventsV2BatchResponseBody(UniversalBaseModel):
    request_id: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="requestId"),
        pydantic.Field(
            alias="requestId",
            description="Server-generated UUID for client-side correlation and logging. Not stored or queryable on the backend.",
        ),
    ]
    responses: typing.List[PatchSafetyEventsResponseItemResponseBody] = pydantic.Field()
    """
    One entry per requested safetyEventId, in the same order as the request.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
