# This file was auto-generated by Fern from our API Definition.

import typing

VehicleResponseObjectResponseBodyVehicleType = typing.Union[
    typing.Literal["unset", "passenger", "truck", "bus"], typing.Any
]
