# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class V1VehicleHarshEventResponseLocation(UniversalBaseModel):
    address: typing.Optional[str] = pydantic.Field(default=None)
    """
    Address of location where the harsh event occurred
    """

    latitude: typing.Optional[float] = pydantic.Field(default=None)
    """
    Latitude of location where the harsh event occurred
    """

    longitude: typing.Optional[float] = pydantic.Field(default=None)
    """
    Longitude of location where the harsh event occurred
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
