# This file was auto-generated by Fern from our API Definition.

import typing

CellConnectivityResponseResponseBodySignalBar = typing.Union[
    typing.Literal["1/4", "2/4", "3/4", "4/4", "unknown"], typing.Any
]
