# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .fuel_volume_response_body_unit import FuelVolumeResponseBodyUnit


class FuelVolumeResponseBody(UniversalBaseModel):
    unit: FuelVolumeResponseBodyUnit = pydantic.Field()
    """
    Units in which volume is being presented.  Valid values: `GALLONS`, `LITERS`
    """

    value: float = pydantic.Field()
    """
    The volume of the measured fuel.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
