# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class DocumentPdfGenerationResponseData(UniversalBaseModel):
    document_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="documentId"),
        pydantic.Field(alias="documentId", description="ID of the document."),
    ] = None
    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    ID of the PDF file generated or being generated for the document.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
