# This file was auto-generated by Fern from our API Definition.

import typing

FormsFieldInputObjectResponseBodyType = typing.Union[
    typing.Literal[
        "number",
        "text",
        "multiple_choice",
        "check_boxes",
        "datetime",
        "signature",
        "media",
        "asset",
        "table",
        "person",
        "geofence",
    ],
    typing.Any,
]
