# This file was auto-generated by Fern from our API Definition.

import typing

DepreciationTransactionObjectResponseBodyTransactionType = typing.Union[
    typing.Literal["depreciation", "adjustment", "unknown"], typing.Any
]
