# This file was auto-generated by Fern from our API Definition.

import typing

FormsActionObjectResponseBodyType = typing.Union[
    typing.Literal["askFollowupQuestion", "showSection", "requirePhoto", "requireNote", "createIssue"], typing.Any
]
