# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .training_learner_object_response_body_type import TrainingLearnerObjectResponseBodyType


class TrainingLearnerObjectResponseBody(UniversalBaseModel):
    """
    Learner that is associated with the training assignment. Only driver learners are supported currently.
    """

    id: str = pydantic.Field()
    """
    ID of the polymorphic user.
    """

    type: TrainingLearnerObjectResponseBodyType = pydantic.Field()
    """
    The type of the polymorphic user.  Valid values: `driver`
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
