# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .form_submission_request_assigned_to_request_body_type import FormSubmissionRequestAssignedToRequestBodyType


class FormSubmissionRequestAssignedToRequestBody(UniversalBaseModel):
    """
    Form submission assignee update object
    """

    id: str = pydantic.Field()
    """
    ID of the form submission assignee.
    """

    type: FormSubmissionRequestAssignedToRequestBodyType = pydantic.Field()
    """
    Type of the form submission assignee.  Valid values: `driver`, `user`
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
