# This file was auto-generated by Fern from our API Definition.

import typing

WebhooksPostWebhooksRequestBodyVersion = typing.Union[
    typing.Literal["2018-01-01", "2021-06-09", "2022-09-13", "2024-02-27"], typing.Any
]
