# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .trailer_stat_decoration_response_body import TrailerStatDecorationResponseBody


class TrailerStatReeferStateWithDecorationsTypeResponseBody(UniversalBaseModel):
    """
    Reefer state event.
    """

    decorations: typing.Optional[TrailerStatDecorationResponseBody] = None
    substate_value: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="substateValue"),
        pydantic.Field(
            alias="substateValue", description="The substate of the multizone carrier reefer, if available."
        ),
    ] = None
    time: str = pydantic.Field()
    """
    UTC timestamp in RFC 3339 format.
    """

    value: str = pydantic.Field()
    """
    The overall state of the multizone carrier reefer.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
