# This file was auto-generated by Fern from our API Definition.

import typing

HarshEventTriggerDetailsObjectResponseBodyTypesItem = typing.Union[
    typing.Literal[
        "haAccel",
        "haBraking",
        "haCameraMisaligned",
        "haCrash",
        "haDistractedDriving",
        "haDistractedDrivingCalibration",
        "haDrinkPolicy",
        "haDriverObstructionPolicy",
        "haDrowsinessDetection",
        "haEvent",
        "haFalsePositive",
        "haFoodPolicy",
        "haHighSpeedSuddenDisconnect",
        "haInvalid",
        "haLaneDeparture",
        "haMaskPolicy",
        "haNearCollision",
        "haOutwardObstructionPolicy",
        "haPassengerPolicy",
        "haPersonalProtectiveEquipment",
        "haPhonePolicy",
        "haPolicyDetector",
        "haRearCollisionWarning",
        "haRedLightViolation",
        "haReversing",
        "haRolledStopSign",
        "haRollover",
        "haRolloverProtectionBrakeControlActivated",
        "haRolloverProtectionEngineControlActivated",
        "haSeatbeltPolicy",
        "haSharpTurn",
        "haSignDetection",
        "haSmokingPolicy",
        "haSpeeding",
        "haTailgating",
        "haTileRollingRailroadCrossing",
        "haTileRollingStopSign",
        "haTrafficLightDetection",
        "haUnsafeParking",
        "haVehicleInBlindSpotWarning",
        "haVulnerableRoadUserCollisionWarning",
        "haYawControlBrakeControlActivated",
        "haYawControlEngineControlActivated",
    ],
    typing.Any,
]
