# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .dvir_2_assigned_to_polymorphic_user_object_response_body import Dvir2AssignedToPolymorphicUserObjectResponseBody


class Dvir2FormSubmissionObjectResponseBody(UniversalBaseModel):
    """
    Base form submission metadata.
    """

    assigned_to_polymorphic_user: typing_extensions.Annotated[
        typing.Optional[Dvir2AssignedToPolymorphicUserObjectResponseBody],
        FieldMetadata(alias="assignedToPolymorphicUser"),
        pydantic.Field(alias="assignedToPolymorphicUser"),
    ] = None
    due_date: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="dueDate"),
        pydantic.Field(
            alias="dueDate", description="Time of when the form submission is due. UTC timestamp in RFC 3339 format."
        ),
    ] = None
    server_updated_at: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="serverUpdatedAt"),
        pydantic.Field(
            alias="serverUpdatedAt",
            description="Time when the form submission was last updated on the server. UTC timestamp in RFC 3339 format.",
        ),
    ]
    uuid_: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="uuid"),
        pydantic.Field(alias="uuid", description="The unique UUID of the form submission"),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
