# This file was auto-generated by Fern from our API Definition.

import typing

SafetyEventCoachingState = typing.Union[
    typing.Literal[
        "needsReview",
        "coached",
        "dismissed",
        "reviewed",
        "archived",
        "manualReview",
        "needsCoaching",
        "autoDismissed",
        "needsRecognition",
        "recognized",
        "invalid",
    ],
    typing.Any,
]
