# This file was auto-generated by Fern from our API Definition.

import typing

PolicyViolationsDetectionAlertSettingsObjectResponseBodyEventsToCoachItem = typing.Union[
    typing.Literal[
        "noSeatbelt",
        "noMask",
        "mobileUsage",
        "smoking",
        "eatingDrinking",
        "inwardCameraObstruction",
        "outwardCameraObstruction",
    ],
    typing.Any,
]
