# This file was auto-generated by Fern from our API Definition.

import typing

DvirDefectsObjectV20220913ResponseBodyDefectSeverity = typing.Union[
    typing.Literal["minor", "major", "unspecified"], typing.Any
]
