# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .stop_task_skipped_event_details_response_body_task_type import StopTaskSkippedEventDetailsResponseBodyTaskType


class StopTaskSkippedEventDetailsResponseBody(UniversalBaseModel):
    """
    Details for stop task skipped events.
    """

    task_id: typing_extensions.Annotated[
        str, FieldMetadata(alias="taskId"), pydantic.Field(alias="taskId", description="ID of the skipped stop task.")
    ]
    task_type: typing_extensions.Annotated[
        StopTaskSkippedEventDetailsResponseBodyTaskType,
        FieldMetadata(alias="taskType"),
        pydantic.Field(
            alias="taskType", description="Type of the skipped stop task.  Valid values: `form`, `document`"
        ),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
