# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class PrimaryTimeRangeResponseBody(UniversalBaseModel):
    """
    Primary time range of the report that not all datasets and report configs support.
    """

    end_time: typing_extensions.Annotated[
        dt.datetime,
        FieldMetadata(alias="endTime"),
        pydantic.Field(alias="endTime", description="End time of the time range filter in RFC3339 format."),
    ]
    start_time: typing_extensions.Annotated[
        dt.datetime,
        FieldMetadata(alias="startTime"),
        pydantic.Field(alias="startTime", description="Start time of the time range filter in RFC3339 format."),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
