# This file was auto-generated by Fern from our API Definition.

import typing

DocumentResponseObjectResponseBodyState = typing.Union[typing.Literal["submitted", "required", "archived"], typing.Any]
