# This file was auto-generated by Fern from our API Definition.

import typing

GatewayDetailsResponseResponseBodyGatewayBatteryState = typing.Union[
    typing.Literal["critical", "low", "ok", "unknown"], typing.Any
]
