# This file was auto-generated by Fern from our API Definition.

import typing

DriverRulesetObjectResponseBodyShift = typing.Union[
    typing.Literal["US Interstate Property", "US Interstate Passenger"], typing.Any
]
