# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .depreciation_transaction_money_object_response_body_currency import (
    DepreciationTransactionMoneyObjectResponseBodyCurrency,
)


class DepreciationTransactionMoneyObjectResponseBody(UniversalBaseModel):
    """
    The transaction amount. Negative values indicate depreciation/write-downs, positive values indicate appreciation.
    """

    amount: str = pydantic.Field()
    """
    The money amount.
    """

    currency: DepreciationTransactionMoneyObjectResponseBodyCurrency = pydantic.Field()
    """
    The currency of money. This is a 3-letter ISO 4217 currency code.  Valid values: `usd`, `gbp`, `cad`, `eur`, `chf`, `mxn`
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
