# This file was auto-generated by Fern from our API Definition.

import typing

PolicyViolationsDetectionAlertSettingsObjectResponseBodyEventsAvailableForTestingItem = typing.Union[
    typing.Literal["mobileUsage", "smoking", "eatingDrinking", "inwardCameraObstruction", "outwardCameraObstruction"],
    typing.Any,
]
