# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .reading_trigger_continuous_value_object_response_body import ReadingTriggerContinuousValueObjectResponseBody
from .reading_trigger_enum_value_object_response_body import ReadingTriggerEnumValueObjectResponseBody


class ReadingTriggerDetailsObjectResponseBody(UniversalBaseModel):
    """
    Details specific to reading based Trigger, readings can be discovered through the Readings API.
    """

    continuous_threshold: typing_extensions.Annotated[
        typing.Optional[ReadingTriggerContinuousValueObjectResponseBody],
        FieldMetadata(alias="continuousThreshold"),
        pydantic.Field(alias="continuousThreshold"),
    ] = None
    entity_type: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="entityType"),
        pydantic.Field(alias="entityType", description="The type of the entity associated with the reading."),
    ]
    enum_threshold: typing_extensions.Annotated[
        typing.Optional[ReadingTriggerEnumValueObjectResponseBody],
        FieldMetadata(alias="enumThreshold"),
        pydantic.Field(alias="enumThreshold"),
    ] = None
    id: str = pydantic.Field()
    """
    The ID of the reading.
    """

    min_duration_milliseconds: typing_extensions.Annotated[
        int,
        FieldMetadata(alias="minDurationMilliseconds"),
        pydantic.Field(
            alias="minDurationMilliseconds",
            description="The number of milliseconds the trigger needs to stay active before alerting.",
        ),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
