# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class RidershipPassengerSpecialInstructionsInputRequestBody(UniversalBaseModel):
    """
    Special instructions for the passenger.
    """

    is_guardian_required: typing_extensions.Annotated[
        typing.Optional[bool],
        FieldMetadata(alias="isGuardianRequired"),
        pydantic.Field(alias="isGuardianRequired", description="Whether a guardian is required for the passenger."),
    ] = None
    is_special_education: typing_extensions.Annotated[
        typing.Optional[bool],
        FieldMetadata(alias="isSpecialEducation"),
        pydantic.Field(
            alias="isSpecialEducation", description="Whether the passenger requires special education accommodations."
        ),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
