# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class AssetsLocationLinkConfigAddressDetailsObject(UniversalBaseModel):
    """
    Location object that indicates what address information (destination point and/or ETA) will be shown by Live Sharing Link.
    """

    formatted_address: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="formattedAddress"),
        pydantic.Field(alias="formattedAddress", description="Formatted address of a location"),
    ]
    latitude: float = pydantic.Field()
    """
    Latitude of a location
    """

    longitude: float = pydantic.Field()
    """
    Longitude of a location
    """

    name: str = pydantic.Field()
    """
    Name of a location
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
