# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .qualification_owner_request_object_request_body_entity_type import (
    QualificationOwnerRequestObjectRequestBodyEntityType,
)


class QualificationOwnerRequestObjectRequestBody(UniversalBaseModel):
    """
    Owner of the qualification record.
    """

    entity_type: typing_extensions.Annotated[
        QualificationOwnerRequestObjectRequestBodyEntityType,
        FieldMetadata(alias="entityType"),
        pydantic.Field(alias="entityType", description="Owner entity type  Valid values: `worker`, `asset`"),
    ]
    id: str = pydantic.Field()
    """
    ID of the owner (worker/asset)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
