# This file was auto-generated by Fern from our API Definition.

import typing

ServiceTaskInstanceObjectResponseBodyStatus = typing.Union[
    typing.Literal["Unknown", "Open", "In Progress", "On Hold", "Completed"], typing.Any
]
