# This file was auto-generated by Fern from our API Definition.

import typing

WorkerSafetySosDataResponseBodySourceType = typing.Union[
    typing.Literal["appSos", "noResponseCheckIn", "wearableSos", "fallDetected"], typing.Any
]
