# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .notification_recipient_request_body_notification_types_item import (
    NotificationRecipientRequestBodyNotificationTypesItem,
)


class NotificationRecipientRequestBody(UniversalBaseModel):
    """
    A user to notify about recovery state changes.
    """

    notification_types: typing.List[NotificationRecipientRequestBodyNotificationTypesItem] = pydantic.Field()
    """
    How the user should be notified.
    """

    user_id: int = pydantic.Field()
    """
    The ID of the user to notify. Users can be retrieved via the getUser API endpoint.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
