# This file was auto-generated by Fern from our API Definition.

import typing

from .safety_event_behavior_label import SafetyEventBehaviorLabel

SafetyEventBehaviorLabels = typing.List[SafetyEventBehaviorLabel]
