# This file was auto-generated by Fern from our API Definition.

import typing

OperationalSettingsObjectRequestBodyTimeRangeType = typing.Union[
    typing.Literal["activeBetween", "inactiveBetween"], typing.Any
]
