# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class HosEldEventRemarkObjectResponseBody(UniversalBaseModel):
    comment: str = pydantic.Field()
    """
    The content of the remark.
    """

    location_description: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="locationDescription"),
        pydantic.Field(alias="locationDescription", description="The location description entered by the user"),
    ]
    time: str = pydantic.Field()
    """
    The time in RFC 3339 format at which the remark was created.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
