# This file was auto-generated by Fern from our API Definition.

import typing

VehicleHarshAccelerationSettingType = typing.Union[
    typing.Literal["passengerCar", "lightTruck", "heavyDuty", "off", "automatic"], typing.Any
]
