# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .notification_recipient_response_response_body_notification_types_item import (
    NotificationRecipientResponseResponseBodyNotificationTypesItem,
)


class NotificationRecipientResponseResponseBody(UniversalBaseModel):
    """
    A user subscribed to recovery state change notifications, including their name and email.
    """

    email: str = pydantic.Field()
    """
    The email address of the user.
    """

    name: str = pydantic.Field()
    """
    The display name of the user.
    """

    notification_types: typing.List[NotificationRecipientResponseResponseBodyNotificationTypesItem] = pydantic.Field()
    """
    How the user is notified.
    """

    user_id: int = pydantic.Field()
    """
    The ID of the user.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
