# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class ReadingHistoryResponseBody(UniversalBaseModel):
    """
    A history of reading values for an entity.
    """

    entity_id: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="entityId"),
        pydantic.Field(alias="entityId", description="The ID of the entity this readings is for."),
    ]
    external_ids: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, str]],
        FieldMetadata(alias="externalIds"),
        pydantic.Field(alias="externalIds", description="A map of external ids"),
    ] = None
    happened_at_time: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="happenedAtTime"),
        pydantic.Field(
            alias="happenedAtTime", description="The time in RFC 3339 format when the reading was measured."
        ),
    ] = None
    value: typing.Optional[typing.Dict[str, typing.Any]] = pydantic.Field(default=None)
    """
    The value of the reading.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
