# This file was auto-generated by Fern from our API Definition.

import typing

VehicleResponseObjectResponseBodyVehicleRegulationMode = typing.Union[
    typing.Literal["regulated", "unregulated"], typing.Any
]
