# This file was auto-generated by Fern from our API Definition.

import typing

FormTemplateResponseObjectResponseBodyFormCategory = typing.Union[
    typing.Literal["general", "routing", "fuel"], typing.Any
]
