# This file was auto-generated by Fern from our API Definition.

import typing

FunctionCodePackageResponseBodyStatus = typing.Union[
    typing.Literal["unknown", "pendingUpload", "uploaded", "deployed"], typing.Any
]
