# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .sensor import Sensor
from .vehicle_sensor_configuration_door_position import VehicleSensorConfigurationDoorPosition


class VehicleSensorConfigurationDoor(UniversalBaseModel):
    """
    A door monitor configuration for a vehicle
    """

    position: typing.Optional[VehicleSensorConfigurationDoorPosition] = pydantic.Field(default=None)
    """
    Position of the door monitor on the vehicle
    """

    sensor: typing.Optional[Sensor] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
