# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .fuel_energy_vehicle_report_object_response_body import FuelEnergyVehicleReportObjectResponseBody


class FuelEnergyVehicleReportDataObjectResponseBody(UniversalBaseModel):
    """
    Dictionary containing summarized vehicle report data.
    """

    vehicle_reports: typing_extensions.Annotated[
        typing.List[FuelEnergyVehicleReportObjectResponseBody],
        FieldMetadata(alias="vehicleReports"),
        pydantic.Field(alias="vehicleReports", description="List of summarized vehicle reports."),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
