# This file was auto-generated by Fern from our API Definition.

import typing

from .carrier_proposed_assignment_trailer import CarrierProposedAssignmentTrailer

CarrierProposedAssignmentTrailers = typing.List[CarrierProposedAssignmentTrailer]
