# This file was auto-generated by Fern from our API Definition.

import typing

AmbientTemperatureDetailsObjectRequestBodyOperation = typing.Union[
    typing.Literal["GREATER", "INSIDE_RANGE", "LESS", "OUTSIDE_RANGE"], typing.Any
]
