# This file was auto-generated by Fern from our API Definition.

import typing

RouteSettingsRequestBodyRouteStartingCondition = typing.Union[
    typing.Literal["departFirstStop", "arriveFirstStop"], typing.Any
]
