# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .forms_table_column_object_response_body_type import FormsTableColumnObjectResponseBodyType


class FormsTableColumnObjectResponseBody(UniversalBaseModel):
    """
    Defines a column in a table form input field.
    """

    id: str = pydantic.Field()
    """
    Unique identifier for the column.
    """

    label: str = pydantic.Field()
    """
    Label of the column.
    """

    type: FormsTableColumnObjectResponseBodyType = pydantic.Field()
    """
    Type of the column field.  Valid values: `text`, `number`, `datetime`, `check_boxes`, `multiple_choice`, `signature`, `media`, `person`
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
