# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .vehicle_stats_fault_codes_j_1939_lights import VehicleStatsFaultCodesJ1939Lights
from .vehicle_stats_fault_codes_j_1939_trouble_codes import VehicleStatsFaultCodesJ1939TroubleCodes


class VehicleStatsFaultCodesJ1939(UniversalBaseModel):
    """
    Vehicle fault codes for J1939 vehicles.
    """

    check_engine_lights: typing_extensions.Annotated[
        typing.Optional[VehicleStatsFaultCodesJ1939Lights],
        FieldMetadata(alias="checkEngineLights"),
        pydantic.Field(alias="checkEngineLights"),
    ] = None
    diagnostic_trouble_codes: typing_extensions.Annotated[
        typing.Optional[VehicleStatsFaultCodesJ1939TroubleCodes],
        FieldMetadata(alias="diagnosticTroubleCodes"),
        pydantic.Field(alias="diagnosticTroubleCodes"),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
