# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class FormSubmissionRequestMediaItemObjectRequestBody(UniversalBaseModel):
    """
    A media item in a form submission request.
    """

    base_64_payload: typing_extensions.Annotated[
        str,
        FieldMetadata(alias="base64Payload"),
        pydantic.Field(alias="base64Payload", description="Base64-encoded binary content of the media."),
    ]
    media_type: typing_extensions.Annotated[
        str, FieldMetadata(alias="mediaType"), pydantic.Field(alias="mediaType", description="MIME type of the media.")
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
