# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class ListHubPlansResponsePaginationResponseBody(UniversalBaseModel):
    """
    Pagination information
    """

    end_cursor: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="endCursor"),
        pydantic.Field(alias="endCursor", description="Cursor for the last item in the page"),
    ] = None
    has_next_page: typing_extensions.Annotated[
        bool,
        FieldMetadata(alias="hasNextPage"),
        pydantic.Field(alias="hasNextPage", description="Whether there are more pages available"),
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
