# This file was auto-generated by Fern from our API Definition.

import typing

WebhooksPostWebhooksResponseBodyEventTypesItem = typing.Union[
    typing.Literal[
        "AddressCreated",
        "AddressDeleted",
        "AddressUpdated",
        "AlertIncident",
        "AlertObjectEvent",
        "DocumentSubmitted",
        "DriverCreated",
        "DriverUpdated",
        "DvirSubmitted",
        "EngineFaultOff",
        "EngineFaultOn",
        "FormSubmitted",
        "FormUpdated",
        "GatewayUnplugged",
        "GeofenceEntry",
        "GeofenceExit",
        "IssueCreated",
        "MissingDvirPastDue",
        "PredictiveMaintenanceAlert",
        "RouteStopArrival",
        "RouteStopDeparture",
        "RouteStopEarlyLateArrival",
        "RouteStopEtaUpdated",
        "RouteStopResequence",
        "SevereSpeedingEnded",
        "SevereSpeedingStarted",
        "SpeedingEventEnded",
        "SpeedingEventStarted",
        "SuddenFuelLevelDrop",
        "SuddenFuelLevelRise",
        "VehicleCreated",
        "VehicleUpdated",
    ],
    typing.Any,
]
