# This file was auto-generated by Fern from our API Definition.

import typing

from .v_1_programs_for_the_camera_response_item import V1ProgramsForTheCameraResponseItem

V1ProgramsForTheCameraResponse = typing.List[V1ProgramsForTheCameraResponseItem]
