# This file was auto-generated by Fern from our API Definition.

import typing

HosEldEventObjectResponseBodyMalfunctionDiagnosticCode = typing.Union[
    typing.Literal["P", "E", "T", "L", "R", "S", "O", "1", "2", "3", "4", "5", "6"], typing.Any
]
