# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class HosShift(UniversalBaseModel):
    """
    Remaining durations and start time for the HOS on duty shift limits.
    """

    shift_remaining_duration_ms: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="shiftRemainingDurationMs"),
        pydantic.Field(
            alias="shiftRemainingDurationMs",
            description="Remaining on duty or driving time the driver in the current shift in milliseconds. For property-carrying drivers, this is the amount of time the driver can be on duty or driving before hitting the 14-hour limit.",
        ),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
