# This file was auto-generated by Fern from our API Definition.

import typing

ListUploadedMediaRequestTriggerReasonsItem = typing.Union[
    typing.Literal[
        "api",
        "panicButton",
        "periodicStill",
        "rfidEvent",
        "safetyEvent",
        "tripEndStill",
        "tripStartStill",
        "videoRetrieval",
    ],
    typing.Any,
]
