# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class GoaTagTinyResponseResponseBody(UniversalBaseModel):
    """
    A minified tag object
    """

    id: str = pydantic.Field()
    """
    ID of the tag
    """

    name: str = pydantic.Field()
    """
    Name of the tag.
    """

    parent_tag_id: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="parentTagId"),
        pydantic.Field(
            alias="parentTagId",
            description="If this tag is part a hierarchical tag tree, this is the ID of the parent tag, otherwise this will be omitted.",
        ),
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
