# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .recovery_photo_response_body_status import RecoveryPhotoResponseBodyStatus


class RecoveryPhotoResponseBody(UniversalBaseModel):
    """
    A photo associated with an asset recovery event.
    """

    start_ms: int = pydantic.Field()
    """
    Timestamp of when the photo was captured, in milliseconds since epoch.
    """

    status: RecoveryPhotoResponseBodyStatus = pydantic.Field()
    """
    The availability status of the photo.  Valid values: `EXISTS`, `NOT_FOUND`, `SERVER_ERROR`
    """

    url: str = pydantic.Field()
    """
    A temporary presigned URL for the recovery photo. This URL expires at the time indicated by url_expires_at_ms.
    """

    url_expires_at_ms: int = pydantic.Field()
    """
    Timestamp when the presigned URL expires, in milliseconds since epoch.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
