# This file was auto-generated by Fern from our API Definition.

import typing

VehicleSensorConfigurationAreaPosition = typing.Union[
    typing.Literal["Position_Front", "Position_Middle", "Position_Back"], typing.Any
]
