# This file was auto-generated by Fern from our API Definition.

import typing

GetSafetyEventsV2StreamRequestQueryByTimeField = typing.Union[
    typing.Literal["updatedAtTime", "createdAtTime"], typing.Any
]
