# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .j_1939_d_1_status_data_point_value import J1939D1StatusDataPointValue
from .time import Time


class J1939D1StatusDataPoint(UniversalBaseModel):
    """
    Active J1939D1 statuses of a device.
    """

    time: typing.Optional[Time] = None
    value: typing.Optional[typing.List[J1939D1StatusDataPointValue]] = pydantic.Field(default=None)
    """
    List of active statuses.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
