# This file was auto-generated by Fern from our API Definition.

import typing

CoachingSessionsResponseResponseBodySessionStatus = typing.Union[
    typing.Literal["unknown", "upcoming", "completed", "deleted"], typing.Any
]
