# This file was auto-generated by Fern from our API Definition.

import typing

V1SensorsHistorySeriesField = typing.Union[
    typing.Literal[
        "ambientTemperature",
        "cargoPercent",
        "currentLoop1Raw",
        "currentLoop1Mapped",
        "currentLoop2Raw",
        "currentLoop2Mapped",
        "doorClosed",
        "humidity",
        "pmPowerTotal",
        "pmPhase1Power",
        "pmPhase2Power",
        "pmPhase3Power",
        "pmPhase1PowerFactor",
        "pmPhase2PowerFactor",
        "pmPhase3PowerFactor",
        "probeTemperature",
    ],
    typing.Any,
]
