# This file was auto-generated by Fern from our API Definition.

import typing

SafetyBehaviorTriggerDetailsObjectResponseBodySeveritiesItem = typing.Union[
    typing.Literal["low", "medium", "high"], typing.Any
]
