# This file was auto-generated by Fern from our API Definition.

import typing

RouteSettingsResponseBodyRouteCompletionCondition = typing.Union[
    typing.Literal["arriveLastStop", "departLastStop"], typing.Any
]
