# This file was auto-generated by Fern from our API Definition.

import typing

CoachingSessionsResponseResponseBodyCoachingType = typing.Union[
    typing.Literal["fullySharedWithManager", "selfCoaching", "unknown", "unshared", "withManager"], typing.Any
]
