# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .location_data_point_gps_location_place import LocationDataPointGpsLocationPlace


class LocationDataPointGpsLocation(UniversalBaseModel):
    """
    GPS location information of the data input's datapoint.
    """

    formatted_address: typing_extensions.Annotated[
        typing.Optional[str],
        FieldMetadata(alias="formattedAddress"),
        pydantic.Field(alias="formattedAddress", description="Formatted address of the location"),
    ] = None
    gps_meters_per_second: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="gpsMetersPerSecond"),
        pydantic.Field(alias="gpsMetersPerSecond", description="Speed of GPS (meters per second)"),
    ] = None
    heading_degrees: typing_extensions.Annotated[
        typing.Optional[float],
        FieldMetadata(alias="headingDegrees"),
        pydantic.Field(alias="headingDegrees", description="Heading degrees"),
    ] = None
    latitude: typing.Optional[float] = pydantic.Field(default=None)
    """
    Latitude of the location
    """

    longitude: typing.Optional[float] = pydantic.Field(default=None)
    """
    Longitude of the location
    """

    place: typing.Optional[LocationDataPointGpsLocationPlace] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
