# This file was auto-generated by Fern from our API Definition.

import typing

BehaviorResponseBodyCoachableBehaviorType = typing.Union[
    typing.Literal[
        "acceleration",
        "braking",
        "cameraObstruction",
        "crash",
        "defensiveDriving",
        "didNotYield",
        "drinkPolicy",
        "drowsy",
        "eatingDrinking",
        "event",
        "falsePositive",
        "foodPolicy",
        "forwardCollisionWarning",
        "genericDistraction",
        "harshTurn",
        "hosViolation",
        "idling",
        "laneDeparture",
        "lateResponse",
        "maskPolicy",
        "maxSpeed",
        "mobileUsage",
        "nearCollison",
        "noSeatbelt",
        "obstructedCamera",
        "outwardObstruction",
        "passengerPolicy",
        "ranRedLight",
        "rollingRailroadCrossing",
        "rollingStop",
        "rollover",
        "rolloverProtection",
        "rolloverProtectionBrakeControlActivated",
        "rolloverProtectionEngineControlActivated",
        "severeSpeeding",
        "smoking",
        "speeding",
        "tailgating",
        "unknown",
        "yawControl",
        "yawControlBrakeControlActivated",
        "yawControlEngineControlActivated",
    ],
    typing.Any,
]
