# This file was auto-generated by Fern from our API Definition.

import typing

RidershipPassengersCreateRidershipPassengerRequestBodyClassification = typing.Union[
    typing.Literal[
        "unknown",
        "pk1",
        "pk2",
        "pk3",
        "pk4",
        "k",
        "grade1",
        "grade2",
        "grade3",
        "grade4",
        "grade5",
        "grade6",
        "grade7",
        "grade8",
        "grade9",
        "grade10",
        "grade11",
        "grade12",
    ],
    typing.Any,
]
