# This file was auto-generated by Fern from our API Definition.

import typing

TireFaultCodeDetailsObjectResponseBodySpecificTireFaultCodesItem = typing.Union[
    typing.Literal[
        "TIRE_ALERT_ACROSS_AXLE_FAULT",
        "TIRE_ALERT_EXTREME_OVER_PRESSURE",
        "TIRE_ALERT_EXTREME_UNDER_PRESSURE",
        "TIRE_ALERT_FLAT_SPOT",
        "TIRE_ALERT_IMBALANCE",
        "TIRE_ALERT_INVALID",
        "TIRE_ALERT_LEAK_DETECTED",
        "TIRE_ALERT_OVER_PRESSURE",
        "TIRE_ALERT_OVER_TEMPERATURE",
        "TIRE_ALERT_SENSOR_DEFECT",
        "TIRE_ALERT_SENSOR_LOOSE_OR_FLIPPED",
        "TIRE_ALERT_SENSOR_LOW_BATTERY",
        "TIRE_ALERT_SENSOR_MISSING",
        "TIRE_ALERT_UNDER_PRESSURE",
    ],
    typing.Any,
]
