# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .get_vehicle_stats_feed_request_decorations_item import GetVehicleStatsFeedRequestDecorationsItem
    from .get_vehicle_stats_feed_request_types_item import GetVehicleStatsFeedRequestTypesItem
    from .get_vehicle_stats_history_request_decorations_item import GetVehicleStatsHistoryRequestDecorationsItem
    from .get_vehicle_stats_history_request_types_item import GetVehicleStatsHistoryRequestTypesItem
    from .get_vehicle_stats_request_types_item import GetVehicleStatsRequestTypesItem
_dynamic_imports: typing.Dict[str, str] = {
    "GetVehicleStatsFeedRequestDecorationsItem": ".get_vehicle_stats_feed_request_decorations_item",
    "GetVehicleStatsFeedRequestTypesItem": ".get_vehicle_stats_feed_request_types_item",
    "GetVehicleStatsHistoryRequestDecorationsItem": ".get_vehicle_stats_history_request_decorations_item",
    "GetVehicleStatsHistoryRequestTypesItem": ".get_vehicle_stats_history_request_types_item",
    "GetVehicleStatsRequestTypesItem": ".get_vehicle_stats_request_types_item",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "GetVehicleStatsFeedRequestDecorationsItem",
    "GetVehicleStatsFeedRequestTypesItem",
    "GetVehicleStatsHistoryRequestDecorationsItem",
    "GetVehicleStatsHistoryRequestTypesItem",
    "GetVehicleStatsRequestTypesItem",
]
