# This file was auto-generated by Fern from our API Definition.

import typing

ListUploadedMediaRequestInputsItem = typing.Union[
    typing.Literal["dashcamRoadFacing", "dashcamDriverFacing", "analog1", "analog2", "analog3", "analog4"], typing.Any
]
