# This file was auto-generated by Fern from our API Definition.

import typing

DocumentPdfQueryResponseDataJobStatus = typing.Union[typing.Literal["requested", "processing", "completed"], typing.Any]
