# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        AccessoryResponseObjectResponseBody,
        ActionObjectRequestBody,
        ActionObjectResponseBody,
        ActionParamsObjectRequestBody,
        ActionParamsObjectResponseBody,
        Address,
        AddressAddressTypesItem,
        AddressExternalIds,
        AddressGeofence,
        AddressGeofenceCircle,
        AddressGeofencePolygon,
        AddressGeofencePolygonVertices,
        AddressGeofenceSettings,
        AddressResponse,
        AddressResponseResponseBody,
        AddressTinyResponse,
        AdvancedIdlingGetIdlingEventsBadGatewayErrorResponseBody,
        AdvancedIdlingGetIdlingEventsGatewayTimeoutErrorResponseBody,
        AdvancedIdlingGetIdlingEventsInternalServerErrorResponseBody,
        AdvancedIdlingGetIdlingEventsMethodNotAllowedErrorResponseBody,
        AdvancedIdlingGetIdlingEventsNotFoundErrorResponseBody,
        AdvancedIdlingGetIdlingEventsNotImplementedErrorResponseBody,
        AdvancedIdlingGetIdlingEventsResponseBody,
        AdvancedIdlingGetIdlingEventsServiceUnavailableErrorResponseBody,
        AdvancedIdlingGetIdlingEventsTooManyRequestsErrorResponseBody,
        AdvancedIdlingGetIdlingEventsUnauthorizedErrorResponseBody,
        AempEquipmentGetAempEquipmentListBadGatewayErrorResponseBody,
        AempEquipmentGetAempEquipmentListGatewayTimeoutErrorResponseBody,
        AempEquipmentGetAempEquipmentListInternalServerErrorResponseBody,
        AempEquipmentGetAempEquipmentListMethodNotAllowedErrorResponseBody,
        AempEquipmentGetAempEquipmentListNotFoundErrorResponseBody,
        AempEquipmentGetAempEquipmentListNotImplementedErrorResponseBody,
        AempEquipmentGetAempEquipmentListResponseBody,
        AempEquipmentGetAempEquipmentListServiceUnavailableErrorResponseBody,
        AempEquipmentGetAempEquipmentListTooManyRequestsErrorResponseBody,
        AempEquipmentGetAempEquipmentListUnauthorizedErrorResponseBody,
        AempEquipmentWithAdditionalFieldsResponseBody,
        AempFleetListResponseBody,
        AempLinkResponseBody,
        AlertObjectAssetResponseBody,
        AlertObjectAssetResponseBodyType,
        AlertObjectDriverResponseBody,
        AlertObjectMachineInputResponseBody,
        AlertObjectOnvifCameraStreamResponseBody,
        AlertObjectProductResponseBody,
        AlertObjectSensorResponseBody,
        AlertObjectSitesResponseBody,
        AlertObjectTrailerResponseBody,
        AlertObjectVehicleResponseBody,
        AlertObjectWorkforceCameraDeviceResponseBody,
        AlertsDeleteConfigurationsBadGatewayErrorResponseBody,
        AlertsDeleteConfigurationsGatewayTimeoutErrorResponseBody,
        AlertsDeleteConfigurationsInternalServerErrorResponseBody,
        AlertsDeleteConfigurationsMethodNotAllowedErrorResponseBody,
        AlertsDeleteConfigurationsNotFoundErrorResponseBody,
        AlertsDeleteConfigurationsNotImplementedErrorResponseBody,
        AlertsDeleteConfigurationsServiceUnavailableErrorResponseBody,
        AlertsDeleteConfigurationsTooManyRequestsErrorResponseBody,
        AlertsDeleteConfigurationsUnauthorizedErrorResponseBody,
        AlertsGetConfigurationsBadGatewayErrorResponseBody,
        AlertsGetConfigurationsGatewayTimeoutErrorResponseBody,
        AlertsGetConfigurationsInternalServerErrorResponseBody,
        AlertsGetConfigurationsMethodNotAllowedErrorResponseBody,
        AlertsGetConfigurationsNotFoundErrorResponseBody,
        AlertsGetConfigurationsNotImplementedErrorResponseBody,
        AlertsGetConfigurationsResponseBody,
        AlertsGetConfigurationsServiceUnavailableErrorResponseBody,
        AlertsGetConfigurationsTooManyRequestsErrorResponseBody,
        AlertsGetConfigurationsUnauthorizedErrorResponseBody,
        AlertsGetIncidentsBadGatewayErrorResponseBody,
        AlertsGetIncidentsGatewayTimeoutErrorResponseBody,
        AlertsGetIncidentsInternalServerErrorResponseBody,
        AlertsGetIncidentsMethodNotAllowedErrorResponseBody,
        AlertsGetIncidentsNotFoundErrorResponseBody,
        AlertsGetIncidentsNotImplementedErrorResponseBody,
        AlertsGetIncidentsResponseBody,
        AlertsGetIncidentsServiceUnavailableErrorResponseBody,
        AlertsGetIncidentsTooManyRequestsErrorResponseBody,
        AlertsGetIncidentsUnauthorizedErrorResponseBody,
        AlertsPatchConfigurationsBadGatewayErrorResponseBody,
        AlertsPatchConfigurationsGatewayTimeoutErrorResponseBody,
        AlertsPatchConfigurationsInternalServerErrorResponseBody,
        AlertsPatchConfigurationsMethodNotAllowedErrorResponseBody,
        AlertsPatchConfigurationsNotFoundErrorResponseBody,
        AlertsPatchConfigurationsNotImplementedErrorResponseBody,
        AlertsPatchConfigurationsResponseBody,
        AlertsPatchConfigurationsServiceUnavailableErrorResponseBody,
        AlertsPatchConfigurationsTooManyRequestsErrorResponseBody,
        AlertsPatchConfigurationsUnauthorizedErrorResponseBody,
        AlertsPostConfigurationsBadGatewayErrorResponseBody,
        AlertsPostConfigurationsGatewayTimeoutErrorResponseBody,
        AlertsPostConfigurationsInternalServerErrorResponseBody,
        AlertsPostConfigurationsMethodNotAllowedErrorResponseBody,
        AlertsPostConfigurationsNotFoundErrorResponseBody,
        AlertsPostConfigurationsNotImplementedErrorResponseBody,
        AlertsPostConfigurationsResponseBody,
        AlertsPostConfigurationsServiceUnavailableErrorResponseBody,
        AlertsPostConfigurationsTooManyRequestsErrorResponseBody,
        AlertsPostConfigurationsUnauthorizedErrorResponseBody,
        AmbientTemperatureDetailsObjectRequestBody,
        AmbientTemperatureDetailsObjectRequestBodyOperation,
        AmbientTemperatureDetailsObjectResponseBody,
        AmbientTemperatureDetailsObjectResponseBodyOperation,
        AmbientTemperatureResponseBody,
        AnticipationBrakeEventCount,
        AppointmentWindowRequestBody,
        AppointmentWindowResponseBody,
        AssetDataInput,
        AssetDataInputLastPoint,
        AssetDataOutput,
        AssetDataOutputsPatchAssetDataOutputsBadGatewayErrorResponseBody,
        AssetDataOutputsPatchAssetDataOutputsGatewayTimeoutErrorResponseBody,
        AssetDataOutputsPatchAssetDataOutputsInternalServerErrorResponseBody,
        AssetDataOutputsPatchAssetDataOutputsMethodNotAllowedErrorResponseBody,
        AssetDataOutputsPatchAssetDataOutputsNotFoundErrorResponseBody,
        AssetDataOutputsPatchAssetDataOutputsNotImplementedErrorResponseBody,
        AssetDataOutputsPatchAssetDataOutputsResponseBody,
        AssetDataOutputsPatchAssetDataOutputsServiceUnavailableErrorResponseBody,
        AssetDataOutputsPatchAssetDataOutputsTooManyRequestsErrorResponseBody,
        AssetDataOutputsPatchAssetDataOutputsUnauthorizedErrorResponseBody,
        AssetLocation,
        AssetLocationHeading,
        AssetLocationSpeed,
        AssetName,
        AssetResponse,
        AssetResponseBody,
        AssetResponseBodyRegulationMode,
        AssetResponseBodyType,
        AssetResponseLocationDataInput,
        AssetResponseParentAsset,
        AssetResponseResponseBody,
        AssetResponseRunningStatusDataInput,
        AssetsCreateAssetBadGatewayErrorResponseBody,
        AssetsCreateAssetGatewayTimeoutErrorResponseBody,
        AssetsCreateAssetInternalServerErrorResponseBody,
        AssetsCreateAssetMethodNotAllowedErrorResponseBody,
        AssetsCreateAssetNotFoundErrorResponseBody,
        AssetsCreateAssetNotImplementedErrorResponseBody,
        AssetsCreateAssetResponseBody,
        AssetsCreateAssetServiceUnavailableErrorResponseBody,
        AssetsCreateAssetTooManyRequestsErrorResponseBody,
        AssetsCreateAssetUnauthorizedErrorResponseBody,
        AssetsDeleteAssetBadGatewayErrorResponseBody,
        AssetsDeleteAssetGatewayTimeoutErrorResponseBody,
        AssetsDeleteAssetInternalServerErrorResponseBody,
        AssetsDeleteAssetMethodNotAllowedErrorResponseBody,
        AssetsDeleteAssetNotFoundErrorResponseBody,
        AssetsDeleteAssetNotImplementedErrorResponseBody,
        AssetsDeleteAssetServiceUnavailableErrorResponseBody,
        AssetsDeleteAssetTooManyRequestsErrorResponseBody,
        AssetsDeleteAssetUnauthorizedErrorResponseBody,
        AssetsInputsAssetResponseResponseBody,
        AssetsInputsAuxInputResponseBody,
        AssetsInputsGetAssetsInputsBadGatewayErrorResponseBody,
        AssetsInputsGetAssetsInputsGatewayTimeoutErrorResponseBody,
        AssetsInputsGetAssetsInputsInternalServerErrorResponseBody,
        AssetsInputsGetAssetsInputsMethodNotAllowedErrorResponseBody,
        AssetsInputsGetAssetsInputsNotFoundErrorResponseBody,
        AssetsInputsGetAssetsInputsNotImplementedErrorResponseBody,
        AssetsInputsGetAssetsInputsResponseBody,
        AssetsInputsGetAssetsInputsServiceUnavailableErrorResponseBody,
        AssetsInputsGetAssetsInputsTooManyRequestsErrorResponseBody,
        AssetsInputsGetAssetsInputsUnauthorizedErrorResponseBody,
        AssetsInputsResponseResponseBody,
        AssetsInputsResponseResponseBodyUnits,
        AssetsListAssetsBadGatewayErrorResponseBody,
        AssetsListAssetsGatewayTimeoutErrorResponseBody,
        AssetsListAssetsInternalServerErrorResponseBody,
        AssetsListAssetsMethodNotAllowedErrorResponseBody,
        AssetsListAssetsNotFoundErrorResponseBody,
        AssetsListAssetsNotImplementedErrorResponseBody,
        AssetsListAssetsResponseBody,
        AssetsListAssetsServiceUnavailableErrorResponseBody,
        AssetsListAssetsTooManyRequestsErrorResponseBody,
        AssetsListAssetsUnauthorizedErrorResponseBody,
        AssetsLocationLinkConfigAddressDetailsObject,
        AssetsLocationLinkConfigAddressDetailsObjectResponseBody,
        AssetsLocationLinkRequestConfigObject,
        AssetsLocationLinkResponseConfigObjectResponseBody,
        AssetsNearLocationLinkConfigObject,
        AssetsNearLocationLinkConfigObjectResponseBody,
        AssetsOnRouteLinkConfigObject,
        AssetsOnRouteLinkConfigObjectResponseBody,
        AssetsUpdateAssetBadGatewayErrorResponseBody,
        AssetsUpdateAssetGatewayTimeoutErrorResponseBody,
        AssetsUpdateAssetInternalServerErrorResponseBody,
        AssetsUpdateAssetMethodNotAllowedErrorResponseBody,
        AssetsUpdateAssetNotFoundErrorResponseBody,
        AssetsUpdateAssetNotImplementedErrorResponseBody,
        AssetsUpdateAssetResponseBody,
        AssetsUpdateAssetServiceUnavailableErrorResponseBody,
        AssetsUpdateAssetTooManyRequestsErrorResponseBody,
        AssetsUpdateAssetUnauthorizedErrorResponseBody,
        AssociationResponseBody,
        AssociationsListAssociationsBadGatewayErrorResponseBody,
        AssociationsListAssociationsGatewayTimeoutErrorResponseBody,
        AssociationsListAssociationsInternalServerErrorResponseBody,
        AssociationsListAssociationsMethodNotAllowedErrorResponseBody,
        AssociationsListAssociationsNotFoundErrorResponseBody,
        AssociationsListAssociationsNotImplementedErrorResponseBody,
        AssociationsListAssociationsResponseBody,
        AssociationsListAssociationsServiceUnavailableErrorResponseBody,
        AssociationsListAssociationsTooManyRequestsErrorResponseBody,
        AssociationsListAssociationsUnauthorizedErrorResponseBody,
        Attribute,
        AttributeAttributeType,
        AttributeEntity,
        AttributeEntityExternalIds,
        AttributeEntityType,
        AttributeExpanded,
        AttributeExpandedAllOf,
        AttributeExpandedResponse,
        AttributeTiny,
        AttributeUnit,
        AttributeValueTiny,
        AuthTokenAuthTokenBadGatewayErrorResponseBody,
        AuthTokenAuthTokenGatewayTimeoutErrorResponseBody,
        AuthTokenAuthTokenInternalServerErrorResponseBody,
        AuthTokenAuthTokenMethodNotAllowedErrorResponseBody,
        AuthTokenAuthTokenNotFoundErrorResponseBody,
        AuthTokenAuthTokenNotImplementedErrorResponseBody,
        AuthTokenAuthTokenResponseBody,
        AuthTokenAuthTokenServiceUnavailableErrorResponseBody,
        AuthTokenAuthTokenTooManyRequestsErrorResponseBody,
        AuthTokenAuthTokenUnauthorizedErrorResponseBody,
        AuthTokenForDriverResponseResponseBody,
        AuthorSignatureObjectResponseBody,
        AuthorSignatureObjectResponseBodyType,
        BarcodeValueObjectRequestBody,
        BarcodeValueObjectResponseBody,
        BaseRouteResponseObjectResponseBody,
        BehaviorCountDetailsRequestBody,
        BehaviorCountDetailsRequestBodyComparison,
        BehaviorCountDetailsResponseBody,
        BehaviorCountDetailsResponseBodyComparison,
        BehaviorResponseBody,
        BehaviorResponseBodyCoachableBehaviorType,
        CameraConnectorDisconectedResponseBody,
        CameraDetailsResponseResponseBody,
        CameraSerial,
        CameraStreamIssueResponseBody,
        CarbCtcListCarbCtcVehicleHistoryBadGatewayErrorResponseBody,
        CarbCtcListCarbCtcVehicleHistoryGatewayTimeoutErrorResponseBody,
        CarbCtcListCarbCtcVehicleHistoryInternalServerErrorResponseBody,
        CarbCtcListCarbCtcVehicleHistoryMethodNotAllowedErrorResponseBody,
        CarbCtcListCarbCtcVehicleHistoryNotFoundErrorResponseBody,
        CarbCtcListCarbCtcVehicleHistoryNotImplementedErrorResponseBody,
        CarbCtcListCarbCtcVehicleHistoryResponseBody,
        CarbCtcListCarbCtcVehicleHistoryServiceUnavailableErrorResponseBody,
        CarbCtcListCarbCtcVehicleHistoryTooManyRequestsErrorResponseBody,
        CarbCtcListCarbCtcVehicleHistoryUnauthorizedErrorResponseBody,
        CarbCtcListCarbCtcVehiclesBadGatewayErrorResponseBody,
        CarbCtcListCarbCtcVehiclesGatewayTimeoutErrorResponseBody,
        CarbCtcListCarbCtcVehiclesInternalServerErrorResponseBody,
        CarbCtcListCarbCtcVehiclesMethodNotAllowedErrorResponseBody,
        CarbCtcListCarbCtcVehiclesNotFoundErrorResponseBody,
        CarbCtcListCarbCtcVehiclesNotImplementedErrorResponseBody,
        CarbCtcListCarbCtcVehiclesResponseBody,
        CarbCtcListCarbCtcVehiclesServiceUnavailableErrorResponseBody,
        CarbCtcListCarbCtcVehiclesTooManyRequestsErrorResponseBody,
        CarbCtcListCarbCtcVehiclesUnauthorizedErrorResponseBody,
        CarbCtcVehicleHistoryObjectResponseBody,
        CarbCtcVehicleHistoryObjectResponseBodyTestResult,
        CarbCtcVehicleObjectResponseBody,
        CarbCtcVehicleObjectResponseBodyTestStatus,
        CarrierProposedAssignment,
        CarrierProposedAssignmentAcceptedTime,
        CarrierProposedAssignmentActiveTime,
        CarrierProposedAssignmentDriver,
        CarrierProposedAssignmentDriverAllOf,
        CarrierProposedAssignmentDriverAllOf2ExternalIds,
        CarrierProposedAssignmentFirstSeenTime,
        CarrierProposedAssignmentId,
        CarrierProposedAssignmentRejectedTime,
        CarrierProposedAssignmentResponse,
        CarrierProposedAssignmentShippingDocs,
        CarrierProposedAssignmentTrailer,
        CarrierProposedAssignmentTrailers,
        CarrierProposedAssignmentVehicle,
        CellConnectivityResponseResponseBody,
        CellConnectivityResponseResponseBodySignalBar,
        CellSignalLossDetailsObjectRequestBody,
        CellSignalLossDetailsObjectResponseBody,
        CellSignalLossResponseBody,
        CircleRequestBody,
        CircleResponseBody,
        CloudBackupUploadIssueResponseBody,
        CoachAssignmentWithDriverExternalIdsResponseResponseBody,
        CoachAssignmentWithoutDriverExternalIdsResponseResponseBody,
        CoachableEventResponseBody,
        CoachingSessionsGetCoachingSessionsBadGatewayErrorResponseBody,
        CoachingSessionsGetCoachingSessionsGatewayTimeoutErrorResponseBody,
        CoachingSessionsGetCoachingSessionsInternalServerErrorResponseBody,
        CoachingSessionsGetCoachingSessionsMethodNotAllowedErrorResponseBody,
        CoachingSessionsGetCoachingSessionsNotFoundErrorResponseBody,
        CoachingSessionsGetCoachingSessionsNotImplementedErrorResponseBody,
        CoachingSessionsGetCoachingSessionsResponseBody,
        CoachingSessionsGetCoachingSessionsServiceUnavailableErrorResponseBody,
        CoachingSessionsGetCoachingSessionsTooManyRequestsErrorResponseBody,
        CoachingSessionsGetCoachingSessionsUnauthorizedErrorResponseBody,
        CoachingSessionsResponseResponseBody,
        CoachingSessionsResponseResponseBodyCoachingType,
        CoachingSessionsResponseResponseBodySessionStatus,
        CoastingDurationMs,
        ColumnResponseBody,
        ColumnResponseBodyDataType,
        ColumnResponseBodyUnit,
        ConditionalFieldSectionObjectResponseBody,
        ConnectionStatusResponseObjectResponseBody,
        ConnectionStatusResponseObjectResponseBodyHealthStatus,
        Contact,
        ContactEmail,
        ContactFirstName,
        ContactId,
        ContactLastName,
        ContactPhone,
        ContactResponse,
        ContactTinyResponse,
        ContinuousReadingAlertThresholdResponseBody,
        ContinuousReadingAlertThresholdResponseBodyOperation,
        ContinuousReadingAlertThresholdResponseBodyUnit,
        CreateAddressRequestGeofence,
        CreateAddressRequestGeofenceSettings,
        CreateAttributeRequestEntities,
        CreateDriverAuthTokenResponseResponseBody,
        CreateDriverRequestAttributes,
        CreateFunctionDetailResponseBody,
        CreateFunctionRequestConfigRequestBody,
        CreateFunctionRequestConfigRequestBodyParams,
        CreateFunctionRequestConfigRequestBodySecrets,
        CreateReportConfigColumnRequestBody,
        CreateReportConfigObjectRequestBody,
        CreateRoutesStopRequestObjectRequestBody,
        CreateUserRequestRoles,
        CruiseControlDurationMs,
        CumulativeOperatingHoursResponseBody,
        CurrentDutyStatus,
        CurrentDutyStatusHosStatusType,
        CustomHeadersObjectRequestBody,
        CustomHeadersObjectResponseBody,
        CustomMetadata,
        DashcamDisconnectedResponseBody,
        DataInputListResponse,
        DataInputResponse,
        DataInputResponseAllOf,
        DataInputSnapshot,
        DataInputSnapshotAllOf,
        DataInputSnapshotResponse,
        DataInputTinyResponse,
        DataInputValueResponseBody,
        DataInputsTinyResponse,
        DataUsageResponseObjectResponseBody,
        DateTimeValueObjectRequestBody,
        DateTimeValueObjectResponseBody,
        DefLevelTriggerDetailsObjectRequestBody,
        DefLevelTriggerDetailsObjectRequestBodyOperation,
        DefLevelTriggerDetailsObjectResponseBody,
        DefLevelTriggerDetailsObjectResponseBodyOperation,
        DefRemainingResponseBody,
        Defect,
        DefectPhotoResponseResponseBody,
        DefectResolvedBy,
        DefectResolvedByType,
        DefectResponse,
        DefectTrailer,
        DefectTrailerResponseResponseBody,
        DefectTypesResponseDataResponseBody,
        DefectTypesResponseDataResponseBodySectionType,
        DefectTypesResponseDataResponseBodySeverity,
        DefectVehicle,
        DefectVehicleResponseResponseBody,
        DefectsResponse,
        DefectsResponseDataResponseBody,
        DeployFunctionDetailResponseBody,
        DepreciationGetDepreciationTransactionsBadGatewayErrorResponseBody,
        DepreciationGetDepreciationTransactionsGatewayTimeoutErrorResponseBody,
        DepreciationGetDepreciationTransactionsInternalServerErrorResponseBody,
        DepreciationGetDepreciationTransactionsMethodNotAllowedErrorResponseBody,
        DepreciationGetDepreciationTransactionsNotFoundErrorResponseBody,
        DepreciationGetDepreciationTransactionsNotImplementedErrorResponseBody,
        DepreciationGetDepreciationTransactionsResponseBody,
        DepreciationGetDepreciationTransactionsServiceUnavailableErrorResponseBody,
        DepreciationGetDepreciationTransactionsTooManyRequestsErrorResponseBody,
        DepreciationGetDepreciationTransactionsUnauthorizedErrorResponseBody,
        DepreciationTransactionMoneyObjectResponseBody,
        DepreciationTransactionMoneyObjectResponseBodyCurrency,
        DepreciationTransactionObjectResponseBody,
        DepreciationTransactionObjectResponseBodyTransactionType,
        DetectionLogAssetObjectResponseBody,
        DetectionLogDetectionObjectResponseBody,
        DetectionLogDetectionObjectResponseBodyTriggerDetectionLabel,
        DetectionLogDriverObjectResponseBody,
        DetectionLogGetDetectionsBadGatewayErrorResponseBody,
        DetectionLogGetDetectionsGatewayTimeoutErrorResponseBody,
        DetectionLogGetDetectionsInternalServerErrorResponseBody,
        DetectionLogGetDetectionsMethodNotAllowedErrorResponseBody,
        DetectionLogGetDetectionsNotFoundErrorResponseBody,
        DetectionLogGetDetectionsNotImplementedErrorResponseBody,
        DetectionLogGetDetectionsResponseBody,
        DetectionLogGetDetectionsServiceUnavailableErrorResponseBody,
        DetectionLogGetDetectionsTooManyRequestsErrorResponseBody,
        DetectionLogGetDetectionsUnauthorizedErrorResponseBody,
        DetectionLogSafetyEventObjectResponseBody,
        DetectionLogSafetyEventObjectResponseBodyInboxFilterReason,
        DeviceAssetResponseResponseBody,
        DeviceMovementDataResponseBody,
        DeviceMovementStoppedDataResponseBody,
        DeviceMovementTriggerDetailsObjectRequestBody,
        DeviceMovementTriggerDetailsObjectResponseBody,
        DeviceRecoveryListDeviceRecoveryMissingAssetsBadGatewayErrorResponseBody,
        DeviceRecoveryListDeviceRecoveryMissingAssetsGatewayTimeoutErrorResponseBody,
        DeviceRecoveryListDeviceRecoveryMissingAssetsInternalServerErrorResponseBody,
        DeviceRecoveryListDeviceRecoveryMissingAssetsMethodNotAllowedErrorResponseBody,
        DeviceRecoveryListDeviceRecoveryMissingAssetsNotFoundErrorResponseBody,
        DeviceRecoveryListDeviceRecoveryMissingAssetsNotImplementedErrorResponseBody,
        DeviceRecoveryListDeviceRecoveryMissingAssetsResponseBody,
        DeviceRecoveryListDeviceRecoveryMissingAssetsServiceUnavailableErrorResponseBody,
        DeviceRecoveryListDeviceRecoveryMissingAssetsTooManyRequestsErrorResponseBody,
        DeviceRecoveryListDeviceRecoveryMissingAssetsUnauthorizedErrorResponseBody,
        DeviceRecoveryMarkAssetMissingBadGatewayErrorResponseBody,
        DeviceRecoveryMarkAssetMissingGatewayTimeoutErrorResponseBody,
        DeviceRecoveryMarkAssetMissingInternalServerErrorResponseBody,
        DeviceRecoveryMarkAssetMissingMethodNotAllowedErrorResponseBody,
        DeviceRecoveryMarkAssetMissingNotFoundErrorResponseBody,
        DeviceRecoveryMarkAssetMissingNotImplementedErrorResponseBody,
        DeviceRecoveryMarkAssetMissingResponseBody,
        DeviceRecoveryMarkAssetMissingServiceUnavailableErrorResponseBody,
        DeviceRecoveryMarkAssetMissingTooManyRequestsErrorResponseBody,
        DeviceRecoveryMarkAssetMissingUnauthorizedErrorResponseBody,
        DeviceRecoveryRecoverAssetBadGatewayErrorResponseBody,
        DeviceRecoveryRecoverAssetGatewayTimeoutErrorResponseBody,
        DeviceRecoveryRecoverAssetInternalServerErrorResponseBody,
        DeviceRecoveryRecoverAssetMethodNotAllowedErrorResponseBody,
        DeviceRecoveryRecoverAssetNotFoundErrorResponseBody,
        DeviceRecoveryRecoverAssetNotImplementedErrorResponseBody,
        DeviceRecoveryRecoverAssetResponseBody,
        DeviceRecoveryRecoverAssetServiceUnavailableErrorResponseBody,
        DeviceRecoveryRecoverAssetTooManyRequestsErrorResponseBody,
        DeviceRecoveryRecoverAssetUnauthorizedErrorResponseBody,
        DeviceResponseResponseBody,
        DeviceResponseResponseBodyModel,
        DevicesGetDevicesBadGatewayErrorResponseBody,
        DevicesGetDevicesGatewayTimeoutErrorResponseBody,
        DevicesGetDevicesInternalServerErrorResponseBody,
        DevicesGetDevicesMethodNotAllowedErrorResponseBody,
        DevicesGetDevicesNotFoundErrorResponseBody,
        DevicesGetDevicesNotImplementedErrorResponseBody,
        DevicesGetDevicesResponseBody,
        DevicesGetDevicesServiceUnavailableErrorResponseBody,
        DevicesGetDevicesTooManyRequestsErrorResponseBody,
        DevicesGetDevicesUnauthorizedErrorResponseBody,
        DistanceDrivenMeters,
        DistanceResponseBody,
        DistanceTraveledObjectResponseBody,
        DistractedDrivingDetectionAlertSettingsObjectResponseBody,
        DocumentPdfGenerationResponse,
        DocumentPdfGenerationResponseData,
        DocumentPdfQueryResponse,
        DocumentPdfQueryResponseData,
        DocumentPdfQueryResponseDataJobStatus,
        DocumentResponseObjectResponseBody,
        DocumentResponseObjectResponseBodyState,
        DocumentTypesGetDocumentTypesBadGatewayErrorResponseBody,
        DocumentTypesGetDocumentTypesGatewayTimeoutErrorResponseBody,
        DocumentTypesGetDocumentTypesInternalServerErrorResponseBody,
        DocumentTypesGetDocumentTypesMethodNotAllowedErrorResponseBody,
        DocumentTypesGetDocumentTypesNotFoundErrorResponseBody,
        DocumentTypesGetDocumentTypesNotImplementedErrorResponseBody,
        DocumentTypesGetDocumentTypesResponseBody,
        DocumentTypesGetDocumentTypesServiceUnavailableErrorResponseBody,
        DocumentTypesGetDocumentTypesTooManyRequestsErrorResponseBody,
        DocumentTypesGetDocumentTypesUnauthorizedErrorResponseBody,
        DocumentsDeleteDocumentBadGatewayErrorResponseBody,
        DocumentsDeleteDocumentGatewayTimeoutErrorResponseBody,
        DocumentsDeleteDocumentInternalServerErrorResponseBody,
        DocumentsDeleteDocumentMethodNotAllowedErrorResponseBody,
        DocumentsDeleteDocumentNotFoundErrorResponseBody,
        DocumentsDeleteDocumentNotImplementedErrorResponseBody,
        DocumentsDeleteDocumentServiceUnavailableErrorResponseBody,
        DocumentsDeleteDocumentTooManyRequestsErrorResponseBody,
        DocumentsDeleteDocumentUnauthorizedErrorResponseBody,
        DocumentsGetDocumentBadGatewayErrorResponseBody,
        DocumentsGetDocumentGatewayTimeoutErrorResponseBody,
        DocumentsGetDocumentInternalServerErrorResponseBody,
        DocumentsGetDocumentMethodNotAllowedErrorResponseBody,
        DocumentsGetDocumentNotFoundErrorResponseBody,
        DocumentsGetDocumentNotImplementedErrorResponseBody,
        DocumentsGetDocumentResponseBody,
        DocumentsGetDocumentServiceUnavailableErrorResponseBody,
        DocumentsGetDocumentTooManyRequestsErrorResponseBody,
        DocumentsGetDocumentUnauthorizedErrorResponseBody,
        DocumentsGetDocumentsBadGatewayErrorResponseBody,
        DocumentsGetDocumentsGatewayTimeoutErrorResponseBody,
        DocumentsGetDocumentsInternalServerErrorResponseBody,
        DocumentsGetDocumentsMethodNotAllowedErrorResponseBody,
        DocumentsGetDocumentsNotFoundErrorResponseBody,
        DocumentsGetDocumentsNotImplementedErrorResponseBody,
        DocumentsGetDocumentsResponseBody,
        DocumentsGetDocumentsServiceUnavailableErrorResponseBody,
        DocumentsGetDocumentsTooManyRequestsErrorResponseBody,
        DocumentsGetDocumentsUnauthorizedErrorResponseBody,
        DocumentsPostDocumentBadGatewayErrorResponseBody,
        DocumentsPostDocumentGatewayTimeoutErrorResponseBody,
        DocumentsPostDocumentInternalServerErrorResponseBody,
        DocumentsPostDocumentMethodNotAllowedErrorResponseBody,
        DocumentsPostDocumentNotFoundErrorResponseBody,
        DocumentsPostDocumentNotImplementedErrorResponseBody,
        DocumentsPostDocumentResponseBody,
        DocumentsPostDocumentServiceUnavailableErrorResponseBody,
        DocumentsPostDocumentTooManyRequestsErrorResponseBody,
        DocumentsPostDocumentUnauthorizedErrorResponseBody,
        DoorOpenResponseBody,
        DriveTimeDurationMs,
        Driver,
        DriverActivationStatus,
        DriverAppNotificationObjectRequestBody,
        DriverAppNotificationObjectResponseBody,
        DriverAppSettingsGamificationConfigTinyObjectRequestBody,
        DriverAppSettingsGamificationConfigTinyObjectResponseBody,
        DriverAppSettingsResponseObjectResponseBody,
        DriverAppSettingsTrailerSelectionConfigTinyObjectRequestBody,
        DriverAppSettingsTrailerSelectionConfigTinyObjectResponseBody,
        DriverAppSignInResponseBody,
        DriverAppSignOutResponseBody,
        DriverAssignmentMetadataTinyObjectResponseBody,
        DriverAssignmentObjectResponseBody,
        DriverAssignmentObjectResponseBodyAssignmentType,
        DriverCarrierSettings,
        DriverCoachAssignmentsGetDriverCoachAssignmentBadGatewayErrorResponseBody,
        DriverCoachAssignmentsGetDriverCoachAssignmentGatewayTimeoutErrorResponseBody,
        DriverCoachAssignmentsGetDriverCoachAssignmentInternalServerErrorResponseBody,
        DriverCoachAssignmentsGetDriverCoachAssignmentMethodNotAllowedErrorResponseBody,
        DriverCoachAssignmentsGetDriverCoachAssignmentNotFoundErrorResponseBody,
        DriverCoachAssignmentsGetDriverCoachAssignmentNotImplementedErrorResponseBody,
        DriverCoachAssignmentsGetDriverCoachAssignmentResponseBody,
        DriverCoachAssignmentsGetDriverCoachAssignmentServiceUnavailableErrorResponseBody,
        DriverCoachAssignmentsGetDriverCoachAssignmentTooManyRequestsErrorResponseBody,
        DriverCoachAssignmentsGetDriverCoachAssignmentUnauthorizedErrorResponseBody,
        DriverCoachAssignmentsPutDriverCoachAssignmentBadGatewayErrorResponseBody,
        DriverCoachAssignmentsPutDriverCoachAssignmentGatewayTimeoutErrorResponseBody,
        DriverCoachAssignmentsPutDriverCoachAssignmentInternalServerErrorResponseBody,
        DriverCoachAssignmentsPutDriverCoachAssignmentMethodNotAllowedErrorResponseBody,
        DriverCoachAssignmentsPutDriverCoachAssignmentNotFoundErrorResponseBody,
        DriverCoachAssignmentsPutDriverCoachAssignmentNotImplementedErrorResponseBody,
        DriverCoachAssignmentsPutDriverCoachAssignmentResponseBody,
        DriverCoachAssignmentsPutDriverCoachAssignmentServiceUnavailableErrorResponseBody,
        DriverCoachAssignmentsPutDriverCoachAssignmentTooManyRequestsErrorResponseBody,
        DriverCoachAssignmentsPutDriverCoachAssignmentUnauthorizedErrorResponseBody,
        DriverCreatedAtTime,
        DriverDocumentSubmittedDetailsObjectRequestBody,
        DriverDocumentSubmittedDetailsObjectResponseBody,
        DriverDocumentSubmittedResponseBody,
        DriverEfficienciesResponse,
        DriverEfficienciesResponseData,
        DriverEfficiency,
        DriverEfficiencyDataObjectResponseBody,
        DriverEfficiencyDifficultyScoreDataObjectResponseBody,
        DriverEfficiencyGetDriverEfficiencyByDriversBadGatewayErrorResponseBody,
        DriverEfficiencyGetDriverEfficiencyByDriversGatewayTimeoutErrorResponseBody,
        DriverEfficiencyGetDriverEfficiencyByDriversInternalServerErrorResponseBody,
        DriverEfficiencyGetDriverEfficiencyByDriversMethodNotAllowedErrorResponseBody,
        DriverEfficiencyGetDriverEfficiencyByDriversNotFoundErrorResponseBody,
        DriverEfficiencyGetDriverEfficiencyByDriversNotImplementedErrorResponseBody,
        DriverEfficiencyGetDriverEfficiencyByDriversResponseBody,
        DriverEfficiencyGetDriverEfficiencyByDriversServiceUnavailableErrorResponseBody,
        DriverEfficiencyGetDriverEfficiencyByDriversTooManyRequestsErrorResponseBody,
        DriverEfficiencyGetDriverEfficiencyByDriversUnauthorizedErrorResponseBody,
        DriverEfficiencyGetDriverEfficiencyByVehiclesBadGatewayErrorResponseBody,
        DriverEfficiencyGetDriverEfficiencyByVehiclesGatewayTimeoutErrorResponseBody,
        DriverEfficiencyGetDriverEfficiencyByVehiclesInternalServerErrorResponseBody,
        DriverEfficiencyGetDriverEfficiencyByVehiclesMethodNotAllowedErrorResponseBody,
        DriverEfficiencyGetDriverEfficiencyByVehiclesNotFoundErrorResponseBody,
        DriverEfficiencyGetDriverEfficiencyByVehiclesNotImplementedErrorResponseBody,
        DriverEfficiencyGetDriverEfficiencyByVehiclesResponseBody,
        DriverEfficiencyGetDriverEfficiencyByVehiclesServiceUnavailableErrorResponseBody,
        DriverEfficiencyGetDriverEfficiencyByVehiclesTooManyRequestsErrorResponseBody,
        DriverEfficiencyGetDriverEfficiencyByVehiclesUnauthorizedErrorResponseBody,
        DriverEfficiencyPercentageDataObjectResponseBody,
        DriverEfficiencyRawDataObjectResponseBody,
        DriverEldAdverseWeatherExemptionEnabled,
        DriverEldBigDayExemptionEnabled,
        DriverEldDayStartHour,
        DriverEldExempt,
        DriverEldExemptReason,
        DriverEldPcEnabled,
        DriverEldRuleset,
        DriverEldRulesetCycle,
        DriverEldRulesetJurisdiction,
        DriverEldRulesetRestBreak,
        DriverEldRulesetRestart,
        DriverEldRulesetShift,
        DriverEldRulesets,
        DriverEldSettings,
        DriverEldYmEnabled,
        DriverExternalIds,
        DriverHasDrivingFeaturesHidden,
        DriverHasVehicleUnpinningEnabled,
        DriverHeavyHaulExemptionToggleEnabled,
        DriverHomeTerminalAddress,
        DriverHomeTerminalName,
        DriverHosSetting,
        DriverId,
        DriverIdCardCode,
        DriverIsDeactivated,
        DriverLicenseNumber,
        DriverLicenseState,
        DriverLocale,
        DriverMessageReceivedResponseBody,
        DriverMessageSentResponseBody,
        DriverName,
        DriverNotes,
        DriverObjectResponseBody,
        DriverOrTagIdsDetailsRequestBody,
        DriverOrTagIdsDetailsResponseBody,
        DriverPhone,
        DriverProfileImageBase64,
        DriverProfileImageUrl,
        DriverQrCodesCreateDriverQrCodeBadGatewayErrorResponseBody,
        DriverQrCodesCreateDriverQrCodeGatewayTimeoutErrorResponseBody,
        DriverQrCodesCreateDriverQrCodeInternalServerErrorResponseBody,
        DriverQrCodesCreateDriverQrCodeMethodNotAllowedErrorResponseBody,
        DriverQrCodesCreateDriverQrCodeNotFoundErrorResponseBody,
        DriverQrCodesCreateDriverQrCodeNotImplementedErrorResponseBody,
        DriverQrCodesCreateDriverQrCodeResponseBody,
        DriverQrCodesCreateDriverQrCodeServiceUnavailableErrorResponseBody,
        DriverQrCodesCreateDriverQrCodeTooManyRequestsErrorResponseBody,
        DriverQrCodesCreateDriverQrCodeUnauthorizedErrorResponseBody,
        DriverQrCodesDeleteDriverQrCodeBadGatewayErrorResponseBody,
        DriverQrCodesDeleteDriverQrCodeGatewayTimeoutErrorResponseBody,
        DriverQrCodesDeleteDriverQrCodeInternalServerErrorResponseBody,
        DriverQrCodesDeleteDriverQrCodeMethodNotAllowedErrorResponseBody,
        DriverQrCodesDeleteDriverQrCodeNotFoundErrorResponseBody,
        DriverQrCodesDeleteDriverQrCodeNotImplementedErrorResponseBody,
        DriverQrCodesDeleteDriverQrCodeServiceUnavailableErrorResponseBody,
        DriverQrCodesDeleteDriverQrCodeTooManyRequestsErrorResponseBody,
        DriverQrCodesDeleteDriverQrCodeUnauthorizedErrorResponseBody,
        DriverQrCodesGetDriversQrCodesBadGatewayErrorResponseBody,
        DriverQrCodesGetDriversQrCodesGatewayTimeoutErrorResponseBody,
        DriverQrCodesGetDriversQrCodesInternalServerErrorResponseBody,
        DriverQrCodesGetDriversQrCodesMethodNotAllowedErrorResponseBody,
        DriverQrCodesGetDriversQrCodesNotFoundErrorResponseBody,
        DriverQrCodesGetDriversQrCodesNotImplementedErrorResponseBody,
        DriverQrCodesGetDriversQrCodesResponseBody,
        DriverQrCodesGetDriversQrCodesServiceUnavailableErrorResponseBody,
        DriverQrCodesGetDriversQrCodesTooManyRequestsErrorResponseBody,
        DriverQrCodesGetDriversQrCodesUnauthorizedErrorResponseBody,
        DriverRecordedResponseBody,
        DriverRemoteSignoutPostDriverRemoteSignoutBadGatewayErrorResponseBody,
        DriverRemoteSignoutPostDriverRemoteSignoutGatewayTimeoutErrorResponseBody,
        DriverRemoteSignoutPostDriverRemoteSignoutInternalServerErrorResponseBody,
        DriverRemoteSignoutPostDriverRemoteSignoutMethodNotAllowedErrorResponseBody,
        DriverRemoteSignoutPostDriverRemoteSignoutNotFoundErrorResponseBody,
        DriverRemoteSignoutPostDriverRemoteSignoutNotImplementedErrorResponseBody,
        DriverRemoteSignoutPostDriverRemoteSignoutResponseBody,
        DriverRemoteSignoutPostDriverRemoteSignoutServiceUnavailableErrorResponseBody,
        DriverRemoteSignoutPostDriverRemoteSignoutTooManyRequestsErrorResponseBody,
        DriverRemoteSignoutPostDriverRemoteSignoutUnauthorizedErrorResponseBody,
        DriverResponse,
        DriverRulesetObjectResponseBody,
        DriverRulesetObjectResponseBodyBreak,
        DriverRulesetObjectResponseBodyCycle,
        DriverRulesetObjectResponseBodyRestart,
        DriverRulesetObjectResponseBodyShift,
        DriverSafetyScoreResponseBody,
        DriverStaticAssignedVehicle,
        DriverTachographActivityData,
        DriverTachographActivityResponse,
        DriverTachographCardNumber,
        DriverTags,
        DriverTimezone,
        DriverTinyResponse,
        DriverUpdatedAtTime,
        DriverUsername,
        DriverVehicleAssignmentV2ObjectResponseBody,
        DriverVehicleAssignmentV2ObjectResponseBodyAssignmentType,
        DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentBadGatewayErrorResponseBody,
        DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentGatewayTimeoutErrorResponseBody,
        DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentInternalServerErrorResponseBody,
        DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentMethodNotAllowedErrorResponseBody,
        DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentNotFoundErrorResponseBody,
        DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentNotImplementedErrorResponseBody,
        DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentResponseBody,
        DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentServiceUnavailableErrorResponseBody,
        DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentTooManyRequestsErrorResponseBody,
        DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentUnauthorizedErrorResponseBody,
        DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsBadGatewayErrorResponseBody,
        DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsGatewayTimeoutErrorResponseBody,
        DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsInternalServerErrorResponseBody,
        DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsMethodNotAllowedErrorResponseBody,
        DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsNotFoundErrorResponseBody,
        DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsNotImplementedErrorResponseBody,
        DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsServiceUnavailableErrorResponseBody,
        DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsTooManyRequestsErrorResponseBody,
        DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsUnauthorizedErrorResponseBody,
        DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsBadGatewayErrorResponseBody,
        DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsGatewayTimeoutErrorResponseBody,
        DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsInternalServerErrorResponseBody,
        DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsMethodNotAllowedErrorResponseBody,
        DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsNotFoundErrorResponseBody,
        DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsNotImplementedErrorResponseBody,
        DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsResponseBody,
        DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsServiceUnavailableErrorResponseBody,
        DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsTooManyRequestsErrorResponseBody,
        DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsUnauthorizedErrorResponseBody,
        DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentBadGatewayErrorResponseBody,
        DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentGatewayTimeoutErrorResponseBody,
        DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentInternalServerErrorResponseBody,
        DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentMethodNotAllowedErrorResponseBody,
        DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentNotFoundErrorResponseBody,
        DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentNotImplementedErrorResponseBody,
        DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentResponseBody,
        DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentServiceUnavailableErrorResponseBody,
        DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentTooManyRequestsErrorResponseBody,
        DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentUnauthorizedErrorResponseBody,
        DriverVehicleGroupTag,
        DriverWaitingTimeDutyStatusEnabled,
        DriverWithExternalIdObjectResponseBody,
        DriverWithTimezoneEldSettingsObjectResponseBody,
        DriversAuthTokenCreateDriverAuthTokenBadGatewayErrorResponseBody,
        DriversAuthTokenCreateDriverAuthTokenGatewayTimeoutErrorResponseBody,
        DriversAuthTokenCreateDriverAuthTokenInternalServerErrorResponseBody,
        DriversAuthTokenCreateDriverAuthTokenMethodNotAllowedErrorResponseBody,
        DriversAuthTokenCreateDriverAuthTokenNotFoundErrorResponseBody,
        DriversAuthTokenCreateDriverAuthTokenNotImplementedErrorResponseBody,
        DriversAuthTokenCreateDriverAuthTokenResponseBody,
        DriversAuthTokenCreateDriverAuthTokenServiceUnavailableErrorResponseBody,
        DriversAuthTokenCreateDriverAuthTokenTooManyRequestsErrorResponseBody,
        DriversAuthTokenCreateDriverAuthTokenUnauthorizedErrorResponseBody,
        DriversVehicleAssignmentsGetDriversVehicleAssignmentsBadGatewayErrorResponseBody,
        DriversVehicleAssignmentsGetDriversVehicleAssignmentsGatewayTimeoutErrorResponseBody,
        DriversVehicleAssignmentsGetDriversVehicleAssignmentsInternalServerErrorResponseBody,
        DriversVehicleAssignmentsGetDriversVehicleAssignmentsMethodNotAllowedErrorResponseBody,
        DriversVehicleAssignmentsGetDriversVehicleAssignmentsNotFoundErrorResponseBody,
        DriversVehicleAssignmentsGetDriversVehicleAssignmentsNotImplementedErrorResponseBody,
        DriversVehicleAssignmentsGetDriversVehicleAssignmentsResponseBody,
        DriversVehicleAssignmentsGetDriversVehicleAssignmentsServiceUnavailableErrorResponseBody,
        DriversVehicleAssignmentsGetDriversVehicleAssignmentsTooManyRequestsErrorResponseBody,
        DriversVehicleAssignmentsGetDriversVehicleAssignmentsUnauthorizedErrorResponseBody,
        DriversVehicleAssignmentsObjectResponseBody,
        DriversVehicleAssignmentsObjectResponseBodyDriverActivationStatus,
        DutyStatusDurationObjectResponseBody,
        Dvir,
        Dvir2AssignedToPolymorphicUserObjectResponseBody,
        Dvir2DeviceObjectResponseBody,
        Dvir2FormSubmissionObjectResponseBody,
        Dvir2RelatedDeviceObjectResponseBody,
        Dvir2RelatedDeviceObjectResponseBodyAssetType,
        Dvir2SubmissionResponseObjectResponseBody,
        Dvir2SubmissionResponseObjectResponseBodyInspectionType,
        DvirAuthorSignature,
        DvirDefectGetDefectBadGatewayErrorResponseBody,
        DvirDefectGetDefectGatewayTimeoutErrorResponseBody,
        DvirDefectGetDefectInternalServerErrorResponseBody,
        DvirDefectGetDefectMethodNotAllowedErrorResponseBody,
        DvirDefectGetDefectNotFoundErrorResponseBody,
        DvirDefectGetDefectNotImplementedErrorResponseBody,
        DvirDefectGetDefectResponseBody,
        DvirDefectGetDefectServiceUnavailableErrorResponseBody,
        DvirDefectGetDefectTooManyRequestsErrorResponseBody,
        DvirDefectGetDefectUnauthorizedErrorResponseBody,
        DvirDefectStreamDefectsBadGatewayErrorResponseBody,
        DvirDefectStreamDefectsGatewayTimeoutErrorResponseBody,
        DvirDefectStreamDefectsInternalServerErrorResponseBody,
        DvirDefectStreamDefectsMethodNotAllowedErrorResponseBody,
        DvirDefectStreamDefectsNotFoundErrorResponseBody,
        DvirDefectStreamDefectsNotImplementedErrorResponseBody,
        DvirDefectStreamDefectsResponseBody,
        DvirDefectStreamDefectsServiceUnavailableErrorResponseBody,
        DvirDefectStreamDefectsTooManyRequestsErrorResponseBody,
        DvirDefectStreamDefectsUnauthorizedErrorResponseBody,
        DvirDefectTypeGetDefectTypesBadGatewayErrorResponseBody,
        DvirDefectTypeGetDefectTypesGatewayTimeoutErrorResponseBody,
        DvirDefectTypeGetDefectTypesInternalServerErrorResponseBody,
        DvirDefectTypeGetDefectTypesMethodNotAllowedErrorResponseBody,
        DvirDefectTypeGetDefectTypesNotFoundErrorResponseBody,
        DvirDefectTypeGetDefectTypesNotImplementedErrorResponseBody,
        DvirDefectTypeGetDefectTypesResponseBody,
        DvirDefectTypeGetDefectTypesServiceUnavailableErrorResponseBody,
        DvirDefectTypeGetDefectTypesTooManyRequestsErrorResponseBody,
        DvirDefectTypeGetDefectTypesUnauthorizedErrorResponseBody,
        DvirDefectsObjectV20220913ResponseBody,
        DvirDefectsObjectV20220913ResponseBodyDefectSeverity,
        DvirGetDvirBadGatewayErrorResponseBody,
        DvirGetDvirGatewayTimeoutErrorResponseBody,
        DvirGetDvirInternalServerErrorResponseBody,
        DvirGetDvirMethodNotAllowedErrorResponseBody,
        DvirGetDvirNotFoundErrorResponseBody,
        DvirGetDvirNotImplementedErrorResponseBody,
        DvirGetDvirResponseBody,
        DvirGetDvirResponseBodySafetyStatus,
        DvirGetDvirResponseBodyType,
        DvirGetDvirServiceUnavailableErrorResponseBody,
        DvirGetDvirTooManyRequestsErrorResponseBody,
        DvirGetDvirUnauthorizedErrorResponseBody,
        DvirGetDvirsBadGatewayErrorResponseBody,
        DvirGetDvirsGatewayTimeoutErrorResponseBody,
        DvirGetDvirsInternalServerErrorResponseBody,
        DvirGetDvirsMethodNotAllowedErrorResponseBody,
        DvirGetDvirsNotFoundErrorResponseBody,
        DvirGetDvirsNotImplementedErrorResponseBody,
        DvirGetDvirsResponseBody,
        DvirGetDvirsServiceUnavailableErrorResponseBody,
        DvirGetDvirsTooManyRequestsErrorResponseBody,
        DvirGetDvirsUnauthorizedErrorResponseBody,
        DvirLicensePlate,
        DvirLocation,
        DvirMechanicNotes,
        DvirOdometerMeters,
        DvirResolvedByObjectResponseBody,
        DvirResolvedByObjectResponseBodyType,
        DvirResponse,
        DvirSafetyStatus,
        DvirSecondSignature,
        DvirSignature,
        DvirSignatureSignatoryUser,
        DvirSignatureType,
        DvirStreamResponseDataResponseBody,
        DvirStreamResponseDataResponseBodySafetyStatus,
        DvirStreamResponseDataResponseBodyType,
        DvirSubmittedDeviceTriggerDetailsObjectRequestBody,
        DvirSubmittedDeviceTriggerDetailsObjectRequestBodyDvirSubmissionTypesItem,
        DvirSubmittedDeviceTriggerDetailsObjectResponseBody,
        DvirSubmittedDeviceTriggerDetailsObjectResponseBodyDvirSubmissionTypesItem,
        DvirThirdSignature,
        DvirTrailer,
        DvirTrailerDefects,
        DvirTrailerDefectsItems,
        DvirTrailerDefectsItemsTrailer,
        DvirTrailerDefectsItemsVehicle,
        DvirType,
        DvirVehicle,
        DvirVehicleDefects,
        DvirsListResponse,
        EldSettingsObjectResponseBody,
        EngineIdleDataResponseBody,
        EngineIdleTriggerDetailsObjectRequestBody,
        EngineIdleTriggerDetailsObjectResponseBody,
        EngineImmobilizerGetEngineImmobilizerStatesBadGatewayErrorResponseBody,
        EngineImmobilizerGetEngineImmobilizerStatesGatewayTimeoutErrorResponseBody,
        EngineImmobilizerGetEngineImmobilizerStatesInternalServerErrorResponseBody,
        EngineImmobilizerGetEngineImmobilizerStatesMethodNotAllowedErrorResponseBody,
        EngineImmobilizerGetEngineImmobilizerStatesNotFoundErrorResponseBody,
        EngineImmobilizerGetEngineImmobilizerStatesNotImplementedErrorResponseBody,
        EngineImmobilizerGetEngineImmobilizerStatesResponseBody,
        EngineImmobilizerGetEngineImmobilizerStatesServiceUnavailableErrorResponseBody,
        EngineImmobilizerGetEngineImmobilizerStatesTooManyRequestsErrorResponseBody,
        EngineImmobilizerGetEngineImmobilizerStatesUnauthorizedErrorResponseBody,
        EngineImmobilizerRelayStateResponseBody,
        EngineImmobilizerRelayStateResponseBodyId,
        EngineImmobilizerStateResponseBody,
        EngineImmobilizerUpdateEngineImmobilizerStateBadGatewayErrorResponseBody,
        EngineImmobilizerUpdateEngineImmobilizerStateGatewayTimeoutErrorResponseBody,
        EngineImmobilizerUpdateEngineImmobilizerStateInternalServerErrorResponseBody,
        EngineImmobilizerUpdateEngineImmobilizerStateMethodNotAllowedErrorResponseBody,
        EngineImmobilizerUpdateEngineImmobilizerStateNotFoundErrorResponseBody,
        EngineImmobilizerUpdateEngineImmobilizerStateNotImplementedErrorResponseBody,
        EngineImmobilizerUpdateEngineImmobilizerStateServiceUnavailableErrorResponseBody,
        EngineImmobilizerUpdateEngineImmobilizerStateTooManyRequestsErrorResponseBody,
        EngineImmobilizerUpdateEngineImmobilizerStateUnauthorizedErrorResponseBody,
        EngineOffDetailsObjectRequestBody,
        EngineOffDetailsObjectResponseBody,
        EngineOffResponseBody,
        EngineOnDetailsObjectRequestBody,
        EngineOnDetailsObjectResponseBody,
        EngineOnResponseBody,
        EngineStatusResponseBody,
        EnumReadingAlertThresholdResponseBody,
        EnumValueResponseBody,
        EquipmentEngineRpm,
        EquipmentEngineSeconds,
        EquipmentEngineState,
        EquipmentEngineStateValue,
        EquipmentEngineTotalIdleTimeMinutes,
        EquipmentFuelPercent,
        EquipmentGatewayEngineSeconds,
        EquipmentGatewayEngineState,
        EquipmentGatewayEngineStateValue,
        EquipmentGatewayJ1939EngineSeconds,
        EquipmentGpsOdometerMeters,
        EquipmentHeaderWithAdditionalFieldsResponseBody,
        EquipmentId,
        EquipmentInstalledGateway,
        EquipmentListResponse,
        EquipmentLocation,
        EquipmentLocationsListResponse,
        EquipmentLocationsListResponseData,
        EquipmentLocationsResponse,
        EquipmentLocationsResponseData,
        EquipmentName,
        EquipmentObdEngineSeconds,
        EquipmentObdEngineState,
        EquipmentObdEngineStateValue,
        EquipmentObject,
        EquipmentPatchEquipmentBadGatewayErrorResponseBody,
        EquipmentPatchEquipmentGatewayTimeoutErrorResponseBody,
        EquipmentPatchEquipmentInternalServerErrorResponseBody,
        EquipmentPatchEquipmentMethodNotAllowedErrorResponseBody,
        EquipmentPatchEquipmentNotFoundErrorResponseBody,
        EquipmentPatchEquipmentNotImplementedErrorResponseBody,
        EquipmentPatchEquipmentResponseBody,
        EquipmentPatchEquipmentServiceUnavailableErrorResponseBody,
        EquipmentPatchEquipmentTooManyRequestsErrorResponseBody,
        EquipmentPatchEquipmentUnauthorizedErrorResponseBody,
        EquipmentResponse,
        EquipmentStatsGps,
        EquipmentStatsListResponse,
        EquipmentStatsListResponseData,
        EquipmentStatsResponse,
        EquipmentStatsResponseData,
        EquipmentTime,
        EquipmentWithAttributesResponseObjectResponseBody,
        EventLocationResponseBody,
        ExtendedDriverTinyResponse,
        ExtendedDriverTinyResponseExternalIds,
        FftSpectraDataPoint,
        FftSpectraDataPointFftSpectra,
        FieldObjectPostRequestBody,
        FieldObjectPostRequestBodyType,
        FieldObjectResponseBody,
        FieldObjectResponseBodyType,
        FieldObjectValueRequestBody,
        FieldObjectValueResponseBody,
        FieldTypesObjectResponseBody,
        FieldTypesObjectResponseBodyFieldType,
        FiltersRequestBody,
        FiltersResponseBody,
        FleetDeviceObjectResponseBody,
        FollowingDistanceDetectionAlertSettingsObjectResponseBody,
        FormSubmissionPdfExportResponseObjectResponseBody,
        FormSubmissionPdfExportResponseObjectResponseBodyJobStatus,
        FormSubmissionRequestApprovalDetailsRequestBody,
        FormSubmissionRequestAssetObjectRequestBody,
        FormSubmissionRequestAssetValueObjectRequestBody,
        FormSubmissionRequestAssignedToRequestBody,
        FormSubmissionRequestAssignedToRequestBodyType,
        FormSubmissionRequestCheckBoxesValueObjectRequestBody,
        FormSubmissionRequestDateTimeValueObjectRequestBody,
        FormSubmissionRequestFieldInputObjectRequestBody,
        FormSubmissionRequestFieldInputObjectRequestBodyType,
        FormSubmissionRequestGeofenceObjectRequestBody,
        FormSubmissionRequestGeofenceValueObjectRequestBody,
        FormSubmissionRequestMediaItemObjectRequestBody,
        FormSubmissionRequestMediaValueObjectRequestBody,
        FormSubmissionRequestMultipleChoiceValueObjectRequestBody,
        FormSubmissionRequestNumberValueObjectRequestBody,
        FormSubmissionRequestPersonObjectRequestBody,
        FormSubmissionRequestPersonValueObjectRequestBody,
        FormSubmissionRequestSignatureValueObjectRequestBody,
        FormSubmissionRequestTableCellObjectRequestBody,
        FormSubmissionRequestTableCellObjectRequestBodyType,
        FormSubmissionRequestTableRowObjectRequestBody,
        FormSubmissionRequestTableValueObjectRequestBody,
        FormSubmissionRequestTextValueObjectRequestBody,
        FormSubmissionResponseObjectResponseBody,
        FormSubmissionResponseObjectResponseBodyStatus,
        FormSubmissionsGetFormSubmissionsBadGatewayErrorResponseBody,
        FormSubmissionsGetFormSubmissionsGatewayTimeoutErrorResponseBody,
        FormSubmissionsGetFormSubmissionsInternalServerErrorResponseBody,
        FormSubmissionsGetFormSubmissionsMethodNotAllowedErrorResponseBody,
        FormSubmissionsGetFormSubmissionsNotFoundErrorResponseBody,
        FormSubmissionsGetFormSubmissionsNotImplementedErrorResponseBody,
        FormSubmissionsGetFormSubmissionsPdfExportsBadGatewayErrorResponseBody,
        FormSubmissionsGetFormSubmissionsPdfExportsGatewayTimeoutErrorResponseBody,
        FormSubmissionsGetFormSubmissionsPdfExportsInternalServerErrorResponseBody,
        FormSubmissionsGetFormSubmissionsPdfExportsMethodNotAllowedErrorResponseBody,
        FormSubmissionsGetFormSubmissionsPdfExportsNotFoundErrorResponseBody,
        FormSubmissionsGetFormSubmissionsPdfExportsNotImplementedErrorResponseBody,
        FormSubmissionsGetFormSubmissionsPdfExportsResponseBody,
        FormSubmissionsGetFormSubmissionsPdfExportsServiceUnavailableErrorResponseBody,
        FormSubmissionsGetFormSubmissionsPdfExportsTooManyRequestsErrorResponseBody,
        FormSubmissionsGetFormSubmissionsPdfExportsUnauthorizedErrorResponseBody,
        FormSubmissionsGetFormSubmissionsResponseBody,
        FormSubmissionsGetFormSubmissionsServiceUnavailableErrorResponseBody,
        FormSubmissionsGetFormSubmissionsStreamBadGatewayErrorResponseBody,
        FormSubmissionsGetFormSubmissionsStreamGatewayTimeoutErrorResponseBody,
        FormSubmissionsGetFormSubmissionsStreamInternalServerErrorResponseBody,
        FormSubmissionsGetFormSubmissionsStreamMethodNotAllowedErrorResponseBody,
        FormSubmissionsGetFormSubmissionsStreamNotFoundErrorResponseBody,
        FormSubmissionsGetFormSubmissionsStreamNotImplementedErrorResponseBody,
        FormSubmissionsGetFormSubmissionsStreamResponseBody,
        FormSubmissionsGetFormSubmissionsStreamServiceUnavailableErrorResponseBody,
        FormSubmissionsGetFormSubmissionsStreamTooManyRequestsErrorResponseBody,
        FormSubmissionsGetFormSubmissionsStreamUnauthorizedErrorResponseBody,
        FormSubmissionsGetFormSubmissionsTooManyRequestsErrorResponseBody,
        FormSubmissionsGetFormSubmissionsUnauthorizedErrorResponseBody,
        FormSubmissionsPatchFormSubmissionBadGatewayErrorResponseBody,
        FormSubmissionsPatchFormSubmissionGatewayTimeoutErrorResponseBody,
        FormSubmissionsPatchFormSubmissionInternalServerErrorResponseBody,
        FormSubmissionsPatchFormSubmissionMethodNotAllowedErrorResponseBody,
        FormSubmissionsPatchFormSubmissionNotFoundErrorResponseBody,
        FormSubmissionsPatchFormSubmissionNotImplementedErrorResponseBody,
        FormSubmissionsPatchFormSubmissionResponseBody,
        FormSubmissionsPatchFormSubmissionServiceUnavailableErrorResponseBody,
        FormSubmissionsPatchFormSubmissionTooManyRequestsErrorResponseBody,
        FormSubmissionsPatchFormSubmissionUnauthorizedErrorResponseBody,
        FormSubmissionsPostFormSubmissionBadGatewayErrorResponseBody,
        FormSubmissionsPostFormSubmissionGatewayTimeoutErrorResponseBody,
        FormSubmissionsPostFormSubmissionInternalServerErrorResponseBody,
        FormSubmissionsPostFormSubmissionMethodNotAllowedErrorResponseBody,
        FormSubmissionsPostFormSubmissionNotFoundErrorResponseBody,
        FormSubmissionsPostFormSubmissionNotImplementedErrorResponseBody,
        FormSubmissionsPostFormSubmissionResponseBody,
        FormSubmissionsPostFormSubmissionServiceUnavailableErrorResponseBody,
        FormSubmissionsPostFormSubmissionTooManyRequestsErrorResponseBody,
        FormSubmissionsPostFormSubmissionUnauthorizedErrorResponseBody,
        FormSubmissionsPostFormSubmissionsPdfExportsBadGatewayErrorResponseBody,
        FormSubmissionsPostFormSubmissionsPdfExportsGatewayTimeoutErrorResponseBody,
        FormSubmissionsPostFormSubmissionsPdfExportsInternalServerErrorResponseBody,
        FormSubmissionsPostFormSubmissionsPdfExportsMethodNotAllowedErrorResponseBody,
        FormSubmissionsPostFormSubmissionsPdfExportsNotFoundErrorResponseBody,
        FormSubmissionsPostFormSubmissionsPdfExportsNotImplementedErrorResponseBody,
        FormSubmissionsPostFormSubmissionsPdfExportsResponseBody,
        FormSubmissionsPostFormSubmissionsPdfExportsServiceUnavailableErrorResponseBody,
        FormSubmissionsPostFormSubmissionsPdfExportsTooManyRequestsErrorResponseBody,
        FormSubmissionsPostFormSubmissionsPdfExportsUnauthorizedErrorResponseBody,
        FormSubmittedResponseBody,
        FormTemplateReferenceObjectResponseBody,
        FormTemplateRequestObjectRequestBody,
        FormTemplateResponseObjectResponseBody,
        FormTemplateResponseObjectResponseBodyFormCategory,
        FormTemplateSectionObjectResponseBody,
        FormTemplatesGetFormTemplatesBadGatewayErrorResponseBody,
        FormTemplatesGetFormTemplatesGatewayTimeoutErrorResponseBody,
        FormTemplatesGetFormTemplatesInternalServerErrorResponseBody,
        FormTemplatesGetFormTemplatesMethodNotAllowedErrorResponseBody,
        FormTemplatesGetFormTemplatesNotFoundErrorResponseBody,
        FormTemplatesGetFormTemplatesNotImplementedErrorResponseBody,
        FormTemplatesGetFormTemplatesResponseBody,
        FormTemplatesGetFormTemplatesServiceUnavailableErrorResponseBody,
        FormTemplatesGetFormTemplatesTooManyRequestsErrorResponseBody,
        FormTemplatesGetFormTemplatesUnauthorizedErrorResponseBody,
        FormUpdatedResponseBody,
        FormsActionObjectResponseBody,
        FormsActionObjectResponseBodyType,
        FormsApprovalConfigObjectResponseBody,
        FormsApprovalConfigObjectResponseBodyType,
        FormsAssetObjectResponseBody,
        FormsAssetObjectResponseBodyEntryType,
        FormsAssetValueObjectResponseBody,
        FormsCheckBoxesValueObjectResponseBody,
        FormsConditionObjectResponseBody,
        FormsConditionObjectResponseBodyType,
        FormsConditionalActionObjectResponseBody,
        FormsDateTimeValueObjectResponseBody,
        FormsDateTimeValueObjectResponseBodyType,
        FormsFieldDefinitionObjectResponseBody,
        FormsFieldDefinitionObjectResponseBodyAllowedAssetTypesItem,
        FormsFieldDefinitionObjectResponseBodyAllowedDateTimeValueType,
        FormsFieldDefinitionObjectResponseBodyType,
        FormsFieldInputObjectResponseBody,
        FormsFieldInputObjectResponseBodyType,
        FormsGeofenceObjectResponseBody,
        FormsGeofenceObjectResponseBodyEntryType,
        FormsGeofenceValueObjectResponseBody,
        FormsIssueCreatedByFieldObjectResponseBody,
        FormsLocationObjectResponseBody,
        FormsMediaRecordObjectResponseBody,
        FormsMediaRecordObjectResponseBodyProcessingStatus,
        FormsMediaValueObjectResponseBody,
        FormsMultipleChoiceValueObjectResponseBody,
        FormsNumberValueObjectResponseBody,
        FormsPersonObjectResponseBody,
        FormsPersonObjectResponseBodyEntryType,
        FormsPersonValueObjectResponseBody,
        FormsPolymorphicUserObjectResponseBody,
        FormsPolymorphicUserObjectResponseBodyType,
        FormsProductSubmissionApprovalDetailsObjectResponseBody,
        FormsScoreObjectResponseBody,
        FormsSelectOptionObjectResponseBody,
        FormsSignatureValueObjectResponseBody,
        FormsSingleApprovalConfigObjectResponseBody,
        FormsTableCellObjectResponseBody,
        FormsTableCellObjectResponseBodyType,
        FormsTableColumnObjectResponseBody,
        FormsTableColumnObjectResponseBodyType,
        FormsTableFieldDefinitionObjectResponseBody,
        FormsTableFieldDefinitionObjectResponseBodyAllowedDateTimeValueType,
        FormsTableFieldDefinitionObjectResponseBodyType,
        FormsTableRowObjectResponseBody,
        FormsTableValueObjectResponseBody,
        FormsTextValueObjectResponseBody,
        ForwardCollisionDetectionAlertSettingsObjectResponseBody,
        ForwardCollisionDetectionAlertSettingsObjectResponseBodySensitivity,
        FuelConsumedMl,
        FuelCostObjectResponseBody,
        FuelCostObjectResponseBodyCurrency,
        FuelEnergyCostResponseResponseBody,
        FuelEnergyDriverReportDataObjectResponseBody,
        FuelEnergyDriverReportObjectResponseBody,
        FuelEnergyGetFuelEnergyDriverReportsBadGatewayErrorResponseBody,
        FuelEnergyGetFuelEnergyDriverReportsGatewayTimeoutErrorResponseBody,
        FuelEnergyGetFuelEnergyDriverReportsInternalServerErrorResponseBody,
        FuelEnergyGetFuelEnergyDriverReportsMethodNotAllowedErrorResponseBody,
        FuelEnergyGetFuelEnergyDriverReportsNotFoundErrorResponseBody,
        FuelEnergyGetFuelEnergyDriverReportsNotImplementedErrorResponseBody,
        FuelEnergyGetFuelEnergyDriverReportsResponseBody,
        FuelEnergyGetFuelEnergyDriverReportsServiceUnavailableErrorResponseBody,
        FuelEnergyGetFuelEnergyDriverReportsTooManyRequestsErrorResponseBody,
        FuelEnergyGetFuelEnergyDriverReportsUnauthorizedErrorResponseBody,
        FuelEnergyGetFuelEnergyVehicleReportsBadGatewayErrorResponseBody,
        FuelEnergyGetFuelEnergyVehicleReportsGatewayTimeoutErrorResponseBody,
        FuelEnergyGetFuelEnergyVehicleReportsInternalServerErrorResponseBody,
        FuelEnergyGetFuelEnergyVehicleReportsMethodNotAllowedErrorResponseBody,
        FuelEnergyGetFuelEnergyVehicleReportsNotFoundErrorResponseBody,
        FuelEnergyGetFuelEnergyVehicleReportsNotImplementedErrorResponseBody,
        FuelEnergyGetFuelEnergyVehicleReportsResponseBody,
        FuelEnergyGetFuelEnergyVehicleReportsServiceUnavailableErrorResponseBody,
        FuelEnergyGetFuelEnergyVehicleReportsTooManyRequestsErrorResponseBody,
        FuelEnergyGetFuelEnergyVehicleReportsUnauthorizedErrorResponseBody,
        FuelEnergyVehicleObjectResponseBody,
        FuelEnergyVehicleObjectResponseBodyEnergyType,
        FuelEnergyVehicleReportDataObjectResponseBody,
        FuelEnergyVehicleReportObjectResponseBody,
        FuelLevelPercentageResponseBody,
        FuelLevelTriggerDetailsObjectRequestBody,
        FuelLevelTriggerDetailsObjectRequestBodyOperation,
        FuelLevelTriggerDetailsObjectResponseBody,
        FuelLevelTriggerDetailsObjectResponseBodyOperation,
        FuelPurchasePostFuelPurchaseBadGatewayErrorResponseBody,
        FuelPurchasePostFuelPurchaseGatewayTimeoutErrorResponseBody,
        FuelPurchasePostFuelPurchaseInternalServerErrorResponseBody,
        FuelPurchasePostFuelPurchaseMethodNotAllowedErrorResponseBody,
        FuelPurchasePostFuelPurchaseNotFoundErrorResponseBody,
        FuelPurchasePostFuelPurchaseNotImplementedErrorResponseBody,
        FuelPurchasePostFuelPurchaseResponseBody,
        FuelPurchasePostFuelPurchaseServiceUnavailableErrorResponseBody,
        FuelPurchasePostFuelPurchaseTooManyRequestsErrorResponseBody,
        FuelPurchasePostFuelPurchaseUnauthorizedErrorResponseBody,
        FuelRemainingResponseBody,
        FuelVolumeResponseBody,
        FuelVolumeResponseBodyUnit,
        FunctionCodePackageResponseBody,
        FunctionCodePackageResponseBodyStatus,
        FunctionConfigResponseBody,
        FunctionConfigResponseBodyParams,
        FunctionConfigResponseBodySecrets,
        FunctionEffectsResponseBody,
        FunctionScheduleEntryRequestBody,
        FunctionScheduleEntryResponseBody,
        FunctionScheduleRequestBody,
        FunctionScheduleResponseBody,
        FunctionsCreateFunctionBadGatewayErrorResponseBody,
        FunctionsCreateFunctionGatewayTimeoutErrorResponseBody,
        FunctionsCreateFunctionInternalServerErrorResponseBody,
        FunctionsCreateFunctionMethodNotAllowedErrorResponseBody,
        FunctionsCreateFunctionNotFoundErrorResponseBody,
        FunctionsCreateFunctionNotImplementedErrorResponseBody,
        FunctionsCreateFunctionResponseBody,
        FunctionsCreateFunctionServiceUnavailableErrorResponseBody,
        FunctionsCreateFunctionTooManyRequestsErrorResponseBody,
        FunctionsCreateFunctionUnauthorizedErrorResponseBody,
        FunctionsDeployFunctionBadGatewayErrorResponseBody,
        FunctionsDeployFunctionGatewayTimeoutErrorResponseBody,
        FunctionsDeployFunctionInternalServerErrorResponseBody,
        FunctionsDeployFunctionMethodNotAllowedErrorResponseBody,
        FunctionsDeployFunctionNotFoundErrorResponseBody,
        FunctionsDeployFunctionNotImplementedErrorResponseBody,
        FunctionsDeployFunctionResponseBody,
        FunctionsDeployFunctionServiceUnavailableErrorResponseBody,
        FunctionsDeployFunctionTooManyRequestsErrorResponseBody,
        FunctionsDeployFunctionUnauthorizedErrorResponseBody,
        FunctionsGetFunctionBadGatewayErrorResponseBody,
        FunctionsGetFunctionGatewayTimeoutErrorResponseBody,
        FunctionsGetFunctionInternalServerErrorResponseBody,
        FunctionsGetFunctionMethodNotAllowedErrorResponseBody,
        FunctionsGetFunctionNotFoundErrorResponseBody,
        FunctionsGetFunctionNotImplementedErrorResponseBody,
        FunctionsGetFunctionResponseBody,
        FunctionsGetFunctionServiceUnavailableErrorResponseBody,
        FunctionsGetFunctionTooManyRequestsErrorResponseBody,
        FunctionsGetFunctionUnauthorizedErrorResponseBody,
        FunctionsPatchFunctionBadGatewayErrorResponseBody,
        FunctionsPatchFunctionGatewayTimeoutErrorResponseBody,
        FunctionsPatchFunctionInternalServerErrorResponseBody,
        FunctionsPatchFunctionMethodNotAllowedErrorResponseBody,
        FunctionsPatchFunctionNotFoundErrorResponseBody,
        FunctionsPatchFunctionNotImplementedErrorResponseBody,
        FunctionsPatchFunctionResponseBody,
        FunctionsPatchFunctionServiceUnavailableErrorResponseBody,
        FunctionsPatchFunctionTooManyRequestsErrorResponseBody,
        FunctionsPatchFunctionUnauthorizedErrorResponseBody,
        FunctionsStartFunctionRunBadGatewayErrorResponseBody,
        FunctionsStartFunctionRunGatewayTimeoutErrorResponseBody,
        FunctionsStartFunctionRunInternalServerErrorResponseBody,
        FunctionsStartFunctionRunMethodNotAllowedErrorResponseBody,
        FunctionsStartFunctionRunNotFoundErrorResponseBody,
        FunctionsStartFunctionRunNotImplementedErrorResponseBody,
        FunctionsStartFunctionRunResponseBody,
        FunctionsStartFunctionRunServiceUnavailableErrorResponseBody,
        FunctionsStartFunctionRunTooManyRequestsErrorResponseBody,
        FunctionsStartFunctionRunUnauthorizedErrorResponseBody,
        GaseousFuelCostObjectResponseBody,
        GaseousFuelCostObjectResponseBodyCurrency,
        GatewayAssetResponseObjectResponseBody,
        GatewayDetailsResponseResponseBody,
        GatewayDetailsResponseResponseBodyGatewayBatteryState,
        GatewayDisconnectedDetailsObjectRequestBody,
        GatewayDisconnectedDetailsObjectResponseBody,
        GatewayDisconnectedResponseBody,
        GatewayResponseObjectResponseBody,
        GatewayResponseObjectResponseBodyModel,
        GatewayTiny,
        GatewayUnpluggedTriggerDetailsObjectRequestBody,
        GatewayUnpluggedTriggerDetailsObjectResponseBody,
        GatewayWithVehicleTinyResponseResponseBody,
        GatewayWithVehicleTinyResponseResponseBodyModel,
        GatewaysDeleteGatewayBadGatewayErrorResponseBody,
        GatewaysDeleteGatewayGatewayTimeoutErrorResponseBody,
        GatewaysDeleteGatewayInternalServerErrorResponseBody,
        GatewaysDeleteGatewayMethodNotAllowedErrorResponseBody,
        GatewaysDeleteGatewayNotFoundErrorResponseBody,
        GatewaysDeleteGatewayNotImplementedErrorResponseBody,
        GatewaysDeleteGatewayServiceUnavailableErrorResponseBody,
        GatewaysDeleteGatewayTooManyRequestsErrorResponseBody,
        GatewaysDeleteGatewayUnauthorizedErrorResponseBody,
        GatewaysGetGatewaysBadGatewayErrorResponseBody,
        GatewaysGetGatewaysGatewayTimeoutErrorResponseBody,
        GatewaysGetGatewaysInternalServerErrorResponseBody,
        GatewaysGetGatewaysMethodNotAllowedErrorResponseBody,
        GatewaysGetGatewaysNotFoundErrorResponseBody,
        GatewaysGetGatewaysNotImplementedErrorResponseBody,
        GatewaysGetGatewaysResponseBody,
        GatewaysGetGatewaysServiceUnavailableErrorResponseBody,
        GatewaysGetGatewaysTooManyRequestsErrorResponseBody,
        GatewaysGetGatewaysUnauthorizedErrorResponseBody,
        GatewaysPostGatewayBadGatewayErrorResponseBody,
        GatewaysPostGatewayGatewayTimeoutErrorResponseBody,
        GatewaysPostGatewayInternalServerErrorResponseBody,
        GatewaysPostGatewayMethodNotAllowedErrorResponseBody,
        GatewaysPostGatewayNotFoundErrorResponseBody,
        GatewaysPostGatewayNotImplementedErrorResponseBody,
        GatewaysPostGatewayResponseBody,
        GatewaysPostGatewayServiceUnavailableErrorResponseBody,
        GatewaysPostGatewayTooManyRequestsErrorResponseBody,
        GatewaysPostGatewayUnauthorizedErrorResponseBody,
        GeofenceEntryTriggerDetailsObjectRequestBody,
        GeofenceEntryTriggerDetailsObjectResponseBody,
        GeofenceExitTriggerDetailsObjectRequestBody,
        GeofenceExitTriggerDetailsObjectResponseBody,
        GeofenceResponseResponseBody,
        GetAttributesByEntityTypeResponse,
        GetDocumentTypeResponseObjectResponseBody,
        GetDriverTrailerAssignmentsResponseBodyResponseBody,
        GetFunctionDetailResponseBody,
        GetMediaRetrievalObjectResponseBody,
        GetReportRunsDataObjectResponseBody,
        GetReportRunsDataObjectResponseBodyStatus,
        GetResponseWorkflowConfigurationObjectResponseBody,
        GetWorkflowIncidentResponseObjectResponseBody,
        GoaAddressTinyResponseResponseBody,
        GoaAttributeTiny,
        GoaAttributeTinyRequestBody,
        GoaAttributeTinyResponseBody,
        GoaDocumentTinyResponseResponseBody,
        GoaDocumentTypeTinyResponseResponseBody,
        GoaDriverTinyResponseResponseBody,
        GoaFormTinyResponseResponseBody,
        GoaGatewayTinyResponseResponseBody,
        GoaGatewayTinyResponseResponseBodyModel,
        GoaIssueTinyResponseResponseBody,
        GoaPaginationResponseResponseBody,
        GoaPaginationWithTokensResponseResponseBody,
        GoaRouteStopTinyResponseResponseBody,
        GoaRouteTinyResponseResponseBody,
        GoaTagTinyResponseRequestBody,
        GoaTagTinyResponseResponseBody,
        GoaTrailerTinyResponseResponseBody,
        GoaVehicleTinyResponseResponseBody,
        GpsSignalLossDetailsObjectRequestBody,
        GpsSignalLossDetailsObjectResponseBody,
        GpsSignalLossResponseBody,
        GreenBandDrivingDurationMs,
        GrossVehicleWeight,
        GrossVehicleWeightUnit,
        HarshAccelSensitivityGForceSettingsObjectResponseBody,
        HarshAccelSensitivityV2SettingsObjectResponseBody,
        HarshAccelSensitivityV2SettingsObjectResponseBodyHeavyDuty,
        HarshAccelSensitivityV2SettingsObjectResponseBodyLightDuty,
        HarshAccelSensitivityV2SettingsObjectResponseBodyPassenger,
        HarshBrakeSensitivityGForceSettingsObjectResponseBody,
        HarshBrakeSensitivityV2SettingsObjectResponseBody,
        HarshBrakeSensitivityV2SettingsObjectResponseBodyHeavyDuty,
        HarshBrakeSensitivityV2SettingsObjectResponseBodyLightDuty,
        HarshBrakeSensitivityV2SettingsObjectResponseBodyPassenger,
        HarshEventDataResponseBody,
        HarshEventSensitivitySettingsObjectResponseBody,
        HarshEventSensitivityV2SettingsObjectResponseBody,
        HarshEventTriggerDetailsObjectRequestBody,
        HarshEventTriggerDetailsObjectRequestBodyTypesItem,
        HarshEventTriggerDetailsObjectResponseBody,
        HarshEventTriggerDetailsObjectResponseBodyTypesItem,
        HarshTurnSensitivityGForceSettingsObjectResponseBody,
        HarshTurnSensitivityV2SettingsObjectResponseBody,
        HarshTurnSensitivityV2SettingsObjectResponseBodyHeavyDuty,
        HarshTurnSensitivityV2SettingsObjectResponseBodyLightDuty,
        HarshTurnSensitivityV2SettingsObjectResponseBodyPassenger,
        HealthDetailsResponseResponseBody,
        HealthReasonResponseResponseBody,
        HealthReasonResponseResponseBodyHealthReasonCode,
        HealthResponseResponseBody,
        HealthResponseResponseBodyHealthStatus,
        HealthResponseResponseBodyPrimaryHealthReason,
        HealthResponseResponseBodyRecommendedAction,
        HighTorqueMs,
        HosBreak,
        HosClocks,
        HosClocksForDriver,
        HosClocksForDrivers,
        HosClocksResponse,
        HosCycle,
        HosDailyLogsGetHosDailyLogsBadGatewayErrorResponseBody,
        HosDailyLogsGetHosDailyLogsGatewayTimeoutErrorResponseBody,
        HosDailyLogsGetHosDailyLogsInternalServerErrorResponseBody,
        HosDailyLogsGetHosDailyLogsMethodNotAllowedErrorResponseBody,
        HosDailyLogsGetHosDailyLogsNotFoundErrorResponseBody,
        HosDailyLogsGetHosDailyLogsNotImplementedErrorResponseBody,
        HosDailyLogsGetHosDailyLogsResponseBody,
        HosDailyLogsGetHosDailyLogsServiceUnavailableErrorResponseBody,
        HosDailyLogsGetHosDailyLogsTooManyRequestsErrorResponseBody,
        HosDailyLogsGetHosDailyLogsUnauthorizedErrorResponseBody,
        HosDailyLogsObjectResponseBody,
        HosDailyLogsUpdateShippingDocsBadGatewayErrorResponseBody,
        HosDailyLogsUpdateShippingDocsGatewayTimeoutErrorResponseBody,
        HosDailyLogsUpdateShippingDocsInternalServerErrorResponseBody,
        HosDailyLogsUpdateShippingDocsMethodNotAllowedErrorResponseBody,
        HosDailyLogsUpdateShippingDocsNotFoundErrorResponseBody,
        HosDailyLogsUpdateShippingDocsNotImplementedErrorResponseBody,
        HosDailyLogsUpdateShippingDocsResponseBody,
        HosDailyLogsUpdateShippingDocsServiceUnavailableErrorResponseBody,
        HosDailyLogsUpdateShippingDocsTooManyRequestsErrorResponseBody,
        HosDailyLogsUpdateShippingDocsUnauthorizedErrorResponseBody,
        HosDrive,
        HosDriversEldEventObjectResponseBody,
        HosDriversEldEventObjectResponseBodyDriverActivationStatus,
        HosEldEventLocationObjectResponseBody,
        HosEldEventObjectResponseBody,
        HosEldEventObjectResponseBodyMalfunctionDiagnosticCode,
        HosEldEventRemarkObjectResponseBody,
        HosEldEventsGetHosEldEventsBadGatewayErrorResponseBody,
        HosEldEventsGetHosEldEventsGatewayTimeoutErrorResponseBody,
        HosEldEventsGetHosEldEventsInternalServerErrorResponseBody,
        HosEldEventsGetHosEldEventsMethodNotAllowedErrorResponseBody,
        HosEldEventsGetHosEldEventsNotFoundErrorResponseBody,
        HosEldEventsGetHosEldEventsNotImplementedErrorResponseBody,
        HosEldEventsGetHosEldEventsResponseBody,
        HosEldEventsGetHosEldEventsServiceUnavailableErrorResponseBody,
        HosEldEventsGetHosEldEventsTooManyRequestsErrorResponseBody,
        HosEldEventsGetHosEldEventsUnauthorizedErrorResponseBody,
        HosLogEntry,
        HosLogEntryHosStatusType,
        HosLogLocation,
        HosLogsForDriver,
        HosLogsForDrivers,
        HosLogsList,
        HosLogsResponse,
        HosShift,
        HosViolationDataResponseBody,
        HosViolationDayObjectResponseBody,
        HosViolationObjectResponseBody,
        HosViolationObjectResponseBodyType,
        HosViolationTriggerDetailsObjectRequestBody,
        HosViolationTriggerDetailsObjectRequestBodyViolation,
        HosViolationTriggerDetailsObjectResponseBody,
        HosViolationTriggerDetailsObjectResponseBodyViolation,
        HosViolations,
        HosViolationsGetHosViolationsBadGatewayErrorResponseBody,
        HosViolationsGetHosViolationsGatewayTimeoutErrorResponseBody,
        HosViolationsGetHosViolationsInternalServerErrorResponseBody,
        HosViolationsGetHosViolationsMethodNotAllowedErrorResponseBody,
        HosViolationsGetHosViolationsNotFoundErrorResponseBody,
        HosViolationsGetHosViolationsNotImplementedErrorResponseBody,
        HosViolationsGetHosViolationsResponseBody,
        HosViolationsGetHosViolationsServiceUnavailableErrorResponseBody,
        HosViolationsGetHosViolationsTooManyRequestsErrorResponseBody,
        HosViolationsGetHosViolationsUnauthorizedErrorResponseBody,
        HosViolationsObjectResponseBody,
        HubCapacitiesListHubCapacitiesBadGatewayErrorResponseBody,
        HubCapacitiesListHubCapacitiesGatewayTimeoutErrorResponseBody,
        HubCapacitiesListHubCapacitiesInternalServerErrorResponseBody,
        HubCapacitiesListHubCapacitiesMethodNotAllowedErrorResponseBody,
        HubCapacitiesListHubCapacitiesNotFoundErrorResponseBody,
        HubCapacitiesListHubCapacitiesNotImplementedErrorResponseBody,
        HubCapacitiesListHubCapacitiesResponseBody,
        HubCapacitiesListHubCapacitiesServiceUnavailableErrorResponseBody,
        HubCapacitiesListHubCapacitiesTooManyRequestsErrorResponseBody,
        HubCapacitiesListHubCapacitiesUnauthorizedErrorResponseBody,
        HubCapacityObjectResponseBody,
        HubCustomPropertiesListHubCustomPropertiesBadGatewayErrorResponseBody,
        HubCustomPropertiesListHubCustomPropertiesGatewayTimeoutErrorResponseBody,
        HubCustomPropertiesListHubCustomPropertiesInternalServerErrorResponseBody,
        HubCustomPropertiesListHubCustomPropertiesMethodNotAllowedErrorResponseBody,
        HubCustomPropertiesListHubCustomPropertiesNotFoundErrorResponseBody,
        HubCustomPropertiesListHubCustomPropertiesNotImplementedErrorResponseBody,
        HubCustomPropertiesListHubCustomPropertiesResponseBody,
        HubCustomPropertiesListHubCustomPropertiesServiceUnavailableErrorResponseBody,
        HubCustomPropertiesListHubCustomPropertiesTooManyRequestsErrorResponseBody,
        HubCustomPropertiesListHubCustomPropertiesUnauthorizedErrorResponseBody,
        HubCustomPropertyObjectResponseBody,
        HubLocationCreatedObjectResponseBody,
        HubLocationInputObjectRequestBody,
        HubLocationObjectResponseBody,
        HubLocationServiceWindowInputRequestBody,
        HubLocationUpdatedObjectResponseBody,
        HubLocationsCreateHubLocationsBadGatewayErrorResponseBody,
        HubLocationsCreateHubLocationsGatewayTimeoutErrorResponseBody,
        HubLocationsCreateHubLocationsInternalServerErrorResponseBody,
        HubLocationsCreateHubLocationsMethodNotAllowedErrorResponseBody,
        HubLocationsCreateHubLocationsNotFoundErrorResponseBody,
        HubLocationsCreateHubLocationsNotImplementedErrorResponseBody,
        HubLocationsCreateHubLocationsResponseBody,
        HubLocationsCreateHubLocationsServiceUnavailableErrorResponseBody,
        HubLocationsCreateHubLocationsTooManyRequestsErrorResponseBody,
        HubLocationsCreateHubLocationsUnauthorizedErrorResponseBody,
        HubLocationsListHubLocationsBadGatewayErrorResponseBody,
        HubLocationsListHubLocationsGatewayTimeoutErrorResponseBody,
        HubLocationsListHubLocationsInternalServerErrorResponseBody,
        HubLocationsListHubLocationsMethodNotAllowedErrorResponseBody,
        HubLocationsListHubLocationsNotFoundErrorResponseBody,
        HubLocationsListHubLocationsNotImplementedErrorResponseBody,
        HubLocationsListHubLocationsResponseBody,
        HubLocationsListHubLocationsServiceUnavailableErrorResponseBody,
        HubLocationsListHubLocationsTooManyRequestsErrorResponseBody,
        HubLocationsListHubLocationsUnauthorizedErrorResponseBody,
        HubLocationsUpdateHubLocationBadGatewayErrorResponseBody,
        HubLocationsUpdateHubLocationGatewayTimeoutErrorResponseBody,
        HubLocationsUpdateHubLocationInternalServerErrorResponseBody,
        HubLocationsUpdateHubLocationMethodNotAllowedErrorResponseBody,
        HubLocationsUpdateHubLocationNotFoundErrorResponseBody,
        HubLocationsUpdateHubLocationNotImplementedErrorResponseBody,
        HubLocationsUpdateHubLocationResponseBody,
        HubLocationsUpdateHubLocationServiceUnavailableErrorResponseBody,
        HubLocationsUpdateHubLocationTooManyRequestsErrorResponseBody,
        HubLocationsUpdateHubLocationUnauthorizedErrorResponseBody,
        HubObjectResponseBody,
        HubPlanRoutesListHubPlanRoutesBadGatewayErrorResponseBody,
        HubPlanRoutesListHubPlanRoutesGatewayTimeoutErrorResponseBody,
        HubPlanRoutesListHubPlanRoutesInternalServerErrorResponseBody,
        HubPlanRoutesListHubPlanRoutesMethodNotAllowedErrorResponseBody,
        HubPlanRoutesListHubPlanRoutesNotFoundErrorResponseBody,
        HubPlanRoutesListHubPlanRoutesNotImplementedErrorResponseBody,
        HubPlanRoutesListHubPlanRoutesResponseBody,
        HubPlanRoutesListHubPlanRoutesServiceUnavailableErrorResponseBody,
        HubPlanRoutesListHubPlanRoutesTooManyRequestsErrorResponseBody,
        HubPlanRoutesListHubPlanRoutesUnauthorizedErrorResponseBody,
        HubPlansCreateHubPlanBadGatewayErrorResponseBody,
        HubPlansCreateHubPlanGatewayTimeoutErrorResponseBody,
        HubPlansCreateHubPlanInternalServerErrorResponseBody,
        HubPlansCreateHubPlanMethodNotAllowedErrorResponseBody,
        HubPlansCreateHubPlanNotFoundErrorResponseBody,
        HubPlansCreateHubPlanNotImplementedErrorResponseBody,
        HubPlansCreateHubPlanResponseBody,
        HubPlansCreateHubPlanServiceUnavailableErrorResponseBody,
        HubPlansCreateHubPlanTooManyRequestsErrorResponseBody,
        HubPlansCreateHubPlanUnauthorizedErrorResponseBody,
        HubPlansListHubPlansBadGatewayErrorResponseBody,
        HubPlansListHubPlansGatewayTimeoutErrorResponseBody,
        HubPlansListHubPlansInternalServerErrorResponseBody,
        HubPlansListHubPlansMethodNotAllowedErrorResponseBody,
        HubPlansListHubPlansNotFoundErrorResponseBody,
        HubPlansListHubPlansNotImplementedErrorResponseBody,
        HubPlansListHubPlansResponseBody,
        HubPlansListHubPlansServiceUnavailableErrorResponseBody,
        HubPlansListHubPlansTooManyRequestsErrorResponseBody,
        HubPlansListHubPlansUnauthorizedErrorResponseBody,
        HubSkillObjectResponseBody,
        HubSkillsListHubSkillsBadGatewayErrorResponseBody,
        HubSkillsListHubSkillsGatewayTimeoutErrorResponseBody,
        HubSkillsListHubSkillsInternalServerErrorResponseBody,
        HubSkillsListHubSkillsMethodNotAllowedErrorResponseBody,
        HubSkillsListHubSkillsNotFoundErrorResponseBody,
        HubSkillsListHubSkillsNotImplementedErrorResponseBody,
        HubSkillsListHubSkillsResponseBody,
        HubSkillsListHubSkillsServiceUnavailableErrorResponseBody,
        HubSkillsListHubSkillsTooManyRequestsErrorResponseBody,
        HubSkillsListHubSkillsUnauthorizedErrorResponseBody,
        HubsListHubsBadGatewayErrorResponseBody,
        HubsListHubsGatewayTimeoutErrorResponseBody,
        HubsListHubsInternalServerErrorResponseBody,
        HubsListHubsMethodNotAllowedErrorResponseBody,
        HubsListHubsNotFoundErrorResponseBody,
        HubsListHubsNotImplementedErrorResponseBody,
        HubsListHubsResponseBody,
        HubsListHubsServiceUnavailableErrorResponseBody,
        HubsListHubsTooManyRequestsErrorResponseBody,
        HubsListHubsUnauthorizedErrorResponseBody,
        IdleTimeDurationMs,
        IdlingEventAddressObjectResponseBody,
        IdlingEventAddressObjectResponseBodyAddressTypesItem,
        IdlingEventAssetObjectResponseBody,
        IdlingEventObjectV20251023ResponseBody,
        IdlingEventObjectV20251023ResponseBodyPtoState,
        IdlingEventOperatorObjectResponseBody,
        IdlingReportEventAddressResponseBody,
        IdlingReportEventResponseBody,
        IdlingReportsGetVehicleIdlingReportsBadGatewayErrorResponseBody,
        IdlingReportsGetVehicleIdlingReportsGatewayTimeoutErrorResponseBody,
        IdlingReportsGetVehicleIdlingReportsInternalServerErrorResponseBody,
        IdlingReportsGetVehicleIdlingReportsMethodNotAllowedErrorResponseBody,
        IdlingReportsGetVehicleIdlingReportsNotFoundErrorResponseBody,
        IdlingReportsGetVehicleIdlingReportsNotImplementedErrorResponseBody,
        IdlingReportsGetVehicleIdlingReportsResponseBody,
        IdlingReportsGetVehicleIdlingReportsServiceUnavailableErrorResponseBody,
        IdlingReportsGetVehicleIdlingReportsTooManyRequestsErrorResponseBody,
        IdlingReportsGetVehicleIdlingReportsUnauthorizedErrorResponseBody,
        IftaCreateIftaDetailJobBadGatewayErrorResponseBody,
        IftaCreateIftaDetailJobGatewayTimeoutErrorResponseBody,
        IftaCreateIftaDetailJobInternalServerErrorResponseBody,
        IftaCreateIftaDetailJobMethodNotAllowedErrorResponseBody,
        IftaCreateIftaDetailJobNotFoundErrorResponseBody,
        IftaCreateIftaDetailJobNotImplementedErrorResponseBody,
        IftaCreateIftaDetailJobResponseBody,
        IftaCreateIftaDetailJobServiceUnavailableErrorResponseBody,
        IftaCreateIftaDetailJobTooManyRequestsErrorResponseBody,
        IftaCreateIftaDetailJobUnauthorizedErrorResponseBody,
        IftaDetailJobArgsResponseBody,
        IftaDetailJobOutputResponseBody,
        IftaDetailJobResponseBody,
        IftaDetailJobResponseBodyJobStatus,
        IftaGetIftaDetailJobBadGatewayErrorResponseBody,
        IftaGetIftaDetailJobGatewayTimeoutErrorResponseBody,
        IftaGetIftaDetailJobInternalServerErrorResponseBody,
        IftaGetIftaDetailJobMethodNotAllowedErrorResponseBody,
        IftaGetIftaDetailJobNotFoundErrorResponseBody,
        IftaGetIftaDetailJobNotImplementedErrorResponseBody,
        IftaGetIftaDetailJobResponseBody,
        IftaGetIftaDetailJobServiceUnavailableErrorResponseBody,
        IftaGetIftaDetailJobTooManyRequestsErrorResponseBody,
        IftaGetIftaDetailJobUnauthorizedErrorResponseBody,
        IftaGetIftaJurisdictionReportsBadGatewayErrorResponseBody,
        IftaGetIftaJurisdictionReportsGatewayTimeoutErrorResponseBody,
        IftaGetIftaJurisdictionReportsInternalServerErrorResponseBody,
        IftaGetIftaJurisdictionReportsMethodNotAllowedErrorResponseBody,
        IftaGetIftaJurisdictionReportsNotFoundErrorResponseBody,
        IftaGetIftaJurisdictionReportsNotImplementedErrorResponseBody,
        IftaGetIftaJurisdictionReportsResponseBody,
        IftaGetIftaJurisdictionReportsServiceUnavailableErrorResponseBody,
        IftaGetIftaJurisdictionReportsTooManyRequestsErrorResponseBody,
        IftaGetIftaJurisdictionReportsUnauthorizedErrorResponseBody,
        IftaGetIftaVehicleReportsBadGatewayErrorResponseBody,
        IftaGetIftaVehicleReportsGatewayTimeoutErrorResponseBody,
        IftaGetIftaVehicleReportsInternalServerErrorResponseBody,
        IftaGetIftaVehicleReportsMethodNotAllowedErrorResponseBody,
        IftaGetIftaVehicleReportsNotFoundErrorResponseBody,
        IftaGetIftaVehicleReportsNotImplementedErrorResponseBody,
        IftaGetIftaVehicleReportsResponseBody,
        IftaGetIftaVehicleReportsServiceUnavailableErrorResponseBody,
        IftaGetIftaVehicleReportsTooManyRequestsErrorResponseBody,
        IftaGetIftaVehicleReportsUnauthorizedErrorResponseBody,
        IftaJurisdictionReportDataObjectResponseBody,
        IftaJurisdictionSummaryObjectResponseBody,
        IftaReportTroubleshootingObjectResponseBody,
        IftaVehicleReportDataObjectResponseBody,
        IftaVehicleReportObjectResponseBody,
        InAppNotificationOptionsObjectRequestBody,
        InAppNotificationOptionsObjectResponseBody,
        InactivityResponseBody,
        InattentiveDrivingDetectionAlertSettingsObjectResponseBody,
        InattentiveDrivingDetectionAlertSettingsObjectResponseBodySeverity,
        IndustrialAssetObjectResponseBody,
        InlineResponse200,
        InlineResponse2001,
        InlineResponse2002,
        InlineResponse2003,
        InlineResponse2004,
        InlineResponse2005,
        InlineResponse2006,
        InlineResponse2007,
        InlineResponse2008,
        InlineResponse2009,
        InsideGeofenceDataResponseBody,
        InsideGeofenceTriggerDetailsObjectRequestBody,
        InsideGeofenceTriggerDetailsObjectResponseBody,
        InvoiceScanFileRequestBody,
        IssueCreatedResponseBody,
        IssueResponseObjectResponseBody,
        IssueResponseObjectResponseBodyPriority,
        IssueResponseObjectResponseBodyStatus,
        IssueSourceObjectResponseBody,
        IssueSourceObjectResponseBodyType,
        IssuesGetIssuesBadGatewayErrorResponseBody,
        IssuesGetIssuesGatewayTimeoutErrorResponseBody,
        IssuesGetIssuesInternalServerErrorResponseBody,
        IssuesGetIssuesMethodNotAllowedErrorResponseBody,
        IssuesGetIssuesNotFoundErrorResponseBody,
        IssuesGetIssuesNotImplementedErrorResponseBody,
        IssuesGetIssuesResponseBody,
        IssuesGetIssuesServiceUnavailableErrorResponseBody,
        IssuesGetIssuesStreamBadGatewayErrorResponseBody,
        IssuesGetIssuesStreamGatewayTimeoutErrorResponseBody,
        IssuesGetIssuesStreamInternalServerErrorResponseBody,
        IssuesGetIssuesStreamMethodNotAllowedErrorResponseBody,
        IssuesGetIssuesStreamNotFoundErrorResponseBody,
        IssuesGetIssuesStreamNotImplementedErrorResponseBody,
        IssuesGetIssuesStreamResponseBody,
        IssuesGetIssuesStreamServiceUnavailableErrorResponseBody,
        IssuesGetIssuesStreamTooManyRequestsErrorResponseBody,
        IssuesGetIssuesStreamUnauthorizedErrorResponseBody,
        IssuesGetIssuesTooManyRequestsErrorResponseBody,
        IssuesGetIssuesUnauthorizedErrorResponseBody,
        IssuesPatchIssueBadGatewayErrorResponseBody,
        IssuesPatchIssueGatewayTimeoutErrorResponseBody,
        IssuesPatchIssueInternalServerErrorResponseBody,
        IssuesPatchIssueMethodNotAllowedErrorResponseBody,
        IssuesPatchIssueNotFoundErrorResponseBody,
        IssuesPatchIssueNotImplementedErrorResponseBody,
        IssuesPatchIssueResponseBody,
        IssuesPatchIssueServiceUnavailableErrorResponseBody,
        IssuesPatchIssueTooManyRequestsErrorResponseBody,
        IssuesPatchIssueUnauthorizedErrorResponseBody,
        J1939D1StatusDataPoint,
        J1939D1StatusDataPointValue,
        JammingDetectedResponseBody,
        JobLocationResponseObjectResponseBody,
        JobResponseObjectResponseBody,
        JobResponseObjectResponseBodyStatus,
        JobsCreateJobBadGatewayErrorResponseBody,
        JobsCreateJobGatewayTimeoutErrorResponseBody,
        JobsCreateJobInternalServerErrorResponseBody,
        JobsCreateJobMethodNotAllowedErrorResponseBody,
        JobsCreateJobNotFoundErrorResponseBody,
        JobsCreateJobNotImplementedErrorResponseBody,
        JobsCreateJobResponseBody,
        JobsCreateJobServiceUnavailableErrorResponseBody,
        JobsCreateJobTooManyRequestsErrorResponseBody,
        JobsCreateJobUnauthorizedErrorResponseBody,
        JobsDeleteJobBadGatewayErrorResponseBody,
        JobsDeleteJobGatewayTimeoutErrorResponseBody,
        JobsDeleteJobInternalServerErrorResponseBody,
        JobsDeleteJobMethodNotAllowedErrorResponseBody,
        JobsDeleteJobNotFoundErrorResponseBody,
        JobsDeleteJobNotImplementedErrorResponseBody,
        JobsDeleteJobResponseBody,
        JobsDeleteJobServiceUnavailableErrorResponseBody,
        JobsDeleteJobTooManyRequestsErrorResponseBody,
        JobsDeleteJobUnauthorizedErrorResponseBody,
        JobsGetJobsBadGatewayErrorResponseBody,
        JobsGetJobsGatewayTimeoutErrorResponseBody,
        JobsGetJobsInternalServerErrorResponseBody,
        JobsGetJobsMethodNotAllowedErrorResponseBody,
        JobsGetJobsNotFoundErrorResponseBody,
        JobsGetJobsNotImplementedErrorResponseBody,
        JobsGetJobsResponseBody,
        JobsGetJobsServiceUnavailableErrorResponseBody,
        JobsGetJobsTooManyRequestsErrorResponseBody,
        JobsGetJobsUnauthorizedErrorResponseBody,
        JobsPatchJobBadGatewayErrorResponseBody,
        JobsPatchJobGatewayTimeoutErrorResponseBody,
        JobsPatchJobInternalServerErrorResponseBody,
        JobsPatchJobMethodNotAllowedErrorResponseBody,
        JobsPatchJobNotFoundErrorResponseBody,
        JobsPatchJobNotImplementedErrorResponseBody,
        JobsPatchJobResponseBody,
        JobsPatchJobServiceUnavailableErrorResponseBody,
        JobsPatchJobTooManyRequestsErrorResponseBody,
        JobsPatchJobUnauthorizedErrorResponseBody,
        LastKnownLocationResponseResponseBody,
        Latitude,
        ListAddressesResponse,
        ListCarrierProposedAssignmentResponse,
        ListContactsResponse,
        ListDriversResponse,
        ListHubCapacitiesResponsePaginationResponseBody,
        ListHubCustomPropertiesResponsePaginationResponseBody,
        ListHubLocationsResponsePaginationResponseBody,
        ListHubPlanRoutesResponsePaginationResponseBody,
        ListHubPlansResponsePaginationResponseBody,
        ListHubSkillsResponsePaginationResponseBody,
        ListHubsResponsePaginationResponseBody,
        ListIndustrialAssetsResponse,
        ListTagsResponse,
        ListUploadedMediaObjectResponseBody,
        ListUserRolesResponse,
        ListUsersResponse,
        LiveSharingLinkFullResponseObjectResponseBody,
        LiveSharingLinkFullResponseObjectResponseBodyType,
        LiveSharingLinkResponseObjectResponseBody,
        LiveSharingLinksCreateLiveSharingLinkBadGatewayErrorResponseBody,
        LiveSharingLinksCreateLiveSharingLinkGatewayTimeoutErrorResponseBody,
        LiveSharingLinksCreateLiveSharingLinkInternalServerErrorResponseBody,
        LiveSharingLinksCreateLiveSharingLinkMethodNotAllowedErrorResponseBody,
        LiveSharingLinksCreateLiveSharingLinkNotFoundErrorResponseBody,
        LiveSharingLinksCreateLiveSharingLinkNotImplementedErrorResponseBody,
        LiveSharingLinksCreateLiveSharingLinkResponseBody,
        LiveSharingLinksCreateLiveSharingLinkServiceUnavailableErrorResponseBody,
        LiveSharingLinksCreateLiveSharingLinkTooManyRequestsErrorResponseBody,
        LiveSharingLinksCreateLiveSharingLinkUnauthorizedErrorResponseBody,
        LiveSharingLinksDeleteLiveSharingLinkBadGatewayErrorResponseBody,
        LiveSharingLinksDeleteLiveSharingLinkGatewayTimeoutErrorResponseBody,
        LiveSharingLinksDeleteLiveSharingLinkInternalServerErrorResponseBody,
        LiveSharingLinksDeleteLiveSharingLinkMethodNotAllowedErrorResponseBody,
        LiveSharingLinksDeleteLiveSharingLinkNotFoundErrorResponseBody,
        LiveSharingLinksDeleteLiveSharingLinkNotImplementedErrorResponseBody,
        LiveSharingLinksDeleteLiveSharingLinkServiceUnavailableErrorResponseBody,
        LiveSharingLinksDeleteLiveSharingLinkTooManyRequestsErrorResponseBody,
        LiveSharingLinksDeleteLiveSharingLinkUnauthorizedErrorResponseBody,
        LiveSharingLinksGetLiveSharingLinksBadGatewayErrorResponseBody,
        LiveSharingLinksGetLiveSharingLinksGatewayTimeoutErrorResponseBody,
        LiveSharingLinksGetLiveSharingLinksInternalServerErrorResponseBody,
        LiveSharingLinksGetLiveSharingLinksMethodNotAllowedErrorResponseBody,
        LiveSharingLinksGetLiveSharingLinksNotFoundErrorResponseBody,
        LiveSharingLinksGetLiveSharingLinksNotImplementedErrorResponseBody,
        LiveSharingLinksGetLiveSharingLinksResponseBody,
        LiveSharingLinksGetLiveSharingLinksServiceUnavailableErrorResponseBody,
        LiveSharingLinksGetLiveSharingLinksTooManyRequestsErrorResponseBody,
        LiveSharingLinksGetLiveSharingLinksUnauthorizedErrorResponseBody,
        LiveSharingLinksUpdateLiveSharingLinkBadGatewayErrorResponseBody,
        LiveSharingLinksUpdateLiveSharingLinkGatewayTimeoutErrorResponseBody,
        LiveSharingLinksUpdateLiveSharingLinkInternalServerErrorResponseBody,
        LiveSharingLinksUpdateLiveSharingLinkMethodNotAllowedErrorResponseBody,
        LiveSharingLinksUpdateLiveSharingLinkNotFoundErrorResponseBody,
        LiveSharingLinksUpdateLiveSharingLinkNotImplementedErrorResponseBody,
        LiveSharingLinksUpdateLiveSharingLinkResponseBody,
        LiveSharingLinksUpdateLiveSharingLinkServiceUnavailableErrorResponseBody,
        LiveSharingLinksUpdateLiveSharingLinkTooManyRequestsErrorResponseBody,
        LiveSharingLinksUpdateLiveSharingLinkUnauthorizedErrorResponseBody,
        Location,
        LocationAndSpeedGetLocationAndSpeedBadGatewayErrorResponseBody,
        LocationAndSpeedGetLocationAndSpeedGatewayTimeoutErrorResponseBody,
        LocationAndSpeedGetLocationAndSpeedInternalServerErrorResponseBody,
        LocationAndSpeedGetLocationAndSpeedMethodNotAllowedErrorResponseBody,
        LocationAndSpeedGetLocationAndSpeedNotFoundErrorResponseBody,
        LocationAndSpeedGetLocationAndSpeedNotImplementedErrorResponseBody,
        LocationAndSpeedGetLocationAndSpeedResponseBody,
        LocationAndSpeedGetLocationAndSpeedServiceUnavailableErrorResponseBody,
        LocationAndSpeedGetLocationAndSpeedTooManyRequestsErrorResponseBody,
        LocationAndSpeedGetLocationAndSpeedUnauthorizedErrorResponseBody,
        LocationAndSpeedResponseResponseBody,
        LocationDataPoint,
        LocationDataPointGpsLocation,
        LocationDataPointGpsLocationPlace,
        LocationObjectRequestBody,
        LocationObjectRequestBodyAddressTypesItem,
        LocationObjectResponseBody,
        LocationObjectResponseBodyAddressTypesItem,
        LocationResponseBody,
        LocationResponseResponseBody,
        LocationType,
        LogMetaDataObjectResponseBody,
        Longitude,
        MaintenanceVendorsListMaintenanceVendorsBadGatewayErrorResponseBody,
        MaintenanceVendorsListMaintenanceVendorsGatewayTimeoutErrorResponseBody,
        MaintenanceVendorsListMaintenanceVendorsInternalServerErrorResponseBody,
        MaintenanceVendorsListMaintenanceVendorsMethodNotAllowedErrorResponseBody,
        MaintenanceVendorsListMaintenanceVendorsNotFoundErrorResponseBody,
        MaintenanceVendorsListMaintenanceVendorsNotImplementedErrorResponseBody,
        MaintenanceVendorsListMaintenanceVendorsResponseBody,
        MaintenanceVendorsListMaintenanceVendorsServiceUnavailableErrorResponseBody,
        MaintenanceVendorsListMaintenanceVendorsTooManyRequestsErrorResponseBody,
        MaintenanceVendorsListMaintenanceVendorsUnauthorizedErrorResponseBody,
        MaintenanceVendorsListVendorCategoriesBadGatewayErrorResponseBody,
        MaintenanceVendorsListVendorCategoriesGatewayTimeoutErrorResponseBody,
        MaintenanceVendorsListVendorCategoriesInternalServerErrorResponseBody,
        MaintenanceVendorsListVendorCategoriesMethodNotAllowedErrorResponseBody,
        MaintenanceVendorsListVendorCategoriesNotFoundErrorResponseBody,
        MaintenanceVendorsListVendorCategoriesNotImplementedErrorResponseBody,
        MaintenanceVendorsListVendorCategoriesResponseBody,
        MaintenanceVendorsListVendorCategoriesServiceUnavailableErrorResponseBody,
        MaintenanceVendorsListVendorCategoriesTooManyRequestsErrorResponseBody,
        MaintenanceVendorsListVendorCategoriesUnauthorizedErrorResponseBody,
        MediaObjectResponseBody,
        MediaObjectResponseBodyCameraRole,
        MediaObjectResponseBodyInput,
        MediaObjectResponseBodyMediaType,
        MediaObjectResponseBodyStatus,
        MediaRetrievalGetMediaRetrievalBadGatewayErrorResponseBody,
        MediaRetrievalGetMediaRetrievalGatewayTimeoutErrorResponseBody,
        MediaRetrievalGetMediaRetrievalInternalServerErrorResponseBody,
        MediaRetrievalGetMediaRetrievalMethodNotAllowedErrorResponseBody,
        MediaRetrievalGetMediaRetrievalNotFoundErrorResponseBody,
        MediaRetrievalGetMediaRetrievalNotImplementedErrorResponseBody,
        MediaRetrievalGetMediaRetrievalResponseBody,
        MediaRetrievalGetMediaRetrievalServiceUnavailableErrorResponseBody,
        MediaRetrievalGetMediaRetrievalTooManyRequestsErrorResponseBody,
        MediaRetrievalGetMediaRetrievalUnauthorizedErrorResponseBody,
        MediaRetrievalListUploadedMediaBadGatewayErrorResponseBody,
        MediaRetrievalListUploadedMediaGatewayTimeoutErrorResponseBody,
        MediaRetrievalListUploadedMediaInternalServerErrorResponseBody,
        MediaRetrievalListUploadedMediaMethodNotAllowedErrorResponseBody,
        MediaRetrievalListUploadedMediaNotFoundErrorResponseBody,
        MediaRetrievalListUploadedMediaNotImplementedErrorResponseBody,
        MediaRetrievalListUploadedMediaResponseBody,
        MediaRetrievalListUploadedMediaServiceUnavailableErrorResponseBody,
        MediaRetrievalListUploadedMediaTooManyRequestsErrorResponseBody,
        MediaRetrievalListUploadedMediaUnauthorizedErrorResponseBody,
        MediaRetrievalPostMediaRetrievalBadGatewayErrorResponseBody,
        MediaRetrievalPostMediaRetrievalGatewayTimeoutErrorResponseBody,
        MediaRetrievalPostMediaRetrievalInternalServerErrorResponseBody,
        MediaRetrievalPostMediaRetrievalMethodNotAllowedErrorResponseBody,
        MediaRetrievalPostMediaRetrievalNotFoundErrorResponseBody,
        MediaRetrievalPostMediaRetrievalNotImplementedErrorResponseBody,
        MediaRetrievalPostMediaRetrievalResponseBody,
        MediaRetrievalPostMediaRetrievalServiceUnavailableErrorResponseBody,
        MediaRetrievalPostMediaRetrievalTooManyRequestsErrorResponseBody,
        MediaRetrievalPostMediaRetrievalUnauthorizedErrorResponseBody,
        MinimalRouteAuditLogsResponseBody,
        MinimalRouteStopAuditLogsResponseBody,
        MinimalRouteStopAuditLogsResponseBodyState,
        MinimalRouteStopResponseBody,
        MinimalRouteStopResponseBodyState,
        MissingDvirPastDueResponseBody,
        MissingStateResponseBody,
        MissingStateResponseBodyUpdateSource,
        MobileUsageDetectionAlertSettingsObjectResponseBody,
        MotionDetectedResponseBody,
        MultipleChoiceFieldTypeMetaDataObjectResponseBody,
        MultipleChoiceValueObjectRequestBody,
        MultipleChoiceValueObjectResponseBody,
        NotificationRecipientRequestBody,
        NotificationRecipientRequestBodyNotificationTypesItem,
        NotificationRecipientResponseResponseBody,
        NotificationRecipientResponseResponseBodyNotificationTypesItem,
        NumberDataPoint,
        NumberFieldTypeMetaDataObjectResponseBody,
        OperationalSettingsObjectRequestBody,
        OperationalSettingsObjectRequestBodyTimeRangeType,
        OperationalSettingsObjectResponseBody,
        OperationalSettingsObjectResponseBodyTimeRangeType,
        OrderCustomPropertyInputRequestBody,
        OrderCustomPropertyResponseBody,
        OrderInputObjectRequestBody,
        OrderObjectResponseBody,
        OrderQuantityInputRequestBody,
        OrderQuantityResponseBody,
        OrderTaskCustomPropertyObjectResponseBody,
        OrderTaskObjectResponseBody,
        OrderTaskRequestBody,
        OrderTaskRequestBodyPosition,
        OrderTaskResponseBody,
        OrderTaskResponseBodyPosition,
        OrderTaskSkillObjectResponseBody,
        OrganizationInfoCarrierSettings,
        OrganizationInfoObject,
        OrganizationInfoResponse,
        OutOfRouteDetailsObjectRequestBody,
        OutOfRouteDetailsObjectResponseBody,
        OutOfRouteResponseBody,
        OutsideGeofenceDataResponseBody,
        OutsideGeofenceTriggerDetailsObjectRequestBody,
        OutsideGeofenceTriggerDetailsObjectResponseBody,
        OverSpeedMs,
        PaginationResponse,
        PanicButtonDetailsObjectRequestBody,
        PanicButtonDetailsObjectResponseBody,
        PanicButtonResponseBody,
        ParentId,
        ParentTag,
        ParentTagId,
        ParentTagName,
        PartInstanceInputObjectRequestBody,
        PartInstanceObjectResponseBody,
        PatchAssetDataOutputsSingleResponseResponseBody,
        PatchDriverTrailerAssignmentsResponseBodyResponseBody,
        PatchDriverVehicleAssignmentsV2RequestBodyMetadataRequestBody,
        PatchDriverVehicleAssignmentsV2ResponseBodyResponseBody,
        PatchFunctionDetailResponseBody,
        PatchFunctionRequestConfigRequestBody,
        PatchFunctionRequestConfigRequestBodyParams,
        PatchFunctionRequestConfigRequestBodySecrets,
        PatchIssueRequestBodyAssignedToRequestBody,
        PatchIssueRequestBodyAssignedToRequestBodyType,
        PatchJobObjectRequestBody,
        PatchJobObjectjobLocationRequestObjectRequestBody,
        PatchResponseWorkflowConfigurationObjectResponseBody,
        PatchSafetyEventsDismissalReasonBodyRequestBody,
        PatchSafetyEventsDismissalReasonBodyRequestBodyCode,
        PatchSafetyEventsResponseItemDataResponseBody,
        PatchSafetyEventsResponseItemResponseBody,
        PatchShippingDocsResponseBodyResponseBody,
        PendingDutyStatusDurationsObjectResponseBody,
        PersonDetectedResponseBody,
        PhotoValueObjectRequestBody,
        PhotoValueObjectResponseBody,
        PlanObjectResponseBody,
        PlanOrdersCreatePlanOrdersBadGatewayErrorResponseBody,
        PlanOrdersCreatePlanOrdersGatewayTimeoutErrorResponseBody,
        PlanOrdersCreatePlanOrdersInternalServerErrorResponseBody,
        PlanOrdersCreatePlanOrdersMethodNotAllowedErrorResponseBody,
        PlanOrdersCreatePlanOrdersNotFoundErrorResponseBody,
        PlanOrdersCreatePlanOrdersNotImplementedErrorResponseBody,
        PlanOrdersCreatePlanOrdersResponseBody,
        PlanOrdersCreatePlanOrdersServiceUnavailableErrorResponseBody,
        PlanOrdersCreatePlanOrdersTooManyRequestsErrorResponseBody,
        PlanOrdersCreatePlanOrdersUnauthorizedErrorResponseBody,
        PolicyViolationsDetectionAlertSettingsObjectResponseBody,
        PolicyViolationsDetectionAlertSettingsObjectResponseBodyEventsAvailableForTestingItem,
        PolicyViolationsDetectionAlertSettingsObjectResponseBodyEventsToCoachItem,
        PolygonRequestBody,
        PolygonResponseBody,
        PostDriverTrailerAssignmentsResponseBodyResponseBody,
        PostDriverVehicleAssignmentsV2RequestBodyMetadataRequestBody,
        PostDriverVehicleAssignmentsV2ResponseBodyResponseBody,
        PostFuelPurchaseRequestBodyDiscountRequestBody,
        PostFuelPurchaseRequestBodyDiscountRequestBodyCurrency,
        PostFuelPurchaseRequestBodyPriceRequestBody,
        PostFuelPurchaseRequestBodyPriceRequestBodyCurrency,
        PostFuelPurchaseResponseBodyResponseBody,
        PostInvoiceScanResponseDataResponseBody,
        PostJobObjectRequestBody,
        PostJobObjectjobLocationRequestObjectRequestBody,
        PostMediaRetrievalObjectResponseBody,
        PostResponseResWorkflowConfigurationObjectResponseBody,
        PowerTakeOffDurationMs,
        PrimaryTimeRangeRequestBody,
        PrimaryTimeRangeResponseBody,
        PushNotificationOptionsObjectRequestBody,
        PushNotificationOptionsObjectResponseBody,
        QrCodeResponseObjectResponseBody,
        QualificationFieldInputObjectResponseBody,
        QualificationFieldInputObjectResponseBodyType,
        QualificationOwnerObjectResponseBody,
        QualificationOwnerObjectResponseBodyEntityType,
        QualificationOwnerRequestObjectRequestBody,
        QualificationOwnerRequestObjectRequestBodyEntityType,
        QualificationRecordRequestFieldInputObjectRequestBody,
        QualificationRecordRequestFieldInputObjectRequestBodyType,
        QualificationRecordResponseObjectResponseBody,
        QualificationRecordResponseObjectResponseBodyRecordStatus,
        QualificationTypeReferenceObjectResponseBody,
        QualificationTypeRequestObjectRequestBody,
        QualificationTypeResponseObjectResponseBody,
        QualificationTypeResponseObjectResponseBodyEntityType,
        QualificationsArchiveQualificationRecordBadGatewayErrorResponseBody,
        QualificationsArchiveQualificationRecordGatewayTimeoutErrorResponseBody,
        QualificationsArchiveQualificationRecordInternalServerErrorResponseBody,
        QualificationsArchiveQualificationRecordMethodNotAllowedErrorResponseBody,
        QualificationsArchiveQualificationRecordNotFoundErrorResponseBody,
        QualificationsArchiveQualificationRecordNotImplementedErrorResponseBody,
        QualificationsArchiveQualificationRecordServiceUnavailableErrorResponseBody,
        QualificationsArchiveQualificationRecordTooManyRequestsErrorResponseBody,
        QualificationsArchiveQualificationRecordUnauthorizedErrorResponseBody,
        QualificationsDeleteQualificationRecordBadGatewayErrorResponseBody,
        QualificationsDeleteQualificationRecordGatewayTimeoutErrorResponseBody,
        QualificationsDeleteQualificationRecordInternalServerErrorResponseBody,
        QualificationsDeleteQualificationRecordMethodNotAllowedErrorResponseBody,
        QualificationsDeleteQualificationRecordNotFoundErrorResponseBody,
        QualificationsDeleteQualificationRecordNotImplementedErrorResponseBody,
        QualificationsDeleteQualificationRecordServiceUnavailableErrorResponseBody,
        QualificationsDeleteQualificationRecordTooManyRequestsErrorResponseBody,
        QualificationsDeleteQualificationRecordUnauthorizedErrorResponseBody,
        QualificationsGetQualificationRecordsBadGatewayErrorResponseBody,
        QualificationsGetQualificationRecordsGatewayTimeoutErrorResponseBody,
        QualificationsGetQualificationRecordsInternalServerErrorResponseBody,
        QualificationsGetQualificationRecordsMethodNotAllowedErrorResponseBody,
        QualificationsGetQualificationRecordsNotFoundErrorResponseBody,
        QualificationsGetQualificationRecordsNotImplementedErrorResponseBody,
        QualificationsGetQualificationRecordsResponseBody,
        QualificationsGetQualificationRecordsServiceUnavailableErrorResponseBody,
        QualificationsGetQualificationRecordsStreamBadGatewayErrorResponseBody,
        QualificationsGetQualificationRecordsStreamGatewayTimeoutErrorResponseBody,
        QualificationsGetQualificationRecordsStreamInternalServerErrorResponseBody,
        QualificationsGetQualificationRecordsStreamMethodNotAllowedErrorResponseBody,
        QualificationsGetQualificationRecordsStreamNotFoundErrorResponseBody,
        QualificationsGetQualificationRecordsStreamNotImplementedErrorResponseBody,
        QualificationsGetQualificationRecordsStreamResponseBody,
        QualificationsGetQualificationRecordsStreamServiceUnavailableErrorResponseBody,
        QualificationsGetQualificationRecordsStreamTooManyRequestsErrorResponseBody,
        QualificationsGetQualificationRecordsStreamUnauthorizedErrorResponseBody,
        QualificationsGetQualificationRecordsTooManyRequestsErrorResponseBody,
        QualificationsGetQualificationRecordsUnauthorizedErrorResponseBody,
        QualificationsGetQualificationTypesBadGatewayErrorResponseBody,
        QualificationsGetQualificationTypesGatewayTimeoutErrorResponseBody,
        QualificationsGetQualificationTypesInternalServerErrorResponseBody,
        QualificationsGetQualificationTypesMethodNotAllowedErrorResponseBody,
        QualificationsGetQualificationTypesNotFoundErrorResponseBody,
        QualificationsGetQualificationTypesNotImplementedErrorResponseBody,
        QualificationsGetQualificationTypesResponseBody,
        QualificationsGetQualificationTypesServiceUnavailableErrorResponseBody,
        QualificationsGetQualificationTypesTooManyRequestsErrorResponseBody,
        QualificationsGetQualificationTypesUnauthorizedErrorResponseBody,
        QualificationsPatchQualificationRecordBadGatewayErrorResponseBody,
        QualificationsPatchQualificationRecordGatewayTimeoutErrorResponseBody,
        QualificationsPatchQualificationRecordInternalServerErrorResponseBody,
        QualificationsPatchQualificationRecordMethodNotAllowedErrorResponseBody,
        QualificationsPatchQualificationRecordNotFoundErrorResponseBody,
        QualificationsPatchQualificationRecordNotImplementedErrorResponseBody,
        QualificationsPatchQualificationRecordResponseBody,
        QualificationsPatchQualificationRecordServiceUnavailableErrorResponseBody,
        QualificationsPatchQualificationRecordTooManyRequestsErrorResponseBody,
        QualificationsPatchQualificationRecordUnauthorizedErrorResponseBody,
        QualificationsPostQualificationRecordBadGatewayErrorResponseBody,
        QualificationsPostQualificationRecordGatewayTimeoutErrorResponseBody,
        QualificationsPostQualificationRecordInternalServerErrorResponseBody,
        QualificationsPostQualificationRecordMethodNotAllowedErrorResponseBody,
        QualificationsPostQualificationRecordNotFoundErrorResponseBody,
        QualificationsPostQualificationRecordNotImplementedErrorResponseBody,
        QualificationsPostQualificationRecordResponseBody,
        QualificationsPostQualificationRecordServiceUnavailableErrorResponseBody,
        QualificationsPostQualificationRecordTooManyRequestsErrorResponseBody,
        QualificationsPostQualificationRecordUnauthorizedErrorResponseBody,
        QualificationsUnarchiveQualificationRecordBadGatewayErrorResponseBody,
        QualificationsUnarchiveQualificationRecordGatewayTimeoutErrorResponseBody,
        QualificationsUnarchiveQualificationRecordInternalServerErrorResponseBody,
        QualificationsUnarchiveQualificationRecordMethodNotAllowedErrorResponseBody,
        QualificationsUnarchiveQualificationRecordNotFoundErrorResponseBody,
        QualificationsUnarchiveQualificationRecordNotImplementedErrorResponseBody,
        QualificationsUnarchiveQualificationRecordServiceUnavailableErrorResponseBody,
        QualificationsUnarchiveQualificationRecordTooManyRequestsErrorResponseBody,
        QualificationsUnarchiveQualificationRecordUnauthorizedErrorResponseBody,
        QuantityObjectResponseBody,
        ReadingDatapointRequestBody,
        ReadingDatapointRequestBodyEntityType,
        ReadingDefinitionResponseBody,
        ReadingHistoryResponseBody,
        ReadingSnapshotResponseBody,
        ReadingTriggerContinuousValueObjectRequestBody,
        ReadingTriggerContinuousValueObjectRequestBodyOperation,
        ReadingTriggerContinuousValueObjectRequestBodyUnit,
        ReadingTriggerContinuousValueObjectResponseBody,
        ReadingTriggerContinuousValueObjectResponseBodyOperation,
        ReadingTriggerContinuousValueObjectResponseBodyUnit,
        ReadingTriggerDetailsObjectRequestBody,
        ReadingTriggerDetailsObjectResponseBody,
        ReadingTriggerDetailsResponseBody,
        ReadingTriggerEnumValueObjectRequestBody,
        ReadingTriggerEnumValueObjectResponseBody,
        ReadingsGetReadingsHistoryBadGatewayErrorResponseBody,
        ReadingsGetReadingsHistoryGatewayTimeoutErrorResponseBody,
        ReadingsGetReadingsHistoryInternalServerErrorResponseBody,
        ReadingsGetReadingsHistoryMethodNotAllowedErrorResponseBody,
        ReadingsGetReadingsHistoryNotFoundErrorResponseBody,
        ReadingsGetReadingsHistoryNotImplementedErrorResponseBody,
        ReadingsGetReadingsHistoryResponseBody,
        ReadingsGetReadingsHistoryServiceUnavailableErrorResponseBody,
        ReadingsGetReadingsHistoryTooManyRequestsErrorResponseBody,
        ReadingsGetReadingsHistoryUnauthorizedErrorResponseBody,
        ReadingsGetReadingsSnapshotBadGatewayErrorResponseBody,
        ReadingsGetReadingsSnapshotGatewayTimeoutErrorResponseBody,
        ReadingsGetReadingsSnapshotInternalServerErrorResponseBody,
        ReadingsGetReadingsSnapshotMethodNotAllowedErrorResponseBody,
        ReadingsGetReadingsSnapshotNotFoundErrorResponseBody,
        ReadingsGetReadingsSnapshotNotImplementedErrorResponseBody,
        ReadingsGetReadingsSnapshotResponseBody,
        ReadingsGetReadingsSnapshotServiceUnavailableErrorResponseBody,
        ReadingsGetReadingsSnapshotTooManyRequestsErrorResponseBody,
        ReadingsGetReadingsSnapshotUnauthorizedErrorResponseBody,
        ReadingsListReadingsDefinitionsBadGatewayErrorResponseBody,
        ReadingsListReadingsDefinitionsGatewayTimeoutErrorResponseBody,
        ReadingsListReadingsDefinitionsInternalServerErrorResponseBody,
        ReadingsListReadingsDefinitionsMethodNotAllowedErrorResponseBody,
        ReadingsListReadingsDefinitionsNotFoundErrorResponseBody,
        ReadingsListReadingsDefinitionsNotImplementedErrorResponseBody,
        ReadingsListReadingsDefinitionsResponseBody,
        ReadingsListReadingsDefinitionsServiceUnavailableErrorResponseBody,
        ReadingsListReadingsDefinitionsTooManyRequestsErrorResponseBody,
        ReadingsListReadingsDefinitionsUnauthorizedErrorResponseBody,
        ReadingsPostReadingsBadGatewayErrorResponseBody,
        ReadingsPostReadingsGatewayTimeoutErrorResponseBody,
        ReadingsPostReadingsInternalServerErrorResponseBody,
        ReadingsPostReadingsMethodNotAllowedErrorResponseBody,
        ReadingsPostReadingsNotFoundErrorResponseBody,
        ReadingsPostReadingsNotImplementedErrorResponseBody,
        ReadingsPostReadingsServiceUnavailableErrorResponseBody,
        ReadingsPostReadingsTooManyRequestsErrorResponseBody,
        ReadingsPostReadingsUnauthorizedErrorResponseBody,
        RecipientObjectRequestBody,
        RecipientObjectRequestBodyNotificationTypesItem,
        RecipientObjectRequestBodyType,
        RecipientObjectResponseBody,
        RecipientObjectResponseBodyNotificationTypesItem,
        RecipientObjectResponseBodyType,
        RecoveryPhotoResponseBody,
        RecoveryPhotoResponseBodyStatus,
        RecoveryStateResponseBody,
        RecoveryStateResponseBodyUpdateSource,
        ReeferTemperatureResponseBody,
        ReportColumnsObjectResponseBody,
        ReportColumnsObjectResponseBodyDataType,
        ReportColumnsObjectResponseBodyUnit,
        ReportConfigObjectResponseBody,
        ReportRunObjectResponseBody,
        ReportRunObjectResponseBodyStatus,
        ReportsCreateReportRunBadGatewayErrorResponseBody,
        ReportsCreateReportRunGatewayTimeoutErrorResponseBody,
        ReportsCreateReportRunInternalServerErrorResponseBody,
        ReportsCreateReportRunMethodNotAllowedErrorResponseBody,
        ReportsCreateReportRunNotFoundErrorResponseBody,
        ReportsCreateReportRunNotImplementedErrorResponseBody,
        ReportsCreateReportRunResponseBody,
        ReportsCreateReportRunServiceUnavailableErrorResponseBody,
        ReportsCreateReportRunTooManyRequestsErrorResponseBody,
        ReportsCreateReportRunUnauthorizedErrorResponseBody,
        ReportsDatasetFieldResponseBody,
        ReportsDatasetFieldResponseBodyDataType,
        ReportsDatasetFieldResponseBodyUnit,
        ReportsDatasetResponseBody,
        ReportsGetDatasetsBadGatewayErrorResponseBody,
        ReportsGetDatasetsGatewayTimeoutErrorResponseBody,
        ReportsGetDatasetsInternalServerErrorResponseBody,
        ReportsGetDatasetsMethodNotAllowedErrorResponseBody,
        ReportsGetDatasetsNotFoundErrorResponseBody,
        ReportsGetDatasetsNotImplementedErrorResponseBody,
        ReportsGetDatasetsResponseBody,
        ReportsGetDatasetsServiceUnavailableErrorResponseBody,
        ReportsGetDatasetsTooManyRequestsErrorResponseBody,
        ReportsGetDatasetsUnauthorizedErrorResponseBody,
        ReportsGetReportConfigsBadGatewayErrorResponseBody,
        ReportsGetReportConfigsGatewayTimeoutErrorResponseBody,
        ReportsGetReportConfigsInternalServerErrorResponseBody,
        ReportsGetReportConfigsMethodNotAllowedErrorResponseBody,
        ReportsGetReportConfigsNotFoundErrorResponseBody,
        ReportsGetReportConfigsNotImplementedErrorResponseBody,
        ReportsGetReportConfigsResponseBody,
        ReportsGetReportConfigsServiceUnavailableErrorResponseBody,
        ReportsGetReportConfigsTooManyRequestsErrorResponseBody,
        ReportsGetReportConfigsUnauthorizedErrorResponseBody,
        ReportsGetReportRunDataBadGatewayErrorResponseBody,
        ReportsGetReportRunDataGatewayTimeoutErrorResponseBody,
        ReportsGetReportRunDataInternalServerErrorResponseBody,
        ReportsGetReportRunDataMethodNotAllowedErrorResponseBody,
        ReportsGetReportRunDataNotFoundErrorResponseBody,
        ReportsGetReportRunDataNotImplementedErrorResponseBody,
        ReportsGetReportRunDataResponseBody,
        ReportsGetReportRunDataServiceUnavailableErrorResponseBody,
        ReportsGetReportRunDataTooManyRequestsErrorResponseBody,
        ReportsGetReportRunDataUnauthorizedErrorResponseBody,
        ReportsGetReportRunsBadGatewayErrorResponseBody,
        ReportsGetReportRunsGatewayTimeoutErrorResponseBody,
        ReportsGetReportRunsInternalServerErrorResponseBody,
        ReportsGetReportRunsMethodNotAllowedErrorResponseBody,
        ReportsGetReportRunsNotFoundErrorResponseBody,
        ReportsGetReportRunsNotImplementedErrorResponseBody,
        ReportsGetReportRunsResponseBody,
        ReportsGetReportRunsServiceUnavailableErrorResponseBody,
        ReportsGetReportRunsTooManyRequestsErrorResponseBody,
        ReportsGetReportRunsUnauthorizedErrorResponseBody,
        ResolveAssignmentByDetailsResolveAssignmentByDetailsBadGatewayErrorResponseBody,
        ResolveAssignmentByDetailsResolveAssignmentByDetailsGatewayTimeoutErrorResponseBody,
        ResolveAssignmentByDetailsResolveAssignmentByDetailsInternalServerErrorResponseBody,
        ResolveAssignmentByDetailsResolveAssignmentByDetailsMethodNotAllowedErrorResponseBody,
        ResolveAssignmentByDetailsResolveAssignmentByDetailsNotFoundErrorResponseBody,
        ResolveAssignmentByDetailsResolveAssignmentByDetailsNotImplementedErrorResponseBody,
        ResolveAssignmentByDetailsResolveAssignmentByDetailsResponseBody,
        ResolveAssignmentByDetailsResolveAssignmentByDetailsServiceUnavailableErrorResponseBody,
        ResolveAssignmentByDetailsResolveAssignmentByDetailsTooManyRequestsErrorResponseBody,
        ResolveAssignmentByDetailsResolveAssignmentByDetailsUnauthorizedErrorResponseBody,
        ResolveAssignmentByDetailsResponseBodyResponseBody,
        ResolvedBy,
        ResolvedByType,
        ReverseGeo,
        ReverseGeoObjectResponseBody,
        RidershipAccountObjectResponseBody,
        RidershipAccountsCreateRidershipAccountBadGatewayErrorResponseBody,
        RidershipAccountsCreateRidershipAccountGatewayTimeoutErrorResponseBody,
        RidershipAccountsCreateRidershipAccountInternalServerErrorResponseBody,
        RidershipAccountsCreateRidershipAccountMethodNotAllowedErrorResponseBody,
        RidershipAccountsCreateRidershipAccountNotFoundErrorResponseBody,
        RidershipAccountsCreateRidershipAccountNotImplementedErrorResponseBody,
        RidershipAccountsCreateRidershipAccountResponseBody,
        RidershipAccountsCreateRidershipAccountServiceUnavailableErrorResponseBody,
        RidershipAccountsCreateRidershipAccountTooManyRequestsErrorResponseBody,
        RidershipAccountsCreateRidershipAccountUnauthorizedErrorResponseBody,
        RidershipAccountsDeleteRidershipAccountBadGatewayErrorResponseBody,
        RidershipAccountsDeleteRidershipAccountGatewayTimeoutErrorResponseBody,
        RidershipAccountsDeleteRidershipAccountInternalServerErrorResponseBody,
        RidershipAccountsDeleteRidershipAccountMethodNotAllowedErrorResponseBody,
        RidershipAccountsDeleteRidershipAccountNotFoundErrorResponseBody,
        RidershipAccountsDeleteRidershipAccountNotImplementedErrorResponseBody,
        RidershipAccountsDeleteRidershipAccountServiceUnavailableErrorResponseBody,
        RidershipAccountsDeleteRidershipAccountTooManyRequestsErrorResponseBody,
        RidershipAccountsDeleteRidershipAccountUnauthorizedErrorResponseBody,
        RidershipAccountsGetRidershipAccountBadGatewayErrorResponseBody,
        RidershipAccountsGetRidershipAccountGatewayTimeoutErrorResponseBody,
        RidershipAccountsGetRidershipAccountInternalServerErrorResponseBody,
        RidershipAccountsGetRidershipAccountMethodNotAllowedErrorResponseBody,
        RidershipAccountsGetRidershipAccountNotFoundErrorResponseBody,
        RidershipAccountsGetRidershipAccountNotImplementedErrorResponseBody,
        RidershipAccountsGetRidershipAccountResponseBody,
        RidershipAccountsGetRidershipAccountServiceUnavailableErrorResponseBody,
        RidershipAccountsGetRidershipAccountTooManyRequestsErrorResponseBody,
        RidershipAccountsGetRidershipAccountUnauthorizedErrorResponseBody,
        RidershipAccountsListRidershipAccountsBadGatewayErrorResponseBody,
        RidershipAccountsListRidershipAccountsGatewayTimeoutErrorResponseBody,
        RidershipAccountsListRidershipAccountsInternalServerErrorResponseBody,
        RidershipAccountsListRidershipAccountsMethodNotAllowedErrorResponseBody,
        RidershipAccountsListRidershipAccountsNotFoundErrorResponseBody,
        RidershipAccountsListRidershipAccountsNotImplementedErrorResponseBody,
        RidershipAccountsListRidershipAccountsResponseBody,
        RidershipAccountsListRidershipAccountsServiceUnavailableErrorResponseBody,
        RidershipAccountsListRidershipAccountsTooManyRequestsErrorResponseBody,
        RidershipAccountsListRidershipAccountsUnauthorizedErrorResponseBody,
        RidershipAccountsUpdateRidershipAccountBadGatewayErrorResponseBody,
        RidershipAccountsUpdateRidershipAccountGatewayTimeoutErrorResponseBody,
        RidershipAccountsUpdateRidershipAccountInternalServerErrorResponseBody,
        RidershipAccountsUpdateRidershipAccountMethodNotAllowedErrorResponseBody,
        RidershipAccountsUpdateRidershipAccountNotFoundErrorResponseBody,
        RidershipAccountsUpdateRidershipAccountNotImplementedErrorResponseBody,
        RidershipAccountsUpdateRidershipAccountResponseBody,
        RidershipAccountsUpdateRidershipAccountServiceUnavailableErrorResponseBody,
        RidershipAccountsUpdateRidershipAccountTooManyRequestsErrorResponseBody,
        RidershipAccountsUpdateRidershipAccountUnauthorizedErrorResponseBody,
        RidershipPassengerIdentifierInputRequestBody,
        RidershipPassengerIdentifierInputRequestBodyStatus,
        RidershipPassengerIdentifierInputRequestBodyType,
        RidershipPassengerIdentifierObjectResponseBody,
        RidershipPassengerIdentifierObjectResponseBodyStatus,
        RidershipPassengerIdentifierObjectResponseBodyType,
        RidershipPassengerObjectResponseBody,
        RidershipPassengerSpecialInstructionsInputRequestBody,
        RidershipPassengerSpecialInstructionsObjectResponseBody,
        RidershipPassengersCreateRidershipPassengerBadGatewayErrorResponseBody,
        RidershipPassengersCreateRidershipPassengerGatewayTimeoutErrorResponseBody,
        RidershipPassengersCreateRidershipPassengerInternalServerErrorResponseBody,
        RidershipPassengersCreateRidershipPassengerMethodNotAllowedErrorResponseBody,
        RidershipPassengersCreateRidershipPassengerNotFoundErrorResponseBody,
        RidershipPassengersCreateRidershipPassengerNotImplementedErrorResponseBody,
        RidershipPassengersCreateRidershipPassengerResponseBody,
        RidershipPassengersCreateRidershipPassengerServiceUnavailableErrorResponseBody,
        RidershipPassengersCreateRidershipPassengerTooManyRequestsErrorResponseBody,
        RidershipPassengersCreateRidershipPassengerUnauthorizedErrorResponseBody,
        RidershipPassengersDeleteRidershipPassengerBadGatewayErrorResponseBody,
        RidershipPassengersDeleteRidershipPassengerGatewayTimeoutErrorResponseBody,
        RidershipPassengersDeleteRidershipPassengerInternalServerErrorResponseBody,
        RidershipPassengersDeleteRidershipPassengerMethodNotAllowedErrorResponseBody,
        RidershipPassengersDeleteRidershipPassengerNotFoundErrorResponseBody,
        RidershipPassengersDeleteRidershipPassengerNotImplementedErrorResponseBody,
        RidershipPassengersDeleteRidershipPassengerServiceUnavailableErrorResponseBody,
        RidershipPassengersDeleteRidershipPassengerTooManyRequestsErrorResponseBody,
        RidershipPassengersDeleteRidershipPassengerUnauthorizedErrorResponseBody,
        RidershipPassengersGetRidershipPassengerBadGatewayErrorResponseBody,
        RidershipPassengersGetRidershipPassengerGatewayTimeoutErrorResponseBody,
        RidershipPassengersGetRidershipPassengerInternalServerErrorResponseBody,
        RidershipPassengersGetRidershipPassengerMethodNotAllowedErrorResponseBody,
        RidershipPassengersGetRidershipPassengerNotFoundErrorResponseBody,
        RidershipPassengersGetRidershipPassengerNotImplementedErrorResponseBody,
        RidershipPassengersGetRidershipPassengerResponseBody,
        RidershipPassengersGetRidershipPassengerServiceUnavailableErrorResponseBody,
        RidershipPassengersGetRidershipPassengerTooManyRequestsErrorResponseBody,
        RidershipPassengersGetRidershipPassengerUnauthorizedErrorResponseBody,
        RidershipPassengersListRidershipPassengersBadGatewayErrorResponseBody,
        RidershipPassengersListRidershipPassengersGatewayTimeoutErrorResponseBody,
        RidershipPassengersListRidershipPassengersInternalServerErrorResponseBody,
        RidershipPassengersListRidershipPassengersMethodNotAllowedErrorResponseBody,
        RidershipPassengersListRidershipPassengersNotFoundErrorResponseBody,
        RidershipPassengersListRidershipPassengersNotImplementedErrorResponseBody,
        RidershipPassengersListRidershipPassengersResponseBody,
        RidershipPassengersListRidershipPassengersServiceUnavailableErrorResponseBody,
        RidershipPassengersListRidershipPassengersTooManyRequestsErrorResponseBody,
        RidershipPassengersListRidershipPassengersUnauthorizedErrorResponseBody,
        RidershipPassengersUpdateRidershipPassengerBadGatewayErrorResponseBody,
        RidershipPassengersUpdateRidershipPassengerGatewayTimeoutErrorResponseBody,
        RidershipPassengersUpdateRidershipPassengerInternalServerErrorResponseBody,
        RidershipPassengersUpdateRidershipPassengerMethodNotAllowedErrorResponseBody,
        RidershipPassengersUpdateRidershipPassengerNotFoundErrorResponseBody,
        RidershipPassengersUpdateRidershipPassengerNotImplementedErrorResponseBody,
        RidershipPassengersUpdateRidershipPassengerResponseBody,
        RidershipPassengersUpdateRidershipPassengerServiceUnavailableErrorResponseBody,
        RidershipPassengersUpdateRidershipPassengerTooManyRequestsErrorResponseBody,
        RidershipPassengersUpdateRidershipPassengerUnauthorizedErrorResponseBody,
        RidershipRouteSetupObjectResponseBody,
        RidershipRouteSetupPassengerInputRequestBody,
        RidershipRouteSetupPassengerObjectResponseBody,
        RidershipRouteSetupsCreateRidershipRouteSetupBadGatewayErrorResponseBody,
        RidershipRouteSetupsCreateRidershipRouteSetupGatewayTimeoutErrorResponseBody,
        RidershipRouteSetupsCreateRidershipRouteSetupInternalServerErrorResponseBody,
        RidershipRouteSetupsCreateRidershipRouteSetupMethodNotAllowedErrorResponseBody,
        RidershipRouteSetupsCreateRidershipRouteSetupNotFoundErrorResponseBody,
        RidershipRouteSetupsCreateRidershipRouteSetupNotImplementedErrorResponseBody,
        RidershipRouteSetupsCreateRidershipRouteSetupResponseBody,
        RidershipRouteSetupsCreateRidershipRouteSetupServiceUnavailableErrorResponseBody,
        RidershipRouteSetupsCreateRidershipRouteSetupTooManyRequestsErrorResponseBody,
        RidershipRouteSetupsCreateRidershipRouteSetupUnauthorizedErrorResponseBody,
        RidershipRouteSetupsDeleteRidershipRouteSetupBadGatewayErrorResponseBody,
        RidershipRouteSetupsDeleteRidershipRouteSetupGatewayTimeoutErrorResponseBody,
        RidershipRouteSetupsDeleteRidershipRouteSetupInternalServerErrorResponseBody,
        RidershipRouteSetupsDeleteRidershipRouteSetupMethodNotAllowedErrorResponseBody,
        RidershipRouteSetupsDeleteRidershipRouteSetupNotFoundErrorResponseBody,
        RidershipRouteSetupsDeleteRidershipRouteSetupNotImplementedErrorResponseBody,
        RidershipRouteSetupsDeleteRidershipRouteSetupServiceUnavailableErrorResponseBody,
        RidershipRouteSetupsDeleteRidershipRouteSetupTooManyRequestsErrorResponseBody,
        RidershipRouteSetupsDeleteRidershipRouteSetupUnauthorizedErrorResponseBody,
        RidershipRouteSetupsGetRidershipRouteSetupBadGatewayErrorResponseBody,
        RidershipRouteSetupsGetRidershipRouteSetupGatewayTimeoutErrorResponseBody,
        RidershipRouteSetupsGetRidershipRouteSetupInternalServerErrorResponseBody,
        RidershipRouteSetupsGetRidershipRouteSetupMethodNotAllowedErrorResponseBody,
        RidershipRouteSetupsGetRidershipRouteSetupNotFoundErrorResponseBody,
        RidershipRouteSetupsGetRidershipRouteSetupNotImplementedErrorResponseBody,
        RidershipRouteSetupsGetRidershipRouteSetupResponseBody,
        RidershipRouteSetupsGetRidershipRouteSetupServiceUnavailableErrorResponseBody,
        RidershipRouteSetupsGetRidershipRouteSetupTooManyRequestsErrorResponseBody,
        RidershipRouteSetupsGetRidershipRouteSetupUnauthorizedErrorResponseBody,
        RidershipRouteSetupsListRidershipRouteSetupsBadGatewayErrorResponseBody,
        RidershipRouteSetupsListRidershipRouteSetupsGatewayTimeoutErrorResponseBody,
        RidershipRouteSetupsListRidershipRouteSetupsInternalServerErrorResponseBody,
        RidershipRouteSetupsListRidershipRouteSetupsMethodNotAllowedErrorResponseBody,
        RidershipRouteSetupsListRidershipRouteSetupsNotFoundErrorResponseBody,
        RidershipRouteSetupsListRidershipRouteSetupsNotImplementedErrorResponseBody,
        RidershipRouteSetupsListRidershipRouteSetupsResponseBody,
        RidershipRouteSetupsListRidershipRouteSetupsServiceUnavailableErrorResponseBody,
        RidershipRouteSetupsListRidershipRouteSetupsTooManyRequestsErrorResponseBody,
        RidershipRouteSetupsListRidershipRouteSetupsUnauthorizedErrorResponseBody,
        RidershipRouteSetupsUpdateRidershipRouteSetupBadGatewayErrorResponseBody,
        RidershipRouteSetupsUpdateRidershipRouteSetupGatewayTimeoutErrorResponseBody,
        RidershipRouteSetupsUpdateRidershipRouteSetupInternalServerErrorResponseBody,
        RidershipRouteSetupsUpdateRidershipRouteSetupMethodNotAllowedErrorResponseBody,
        RidershipRouteSetupsUpdateRidershipRouteSetupNotFoundErrorResponseBody,
        RidershipRouteSetupsUpdateRidershipRouteSetupNotImplementedErrorResponseBody,
        RidershipRouteSetupsUpdateRidershipRouteSetupResponseBody,
        RidershipRouteSetupsUpdateRidershipRouteSetupServiceUnavailableErrorResponseBody,
        RidershipRouteSetupsUpdateRidershipRouteSetupTooManyRequestsErrorResponseBody,
        RidershipRouteSetupsUpdateRidershipRouteSetupUnauthorizedErrorResponseBody,
        RollingStopDetectionAlertSettingsObjectResponseBody,
        RouteChangesResponseBody,
        RouteEventDetailsResponseBody,
        RouteEventResponseResponseBody,
        RouteEventResponseResponseBodyEventType,
        RouteEventRouteResponseResponseBody,
        RouteEventStopResponseResponseBody,
        RouteFeedObjectResponseBody,
        RouteFeedObjectResponseBodyOperation,
        RouteFeedObjectResponseBodySource,
        RouteFeedObjectResponseBodyType,
        RouteObjectResponseBody,
        RouteSettingsRequestBody,
        RouteSettingsRequestBodyRouteCompletionCondition,
        RouteSettingsRequestBodyRouteStartingCondition,
        RouteSettingsRequestBodySequencingMethod,
        RouteSettingsResponseBody,
        RouteSettingsResponseBodyRouteCompletionCondition,
        RouteSettingsResponseBodyRouteStartingCondition,
        RouteSettingsResponseBodySequencingMethod,
        RouteStopDetailsObjectResponseBody,
        RouteStopDetailsObjectResponseBodyOperation,
        RouteStopDetailsObjectResponseBodyType,
        RouteStopEstimatedArrivalDetailsObjectRequestBody,
        RouteStopEstimatedArrivalDetailsObjectResponseBody,
        RouteStopEtaResponseBody,
        RouteStopObjectResponseBody,
        RoutesCreateRouteBadGatewayErrorResponseBody,
        RoutesCreateRouteGatewayTimeoutErrorResponseBody,
        RoutesCreateRouteInternalServerErrorResponseBody,
        RoutesCreateRouteMethodNotAllowedErrorResponseBody,
        RoutesCreateRouteNotFoundErrorResponseBody,
        RoutesCreateRouteNotImplementedErrorResponseBody,
        RoutesCreateRouteResponseBody,
        RoutesCreateRouteServiceUnavailableErrorResponseBody,
        RoutesCreateRouteTooManyRequestsErrorResponseBody,
        RoutesCreateRouteUnauthorizedErrorResponseBody,
        RoutesDeleteRouteBadGatewayErrorResponseBody,
        RoutesDeleteRouteGatewayTimeoutErrorResponseBody,
        RoutesDeleteRouteInternalServerErrorResponseBody,
        RoutesDeleteRouteMethodNotAllowedErrorResponseBody,
        RoutesDeleteRouteNotFoundErrorResponseBody,
        RoutesDeleteRouteNotImplementedErrorResponseBody,
        RoutesDeleteRouteServiceUnavailableErrorResponseBody,
        RoutesDeleteRouteTooManyRequestsErrorResponseBody,
        RoutesDeleteRouteUnauthorizedErrorResponseBody,
        RoutesFetchRouteBadGatewayErrorResponseBody,
        RoutesFetchRouteGatewayTimeoutErrorResponseBody,
        RoutesFetchRouteInternalServerErrorResponseBody,
        RoutesFetchRouteMethodNotAllowedErrorResponseBody,
        RoutesFetchRouteNotFoundErrorResponseBody,
        RoutesFetchRouteNotImplementedErrorResponseBody,
        RoutesFetchRouteResponseBody,
        RoutesFetchRouteServiceUnavailableErrorResponseBody,
        RoutesFetchRouteTooManyRequestsErrorResponseBody,
        RoutesFetchRouteUnauthorizedErrorResponseBody,
        RoutesFetchRoutesBadGatewayErrorResponseBody,
        RoutesFetchRoutesGatewayTimeoutErrorResponseBody,
        RoutesFetchRoutesInternalServerErrorResponseBody,
        RoutesFetchRoutesMethodNotAllowedErrorResponseBody,
        RoutesFetchRoutesNotFoundErrorResponseBody,
        RoutesFetchRoutesNotImplementedErrorResponseBody,
        RoutesFetchRoutesResponseBody,
        RoutesFetchRoutesServiceUnavailableErrorResponseBody,
        RoutesFetchRoutesTooManyRequestsErrorResponseBody,
        RoutesFetchRoutesUnauthorizedErrorResponseBody,
        RoutesGetRouteEventsStreamBadGatewayErrorResponseBody,
        RoutesGetRouteEventsStreamGatewayTimeoutErrorResponseBody,
        RoutesGetRouteEventsStreamInternalServerErrorResponseBody,
        RoutesGetRouteEventsStreamMethodNotAllowedErrorResponseBody,
        RoutesGetRouteEventsStreamNotFoundErrorResponseBody,
        RoutesGetRouteEventsStreamNotImplementedErrorResponseBody,
        RoutesGetRouteEventsStreamResponseBody,
        RoutesGetRouteEventsStreamServiceUnavailableErrorResponseBody,
        RoutesGetRouteEventsStreamTooManyRequestsErrorResponseBody,
        RoutesGetRouteEventsStreamUnauthorizedErrorResponseBody,
        RoutesGetRoutesFeedBadGatewayErrorResponseBody,
        RoutesGetRoutesFeedGatewayTimeoutErrorResponseBody,
        RoutesGetRoutesFeedInternalServerErrorResponseBody,
        RoutesGetRoutesFeedMethodNotAllowedErrorResponseBody,
        RoutesGetRoutesFeedNotFoundErrorResponseBody,
        RoutesGetRoutesFeedNotImplementedErrorResponseBody,
        RoutesGetRoutesFeedResponseBody,
        RoutesGetRoutesFeedServiceUnavailableErrorResponseBody,
        RoutesGetRoutesFeedTooManyRequestsErrorResponseBody,
        RoutesGetRoutesFeedUnauthorizedErrorResponseBody,
        RoutesPatchRouteBadGatewayErrorResponseBody,
        RoutesPatchRouteGatewayTimeoutErrorResponseBody,
        RoutesPatchRouteInternalServerErrorResponseBody,
        RoutesPatchRouteMethodNotAllowedErrorResponseBody,
        RoutesPatchRouteNotFoundErrorResponseBody,
        RoutesPatchRouteNotImplementedErrorResponseBody,
        RoutesPatchRouteResponseBody,
        RoutesPatchRouteServiceUnavailableErrorResponseBody,
        RoutesPatchRouteTooManyRequestsErrorResponseBody,
        RoutesPatchRouteUnauthorizedErrorResponseBody,
        RoutesSingleUseAddressObjectRequestBody,
        RoutesSingleUseAddressObjectResponseBody,
        RoutesStopResponseObjectResponseBody,
        RoutesStopResponseObjectResponseBodyState,
        SafetyBehaviorTriggerDetailsObjectRequestBody,
        SafetyBehaviorTriggerDetailsObjectRequestBodyBehaviorsItem,
        SafetyBehaviorTriggerDetailsObjectRequestBodySeveritiesItem,
        SafetyBehaviorTriggerDetailsObjectRequestBodyStatusesItem,
        SafetyBehaviorTriggerDetailsObjectResponseBody,
        SafetyBehaviorTriggerDetailsObjectResponseBodyBehaviorsItem,
        SafetyBehaviorTriggerDetailsObjectResponseBodySeveritiesItem,
        SafetyBehaviorTriggerDetailsObjectResponseBodyStatusesItem,
        SafetyEvent,
        SafetyEventActivityFeedItemResponseBody,
        SafetyEventActivityFeedItemResponseBodyType,
        SafetyEventBehaviorLabel,
        SafetyEventBehaviorLabelName,
        SafetyEventBehaviorLabelSource,
        SafetyEventBehaviorLabelType,
        SafetyEventBehaviorLabels,
        SafetyEventBehaviorLabelsResponseBody,
        SafetyEventBehaviorLabelsResponseBodyType,
        SafetyEventCoachingState,
        SafetyEventDismissalReasonResponseBody,
        SafetyEventDismissalReasonResponseBodyCode,
        SafetyEventDownloadForwardVideoUrl,
        SafetyEventDownloadInwardVideoUrl,
        SafetyEventDownloadTrackedInwardVideoUrl,
        SafetyEventDriverObjectResponseBody,
        SafetyEventId,
        SafetyEventMaxAccelerationGForce,
        SafetyEventObjectResponseBody,
        SafetyEventSpeedingMetadataResponseBody,
        SafetyEventTime,
        SafetyEventV2AssetObjectResponseBody,
        SafetyEventV2AssetObjectResponseBodyType,
        SafetyEventV2BehaviorLabelsResponseBody,
        SafetyEventV2BehaviorLabelsResponseBodyLabel,
        SafetyEventV2BehaviorLabelsResponseBodySource,
        SafetyEventV2ContextLabelsResponseBody,
        SafetyEventV2DriverObjectResponseBody,
        SafetyEventV2MediaResponseBody,
        SafetyEventV2MediaResponseBodyCameraRole,
        SafetyEventV2MediaResponseBodyInput,
        SafetyEventV2ObjectResponseBody,
        SafetyEventV2ObjectResponseBodyEventState,
        SafetyEventVehicleObjectResponseBody,
        SafetyEventsGetSafetyActivityEventFeedBadGatewayErrorResponseBody,
        SafetyEventsGetSafetyActivityEventFeedGatewayTimeoutErrorResponseBody,
        SafetyEventsGetSafetyActivityEventFeedInternalServerErrorResponseBody,
        SafetyEventsGetSafetyActivityEventFeedMethodNotAllowedErrorResponseBody,
        SafetyEventsGetSafetyActivityEventFeedNotFoundErrorResponseBody,
        SafetyEventsGetSafetyActivityEventFeedNotImplementedErrorResponseBody,
        SafetyEventsGetSafetyActivityEventFeedResponseBody,
        SafetyEventsGetSafetyActivityEventFeedServiceUnavailableErrorResponseBody,
        SafetyEventsGetSafetyActivityEventFeedTooManyRequestsErrorResponseBody,
        SafetyEventsGetSafetyActivityEventFeedUnauthorizedErrorResponseBody,
        SafetyEventsListResponse,
        SafetyEventsV2GetSafetyEventsV2BadGatewayErrorResponseBody,
        SafetyEventsV2GetSafetyEventsV2GatewayTimeoutErrorResponseBody,
        SafetyEventsV2GetSafetyEventsV2InternalServerErrorResponseBody,
        SafetyEventsV2GetSafetyEventsV2MethodNotAllowedErrorResponseBody,
        SafetyEventsV2GetSafetyEventsV2NotFoundErrorResponseBody,
        SafetyEventsV2GetSafetyEventsV2NotImplementedErrorResponseBody,
        SafetyEventsV2GetSafetyEventsV2ResponseBody,
        SafetyEventsV2GetSafetyEventsV2ServiceUnavailableErrorResponseBody,
        SafetyEventsV2GetSafetyEventsV2StreamBadGatewayErrorResponseBody,
        SafetyEventsV2GetSafetyEventsV2StreamGatewayTimeoutErrorResponseBody,
        SafetyEventsV2GetSafetyEventsV2StreamInternalServerErrorResponseBody,
        SafetyEventsV2GetSafetyEventsV2StreamMethodNotAllowedErrorResponseBody,
        SafetyEventsV2GetSafetyEventsV2StreamNotFoundErrorResponseBody,
        SafetyEventsV2GetSafetyEventsV2StreamNotImplementedErrorResponseBody,
        SafetyEventsV2GetSafetyEventsV2StreamResponseBody,
        SafetyEventsV2GetSafetyEventsV2StreamServiceUnavailableErrorResponseBody,
        SafetyEventsV2GetSafetyEventsV2StreamTooManyRequestsErrorResponseBody,
        SafetyEventsV2GetSafetyEventsV2StreamUnauthorizedErrorResponseBody,
        SafetyEventsV2GetSafetyEventsV2TooManyRequestsErrorResponseBody,
        SafetyEventsV2GetSafetyEventsV2UnauthorizedErrorResponseBody,
        SafetyEventsV2PatchSafetyEventsV2BatchBadGatewayErrorResponseBody,
        SafetyEventsV2PatchSafetyEventsV2BatchGatewayTimeoutErrorResponseBody,
        SafetyEventsV2PatchSafetyEventsV2BatchInternalServerErrorResponseBody,
        SafetyEventsV2PatchSafetyEventsV2BatchMethodNotAllowedErrorResponseBody,
        SafetyEventsV2PatchSafetyEventsV2BatchNotFoundErrorResponseBody,
        SafetyEventsV2PatchSafetyEventsV2BatchNotImplementedErrorResponseBody,
        SafetyEventsV2PatchSafetyEventsV2BatchResponseBody,
        SafetyEventsV2PatchSafetyEventsV2BatchServiceUnavailableErrorResponseBody,
        SafetyEventsV2PatchSafetyEventsV2BatchTooManyRequestsErrorResponseBody,
        SafetyEventsV2PatchSafetyEventsV2BatchUnauthorizedErrorResponseBody,
        SafetyScoreBehaviorObjectResponseBody,
        SafetyScoreBehaviorObjectResponseBodyBehaviorType,
        SafetyScoreConfigurationSettingsObjectResponseBody,
        SafetyScoreDetailsRequestBody,
        SafetyScoreDetailsRequestBodyComparison,
        SafetyScoreDetailsResponseBody,
        SafetyScoreDetailsResponseBodyComparison,
        SafetyScoreSpeedingObjectResponseBody,
        SafetyScoreSpeedingObjectResponseBodySpeedingType,
        SafetyScoresGetDriverSafetyScoreTripsBadGatewayErrorResponseBody,
        SafetyScoresGetDriverSafetyScoreTripsGatewayTimeoutErrorResponseBody,
        SafetyScoresGetDriverSafetyScoreTripsInternalServerErrorResponseBody,
        SafetyScoresGetDriverSafetyScoreTripsMethodNotAllowedErrorResponseBody,
        SafetyScoresGetDriverSafetyScoreTripsNotFoundErrorResponseBody,
        SafetyScoresGetDriverSafetyScoreTripsNotImplementedErrorResponseBody,
        SafetyScoresGetDriverSafetyScoreTripsResponseBody,
        SafetyScoresGetDriverSafetyScoreTripsServiceUnavailableErrorResponseBody,
        SafetyScoresGetDriverSafetyScoreTripsTooManyRequestsErrorResponseBody,
        SafetyScoresGetDriverSafetyScoreTripsUnauthorizedErrorResponseBody,
        SafetyScoresGetDriverSafetyScoresBadGatewayErrorResponseBody,
        SafetyScoresGetDriverSafetyScoresGatewayTimeoutErrorResponseBody,
        SafetyScoresGetDriverSafetyScoresInternalServerErrorResponseBody,
        SafetyScoresGetDriverSafetyScoresMethodNotAllowedErrorResponseBody,
        SafetyScoresGetDriverSafetyScoresNotFoundErrorResponseBody,
        SafetyScoresGetDriverSafetyScoresNotImplementedErrorResponseBody,
        SafetyScoresGetDriverSafetyScoresResponseBody,
        SafetyScoresGetDriverSafetyScoresServiceUnavailableErrorResponseBody,
        SafetyScoresGetDriverSafetyScoresTooManyRequestsErrorResponseBody,
        SafetyScoresGetDriverSafetyScoresUnauthorizedErrorResponseBody,
        SafetyScoresGetTagGroupSafetyScoresBadGatewayErrorResponseBody,
        SafetyScoresGetTagGroupSafetyScoresGatewayTimeoutErrorResponseBody,
        SafetyScoresGetTagGroupSafetyScoresInternalServerErrorResponseBody,
        SafetyScoresGetTagGroupSafetyScoresMethodNotAllowedErrorResponseBody,
        SafetyScoresGetTagGroupSafetyScoresNotFoundErrorResponseBody,
        SafetyScoresGetTagGroupSafetyScoresNotImplementedErrorResponseBody,
        SafetyScoresGetTagGroupSafetyScoresResponseBody,
        SafetyScoresGetTagGroupSafetyScoresServiceUnavailableErrorResponseBody,
        SafetyScoresGetTagGroupSafetyScoresTooManyRequestsErrorResponseBody,
        SafetyScoresGetTagGroupSafetyScoresUnauthorizedErrorResponseBody,
        SafetyScoresGetTagSafetyScoresBadGatewayErrorResponseBody,
        SafetyScoresGetTagSafetyScoresGatewayTimeoutErrorResponseBody,
        SafetyScoresGetTagSafetyScoresInternalServerErrorResponseBody,
        SafetyScoresGetTagSafetyScoresMethodNotAllowedErrorResponseBody,
        SafetyScoresGetTagSafetyScoresNotFoundErrorResponseBody,
        SafetyScoresGetTagSafetyScoresNotImplementedErrorResponseBody,
        SafetyScoresGetTagSafetyScoresResponseBody,
        SafetyScoresGetTagSafetyScoresServiceUnavailableErrorResponseBody,
        SafetyScoresGetTagSafetyScoresTooManyRequestsErrorResponseBody,
        SafetyScoresGetTagSafetyScoresUnauthorizedErrorResponseBody,
        SafetyScoresGetVehicleSafetyScoreTripsBadGatewayErrorResponseBody,
        SafetyScoresGetVehicleSafetyScoreTripsGatewayTimeoutErrorResponseBody,
        SafetyScoresGetVehicleSafetyScoreTripsInternalServerErrorResponseBody,
        SafetyScoresGetVehicleSafetyScoreTripsMethodNotAllowedErrorResponseBody,
        SafetyScoresGetVehicleSafetyScoreTripsNotFoundErrorResponseBody,
        SafetyScoresGetVehicleSafetyScoreTripsNotImplementedErrorResponseBody,
        SafetyScoresGetVehicleSafetyScoreTripsResponseBody,
        SafetyScoresGetVehicleSafetyScoreTripsServiceUnavailableErrorResponseBody,
        SafetyScoresGetVehicleSafetyScoreTripsTooManyRequestsErrorResponseBody,
        SafetyScoresGetVehicleSafetyScoreTripsUnauthorizedErrorResponseBody,
        SafetyScoresGetVehicleSafetyScoresBadGatewayErrorResponseBody,
        SafetyScoresGetVehicleSafetyScoresGatewayTimeoutErrorResponseBody,
        SafetyScoresGetVehicleSafetyScoresInternalServerErrorResponseBody,
        SafetyScoresGetVehicleSafetyScoresMethodNotAllowedErrorResponseBody,
        SafetyScoresGetVehicleSafetyScoresNotFoundErrorResponseBody,
        SafetyScoresGetVehicleSafetyScoresNotImplementedErrorResponseBody,
        SafetyScoresGetVehicleSafetyScoresResponseBody,
        SafetyScoresGetVehicleSafetyScoresServiceUnavailableErrorResponseBody,
        SafetyScoresGetVehicleSafetyScoresTooManyRequestsErrorResponseBody,
        SafetyScoresGetVehicleSafetyScoresUnauthorizedErrorResponseBody,
        SafetySettingsGetSafetySettingsBadGatewayErrorResponseBody,
        SafetySettingsGetSafetySettingsGatewayTimeoutErrorResponseBody,
        SafetySettingsGetSafetySettingsInternalServerErrorResponseBody,
        SafetySettingsGetSafetySettingsMethodNotAllowedErrorResponseBody,
        SafetySettingsGetSafetySettingsNotFoundErrorResponseBody,
        SafetySettingsGetSafetySettingsNotImplementedErrorResponseBody,
        SafetySettingsGetSafetySettingsResponseBody,
        SafetySettingsGetSafetySettingsServiceUnavailableErrorResponseBody,
        SafetySettingsGetSafetySettingsTooManyRequestsErrorResponseBody,
        SafetySettingsGetSafetySettingsUnauthorizedErrorResponseBody,
        SafetySettingsObjectResponseBody,
        SafetySettingsObjectResponseBodyDefaultVehicleType,
        ScannedDocumentValueObjectRequestBody,
        ScannedDocumentValueObjectResponseBody,
        ScheduledMaintenanceByEngineHoursDetailsObjectRequestBody,
        ScheduledMaintenanceByEngineHoursDetailsObjectResponseBody,
        ScheduledMaintenanceByEngineHoursResponseBody,
        ScheduledMaintenanceDataResponseBody,
        ScheduledMaintenanceOdometerDataResponseBody,
        ScheduledMaintenanceOdometerTriggerDetailsObjectRequestBody,
        ScheduledMaintenanceOdometerTriggerDetailsObjectResponseBody,
        ScheduledMaintenanceTriggerDetailsObjectRequestBody,
        ScheduledMaintenanceTriggerDetailsObjectResponseBody,
        ScopeObjectRequestBody,
        ScopeObjectResponseBody,
        Sensor,
        SensorResponseBody,
        Serial,
        ServiceTaskDefinitionObjectResponseBody,
        ServiceTaskInstanceInputObjectRequestBody,
        ServiceTaskInstanceInputObjectRequestBodyStatus,
        ServiceTaskInstanceObjectResponseBody,
        ServiceTaskInstanceObjectResponseBodyStatus,
        ServiceWindowObjectResponseBody,
        SettingsComplianceResponseObjectResponseBody,
        SettingsGetComplianceSettingsBadGatewayErrorResponseBody,
        SettingsGetComplianceSettingsGatewayTimeoutErrorResponseBody,
        SettingsGetComplianceSettingsInternalServerErrorResponseBody,
        SettingsGetComplianceSettingsMethodNotAllowedErrorResponseBody,
        SettingsGetComplianceSettingsNotFoundErrorResponseBody,
        SettingsGetComplianceSettingsNotImplementedErrorResponseBody,
        SettingsGetComplianceSettingsResponseBody,
        SettingsGetComplianceSettingsServiceUnavailableErrorResponseBody,
        SettingsGetComplianceSettingsTooManyRequestsErrorResponseBody,
        SettingsGetComplianceSettingsUnauthorizedErrorResponseBody,
        SettingsGetDriverAppSettingsBadGatewayErrorResponseBody,
        SettingsGetDriverAppSettingsGatewayTimeoutErrorResponseBody,
        SettingsGetDriverAppSettingsInternalServerErrorResponseBody,
        SettingsGetDriverAppSettingsMethodNotAllowedErrorResponseBody,
        SettingsGetDriverAppSettingsNotFoundErrorResponseBody,
        SettingsGetDriverAppSettingsNotImplementedErrorResponseBody,
        SettingsGetDriverAppSettingsResponseBody,
        SettingsGetDriverAppSettingsServiceUnavailableErrorResponseBody,
        SettingsGetDriverAppSettingsTooManyRequestsErrorResponseBody,
        SettingsGetDriverAppSettingsUnauthorizedErrorResponseBody,
        SettingsPatchComplianceSettingsBadGatewayErrorResponseBody,
        SettingsPatchComplianceSettingsGatewayTimeoutErrorResponseBody,
        SettingsPatchComplianceSettingsInternalServerErrorResponseBody,
        SettingsPatchComplianceSettingsMethodNotAllowedErrorResponseBody,
        SettingsPatchComplianceSettingsNotFoundErrorResponseBody,
        SettingsPatchComplianceSettingsNotImplementedErrorResponseBody,
        SettingsPatchComplianceSettingsResponseBody,
        SettingsPatchComplianceSettingsServiceUnavailableErrorResponseBody,
        SettingsPatchComplianceSettingsTooManyRequestsErrorResponseBody,
        SettingsPatchComplianceSettingsUnauthorizedErrorResponseBody,
        SettingsPatchDriverAppSettingsBadGatewayErrorResponseBody,
        SettingsPatchDriverAppSettingsGatewayTimeoutErrorResponseBody,
        SettingsPatchDriverAppSettingsInternalServerErrorResponseBody,
        SettingsPatchDriverAppSettingsMethodNotAllowedErrorResponseBody,
        SettingsPatchDriverAppSettingsNotFoundErrorResponseBody,
        SettingsPatchDriverAppSettingsNotImplementedErrorResponseBody,
        SettingsPatchDriverAppSettingsResponseBody,
        SettingsPatchDriverAppSettingsServiceUnavailableErrorResponseBody,
        SettingsPatchDriverAppSettingsTooManyRequestsErrorResponseBody,
        SettingsPatchDriverAppSettingsUnauthorizedErrorResponseBody,
        SettingsResponseBody,
        SevereSpeedingStartedObjectResponseBody,
        SevereSpeedingStartedResponseObjectResponseBody,
        SignatoryUserObjectResponseBody,
        SignatureFieldTypeMetaDataObjectResponseBody,
        SignatureValueObjectRequestBody,
        SignatureValueObjectResponseBody,
        SingleApprovalRequirementsObjectResponseBody,
        SingleDriverEfficiencyByDriverDataObjectResponseBody,
        SingleDriverEfficiencyByVehicleDataObjectResponseBody,
        SingleUseLocationObjectResponseBody,
        SiteGatewayDisconnectedResponseBody,
        SkillObjectResponseBody,
        SpecificVehicleFaultCodeObjectRequestBody,
        SpecificVehicleFaultCodeObjectRequestBodyType,
        SpecificVehicleFaultCodeObjectResponseBody,
        SpecificVehicleFaultCodeObjectResponseBodyType,
        SpeedDataResponseBody,
        SpeedDataResponseBodyOperation,
        SpeedResponseResponseBody,
        SpeedTriggerDetailsObjectRequestBody,
        SpeedTriggerDetailsObjectRequestBodyOperation,
        SpeedTriggerDetailsObjectResponseBody,
        SpeedTriggerDetailsObjectResponseBodyOperation,
        SpeedingIntervalLocationResponseResponseBody,
        SpeedingIntervalResponseBody,
        SpeedingIntervalResponseBodySeverityLevel,
        SpeedingIntervalsGetSpeedingIntervalsBadGatewayErrorResponseBody,
        SpeedingIntervalsGetSpeedingIntervalsGatewayTimeoutErrorResponseBody,
        SpeedingIntervalsGetSpeedingIntervalsInternalServerErrorResponseBody,
        SpeedingIntervalsGetSpeedingIntervalsMethodNotAllowedErrorResponseBody,
        SpeedingIntervalsGetSpeedingIntervalsNotFoundErrorResponseBody,
        SpeedingIntervalsGetSpeedingIntervalsNotImplementedErrorResponseBody,
        SpeedingIntervalsGetSpeedingIntervalsResponseBody,
        SpeedingIntervalsGetSpeedingIntervalsServiceUnavailableErrorResponseBody,
        SpeedingIntervalsGetSpeedingIntervalsTooManyRequestsErrorResponseBody,
        SpeedingIntervalsGetSpeedingIntervalsUnauthorizedErrorResponseBody,
        SpeedingSettingsObjectResponseBody,
        SpeedingSettingsObjectResponseBodyUnit,
        SpeedingSeverityLevelResponseBody,
        SpeedingSeverityLevelResponseBodySeverityLevel,
        StartFunctionRunResponseBodyResponseBody,
        StopEtaUpdatedEventDetailsResponseBody,
        StopTaskCompletedEventDetailsResponseBody,
        StopTaskCompletedEventDetailsResponseBodyTaskType,
        StopTaskSkippedEventDetailsResponseBody,
        StopTaskSkippedEventDetailsResponseBodyTaskType,
        StringDataPoint,
        SuddenFuelLevelDropResponseBody,
        SuddenFuelLevelDropTriggerDetailsObjectRequestBody,
        SuddenFuelLevelDropTriggerDetailsObjectResponseBody,
        SuddenFuelLevelRiseResponseBody,
        SuddenFuelLevelRiseTriggerDetailsObjectRequestBody,
        SuddenFuelLevelRiseTriggerDetailsObjectResponseBody,
        TachographActivity,
        TachographActivityList,
        TachographActivityListWrapper,
        TachographActivityState,
        TachographDriverFile,
        TachographDriverFileData,
        TachographDriverFileList,
        TachographDriverFileListWrapper,
        TachographDriverFilesResponse,
        TachographVehicleFile,
        TachographVehicleFileData,
        TachographVehicleFileList,
        TachographVehicleFileListWrapper,
        TachographVehicleFilesResponse,
        Tag,
        TagAllOf,
        TagAllOfExternalIds,
        TagGroupSafetyScoreResponseBody,
        TagId,
        TagIds,
        TagName,
        TagResponse,
        TagSafetyScoreResponseBody,
        TagTinyResponse,
        TaggedObject,
        TaggedObjectId,
        TaggedObjectName,
        TamperingDetectedResponseBody,
        Time,
        TimeRangeObjectRequestBody,
        TimeRangeObjectRequestBodyDaysOfWeekItem,
        TimeRangeObjectResponseBody,
        TimeRangeObjectResponseBodyDaysOfWeekItem,
        TinyAssetObjectRequestBody,
        TinyAssetObjectRequestBodyAssetType,
        TinyAssetObjectResponseBody,
        TinyAssetObjectResponseBodyAssetType,
        TinyDriverObjectRequestBody,
        TinyDriverObjectResponseBody,
        TinyTag,
        TinyWidgetObjectRequestBody,
        TinyWidgetObjectResponseBody,
        TireFaultCodeDetailsObjectRequestBody,
        TireFaultCodeDetailsObjectRequestBodyManufacturer,
        TireFaultCodeDetailsObjectRequestBodySpecificTireFaultCodesItem,
        TireFaultCodeDetailsObjectResponseBody,
        TireFaultCodeDetailsObjectResponseBodyManufacturer,
        TireFaultCodeDetailsObjectResponseBodySpecificTireFaultCodesItem,
        TireFaultsResponseBody,
        TotalBrakeEventCount,
        TrailerAssignmentsCreateDriverTrailerAssignmentBadGatewayErrorResponseBody,
        TrailerAssignmentsCreateDriverTrailerAssignmentGatewayTimeoutErrorResponseBody,
        TrailerAssignmentsCreateDriverTrailerAssignmentInternalServerErrorResponseBody,
        TrailerAssignmentsCreateDriverTrailerAssignmentMethodNotAllowedErrorResponseBody,
        TrailerAssignmentsCreateDriverTrailerAssignmentNotFoundErrorResponseBody,
        TrailerAssignmentsCreateDriverTrailerAssignmentNotImplementedErrorResponseBody,
        TrailerAssignmentsCreateDriverTrailerAssignmentResponseBody,
        TrailerAssignmentsCreateDriverTrailerAssignmentServiceUnavailableErrorResponseBody,
        TrailerAssignmentsCreateDriverTrailerAssignmentTooManyRequestsErrorResponseBody,
        TrailerAssignmentsCreateDriverTrailerAssignmentUnauthorizedErrorResponseBody,
        TrailerAssignmentsGetDriverTrailerAssignmentsBadGatewayErrorResponseBody,
        TrailerAssignmentsGetDriverTrailerAssignmentsGatewayTimeoutErrorResponseBody,
        TrailerAssignmentsGetDriverTrailerAssignmentsInternalServerErrorResponseBody,
        TrailerAssignmentsGetDriverTrailerAssignmentsMethodNotAllowedErrorResponseBody,
        TrailerAssignmentsGetDriverTrailerAssignmentsNotFoundErrorResponseBody,
        TrailerAssignmentsGetDriverTrailerAssignmentsNotImplementedErrorResponseBody,
        TrailerAssignmentsGetDriverTrailerAssignmentsResponseBody,
        TrailerAssignmentsGetDriverTrailerAssignmentsServiceUnavailableErrorResponseBody,
        TrailerAssignmentsGetDriverTrailerAssignmentsTooManyRequestsErrorResponseBody,
        TrailerAssignmentsGetDriverTrailerAssignmentsUnauthorizedErrorResponseBody,
        TrailerAssignmentsUpdateDriverTrailerAssignmentBadGatewayErrorResponseBody,
        TrailerAssignmentsUpdateDriverTrailerAssignmentGatewayTimeoutErrorResponseBody,
        TrailerAssignmentsUpdateDriverTrailerAssignmentInternalServerErrorResponseBody,
        TrailerAssignmentsUpdateDriverTrailerAssignmentMethodNotAllowedErrorResponseBody,
        TrailerAssignmentsUpdateDriverTrailerAssignmentNotFoundErrorResponseBody,
        TrailerAssignmentsUpdateDriverTrailerAssignmentNotImplementedErrorResponseBody,
        TrailerAssignmentsUpdateDriverTrailerAssignmentResponseBody,
        TrailerAssignmentsUpdateDriverTrailerAssignmentServiceUnavailableErrorResponseBody,
        TrailerAssignmentsUpdateDriverTrailerAssignmentTooManyRequestsErrorResponseBody,
        TrailerAssignmentsUpdateDriverTrailerAssignmentUnauthorizedErrorResponseBody,
        TrailerDvirObjectResponseBody,
        TrailerGoaGatewayTinyResponseResponseBody,
        TrailerGoaGatewayTinyResponseResponseBodyModel,
        TrailerObjectResponseBody,
        TrailerResponseObjectResponseBody,
        TrailerStatDecorationResponseBody,
        TrailerStatGpsOdometerMetersTypeResponseBody,
        TrailerStatGpsOdometerMetersWithDecorationsTypeResponseBody,
        TrailerStatGpsTypeResponseBody,
        TrailerStatGpsWithDecorationsTypeResponseBody,
        TrailerStatReeferAlarmResponseBody,
        TrailerStatReeferAlarmTypeResponseBody,
        TrailerStatReeferAlarmWithDecorationsTypeResponseBody,
        TrailerStatReeferAmbientAirTemperatureMilliCTypeResponseBody,
        TrailerStatReeferAmbientAirTemperatureWithDecorationsTypeResponseBody,
        TrailerStatReeferDoorStateZone1TypeResponseBody,
        TrailerStatReeferDoorStateZone1TypeResponseBodyValue,
        TrailerStatReeferDoorStateZone1WithDecorationsTypeResponseBody,
        TrailerStatReeferDoorStateZone1WithDecorationsTypeResponseBodyValue,
        TrailerStatReeferDoorStateZone2TypeResponseBody,
        TrailerStatReeferDoorStateZone2TypeResponseBodyValue,
        TrailerStatReeferDoorStateZone2WithDecorationsTypeResponseBody,
        TrailerStatReeferDoorStateZone2WithDecorationsTypeResponseBodyValue,
        TrailerStatReeferDoorStateZone3TypeResponseBody,
        TrailerStatReeferDoorStateZone3TypeResponseBodyValue,
        TrailerStatReeferDoorStateZone3WithDecorationsTypeResponseBody,
        TrailerStatReeferDoorStateZone3WithDecorationsTypeResponseBodyValue,
        TrailerStatReeferFuelPercentTypeResponseBody,
        TrailerStatReeferFuelPercentWithDecorationsTypeResponseBody,
        TrailerStatReeferObdEngineSecondsTypeResponseBody,
        TrailerStatReeferObdEngineSecondsWithDecorationsTypeResponseBody,
        TrailerStatReeferReturnAirTemperatureMilliCZone1TypeResponseBody,
        TrailerStatReeferReturnAirTemperatureMilliCZone1WithDecorationsTypeResponseBody,
        TrailerStatReeferReturnAirTemperatureMilliCZone2TypeResponseBody,
        TrailerStatReeferReturnAirTemperatureMilliCZone2WithDecorationsTypeResponseBody,
        TrailerStatReeferReturnAirTemperatureMilliCZone3TypeResponseBody,
        TrailerStatReeferReturnAirTemperatureMilliCZone3WithDecorationsTypeResponseBody,
        TrailerStatReeferRunModeTypeResponseBody,
        TrailerStatReeferRunModeWithDecorationsTypeResponseBody,
        TrailerStatReeferSetPointTemperatureMilliCZone1TypeResponseBody,
        TrailerStatReeferSetPointTemperatureMilliCZone1WithDecorationsTypeResponseBody,
        TrailerStatReeferSetPointTemperatureMilliCZone2TypeResponseBody,
        TrailerStatReeferSetPointTemperatureMilliCZone2WithDecorationsTypeResponseBody,
        TrailerStatReeferSetPointTemperatureMilliCZone3TypeResponseBody,
        TrailerStatReeferSetPointTemperatureMilliCZone3WithDecorationsTypeResponseBody,
        TrailerStatReeferStateTypeResponseBody,
        TrailerStatReeferStateWithDecorationsTypeResponseBody,
        TrailerStatReeferStateZone1TypeResponseBody,
        TrailerStatReeferStateZone1WithDecorationsTypeResponseBody,
        TrailerStatReeferStateZone2TypeResponseBody,
        TrailerStatReeferStateZone2WithDecorationsTypeResponseBody,
        TrailerStatReeferStateZone3TypeResponseBody,
        TrailerStatReeferStateZone3WithDecorationsTypeResponseBody,
        TrailerStatReeferSupplyAirTemperatureMilliCZone1TypeResponseBody,
        TrailerStatReeferSupplyAirTemperatureMilliCZone1WithDecorationsTypeResponseBody,
        TrailerStatReeferSupplyAirTemperatureMilliCZone2TypeResponseBody,
        TrailerStatReeferSupplyAirTemperatureMilliCZone2WithDecorationsTypeResponseBody,
        TrailerStatReeferSupplyAirTemperatureMilliCZone3TypeResponseBody,
        TrailerStatReeferSupplyAirTemperatureMilliCZone3WithDecorationsTypeResponseBody,
        TrailerStatsGetTrailerStatsFeedBadGatewayErrorResponseBody,
        TrailerStatsGetTrailerStatsFeedGatewayTimeoutErrorResponseBody,
        TrailerStatsGetTrailerStatsFeedInternalServerErrorResponseBody,
        TrailerStatsGetTrailerStatsFeedMethodNotAllowedErrorResponseBody,
        TrailerStatsGetTrailerStatsFeedNotFoundErrorResponseBody,
        TrailerStatsGetTrailerStatsFeedNotImplementedErrorResponseBody,
        TrailerStatsGetTrailerStatsFeedResponseBody,
        TrailerStatsGetTrailerStatsFeedServiceUnavailableErrorResponseBody,
        TrailerStatsGetTrailerStatsFeedTooManyRequestsErrorResponseBody,
        TrailerStatsGetTrailerStatsFeedUnauthorizedErrorResponseBody,
        TrailerStatsGetTrailerStatsHistoryBadGatewayErrorResponseBody,
        TrailerStatsGetTrailerStatsHistoryGatewayTimeoutErrorResponseBody,
        TrailerStatsGetTrailerStatsHistoryInternalServerErrorResponseBody,
        TrailerStatsGetTrailerStatsHistoryMethodNotAllowedErrorResponseBody,
        TrailerStatsGetTrailerStatsHistoryNotFoundErrorResponseBody,
        TrailerStatsGetTrailerStatsHistoryNotImplementedErrorResponseBody,
        TrailerStatsGetTrailerStatsHistoryResponseBody,
        TrailerStatsGetTrailerStatsHistoryServiceUnavailableErrorResponseBody,
        TrailerStatsGetTrailerStatsHistoryTooManyRequestsErrorResponseBody,
        TrailerStatsGetTrailerStatsHistoryUnauthorizedErrorResponseBody,
        TrailerStatsGetTrailerStatsSnapshotBadGatewayErrorResponseBody,
        TrailerStatsGetTrailerStatsSnapshotGatewayTimeoutErrorResponseBody,
        TrailerStatsGetTrailerStatsSnapshotInternalServerErrorResponseBody,
        TrailerStatsGetTrailerStatsSnapshotMethodNotAllowedErrorResponseBody,
        TrailerStatsGetTrailerStatsSnapshotNotFoundErrorResponseBody,
        TrailerStatsGetTrailerStatsSnapshotNotImplementedErrorResponseBody,
        TrailerStatsGetTrailerStatsSnapshotResponseBody,
        TrailerStatsGetTrailerStatsSnapshotServiceUnavailableErrorResponseBody,
        TrailerStatsGetTrailerStatsSnapshotTooManyRequestsErrorResponseBody,
        TrailerStatsGetTrailerStatsSnapshotUnauthorizedErrorResponseBody,
        TrailerStatsObjectResponseBody,
        TrailerStatsSnapshotObjectResponseBody,
        TrailerTinyResponse,
        TrailerWithAttributesResponseObjectResponseBody,
        TrailersCreateTrailerBadGatewayErrorResponseBody,
        TrailersCreateTrailerGatewayTimeoutErrorResponseBody,
        TrailersCreateTrailerInternalServerErrorResponseBody,
        TrailersCreateTrailerMethodNotAllowedErrorResponseBody,
        TrailersCreateTrailerNotFoundErrorResponseBody,
        TrailersCreateTrailerNotImplementedErrorResponseBody,
        TrailersCreateTrailerResponseBody,
        TrailersCreateTrailerServiceUnavailableErrorResponseBody,
        TrailersCreateTrailerTooManyRequestsErrorResponseBody,
        TrailersCreateTrailerUnauthorizedErrorResponseBody,
        TrailersDeleteTrailerBadGatewayErrorResponseBody,
        TrailersDeleteTrailerGatewayTimeoutErrorResponseBody,
        TrailersDeleteTrailerInternalServerErrorResponseBody,
        TrailersDeleteTrailerMethodNotAllowedErrorResponseBody,
        TrailersDeleteTrailerNotFoundErrorResponseBody,
        TrailersDeleteTrailerNotImplementedErrorResponseBody,
        TrailersDeleteTrailerServiceUnavailableErrorResponseBody,
        TrailersDeleteTrailerTooManyRequestsErrorResponseBody,
        TrailersDeleteTrailerUnauthorizedErrorResponseBody,
        TrailersGetTrailerBadGatewayErrorResponseBody,
        TrailersGetTrailerGatewayTimeoutErrorResponseBody,
        TrailersGetTrailerInternalServerErrorResponseBody,
        TrailersGetTrailerMethodNotAllowedErrorResponseBody,
        TrailersGetTrailerNotFoundErrorResponseBody,
        TrailersGetTrailerNotImplementedErrorResponseBody,
        TrailersGetTrailerResponseBody,
        TrailersGetTrailerServiceUnavailableErrorResponseBody,
        TrailersGetTrailerTooManyRequestsErrorResponseBody,
        TrailersGetTrailerUnauthorizedErrorResponseBody,
        TrailersListTrailersBadGatewayErrorResponseBody,
        TrailersListTrailersGatewayTimeoutErrorResponseBody,
        TrailersListTrailersInternalServerErrorResponseBody,
        TrailersListTrailersMethodNotAllowedErrorResponseBody,
        TrailersListTrailersNotFoundErrorResponseBody,
        TrailersListTrailersNotImplementedErrorResponseBody,
        TrailersListTrailersResponseBody,
        TrailersListTrailersServiceUnavailableErrorResponseBody,
        TrailersListTrailersTooManyRequestsErrorResponseBody,
        TrailersListTrailersUnauthorizedErrorResponseBody,
        TrailersUpdateTrailerBadGatewayErrorResponseBody,
        TrailersUpdateTrailerGatewayTimeoutErrorResponseBody,
        TrailersUpdateTrailerInternalServerErrorResponseBody,
        TrailersUpdateTrailerMethodNotAllowedErrorResponseBody,
        TrailersUpdateTrailerNotFoundErrorResponseBody,
        TrailersUpdateTrailerNotImplementedErrorResponseBody,
        TrailersUpdateTrailerResponseBody,
        TrailersUpdateTrailerServiceUnavailableErrorResponseBody,
        TrailersUpdateTrailerTooManyRequestsErrorResponseBody,
        TrailersUpdateTrailerUnauthorizedErrorResponseBody,
        TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectRequestBody,
        TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectRequestBodyAssignmentGroupType,
        TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectResponseBody,
        TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectResponseBodyAssignmentGroupType,
        TrainingAssignmentNearDueDateTriggerDetailsObjectRequestBody,
        TrainingAssignmentNearDueDateTriggerDetailsObjectRequestBodyConditionUnits,
        TrainingAssignmentNearDueDateTriggerDetailsObjectResponseBody,
        TrainingAssignmentNearDueDateTriggerDetailsObjectResponseBodyConditionUnits,
        TrainingAssignmentPostResponseObjectResponseBody,
        TrainingAssignmentResponseObjectResponseBody,
        TrainingAssignmentResponseObjectResponseBodyStatus,
        TrainingAssignmentsDeleteTrainingAssignmentsBadGatewayErrorResponseBody,
        TrainingAssignmentsDeleteTrainingAssignmentsGatewayTimeoutErrorResponseBody,
        TrainingAssignmentsDeleteTrainingAssignmentsInternalServerErrorResponseBody,
        TrainingAssignmentsDeleteTrainingAssignmentsMethodNotAllowedErrorResponseBody,
        TrainingAssignmentsDeleteTrainingAssignmentsNotFoundErrorResponseBody,
        TrainingAssignmentsDeleteTrainingAssignmentsNotImplementedErrorResponseBody,
        TrainingAssignmentsDeleteTrainingAssignmentsServiceUnavailableErrorResponseBody,
        TrainingAssignmentsDeleteTrainingAssignmentsTooManyRequestsErrorResponseBody,
        TrainingAssignmentsDeleteTrainingAssignmentsUnauthorizedErrorResponseBody,
        TrainingAssignmentsGetTrainingAssignmentsStreamBadGatewayErrorResponseBody,
        TrainingAssignmentsGetTrainingAssignmentsStreamGatewayTimeoutErrorResponseBody,
        TrainingAssignmentsGetTrainingAssignmentsStreamInternalServerErrorResponseBody,
        TrainingAssignmentsGetTrainingAssignmentsStreamMethodNotAllowedErrorResponseBody,
        TrainingAssignmentsGetTrainingAssignmentsStreamNotFoundErrorResponseBody,
        TrainingAssignmentsGetTrainingAssignmentsStreamNotImplementedErrorResponseBody,
        TrainingAssignmentsGetTrainingAssignmentsStreamResponseBody,
        TrainingAssignmentsGetTrainingAssignmentsStreamServiceUnavailableErrorResponseBody,
        TrainingAssignmentsGetTrainingAssignmentsStreamTooManyRequestsErrorResponseBody,
        TrainingAssignmentsGetTrainingAssignmentsStreamUnauthorizedErrorResponseBody,
        TrainingAssignmentsPatchTrainingAssignmentsBadGatewayErrorResponseBody,
        TrainingAssignmentsPatchTrainingAssignmentsGatewayTimeoutErrorResponseBody,
        TrainingAssignmentsPatchTrainingAssignmentsInternalServerErrorResponseBody,
        TrainingAssignmentsPatchTrainingAssignmentsMethodNotAllowedErrorResponseBody,
        TrainingAssignmentsPatchTrainingAssignmentsNotFoundErrorResponseBody,
        TrainingAssignmentsPatchTrainingAssignmentsNotImplementedErrorResponseBody,
        TrainingAssignmentsPatchTrainingAssignmentsResponseBody,
        TrainingAssignmentsPatchTrainingAssignmentsServiceUnavailableErrorResponseBody,
        TrainingAssignmentsPatchTrainingAssignmentsTooManyRequestsErrorResponseBody,
        TrainingAssignmentsPatchTrainingAssignmentsUnauthorizedErrorResponseBody,
        TrainingAssignmentsPostTrainingAssignmentsBadGatewayErrorResponseBody,
        TrainingAssignmentsPostTrainingAssignmentsGatewayTimeoutErrorResponseBody,
        TrainingAssignmentsPostTrainingAssignmentsInternalServerErrorResponseBody,
        TrainingAssignmentsPostTrainingAssignmentsMethodNotAllowedErrorResponseBody,
        TrainingAssignmentsPostTrainingAssignmentsNotFoundErrorResponseBody,
        TrainingAssignmentsPostTrainingAssignmentsNotImplementedErrorResponseBody,
        TrainingAssignmentsPostTrainingAssignmentsResponseBody,
        TrainingAssignmentsPostTrainingAssignmentsServiceUnavailableErrorResponseBody,
        TrainingAssignmentsPostTrainingAssignmentsTooManyRequestsErrorResponseBody,
        TrainingAssignmentsPostTrainingAssignmentsUnauthorizedErrorResponseBody,
        TrainingCategoryObjectResponseBody,
        TrainingCourseLabelObjectResponseBody,
        TrainingCourseObjectResponseBody,
        TrainingCourseResponseObjectResponseBody,
        TrainingCourseResponseObjectResponseBodyStatus,
        TrainingCoursesGetTrainingCoursesBadGatewayErrorResponseBody,
        TrainingCoursesGetTrainingCoursesGatewayTimeoutErrorResponseBody,
        TrainingCoursesGetTrainingCoursesInternalServerErrorResponseBody,
        TrainingCoursesGetTrainingCoursesMethodNotAllowedErrorResponseBody,
        TrainingCoursesGetTrainingCoursesNotFoundErrorResponseBody,
        TrainingCoursesGetTrainingCoursesNotImplementedErrorResponseBody,
        TrainingCoursesGetTrainingCoursesResponseBody,
        TrainingCoursesGetTrainingCoursesServiceUnavailableErrorResponseBody,
        TrainingCoursesGetTrainingCoursesTooManyRequestsErrorResponseBody,
        TrainingCoursesGetTrainingCoursesUnauthorizedErrorResponseBody,
        TrainingLearnerObjectResponseBody,
        TrainingLearnerObjectResponseBodyType,
        TriggerParamsObjectRequestBody,
        TriggerParamsObjectResponseBody,
        TripAssetResponseBody,
        TripAssetResponseBodyType,
        TripResponseBody,
        TripResponseBodyCompletionStatus,
        TripSpeedingIntervalsResponseBody,
        TripsBreakdownResponseBody,
        TripsGetTripsBadGatewayErrorResponseBody,
        TripsGetTripsGatewayTimeoutErrorResponseBody,
        TripsGetTripsInternalServerErrorResponseBody,
        TripsGetTripsMethodNotAllowedErrorResponseBody,
        TripsGetTripsNotFoundErrorResponseBody,
        TripsGetTripsNotImplementedErrorResponseBody,
        TripsGetTripsResponseBody,
        TripsGetTripsServiceUnavailableErrorResponseBody,
        TripsGetTripsTooManyRequestsErrorResponseBody,
        TripsGetTripsUnauthorizedErrorResponseBody,
        UnassignedDrivingDataResponseBody,
        UnassignedDrivingTriggerDetailsObjectRequestBody,
        UnassignedDrivingTriggerDetailsObjectResponseBody,
        UpdateAddressRequestGeofence,
        UpdateDriverRequestAttributes,
        UpdateDriverRequestHosSetting,
        UpdateEngineImmobilizerRelayStateRequestBodyRequestBody,
        UpdateEngineImmobilizerRelayStateRequestBodyRequestBodyId,
        UpdateHubLocationRequestBodyRequestBody,
        UpdateRoutesStopRequestObjectRequestBody,
        UploadedMediaObjectResponseBody,
        UploadedMediaObjectResponseBodyCameraRole,
        UploadedMediaObjectResponseBodyInput,
        UploadedMediaObjectResponseBodyMediaType,
        UploadedMediaObjectResponseBodyTriggerReason,
        UrlInfoObjectResponseBody,
        UsDriverRulesetOverride,
        UsDriverRulesetOverrideCycle,
        UsDriverRulesetOverrideRestart,
        UsDriverRulesetOverrideRestbreak,
        UsDriverRulesetOverrideUsStateToOverride,
        User,
        UserAuthType,
        UserEmail,
        UserExpireAt,
        UserId,
        UserIdentifierSerial,
        UserName,
        UserResponse,
        UserRole,
        UserRoleAssignment,
        UserRoles,
        UserTinyResponse,
        V1Asset,
        V1AssetCable,
        V1AssetCurrentLocation,
        V1AssetCurrentLocationsResponse,
        V1AssetLocationResponse,
        V1AssetLocationResponseItem,
        V1AssetReeferResponse,
        V1AssetReeferResponseReeferStats,
        V1AssetReeferResponseReeferStatsAlarms,
        V1AssetReeferResponseReeferStatsAlarms1,
        V1AssetReeferResponseReeferStatsEngineHours,
        V1AssetReeferResponseReeferStatsFuelPercentage,
        V1AssetReeferResponseReeferStatsPowerStatus,
        V1AssetReeferResponseReeferStatsReturnAirTemp,
        V1AssetReeferResponseReeferStatsSetPoint,
        V1AssetsReefer,
        V1AssetsReeferReeferStats,
        V1AssetsReeferReeferStatsAmbientAirTemperature,
        V1AssetsReeferReeferStatsDischargeAirTemperature,
        V1AssetsReeferReeferStatsPowerStatus,
        V1AssetsReeferReeferStatsPowerStatusStatus,
        V1CargoResponse,
        V1CargoResponseSensors,
        V1DoorResponse,
        V1DoorResponseSensors,
        V1DriverSafetyScoreResponse,
        V1HosAuthenticationLogsResponse,
        V1HosAuthenticationLogsResponseAuthenticationLogs,
        V1HumidityResponse,
        V1HumidityResponseSensors,
        V1Machine,
        V1MachineHistoryResponse,
        V1MachineHistoryResponseMachines,
        V1MachineHistoryResponseVibrations,
        V1Message,
        V1MessageResponse,
        V1MessageSender,
        V1Messages,
        V1MessagesResponse,
        V1Pagination,
        V1ProgramsForTheCameraResponse,
        V1ProgramsForTheCameraResponseItem,
        V1SafetyReportHarshEvent,
        V1Sensor,
        V1SensorHistoryResponse,
        V1SensorHistoryResponseResults,
        V1SensorsHistorySeries,
        V1SensorsHistorySeriesField,
        V1TemperatureResponse,
        V1TemperatureResponseSensors,
        V1TrailerAssignmentResponse,
        V1TrailerAssignmentsResponse,
        V1TrailerAssignmentsResponseAllOf,
        V1TrailerBase,
        V1TripResponse,
        V1TripResponseEndAddress,
        V1TripResponseEndCoordinates,
        V1TripResponseStartAddress,
        V1TripResponseStartCoordinates,
        V1TripResponseTrips,
        V1VehicleHarshEventResponse,
        V1VehicleHarshEventResponseLocation,
        V1VehicleMaintenance,
        V1VehicleMaintenanceJ1939,
        V1VehicleMaintenanceJ1939CheckEngineLight,
        V1VehicleMaintenanceJ1939DiagnosticTroubleCodes,
        V1VehicleMaintenancePassenger,
        V1VehicleMaintenancePassengerCheckEngineLight,
        V1VehicleMaintenancePassengerDiagnosticTroubleCodes,
        V1VehicleSafetyScoreResponse,
        V1VisionCamerasResponse,
        V1VisionCamerasResponseItem,
        V1VisionRunByCameraResponse,
        V1VisionRunByCameraResponseInspectionResults,
        V1VisionRunByCameraResponseProgram,
        V1VisionRunByCameraResponseRunSummary,
        V1VisionRunsByCameraAndProgramResponse,
        V1VisionRunsByCameraResponse,
        V1VisionRunsByCameraResponseItem,
        V1VisionRunsByCameraResponseItemProgram,
        V1VisionRunsByCameraResponseItemReportMetadata,
        V1VisionRunsResponse,
        V1VisionRunsResponseReportMetadata,
        V1VisionRunsResponseVisionRuns,
        V1VisionStepResults,
        V1VisionStepResultsItem,
        V1VisionStepResultsItemAngleCheck,
        V1VisionStepResultsItemAngleCheckAngleConfigured,
        V1VisionStepResultsItemBarcodeItem,
        V1VisionStepResultsItemBooleanLogic,
        V1VisionStepResultsItemBooleanLogicStepsItem,
        V1VisionStepResultsItemCaliper,
        V1VisionStepResultsItemCaliperAngleRange,
        V1VisionStepResultsItemCaliperContrastRange,
        V1VisionStepResultsItemCaliperFilterPolarity,
        V1VisionStepResultsItemCaliperSharpnessRange,
        V1VisionStepResultsItemCaliperStraightnessRange,
        V1VisionStepResultsItemContour,
        V1VisionStepResultsItemDistance,
        V1VisionStepResultsItemExpirationDate,
        V1VisionStepResultsItemFindCopies,
        V1VisionStepResultsItemFindEdge,
        V1VisionStepResultsItemFindEdgeAngleRange,
        V1VisionStepResultsItemFindEdgeContrastRange,
        V1VisionStepResultsItemFindEdgeSharpnessRange,
        V1VisionStepResultsItemFindEdgeStraightnessRange,
        V1VisionStepResultsItemFindShapes,
        V1VisionStepResultsItemFixture,
        V1VisionStepResultsItemFixtureCoordinates,
        V1VisionStepResultsItemLabelMatch,
        V1VisionStepResultsItemPresenceAbsence,
        V1VisionStepResultsItemPresenceAbsenceBlueRange,
        V1VisionStepResultsItemPresenceAbsenceGrayscaleRange,
        V1VisionStepResultsItemPresenceAbsenceGreenRange,
        V1VisionStepResultsItemPresenceAbsenceHueRange,
        V1VisionStepResultsItemPresenceAbsenceRedRange,
        V1VisionStepResultsItemPresenceAbsenceSaturationRange,
        V1VisionStepResultsItemPresenceAbsenceValueRange,
        V1VisionStepResultsItemTextMatch,
        Vehicle,
        VehicleAssignmentObjectResponseBody,
        VehicleAssignmentObjectResponseBodyAssignmentType,
        VehicleAuxInputName,
        VehicleAuxInputType,
        VehicleBatterVoltageDetailsObjectRequestBody,
        VehicleBatterVoltageDetailsObjectRequestBodyOperation,
        VehicleBatterVoltageDetailsObjectResponseBody,
        VehicleBatterVoltageDetailsObjectResponseBodyOperation,
        VehicleBatteryVoltageResponseBody,
        VehicleDefLevelPercentageResponseBody,
        VehicleDetectedResponseBody,
        VehicleDvirObjectResponseBody,
        VehicleEsn,
        VehicleExternalIds,
        VehicleFaultCodeDetailsObjectRequestBody,
        VehicleFaultCodeDetailsObjectResponseBody,
        VehicleFaultsResponseBody,
        VehicleHarshAccelerationSettingType,
        VehicleId,
        VehicleLicensePlate,
        VehicleLocation,
        VehicleLocationAddress,
        VehicleLocationHeading,
        VehicleLocationIsEcuSpeed,
        VehicleLocationLatitude,
        VehicleLocationLongitude,
        VehicleLocationSpeed,
        VehicleLocationsListResponse,
        VehicleLocationsListResponseData,
        VehicleLocationsResponse,
        VehicleLocationsResponseData,
        VehicleMake,
        VehicleModel,
        VehicleName,
        VehicleNotes,
        VehicleRegulationMode,
        VehicleResponse,
        VehicleResponseObjectResponseBody,
        VehicleResponseObjectResponseBodyVehicleRegulationMode,
        VehicleResponseObjectResponseBodyVehicleType,
        VehicleResponseResponseBody,
        VehicleResponseResponseBodyAssetType,
        VehicleSafetyScoreResponseBody,
        VehicleSensorConfiguration,
        VehicleSensorConfigurationArea,
        VehicleSensorConfigurationAreaPosition,
        VehicleSensorConfigurationAreaResponseBody,
        VehicleSensorConfigurationAreaResponseBodyPosition,
        VehicleSensorConfigurationDoor,
        VehicleSensorConfigurationDoorPosition,
        VehicleSensorConfigurationDoorResponseBody,
        VehicleSensorConfigurationDoorResponseBodyPosition,
        VehicleSensorConfigurationResponseBody,
        VehicleStatsAmbientAirTempMilliC,
        VehicleStatsAmbientAirTempMilliCValue,
        VehicleStatsAmbientAirTempMilliCWithDecoration,
        VehicleStatsAuxInput,
        VehicleStatsAuxInputDecoration,
        VehicleStatsAuxInputTime,
        VehicleStatsAuxInputValue,
        VehicleStatsAuxInputWithDecoration,
        VehicleStatsBarometricPressurePa,
        VehicleStatsBarometricPressurePaValue,
        VehicleStatsBarometricPressurePaWithDecoration,
        VehicleStatsBatteryMilliVoltsValue,
        VehicleStatsBatteryVoltage,
        VehicleStatsBatteryVoltageWithDecoration,
        VehicleStatsDecorations,
        VehicleStatsDecorationsAmbientAirTemperatureMilliC,
        VehicleStatsDecorationsBarometricPressurePa,
        VehicleStatsDecorationsBatteryMilliVolts,
        VehicleStatsDecorationsDefLevelMilliPercent,
        VehicleStatsDecorationsEcuSpeedMph,
        VehicleStatsDecorationsEngineCoolantTemperatureMilliC,
        VehicleStatsDecorationsEngineLoadPercent,
        VehicleStatsDecorationsEngineOilPressureKPa,
        VehicleStatsDecorationsEngineRpm,
        VehicleStatsDecorationsEngineStates,
        VehicleStatsDecorationsEngineStatesValue,
        VehicleStatsDecorationsFuelConsumedMilliliters,
        VehicleStatsDecorationsFuelPercents,
        VehicleStatsDecorationsGps,
        VehicleStatsDecorationsGpsDistanceMeters,
        VehicleStatsDecorationsGpsOdometerMeters,
        VehicleStatsDecorationsIdlingDurationMilliseconds,
        VehicleStatsDecorationsIntakeManifoldTemperatureMilliC,
        VehicleStatsDecorationsObdEngineSeconds,
        VehicleStatsDecorationsObdOdometerMeters,
        VehicleStatsDefLevelMilliPercent,
        VehicleStatsDefLevelMilliPercentValue,
        VehicleStatsDefLevelMilliPercentWithDecoration,
        VehicleStatsEcuDoorStatus,
        VehicleStatsEcuDoorStatusValue,
        VehicleStatsEcuSpeedMph,
        VehicleStatsEcuSpeedMphValue,
        VehicleStatsEcuSpeedMphWithDecoration,
        VehicleStatsEngineCoolantTempMilliC,
        VehicleStatsEngineCoolantTempMilliCValue,
        VehicleStatsEngineCoolantTempMilliCWithDecoration,
        VehicleStatsEngineImmobilizer,
        VehicleStatsEngineImmobilizerState,
        VehicleStatsEngineImmobilizerWithDecoration,
        VehicleStatsEngineImmobilizerWithDecorationState,
        VehicleStatsEngineLoadPercent,
        VehicleStatsEngineLoadPercentValue,
        VehicleStatsEngineLoadPercentWithDecoration,
        VehicleStatsEngineOilPressureKPa,
        VehicleStatsEngineOilPressureKPaValue,
        VehicleStatsEngineOilPressureKPaWithDecoration,
        VehicleStatsEngineRpm,
        VehicleStatsEngineRpmValue,
        VehicleStatsEngineRpmWithDecoration,
        VehicleStatsEngineState,
        VehicleStatsEngineStateSetting,
        VehicleStatsEngineStateWithDecoration,
        VehicleStatsEvAverageBatteryTemperatureMilliCelsius,
        VehicleStatsEvBatteryCurrentMilliAmp,
        VehicleStatsEvBatteryStateOfHealthMilliPercent,
        VehicleStatsEvBatteryVoltageMilliVolt,
        VehicleStatsEvChargingCurrentMilliAmp,
        VehicleStatsEvChargingEnergyMicroWh,
        VehicleStatsEvChargingStatus,
        VehicleStatsEvChargingVoltageMilliVolt,
        VehicleStatsEvConsumedEnergyMicroWh,
        VehicleStatsEvDistanceDrivenMeters,
        VehicleStatsEvRegeneratedEnergyMicroWh,
        VehicleStatsEvStateOfChargeMilliPercent,
        VehicleStatsFaultCodes,
        VehicleStatsFaultCodesCanBusType,
        VehicleStatsFaultCodesIgnitionType,
        VehicleStatsFaultCodesJ1939,
        VehicleStatsFaultCodesJ1939Lights,
        VehicleStatsFaultCodesJ1939TroubleCode,
        VehicleStatsFaultCodesJ1939TroubleCodes,
        VehicleStatsFaultCodesObdii,
        VehicleStatsFaultCodesObdiiTroubleCode,
        VehicleStatsFaultCodesOem,
        VehicleStatsFaultCodesOemTroubleCode,
        VehicleStatsFaultCodesOemTroubleCodes,
        VehicleStatsFaultCodesPassengerDtc,
        VehicleStatsFaultCodesPassengerMonitorStatus,
        VehicleStatsFaultCodesPassengerMonitorStatusValue,
        VehicleStatsFaultCodesTxId,
        VehicleStatsFaultCodesValue,
        VehicleStatsFaultCodesValueJ1939,
        VehicleStatsFaultCodesValueJ1939CheckEngineLights,
        VehicleStatsFaultCodesValueJ1939DiagnosticTroubleCodes,
        VehicleStatsFaultCodesValueJ1939VendorSpecificFields,
        VehicleStatsFaultCodesValueObdii,
        VehicleStatsFaultCodesValueObdiiConfirmedDtcs,
        VehicleStatsFaultCodesValueObdiiDiagnosticTroubleCodes,
        VehicleStatsFaultCodesValueObdiiDiagnosticTroubleCodesIgnitionType,
        VehicleStatsFaultCodesValueObdiiMonitorStatus,
        VehicleStatsFaultCodesValueObdiiMonitorStatusCatalyst,
        VehicleStatsFaultCodesValueObdiiMonitorStatusComprehensive,
        VehicleStatsFaultCodesValueObdiiMonitorStatusEgr,
        VehicleStatsFaultCodesValueObdiiMonitorStatusEvapSystem,
        VehicleStatsFaultCodesValueObdiiMonitorStatusFuel,
        VehicleStatsFaultCodesValueObdiiMonitorStatusHeatedCatalyst,
        VehicleStatsFaultCodesValueObdiiMonitorStatusHeatedO2Sensor,
        VehicleStatsFaultCodesValueObdiiMonitorStatusIsoSaeReserved,
        VehicleStatsFaultCodesValueObdiiMonitorStatusMisfire,
        VehicleStatsFaultCodesValueObdiiMonitorStatusO2Sensor,
        VehicleStatsFaultCodesValueObdiiMonitorStatusSecondaryAir,
        VehicleStatsFaultCodesValueOem,
        VehicleStatsFaultCodesValueOemDiagnosticTroubleCodes,
        VehicleStatsFaultCodesVendorSpecificFields,
        VehicleStatsFaultCodesWithDecoration,
        VehicleStatsFuelConsumedMilliliters,
        VehicleStatsFuelConsumedMillilitersValue,
        VehicleStatsFuelConsumedMillilitersWithDecoration,
        VehicleStatsFuelPercent,
        VehicleStatsFuelPercentValue,
        VehicleStatsFuelPercentWithDecoration,
        VehicleStatsGps,
        VehicleStatsGpsDistanceMeters,
        VehicleStatsGpsDistanceMetersValue,
        VehicleStatsGpsDistanceMetersWithDecoration,
        VehicleStatsGpsOdometerMeters,
        VehicleStatsGpsOdometerMetersValue,
        VehicleStatsGpsOdometerMetersWithDecoration,
        VehicleStatsIdlingDurationMilliseconds,
        VehicleStatsIdlingDurationMillisecondsValue,
        VehicleStatsIdlingDurationMillisecondsWithDecoration,
        VehicleStatsIntakeManifoldTempMilliC,
        VehicleStatsIntakeManifoldTempMilliCValue,
        VehicleStatsIntakeManifoldTempMilliCWithDecoration,
        VehicleStatsListGps,
        VehicleStatsListResponse,
        VehicleStatsListResponseData,
        VehicleStatsListSyntheticEngineSeconds,
        VehicleStatsNfcCardScan,
        VehicleStatsNfcCardScanCard,
        VehicleStatsNfcCardScanWithDecoration,
        VehicleStatsObdEngineSeconds,
        VehicleStatsObdEngineSecondsValue,
        VehicleStatsObdEngineSecondsWithDecoration,
        VehicleStatsObdOdometerMeters,
        VehicleStatsObdOdometerMetersValue,
        VehicleStatsObdOdometerMetersWithDecoration,
        VehicleStatsResponse,
        VehicleStatsResponseData,
        VehicleStatsResponseEcuDoorStatus,
        VehicleStatsResponseEcuDoorStatusValue,
        VehicleStatsResponseEvAverageBatteryTemperatureMilliCelsius,
        VehicleStatsResponseEvBatteryCurrentMilliAmp,
        VehicleStatsResponseEvBatteryStateOfHealthMilliPercent,
        VehicleStatsResponseEvBatteryVoltageMilliVolt,
        VehicleStatsResponseEvChargingCurrentMilliAmp,
        VehicleStatsResponseEvChargingEnergyMicroWh,
        VehicleStatsResponseEvChargingStatus,
        VehicleStatsResponseEvChargingVoltageMilliVolt,
        VehicleStatsResponseEvConsumedEnergyMicroWh,
        VehicleStatsResponseEvDistanceDrivenMeters,
        VehicleStatsResponseEvRegeneratedEnergyMicroWh,
        VehicleStatsResponseEvStateOfChargeMilliPercent,
        VehicleStatsResponseSeatbeltDriver,
        VehicleStatsResponseSeatbeltDriverValue,
        VehicleStatsResponseSpreaderActive,
        VehicleStatsResponseSpreaderActiveValue,
        VehicleStatsResponseSpreaderAirTemp,
        VehicleStatsResponseSpreaderBlastState,
        VehicleStatsResponseSpreaderBlastStateValue,
        VehicleStatsResponseSpreaderGranularName,
        VehicleStatsResponseSpreaderGranularRate,
        VehicleStatsResponseSpreaderLiquidName,
        VehicleStatsResponseSpreaderLiquidRate,
        VehicleStatsResponseSpreaderOnState,
        VehicleStatsResponseSpreaderOnStateValue,
        VehicleStatsResponseSpreaderPlowStatus,
        VehicleStatsResponseSpreaderPlowStatusValue,
        VehicleStatsResponseSpreaderPrewetName,
        VehicleStatsResponseSpreaderPrewetRate,
        VehicleStatsResponseSpreaderRoadTemp,
        VehicleStatsSeatbeltDriver,
        VehicleStatsSeatbeltDriverValue,
        VehicleStatsSpreaderActive,
        VehicleStatsSpreaderActiveValue,
        VehicleStatsSpreaderAirTemp,
        VehicleStatsSpreaderBlastState,
        VehicleStatsSpreaderBlastStateValue,
        VehicleStatsSpreaderGranularName,
        VehicleStatsSpreaderGranularRate,
        VehicleStatsSpreaderLiquidName,
        VehicleStatsSpreaderLiquidRate,
        VehicleStatsSpreaderOnState,
        VehicleStatsSpreaderOnStateValue,
        VehicleStatsSpreaderPlowStatus,
        VehicleStatsSpreaderPlowStatusValue,
        VehicleStatsSpreaderPrewetName,
        VehicleStatsSpreaderPrewetRate,
        VehicleStatsSpreaderRoadTemp,
        VehicleStatsSyntheticEngineSeconds,
        VehicleStatsSyntheticEngineSecondsValue,
        VehicleStatsTirePressures,
        VehicleSummary,
        VehicleTags,
        VehicleTinyResponse,
        VehicleType,
        VehicleVin,
        VehicleWithGatewayTinyResponseResponseBody,
        VehicleWithGatewayTinyResponseResponseBodyAssetType,
        VehicleYear,
        VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsBadGatewayErrorResponseBody,
        VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsGatewayTimeoutErrorResponseBody,
        VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsInternalServerErrorResponseBody,
        VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsMethodNotAllowedErrorResponseBody,
        VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsNotFoundErrorResponseBody,
        VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsNotImplementedErrorResponseBody,
        VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsResponseBody,
        VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsServiceUnavailableErrorResponseBody,
        VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsTooManyRequestsErrorResponseBody,
        VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsUnauthorizedErrorResponseBody,
        VehiclesDriverAssignmentsObjectResponseBody,
        VehiclesListVehiclesBadGatewayErrorResponseBody,
        VehiclesListVehiclesGatewayTimeoutErrorResponseBody,
        VehiclesListVehiclesInternalServerErrorResponseBody,
        VehiclesListVehiclesMethodNotAllowedErrorResponseBody,
        VehiclesListVehiclesNotFoundErrorResponseBody,
        VehiclesListVehiclesNotImplementedErrorResponseBody,
        VehiclesListVehiclesResponseBody,
        VehiclesListVehiclesServiceUnavailableErrorResponseBody,
        VehiclesListVehiclesTooManyRequestsErrorResponseBody,
        VehiclesListVehiclesUnauthorizedErrorResponseBody,
        VehiclesLockLockVehicleBadGatewayErrorResponseBody,
        VehiclesLockLockVehicleGatewayTimeoutErrorResponseBody,
        VehiclesLockLockVehicleInternalServerErrorResponseBody,
        VehiclesLockLockVehicleMethodNotAllowedErrorResponseBody,
        VehiclesLockLockVehicleNotFoundErrorResponseBody,
        VehiclesLockLockVehicleNotImplementedErrorResponseBody,
        VehiclesLockLockVehicleServiceUnavailableErrorResponseBody,
        VehiclesLockLockVehicleTooManyRequestsErrorResponseBody,
        VehiclesLockLockVehicleUnauthorizedErrorResponseBody,
        VehiclesLockUnlockVehicleBadGatewayErrorResponseBody,
        VehiclesLockUnlockVehicleGatewayTimeoutErrorResponseBody,
        VehiclesLockUnlockVehicleInternalServerErrorResponseBody,
        VehiclesLockUnlockVehicleMethodNotAllowedErrorResponseBody,
        VehiclesLockUnlockVehicleNotFoundErrorResponseBody,
        VehiclesLockUnlockVehicleNotImplementedErrorResponseBody,
        VehiclesLockUnlockVehicleServiceUnavailableErrorResponseBody,
        VehiclesLockUnlockVehicleTooManyRequestsErrorResponseBody,
        VehiclesLockUnlockVehicleUnauthorizedErrorResponseBody,
        VendorCategoryObjectResponseBody,
        VendorObjectResponseBody,
        VertexRequestBody,
        VertexResponseBody,
        VoiceCoachingSettingsObjectResponseBody,
        VoiceCoachingSettingsObjectResponseBodyEventsToCoachItem,
        VoiceCoachingSettingsObjectResponseBodyLanguage,
        WalkaroundPhotoObjectResponseBody,
        WebhookParamsObjectRequestBody,
        WebhookParamsObjectRequestBodyPayloadType,
        WebhookParamsObjectResponseBody,
        WebhookParamsObjectResponseBodyPayloadType,
        WebhookResponseResponseBody,
        WebhookResponseResponseBodyEventTypesItem,
        WebhookResponseResponseBodyVersion,
        WebhookRouteResponseObjectResponseBody,
        WebhooksDeleteWebhookBadGatewayErrorResponseBody,
        WebhooksDeleteWebhookGatewayTimeoutErrorResponseBody,
        WebhooksDeleteWebhookInternalServerErrorResponseBody,
        WebhooksDeleteWebhookMethodNotAllowedErrorResponseBody,
        WebhooksDeleteWebhookNotFoundErrorResponseBody,
        WebhooksDeleteWebhookNotImplementedErrorResponseBody,
        WebhooksDeleteWebhookServiceUnavailableErrorResponseBody,
        WebhooksDeleteWebhookTooManyRequestsErrorResponseBody,
        WebhooksDeleteWebhookUnauthorizedErrorResponseBody,
        WebhooksGetWebhookBadGatewayErrorResponseBody,
        WebhooksGetWebhookGatewayTimeoutErrorResponseBody,
        WebhooksGetWebhookInternalServerErrorResponseBody,
        WebhooksGetWebhookMethodNotAllowedErrorResponseBody,
        WebhooksGetWebhookNotFoundErrorResponseBody,
        WebhooksGetWebhookNotImplementedErrorResponseBody,
        WebhooksGetWebhookResponseBody,
        WebhooksGetWebhookResponseBodyEventTypesItem,
        WebhooksGetWebhookResponseBodyVersion,
        WebhooksGetWebhookServiceUnavailableErrorResponseBody,
        WebhooksGetWebhookTooManyRequestsErrorResponseBody,
        WebhooksGetWebhookUnauthorizedErrorResponseBody,
        WebhooksListWebhooksBadGatewayErrorResponseBody,
        WebhooksListWebhooksGatewayTimeoutErrorResponseBody,
        WebhooksListWebhooksInternalServerErrorResponseBody,
        WebhooksListWebhooksMethodNotAllowedErrorResponseBody,
        WebhooksListWebhooksNotFoundErrorResponseBody,
        WebhooksListWebhooksNotImplementedErrorResponseBody,
        WebhooksListWebhooksResponseBody,
        WebhooksListWebhooksServiceUnavailableErrorResponseBody,
        WebhooksListWebhooksTooManyRequestsErrorResponseBody,
        WebhooksListWebhooksUnauthorizedErrorResponseBody,
        WebhooksPatchWebhookBadGatewayErrorResponseBody,
        WebhooksPatchWebhookGatewayTimeoutErrorResponseBody,
        WebhooksPatchWebhookInternalServerErrorResponseBody,
        WebhooksPatchWebhookMethodNotAllowedErrorResponseBody,
        WebhooksPatchWebhookNotFoundErrorResponseBody,
        WebhooksPatchWebhookNotImplementedErrorResponseBody,
        WebhooksPatchWebhookResponseBody,
        WebhooksPatchWebhookResponseBodyEventTypesItem,
        WebhooksPatchWebhookResponseBodyVersion,
        WebhooksPatchWebhookServiceUnavailableErrorResponseBody,
        WebhooksPatchWebhookTooManyRequestsErrorResponseBody,
        WebhooksPatchWebhookUnauthorizedErrorResponseBody,
        WebhooksPostWebhooksBadGatewayErrorResponseBody,
        WebhooksPostWebhooksGatewayTimeoutErrorResponseBody,
        WebhooksPostWebhooksInternalServerErrorResponseBody,
        WebhooksPostWebhooksMethodNotAllowedErrorResponseBody,
        WebhooksPostWebhooksNotFoundErrorResponseBody,
        WebhooksPostWebhooksNotImplementedErrorResponseBody,
        WebhooksPostWebhooksResponseBody,
        WebhooksPostWebhooksResponseBodyEventTypesItem,
        WebhooksPostWebhooksResponseBodyVersion,
        WebhooksPostWebhooksServiceUnavailableErrorResponseBody,
        WebhooksPostWebhooksTooManyRequestsErrorResponseBody,
        WebhooksPostWebhooksUnauthorizedErrorResponseBody,
        WorkOrderAttachmentObjectResponseBody,
        WorkOrderAttachmentObjectResponseBodyProcessingStatus,
        WorkOrderDiscountObjectRequestBody,
        WorkOrderDiscountObjectResponseBody,
        WorkOrderItemObjectRequestBody,
        WorkOrderItemObjectRequestBodyType,
        WorkOrderItemObjectResponseBody,
        WorkOrderItemObjectResponseBodyType,
        WorkOrderMoneyObjectRequestBody,
        WorkOrderMoneyObjectRequestBodyCurrency,
        WorkOrderMoneyObjectResponseBody,
        WorkOrderMoneyObjectResponseBodyCurrency,
        WorkOrderObjectResponseBody,
        WorkOrderObjectResponseBodyPriority,
        WorkOrderObjectResponseBodyStatus,
        WorkOrderTaxCreateObjectRequestBody,
        WorkOrderTaxObjectRequestBody,
        WorkOrderTaxObjectResponseBody,
        WorkOrderUnallocatedLaborObjectResponseBody,
        WorkOrdersDeleteWorkOrdersBadGatewayErrorResponseBody,
        WorkOrdersDeleteWorkOrdersGatewayTimeoutErrorResponseBody,
        WorkOrdersDeleteWorkOrdersInternalServerErrorResponseBody,
        WorkOrdersDeleteWorkOrdersMethodNotAllowedErrorResponseBody,
        WorkOrdersDeleteWorkOrdersNotFoundErrorResponseBody,
        WorkOrdersDeleteWorkOrdersNotImplementedErrorResponseBody,
        WorkOrdersDeleteWorkOrdersServiceUnavailableErrorResponseBody,
        WorkOrdersDeleteWorkOrdersTooManyRequestsErrorResponseBody,
        WorkOrdersDeleteWorkOrdersUnauthorizedErrorResponseBody,
        WorkOrdersGetServiceTasksBadGatewayErrorResponseBody,
        WorkOrdersGetServiceTasksGatewayTimeoutErrorResponseBody,
        WorkOrdersGetServiceTasksInternalServerErrorResponseBody,
        WorkOrdersGetServiceTasksMethodNotAllowedErrorResponseBody,
        WorkOrdersGetServiceTasksNotFoundErrorResponseBody,
        WorkOrdersGetServiceTasksNotImplementedErrorResponseBody,
        WorkOrdersGetServiceTasksResponseBody,
        WorkOrdersGetServiceTasksServiceUnavailableErrorResponseBody,
        WorkOrdersGetServiceTasksTooManyRequestsErrorResponseBody,
        WorkOrdersGetServiceTasksUnauthorizedErrorResponseBody,
        WorkOrdersGetWorkOrdersBadGatewayErrorResponseBody,
        WorkOrdersGetWorkOrdersGatewayTimeoutErrorResponseBody,
        WorkOrdersGetWorkOrdersInternalServerErrorResponseBody,
        WorkOrdersGetWorkOrdersMethodNotAllowedErrorResponseBody,
        WorkOrdersGetWorkOrdersNotFoundErrorResponseBody,
        WorkOrdersGetWorkOrdersNotImplementedErrorResponseBody,
        WorkOrdersGetWorkOrdersResponseBody,
        WorkOrdersGetWorkOrdersServiceUnavailableErrorResponseBody,
        WorkOrdersGetWorkOrdersTooManyRequestsErrorResponseBody,
        WorkOrdersGetWorkOrdersUnauthorizedErrorResponseBody,
        WorkOrdersPatchWorkOrdersBadGatewayErrorResponseBody,
        WorkOrdersPatchWorkOrdersGatewayTimeoutErrorResponseBody,
        WorkOrdersPatchWorkOrdersInternalServerErrorResponseBody,
        WorkOrdersPatchWorkOrdersMethodNotAllowedErrorResponseBody,
        WorkOrdersPatchWorkOrdersNotFoundErrorResponseBody,
        WorkOrdersPatchWorkOrdersNotImplementedErrorResponseBody,
        WorkOrdersPatchWorkOrdersResponseBody,
        WorkOrdersPatchWorkOrdersServiceUnavailableErrorResponseBody,
        WorkOrdersPatchWorkOrdersTooManyRequestsErrorResponseBody,
        WorkOrdersPatchWorkOrdersUnauthorizedErrorResponseBody,
        WorkOrdersPostInvoiceScanBadGatewayErrorResponseBody,
        WorkOrdersPostInvoiceScanGatewayTimeoutErrorResponseBody,
        WorkOrdersPostInvoiceScanInternalServerErrorResponseBody,
        WorkOrdersPostInvoiceScanMethodNotAllowedErrorResponseBody,
        WorkOrdersPostInvoiceScanNotFoundErrorResponseBody,
        WorkOrdersPostInvoiceScanNotImplementedErrorResponseBody,
        WorkOrdersPostInvoiceScanResponseBody,
        WorkOrdersPostInvoiceScanServiceUnavailableErrorResponseBody,
        WorkOrdersPostInvoiceScanTooManyRequestsErrorResponseBody,
        WorkOrdersPostInvoiceScanUnauthorizedErrorResponseBody,
        WorkOrdersPostWorkOrdersBadGatewayErrorResponseBody,
        WorkOrdersPostWorkOrdersGatewayTimeoutErrorResponseBody,
        WorkOrdersPostWorkOrdersInternalServerErrorResponseBody,
        WorkOrdersPostWorkOrdersMethodNotAllowedErrorResponseBody,
        WorkOrdersPostWorkOrdersNotFoundErrorResponseBody,
        WorkOrdersPostWorkOrdersNotImplementedErrorResponseBody,
        WorkOrdersPostWorkOrdersResponseBody,
        WorkOrdersPostWorkOrdersServiceUnavailableErrorResponseBody,
        WorkOrdersPostWorkOrdersTooManyRequestsErrorResponseBody,
        WorkOrdersPostWorkOrdersUnauthorizedErrorResponseBody,
        WorkOrdersStreamWorkOrdersBadGatewayErrorResponseBody,
        WorkOrdersStreamWorkOrdersGatewayTimeoutErrorResponseBody,
        WorkOrdersStreamWorkOrdersInternalServerErrorResponseBody,
        WorkOrdersStreamWorkOrdersMethodNotAllowedErrorResponseBody,
        WorkOrdersStreamWorkOrdersNotFoundErrorResponseBody,
        WorkOrdersStreamWorkOrdersNotImplementedErrorResponseBody,
        WorkOrdersStreamWorkOrdersResponseBody,
        WorkOrdersStreamWorkOrdersServiceUnavailableErrorResponseBody,
        WorkOrdersStreamWorkOrdersTooManyRequestsErrorResponseBody,
        WorkOrdersStreamWorkOrdersUnauthorizedErrorResponseBody,
        WorkerSafetySosDataResponseBody,
        WorkerSafetySosDataResponseBodySourceType,
        WorkflowAddressEventWithGeofenceObjectResponseBody,
        WorkflowAuthorSignatureObjectResponseBody,
        WorkflowAuthorSignatureObjectResponseBodyType,
        WorkflowCircleResponseBody,
        WorkflowDvirObjectResponseBody,
        WorkflowDvirObjectResponseBodySafetyStatus,
        WorkflowDvirObjectResponseBodyType,
        WorkflowDvirSubmittedResponseObjectResponseBody,
        WorkflowGeofenceEventResponseObjectResponseBody,
        WorkflowGeofenceResponseBody,
        WorkflowIncidentConditionObjectResponseBody,
        WorkflowIncidentDetailsObjectResponseBody,
        WorkflowPolygonResponseBody,
        WorkflowSignatoryUserObjectResponseBody,
        WorkflowTriggerObjectRequestBody,
        WorkflowTriggerObjectResponseBody,
    )
    from .errors import (
        BadGatewayError,
        GatewayTimeoutError,
        InternalServerError,
        MethodNotAllowedError,
        NotFoundError,
        NotImplementedError,
        ServiceUnavailableError,
        TooManyRequestsError,
        UnauthorizedError,
    )
    from . import (
        addresses,
        alerts,
        assets,
        attributes,
        auth_token_for_driver,
        beta_ap_is,
        carrier_proposed_assignments,
        coaching,
        contacts,
        documents,
        driver_qr_codes,
        driver_trailer_assignments,
        driver_vehicle_assignments,
        drivers,
        equipment,
        fleet,
        forms,
        fuel_and_energy,
        gateways,
        hours_of_service,
        hubs,
        idling,
        ifta,
        industrial,
        issues,
        legacy,
        legacy_ap_is,
        live_sharing_links,
        location_and_speed,
        maintenance,
        media,
        messages,
        organization_info,
        plans,
        preview_ap_is,
        route_events,
        routes,
        safety,
        sensors,
        settings,
        speeding_intervals,
        tachograph_eu_only,
        tags,
        trailer_assignments,
        trailers,
        training_assignments,
        training_courses,
        trips,
        users,
        vehicle_locations,
        vehicle_stats,
        vehicles,
        webhooks,
        work_orders,
    )
    from .addresses import CreateAddressRequestAddressTypesItem, UpdateAddressRequestAddressTypesItem
    from .alerts import GetConfigurationsRequestStatus
    from .assets import (
        AssetsCreateAssetRequestBodyRegulationMode,
        AssetsCreateAssetRequestBodyType,
        AssetsUpdateAssetRequestBodyRegulationMode,
        AssetsUpdateAssetRequestBodyType,
        ListAssetsRequestType,
    )
    from .attributes import (
        CreateAttributeRequestAttributeType,
        CreateAttributeRequestEntityType,
        CreateAttributeRequestUnit,
        DeleteAttributesRequestEntityType,
        GetAttributeRequestEntityType,
        GetAttributesByEntityTypeRequestEntityType,
        UpdateAttributeRequestAttributeType,
        UpdateAttributeRequestEntityType,
    )
    from .beta_ap_is import (
        DeviceRecoveryRecoverAssetRequestBodyMissingReason,
        DeviceRecoveryRecoverAssetRequestBodyRecoveryStatus,
        DeviceRecoveryRecoverAssetRequestBodyStatus,
        FunctionsStartFunctionRunRequestBodyParamsOverride,
        GetAssetsInputsRequestType,
        GetDriverEfficiencyRequestDriverActivationStatus,
        GetHosEldEventsRequestDriverActivationStatus,
        GetJobsRequestStatus,
        GetQualificationRecordsStreamRequestEntityType,
        GetQualificationTypesRequestEntityType,
        GetTagGroupSafetyScoresRequestScoreType,
        GetTagSafetyScoresRequestScoreType,
        ListCarbCtcVehiclesRequestTestStatusItem,
        RidershipPassengersCreateRidershipPassengerRequestBodyClassification,
        RidershipPassengersUpdateRidershipPassengerRequestBodyClassification,
    )
    from .client import AsyncSamsara, Samsara
    from .documents import DocumentsPostDocumentRequestBodyState
    from .driver_vehicle_assignments import (
        GetDriverVehicleAssignmentsRequestAssignmentType,
        GetDriverVehicleAssignmentsRequestFilterBy,
    )
    from .drivers import (
        CreateDriverRequestLocale,
        ListDriversRequestDriverActivationStatus,
        UpdateDriverRequestDriverActivationStatus,
        UpdateDriverRequestLocale,
    )
    from .environment import SamsaraEnvironment
    from .equipment import (
        GetEquipmentStatsFeedRequestTypesItem,
        GetEquipmentStatsHistoryRequestTypesItem,
        GetEquipmentStatsRequestTypesItem,
    )
    from .forms import (
        FormSubmissionsPatchFormSubmissionRequestBodyStatus,
        FormSubmissionsPostFormSubmissionRequestBodyStatus,
    )
    from .fuel_and_energy import (
        FuelPurchasePostFuelPurchaseRequestBodyFuelGrade,
        FuelPurchasePostFuelPurchaseRequestBodyIftaFuelType,
        GetFuelEnergyVehicleReportsRequestEnergyType,
    )
    from .hours_of_service import GetHosDailyLogsRequestDriverActivationStatus, GetHosDailyLogsRequestExpand
    from .idling import GetIdlingEventsRequestPtoState
    from .ifta import (
        GetIftaJurisdictionReportsRequestFuelType,
        GetIftaJurisdictionReportsRequestMonth,
        GetIftaJurisdictionReportsRequestQuarter,
        GetIftaVehicleReportsRequestFuelType,
        GetIftaVehicleReportsRequestMonth,
        GetIftaVehicleReportsRequestQuarter,
    )
    from .issues import IssuesPatchIssueRequestBodyStatus
    from .legacy_ap_is import GetDriversVehicleAssignmentsRequestDriverActivationStatus
    from .live_sharing_links import GetLiveSharingLinksRequestType, LiveSharingLinksCreateLiveSharingLinkRequestBodyType
    from .maintenance import CreateDvirRequestSafetyStatus, CreateDvirRequestType
    from .media import (
        ListUploadedMediaRequestInputsItem,
        ListUploadedMediaRequestMediaTypesItem,
        ListUploadedMediaRequestTriggerReasonsItem,
        MediaRetrievalPostMediaRetrievalRequestBodyInputsItem,
        MediaRetrievalPostMediaRetrievalRequestBodyMediaType,
    )
    from .preview_ap_is import (
        SafetyEventsV2PatchSafetyEventsV2BatchRequestBodyContextLabelsToAddItem,
        SafetyEventsV2PatchSafetyEventsV2BatchRequestBodyContextLabelsToRemoveItem,
        SafetyEventsV2PatchSafetyEventsV2BatchRequestBodyEventState,
    )
    from .routes import GetRoutesFeedRequestExpand
    from .safety import GetSafetyEventsV2StreamRequestQueryByTimeField
    from .sensors import InlineObject6FillMissing
    from .speeding_intervals import GetSpeedingIntervalsRequestQueryBy
    from .trips import GetTripsRequestCompletionStatus, GetTripsRequestQueryBy
    from .users import CreateUserRequestAuthType, UpdateUserRequestAuthType
    from .vehicle_stats import (
        GetVehicleStatsFeedRequestDecorationsItem,
        GetVehicleStatsFeedRequestTypesItem,
        GetVehicleStatsHistoryRequestDecorationsItem,
        GetVehicleStatsHistoryRequestTypesItem,
        GetVehicleStatsRequestTypesItem,
    )
    from .vehicles import (
        UpdateVehicleRequestAuxInputType1,
        UpdateVehicleRequestAuxInputType10,
        UpdateVehicleRequestAuxInputType11,
        UpdateVehicleRequestAuxInputType12,
        UpdateVehicleRequestAuxInputType13,
        UpdateVehicleRequestAuxInputType2,
        UpdateVehicleRequestAuxInputType3,
        UpdateVehicleRequestAuxInputType4,
        UpdateVehicleRequestAuxInputType5,
        UpdateVehicleRequestAuxInputType6,
        UpdateVehicleRequestAuxInputType7,
        UpdateVehicleRequestAuxInputType8,
        UpdateVehicleRequestAuxInputType9,
        UpdateVehicleRequestHarshAccelerationSettingType,
    )
    from .version import __version__
    from .webhooks import (
        WebhooksPatchWebhookRequestBodyVersion,
        WebhooksPostWebhooksRequestBodyEventTypesItem,
        WebhooksPostWebhooksRequestBodyVersion,
    )
    from .work_orders import (
        StreamWorkOrdersRequestWorkOrderStatusesItem,
        WorkOrdersPatchWorkOrdersRequestBodyPriority,
        WorkOrdersPatchWorkOrdersRequestBodyStatus,
        WorkOrdersPostWorkOrdersRequestBodyPriority,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "AccessoryResponseObjectResponseBody": ".types",
    "ActionObjectRequestBody": ".types",
    "ActionObjectResponseBody": ".types",
    "ActionParamsObjectRequestBody": ".types",
    "ActionParamsObjectResponseBody": ".types",
    "Address": ".types",
    "AddressAddressTypesItem": ".types",
    "AddressExternalIds": ".types",
    "AddressGeofence": ".types",
    "AddressGeofenceCircle": ".types",
    "AddressGeofencePolygon": ".types",
    "AddressGeofencePolygonVertices": ".types",
    "AddressGeofenceSettings": ".types",
    "AddressResponse": ".types",
    "AddressResponseResponseBody": ".types",
    "AddressTinyResponse": ".types",
    "AdvancedIdlingGetIdlingEventsBadGatewayErrorResponseBody": ".types",
    "AdvancedIdlingGetIdlingEventsGatewayTimeoutErrorResponseBody": ".types",
    "AdvancedIdlingGetIdlingEventsInternalServerErrorResponseBody": ".types",
    "AdvancedIdlingGetIdlingEventsMethodNotAllowedErrorResponseBody": ".types",
    "AdvancedIdlingGetIdlingEventsNotFoundErrorResponseBody": ".types",
    "AdvancedIdlingGetIdlingEventsNotImplementedErrorResponseBody": ".types",
    "AdvancedIdlingGetIdlingEventsResponseBody": ".types",
    "AdvancedIdlingGetIdlingEventsServiceUnavailableErrorResponseBody": ".types",
    "AdvancedIdlingGetIdlingEventsTooManyRequestsErrorResponseBody": ".types",
    "AdvancedIdlingGetIdlingEventsUnauthorizedErrorResponseBody": ".types",
    "AempEquipmentGetAempEquipmentListBadGatewayErrorResponseBody": ".types",
    "AempEquipmentGetAempEquipmentListGatewayTimeoutErrorResponseBody": ".types",
    "AempEquipmentGetAempEquipmentListInternalServerErrorResponseBody": ".types",
    "AempEquipmentGetAempEquipmentListMethodNotAllowedErrorResponseBody": ".types",
    "AempEquipmentGetAempEquipmentListNotFoundErrorResponseBody": ".types",
    "AempEquipmentGetAempEquipmentListNotImplementedErrorResponseBody": ".types",
    "AempEquipmentGetAempEquipmentListResponseBody": ".types",
    "AempEquipmentGetAempEquipmentListServiceUnavailableErrorResponseBody": ".types",
    "AempEquipmentGetAempEquipmentListTooManyRequestsErrorResponseBody": ".types",
    "AempEquipmentGetAempEquipmentListUnauthorizedErrorResponseBody": ".types",
    "AempEquipmentWithAdditionalFieldsResponseBody": ".types",
    "AempFleetListResponseBody": ".types",
    "AempLinkResponseBody": ".types",
    "AlertObjectAssetResponseBody": ".types",
    "AlertObjectAssetResponseBodyType": ".types",
    "AlertObjectDriverResponseBody": ".types",
    "AlertObjectMachineInputResponseBody": ".types",
    "AlertObjectOnvifCameraStreamResponseBody": ".types",
    "AlertObjectProductResponseBody": ".types",
    "AlertObjectSensorResponseBody": ".types",
    "AlertObjectSitesResponseBody": ".types",
    "AlertObjectTrailerResponseBody": ".types",
    "AlertObjectVehicleResponseBody": ".types",
    "AlertObjectWorkforceCameraDeviceResponseBody": ".types",
    "AlertsDeleteConfigurationsBadGatewayErrorResponseBody": ".types",
    "AlertsDeleteConfigurationsGatewayTimeoutErrorResponseBody": ".types",
    "AlertsDeleteConfigurationsInternalServerErrorResponseBody": ".types",
    "AlertsDeleteConfigurationsMethodNotAllowedErrorResponseBody": ".types",
    "AlertsDeleteConfigurationsNotFoundErrorResponseBody": ".types",
    "AlertsDeleteConfigurationsNotImplementedErrorResponseBody": ".types",
    "AlertsDeleteConfigurationsServiceUnavailableErrorResponseBody": ".types",
    "AlertsDeleteConfigurationsTooManyRequestsErrorResponseBody": ".types",
    "AlertsDeleteConfigurationsUnauthorizedErrorResponseBody": ".types",
    "AlertsGetConfigurationsBadGatewayErrorResponseBody": ".types",
    "AlertsGetConfigurationsGatewayTimeoutErrorResponseBody": ".types",
    "AlertsGetConfigurationsInternalServerErrorResponseBody": ".types",
    "AlertsGetConfigurationsMethodNotAllowedErrorResponseBody": ".types",
    "AlertsGetConfigurationsNotFoundErrorResponseBody": ".types",
    "AlertsGetConfigurationsNotImplementedErrorResponseBody": ".types",
    "AlertsGetConfigurationsResponseBody": ".types",
    "AlertsGetConfigurationsServiceUnavailableErrorResponseBody": ".types",
    "AlertsGetConfigurationsTooManyRequestsErrorResponseBody": ".types",
    "AlertsGetConfigurationsUnauthorizedErrorResponseBody": ".types",
    "AlertsGetIncidentsBadGatewayErrorResponseBody": ".types",
    "AlertsGetIncidentsGatewayTimeoutErrorResponseBody": ".types",
    "AlertsGetIncidentsInternalServerErrorResponseBody": ".types",
    "AlertsGetIncidentsMethodNotAllowedErrorResponseBody": ".types",
    "AlertsGetIncidentsNotFoundErrorResponseBody": ".types",
    "AlertsGetIncidentsNotImplementedErrorResponseBody": ".types",
    "AlertsGetIncidentsResponseBody": ".types",
    "AlertsGetIncidentsServiceUnavailableErrorResponseBody": ".types",
    "AlertsGetIncidentsTooManyRequestsErrorResponseBody": ".types",
    "AlertsGetIncidentsUnauthorizedErrorResponseBody": ".types",
    "AlertsPatchConfigurationsBadGatewayErrorResponseBody": ".types",
    "AlertsPatchConfigurationsGatewayTimeoutErrorResponseBody": ".types",
    "AlertsPatchConfigurationsInternalServerErrorResponseBody": ".types",
    "AlertsPatchConfigurationsMethodNotAllowedErrorResponseBody": ".types",
    "AlertsPatchConfigurationsNotFoundErrorResponseBody": ".types",
    "AlertsPatchConfigurationsNotImplementedErrorResponseBody": ".types",
    "AlertsPatchConfigurationsResponseBody": ".types",
    "AlertsPatchConfigurationsServiceUnavailableErrorResponseBody": ".types",
    "AlertsPatchConfigurationsTooManyRequestsErrorResponseBody": ".types",
    "AlertsPatchConfigurationsUnauthorizedErrorResponseBody": ".types",
    "AlertsPostConfigurationsBadGatewayErrorResponseBody": ".types",
    "AlertsPostConfigurationsGatewayTimeoutErrorResponseBody": ".types",
    "AlertsPostConfigurationsInternalServerErrorResponseBody": ".types",
    "AlertsPostConfigurationsMethodNotAllowedErrorResponseBody": ".types",
    "AlertsPostConfigurationsNotFoundErrorResponseBody": ".types",
    "AlertsPostConfigurationsNotImplementedErrorResponseBody": ".types",
    "AlertsPostConfigurationsResponseBody": ".types",
    "AlertsPostConfigurationsServiceUnavailableErrorResponseBody": ".types",
    "AlertsPostConfigurationsTooManyRequestsErrorResponseBody": ".types",
    "AlertsPostConfigurationsUnauthorizedErrorResponseBody": ".types",
    "AmbientTemperatureDetailsObjectRequestBody": ".types",
    "AmbientTemperatureDetailsObjectRequestBodyOperation": ".types",
    "AmbientTemperatureDetailsObjectResponseBody": ".types",
    "AmbientTemperatureDetailsObjectResponseBodyOperation": ".types",
    "AmbientTemperatureResponseBody": ".types",
    "AnticipationBrakeEventCount": ".types",
    "AppointmentWindowRequestBody": ".types",
    "AppointmentWindowResponseBody": ".types",
    "AssetDataInput": ".types",
    "AssetDataInputLastPoint": ".types",
    "AssetDataOutput": ".types",
    "AssetDataOutputsPatchAssetDataOutputsBadGatewayErrorResponseBody": ".types",
    "AssetDataOutputsPatchAssetDataOutputsGatewayTimeoutErrorResponseBody": ".types",
    "AssetDataOutputsPatchAssetDataOutputsInternalServerErrorResponseBody": ".types",
    "AssetDataOutputsPatchAssetDataOutputsMethodNotAllowedErrorResponseBody": ".types",
    "AssetDataOutputsPatchAssetDataOutputsNotFoundErrorResponseBody": ".types",
    "AssetDataOutputsPatchAssetDataOutputsNotImplementedErrorResponseBody": ".types",
    "AssetDataOutputsPatchAssetDataOutputsResponseBody": ".types",
    "AssetDataOutputsPatchAssetDataOutputsServiceUnavailableErrorResponseBody": ".types",
    "AssetDataOutputsPatchAssetDataOutputsTooManyRequestsErrorResponseBody": ".types",
    "AssetDataOutputsPatchAssetDataOutputsUnauthorizedErrorResponseBody": ".types",
    "AssetLocation": ".types",
    "AssetLocationHeading": ".types",
    "AssetLocationSpeed": ".types",
    "AssetName": ".types",
    "AssetResponse": ".types",
    "AssetResponseBody": ".types",
    "AssetResponseBodyRegulationMode": ".types",
    "AssetResponseBodyType": ".types",
    "AssetResponseLocationDataInput": ".types",
    "AssetResponseParentAsset": ".types",
    "AssetResponseResponseBody": ".types",
    "AssetResponseRunningStatusDataInput": ".types",
    "AssetsCreateAssetBadGatewayErrorResponseBody": ".types",
    "AssetsCreateAssetGatewayTimeoutErrorResponseBody": ".types",
    "AssetsCreateAssetInternalServerErrorResponseBody": ".types",
    "AssetsCreateAssetMethodNotAllowedErrorResponseBody": ".types",
    "AssetsCreateAssetNotFoundErrorResponseBody": ".types",
    "AssetsCreateAssetNotImplementedErrorResponseBody": ".types",
    "AssetsCreateAssetRequestBodyRegulationMode": ".assets",
    "AssetsCreateAssetRequestBodyType": ".assets",
    "AssetsCreateAssetResponseBody": ".types",
    "AssetsCreateAssetServiceUnavailableErrorResponseBody": ".types",
    "AssetsCreateAssetTooManyRequestsErrorResponseBody": ".types",
    "AssetsCreateAssetUnauthorizedErrorResponseBody": ".types",
    "AssetsDeleteAssetBadGatewayErrorResponseBody": ".types",
    "AssetsDeleteAssetGatewayTimeoutErrorResponseBody": ".types",
    "AssetsDeleteAssetInternalServerErrorResponseBody": ".types",
    "AssetsDeleteAssetMethodNotAllowedErrorResponseBody": ".types",
    "AssetsDeleteAssetNotFoundErrorResponseBody": ".types",
    "AssetsDeleteAssetNotImplementedErrorResponseBody": ".types",
    "AssetsDeleteAssetServiceUnavailableErrorResponseBody": ".types",
    "AssetsDeleteAssetTooManyRequestsErrorResponseBody": ".types",
    "AssetsDeleteAssetUnauthorizedErrorResponseBody": ".types",
    "AssetsInputsAssetResponseResponseBody": ".types",
    "AssetsInputsAuxInputResponseBody": ".types",
    "AssetsInputsGetAssetsInputsBadGatewayErrorResponseBody": ".types",
    "AssetsInputsGetAssetsInputsGatewayTimeoutErrorResponseBody": ".types",
    "AssetsInputsGetAssetsInputsInternalServerErrorResponseBody": ".types",
    "AssetsInputsGetAssetsInputsMethodNotAllowedErrorResponseBody": ".types",
    "AssetsInputsGetAssetsInputsNotFoundErrorResponseBody": ".types",
    "AssetsInputsGetAssetsInputsNotImplementedErrorResponseBody": ".types",
    "AssetsInputsGetAssetsInputsResponseBody": ".types",
    "AssetsInputsGetAssetsInputsServiceUnavailableErrorResponseBody": ".types",
    "AssetsInputsGetAssetsInputsTooManyRequestsErrorResponseBody": ".types",
    "AssetsInputsGetAssetsInputsUnauthorizedErrorResponseBody": ".types",
    "AssetsInputsResponseResponseBody": ".types",
    "AssetsInputsResponseResponseBodyUnits": ".types",
    "AssetsListAssetsBadGatewayErrorResponseBody": ".types",
    "AssetsListAssetsGatewayTimeoutErrorResponseBody": ".types",
    "AssetsListAssetsInternalServerErrorResponseBody": ".types",
    "AssetsListAssetsMethodNotAllowedErrorResponseBody": ".types",
    "AssetsListAssetsNotFoundErrorResponseBody": ".types",
    "AssetsListAssetsNotImplementedErrorResponseBody": ".types",
    "AssetsListAssetsResponseBody": ".types",
    "AssetsListAssetsServiceUnavailableErrorResponseBody": ".types",
    "AssetsListAssetsTooManyRequestsErrorResponseBody": ".types",
    "AssetsListAssetsUnauthorizedErrorResponseBody": ".types",
    "AssetsLocationLinkConfigAddressDetailsObject": ".types",
    "AssetsLocationLinkConfigAddressDetailsObjectResponseBody": ".types",
    "AssetsLocationLinkRequestConfigObject": ".types",
    "AssetsLocationLinkResponseConfigObjectResponseBody": ".types",
    "AssetsNearLocationLinkConfigObject": ".types",
    "AssetsNearLocationLinkConfigObjectResponseBody": ".types",
    "AssetsOnRouteLinkConfigObject": ".types",
    "AssetsOnRouteLinkConfigObjectResponseBody": ".types",
    "AssetsUpdateAssetBadGatewayErrorResponseBody": ".types",
    "AssetsUpdateAssetGatewayTimeoutErrorResponseBody": ".types",
    "AssetsUpdateAssetInternalServerErrorResponseBody": ".types",
    "AssetsUpdateAssetMethodNotAllowedErrorResponseBody": ".types",
    "AssetsUpdateAssetNotFoundErrorResponseBody": ".types",
    "AssetsUpdateAssetNotImplementedErrorResponseBody": ".types",
    "AssetsUpdateAssetRequestBodyRegulationMode": ".assets",
    "AssetsUpdateAssetRequestBodyType": ".assets",
    "AssetsUpdateAssetResponseBody": ".types",
    "AssetsUpdateAssetServiceUnavailableErrorResponseBody": ".types",
    "AssetsUpdateAssetTooManyRequestsErrorResponseBody": ".types",
    "AssetsUpdateAssetUnauthorizedErrorResponseBody": ".types",
    "AssociationResponseBody": ".types",
    "AssociationsListAssociationsBadGatewayErrorResponseBody": ".types",
    "AssociationsListAssociationsGatewayTimeoutErrorResponseBody": ".types",
    "AssociationsListAssociationsInternalServerErrorResponseBody": ".types",
    "AssociationsListAssociationsMethodNotAllowedErrorResponseBody": ".types",
    "AssociationsListAssociationsNotFoundErrorResponseBody": ".types",
    "AssociationsListAssociationsNotImplementedErrorResponseBody": ".types",
    "AssociationsListAssociationsResponseBody": ".types",
    "AssociationsListAssociationsServiceUnavailableErrorResponseBody": ".types",
    "AssociationsListAssociationsTooManyRequestsErrorResponseBody": ".types",
    "AssociationsListAssociationsUnauthorizedErrorResponseBody": ".types",
    "AsyncSamsara": ".client",
    "Attribute": ".types",
    "AttributeAttributeType": ".types",
    "AttributeEntity": ".types",
    "AttributeEntityExternalIds": ".types",
    "AttributeEntityType": ".types",
    "AttributeExpanded": ".types",
    "AttributeExpandedAllOf": ".types",
    "AttributeExpandedResponse": ".types",
    "AttributeTiny": ".types",
    "AttributeUnit": ".types",
    "AttributeValueTiny": ".types",
    "AuthTokenAuthTokenBadGatewayErrorResponseBody": ".types",
    "AuthTokenAuthTokenGatewayTimeoutErrorResponseBody": ".types",
    "AuthTokenAuthTokenInternalServerErrorResponseBody": ".types",
    "AuthTokenAuthTokenMethodNotAllowedErrorResponseBody": ".types",
    "AuthTokenAuthTokenNotFoundErrorResponseBody": ".types",
    "AuthTokenAuthTokenNotImplementedErrorResponseBody": ".types",
    "AuthTokenAuthTokenResponseBody": ".types",
    "AuthTokenAuthTokenServiceUnavailableErrorResponseBody": ".types",
    "AuthTokenAuthTokenTooManyRequestsErrorResponseBody": ".types",
    "AuthTokenAuthTokenUnauthorizedErrorResponseBody": ".types",
    "AuthTokenForDriverResponseResponseBody": ".types",
    "AuthorSignatureObjectResponseBody": ".types",
    "AuthorSignatureObjectResponseBodyType": ".types",
    "BadGatewayError": ".errors",
    "BarcodeValueObjectRequestBody": ".types",
    "BarcodeValueObjectResponseBody": ".types",
    "BaseRouteResponseObjectResponseBody": ".types",
    "BehaviorCountDetailsRequestBody": ".types",
    "BehaviorCountDetailsRequestBodyComparison": ".types",
    "BehaviorCountDetailsResponseBody": ".types",
    "BehaviorCountDetailsResponseBodyComparison": ".types",
    "BehaviorResponseBody": ".types",
    "BehaviorResponseBodyCoachableBehaviorType": ".types",
    "CameraConnectorDisconectedResponseBody": ".types",
    "CameraDetailsResponseResponseBody": ".types",
    "CameraSerial": ".types",
    "CameraStreamIssueResponseBody": ".types",
    "CarbCtcListCarbCtcVehicleHistoryBadGatewayErrorResponseBody": ".types",
    "CarbCtcListCarbCtcVehicleHistoryGatewayTimeoutErrorResponseBody": ".types",
    "CarbCtcListCarbCtcVehicleHistoryInternalServerErrorResponseBody": ".types",
    "CarbCtcListCarbCtcVehicleHistoryMethodNotAllowedErrorResponseBody": ".types",
    "CarbCtcListCarbCtcVehicleHistoryNotFoundErrorResponseBody": ".types",
    "CarbCtcListCarbCtcVehicleHistoryNotImplementedErrorResponseBody": ".types",
    "CarbCtcListCarbCtcVehicleHistoryResponseBody": ".types",
    "CarbCtcListCarbCtcVehicleHistoryServiceUnavailableErrorResponseBody": ".types",
    "CarbCtcListCarbCtcVehicleHistoryTooManyRequestsErrorResponseBody": ".types",
    "CarbCtcListCarbCtcVehicleHistoryUnauthorizedErrorResponseBody": ".types",
    "CarbCtcListCarbCtcVehiclesBadGatewayErrorResponseBody": ".types",
    "CarbCtcListCarbCtcVehiclesGatewayTimeoutErrorResponseBody": ".types",
    "CarbCtcListCarbCtcVehiclesInternalServerErrorResponseBody": ".types",
    "CarbCtcListCarbCtcVehiclesMethodNotAllowedErrorResponseBody": ".types",
    "CarbCtcListCarbCtcVehiclesNotFoundErrorResponseBody": ".types",
    "CarbCtcListCarbCtcVehiclesNotImplementedErrorResponseBody": ".types",
    "CarbCtcListCarbCtcVehiclesResponseBody": ".types",
    "CarbCtcListCarbCtcVehiclesServiceUnavailableErrorResponseBody": ".types",
    "CarbCtcListCarbCtcVehiclesTooManyRequestsErrorResponseBody": ".types",
    "CarbCtcListCarbCtcVehiclesUnauthorizedErrorResponseBody": ".types",
    "CarbCtcVehicleHistoryObjectResponseBody": ".types",
    "CarbCtcVehicleHistoryObjectResponseBodyTestResult": ".types",
    "CarbCtcVehicleObjectResponseBody": ".types",
    "CarbCtcVehicleObjectResponseBodyTestStatus": ".types",
    "CarrierProposedAssignment": ".types",
    "CarrierProposedAssignmentAcceptedTime": ".types",
    "CarrierProposedAssignmentActiveTime": ".types",
    "CarrierProposedAssignmentDriver": ".types",
    "CarrierProposedAssignmentDriverAllOf": ".types",
    "CarrierProposedAssignmentDriverAllOf2ExternalIds": ".types",
    "CarrierProposedAssignmentFirstSeenTime": ".types",
    "CarrierProposedAssignmentId": ".types",
    "CarrierProposedAssignmentRejectedTime": ".types",
    "CarrierProposedAssignmentResponse": ".types",
    "CarrierProposedAssignmentShippingDocs": ".types",
    "CarrierProposedAssignmentTrailer": ".types",
    "CarrierProposedAssignmentTrailers": ".types",
    "CarrierProposedAssignmentVehicle": ".types",
    "CellConnectivityResponseResponseBody": ".types",
    "CellConnectivityResponseResponseBodySignalBar": ".types",
    "CellSignalLossDetailsObjectRequestBody": ".types",
    "CellSignalLossDetailsObjectResponseBody": ".types",
    "CellSignalLossResponseBody": ".types",
    "CircleRequestBody": ".types",
    "CircleResponseBody": ".types",
    "CloudBackupUploadIssueResponseBody": ".types",
    "CoachAssignmentWithDriverExternalIdsResponseResponseBody": ".types",
    "CoachAssignmentWithoutDriverExternalIdsResponseResponseBody": ".types",
    "CoachableEventResponseBody": ".types",
    "CoachingSessionsGetCoachingSessionsBadGatewayErrorResponseBody": ".types",
    "CoachingSessionsGetCoachingSessionsGatewayTimeoutErrorResponseBody": ".types",
    "CoachingSessionsGetCoachingSessionsInternalServerErrorResponseBody": ".types",
    "CoachingSessionsGetCoachingSessionsMethodNotAllowedErrorResponseBody": ".types",
    "CoachingSessionsGetCoachingSessionsNotFoundErrorResponseBody": ".types",
    "CoachingSessionsGetCoachingSessionsNotImplementedErrorResponseBody": ".types",
    "CoachingSessionsGetCoachingSessionsResponseBody": ".types",
    "CoachingSessionsGetCoachingSessionsServiceUnavailableErrorResponseBody": ".types",
    "CoachingSessionsGetCoachingSessionsTooManyRequestsErrorResponseBody": ".types",
    "CoachingSessionsGetCoachingSessionsUnauthorizedErrorResponseBody": ".types",
    "CoachingSessionsResponseResponseBody": ".types",
    "CoachingSessionsResponseResponseBodyCoachingType": ".types",
    "CoachingSessionsResponseResponseBodySessionStatus": ".types",
    "CoastingDurationMs": ".types",
    "ColumnResponseBody": ".types",
    "ColumnResponseBodyDataType": ".types",
    "ColumnResponseBodyUnit": ".types",
    "ConditionalFieldSectionObjectResponseBody": ".types",
    "ConnectionStatusResponseObjectResponseBody": ".types",
    "ConnectionStatusResponseObjectResponseBodyHealthStatus": ".types",
    "Contact": ".types",
    "ContactEmail": ".types",
    "ContactFirstName": ".types",
    "ContactId": ".types",
    "ContactLastName": ".types",
    "ContactPhone": ".types",
    "ContactResponse": ".types",
    "ContactTinyResponse": ".types",
    "ContinuousReadingAlertThresholdResponseBody": ".types",
    "ContinuousReadingAlertThresholdResponseBodyOperation": ".types",
    "ContinuousReadingAlertThresholdResponseBodyUnit": ".types",
    "CreateAddressRequestAddressTypesItem": ".addresses",
    "CreateAddressRequestGeofence": ".types",
    "CreateAddressRequestGeofenceSettings": ".types",
    "CreateAttributeRequestAttributeType": ".attributes",
    "CreateAttributeRequestEntities": ".types",
    "CreateAttributeRequestEntityType": ".attributes",
    "CreateAttributeRequestUnit": ".attributes",
    "CreateDriverAuthTokenResponseResponseBody": ".types",
    "CreateDriverRequestAttributes": ".types",
    "CreateDriverRequestLocale": ".drivers",
    "CreateDvirRequestSafetyStatus": ".maintenance",
    "CreateDvirRequestType": ".maintenance",
    "CreateFunctionDetailResponseBody": ".types",
    "CreateFunctionRequestConfigRequestBody": ".types",
    "CreateFunctionRequestConfigRequestBodyParams": ".types",
    "CreateFunctionRequestConfigRequestBodySecrets": ".types",
    "CreateReportConfigColumnRequestBody": ".types",
    "CreateReportConfigObjectRequestBody": ".types",
    "CreateRoutesStopRequestObjectRequestBody": ".types",
    "CreateUserRequestAuthType": ".users",
    "CreateUserRequestRoles": ".types",
    "CruiseControlDurationMs": ".types",
    "CumulativeOperatingHoursResponseBody": ".types",
    "CurrentDutyStatus": ".types",
    "CurrentDutyStatusHosStatusType": ".types",
    "CustomHeadersObjectRequestBody": ".types",
    "CustomHeadersObjectResponseBody": ".types",
    "CustomMetadata": ".types",
    "DashcamDisconnectedResponseBody": ".types",
    "DataInputListResponse": ".types",
    "DataInputResponse": ".types",
    "DataInputResponseAllOf": ".types",
    "DataInputSnapshot": ".types",
    "DataInputSnapshotAllOf": ".types",
    "DataInputSnapshotResponse": ".types",
    "DataInputTinyResponse": ".types",
    "DataInputValueResponseBody": ".types",
    "DataInputsTinyResponse": ".types",
    "DataUsageResponseObjectResponseBody": ".types",
    "DateTimeValueObjectRequestBody": ".types",
    "DateTimeValueObjectResponseBody": ".types",
    "DefLevelTriggerDetailsObjectRequestBody": ".types",
    "DefLevelTriggerDetailsObjectRequestBodyOperation": ".types",
    "DefLevelTriggerDetailsObjectResponseBody": ".types",
    "DefLevelTriggerDetailsObjectResponseBodyOperation": ".types",
    "DefRemainingResponseBody": ".types",
    "Defect": ".types",
    "DefectPhotoResponseResponseBody": ".types",
    "DefectResolvedBy": ".types",
    "DefectResolvedByType": ".types",
    "DefectResponse": ".types",
    "DefectTrailer": ".types",
    "DefectTrailerResponseResponseBody": ".types",
    "DefectTypesResponseDataResponseBody": ".types",
    "DefectTypesResponseDataResponseBodySectionType": ".types",
    "DefectTypesResponseDataResponseBodySeverity": ".types",
    "DefectVehicle": ".types",
    "DefectVehicleResponseResponseBody": ".types",
    "DefectsResponse": ".types",
    "DefectsResponseDataResponseBody": ".types",
    "DeleteAttributesRequestEntityType": ".attributes",
    "DeployFunctionDetailResponseBody": ".types",
    "DepreciationGetDepreciationTransactionsBadGatewayErrorResponseBody": ".types",
    "DepreciationGetDepreciationTransactionsGatewayTimeoutErrorResponseBody": ".types",
    "DepreciationGetDepreciationTransactionsInternalServerErrorResponseBody": ".types",
    "DepreciationGetDepreciationTransactionsMethodNotAllowedErrorResponseBody": ".types",
    "DepreciationGetDepreciationTransactionsNotFoundErrorResponseBody": ".types",
    "DepreciationGetDepreciationTransactionsNotImplementedErrorResponseBody": ".types",
    "DepreciationGetDepreciationTransactionsResponseBody": ".types",
    "DepreciationGetDepreciationTransactionsServiceUnavailableErrorResponseBody": ".types",
    "DepreciationGetDepreciationTransactionsTooManyRequestsErrorResponseBody": ".types",
    "DepreciationGetDepreciationTransactionsUnauthorizedErrorResponseBody": ".types",
    "DepreciationTransactionMoneyObjectResponseBody": ".types",
    "DepreciationTransactionMoneyObjectResponseBodyCurrency": ".types",
    "DepreciationTransactionObjectResponseBody": ".types",
    "DepreciationTransactionObjectResponseBodyTransactionType": ".types",
    "DetectionLogAssetObjectResponseBody": ".types",
    "DetectionLogDetectionObjectResponseBody": ".types",
    "DetectionLogDetectionObjectResponseBodyTriggerDetectionLabel": ".types",
    "DetectionLogDriverObjectResponseBody": ".types",
    "DetectionLogGetDetectionsBadGatewayErrorResponseBody": ".types",
    "DetectionLogGetDetectionsGatewayTimeoutErrorResponseBody": ".types",
    "DetectionLogGetDetectionsInternalServerErrorResponseBody": ".types",
    "DetectionLogGetDetectionsMethodNotAllowedErrorResponseBody": ".types",
    "DetectionLogGetDetectionsNotFoundErrorResponseBody": ".types",
    "DetectionLogGetDetectionsNotImplementedErrorResponseBody": ".types",
    "DetectionLogGetDetectionsResponseBody": ".types",
    "DetectionLogGetDetectionsServiceUnavailableErrorResponseBody": ".types",
    "DetectionLogGetDetectionsTooManyRequestsErrorResponseBody": ".types",
    "DetectionLogGetDetectionsUnauthorizedErrorResponseBody": ".types",
    "DetectionLogSafetyEventObjectResponseBody": ".types",
    "DetectionLogSafetyEventObjectResponseBodyInboxFilterReason": ".types",
    "DeviceAssetResponseResponseBody": ".types",
    "DeviceMovementDataResponseBody": ".types",
    "DeviceMovementStoppedDataResponseBody": ".types",
    "DeviceMovementTriggerDetailsObjectRequestBody": ".types",
    "DeviceMovementTriggerDetailsObjectResponseBody": ".types",
    "DeviceRecoveryListDeviceRecoveryMissingAssetsBadGatewayErrorResponseBody": ".types",
    "DeviceRecoveryListDeviceRecoveryMissingAssetsGatewayTimeoutErrorResponseBody": ".types",
    "DeviceRecoveryListDeviceRecoveryMissingAssetsInternalServerErrorResponseBody": ".types",
    "DeviceRecoveryListDeviceRecoveryMissingAssetsMethodNotAllowedErrorResponseBody": ".types",
    "DeviceRecoveryListDeviceRecoveryMissingAssetsNotFoundErrorResponseBody": ".types",
    "DeviceRecoveryListDeviceRecoveryMissingAssetsNotImplementedErrorResponseBody": ".types",
    "DeviceRecoveryListDeviceRecoveryMissingAssetsResponseBody": ".types",
    "DeviceRecoveryListDeviceRecoveryMissingAssetsServiceUnavailableErrorResponseBody": ".types",
    "DeviceRecoveryListDeviceRecoveryMissingAssetsTooManyRequestsErrorResponseBody": ".types",
    "DeviceRecoveryListDeviceRecoveryMissingAssetsUnauthorizedErrorResponseBody": ".types",
    "DeviceRecoveryMarkAssetMissingBadGatewayErrorResponseBody": ".types",
    "DeviceRecoveryMarkAssetMissingGatewayTimeoutErrorResponseBody": ".types",
    "DeviceRecoveryMarkAssetMissingInternalServerErrorResponseBody": ".types",
    "DeviceRecoveryMarkAssetMissingMethodNotAllowedErrorResponseBody": ".types",
    "DeviceRecoveryMarkAssetMissingNotFoundErrorResponseBody": ".types",
    "DeviceRecoveryMarkAssetMissingNotImplementedErrorResponseBody": ".types",
    "DeviceRecoveryMarkAssetMissingResponseBody": ".types",
    "DeviceRecoveryMarkAssetMissingServiceUnavailableErrorResponseBody": ".types",
    "DeviceRecoveryMarkAssetMissingTooManyRequestsErrorResponseBody": ".types",
    "DeviceRecoveryMarkAssetMissingUnauthorizedErrorResponseBody": ".types",
    "DeviceRecoveryRecoverAssetBadGatewayErrorResponseBody": ".types",
    "DeviceRecoveryRecoverAssetGatewayTimeoutErrorResponseBody": ".types",
    "DeviceRecoveryRecoverAssetInternalServerErrorResponseBody": ".types",
    "DeviceRecoveryRecoverAssetMethodNotAllowedErrorResponseBody": ".types",
    "DeviceRecoveryRecoverAssetNotFoundErrorResponseBody": ".types",
    "DeviceRecoveryRecoverAssetNotImplementedErrorResponseBody": ".types",
    "DeviceRecoveryRecoverAssetRequestBodyMissingReason": ".beta_ap_is",
    "DeviceRecoveryRecoverAssetRequestBodyRecoveryStatus": ".beta_ap_is",
    "DeviceRecoveryRecoverAssetRequestBodyStatus": ".beta_ap_is",
    "DeviceRecoveryRecoverAssetResponseBody": ".types",
    "DeviceRecoveryRecoverAssetServiceUnavailableErrorResponseBody": ".types",
    "DeviceRecoveryRecoverAssetTooManyRequestsErrorResponseBody": ".types",
    "DeviceRecoveryRecoverAssetUnauthorizedErrorResponseBody": ".types",
    "DeviceResponseResponseBody": ".types",
    "DeviceResponseResponseBodyModel": ".types",
    "DevicesGetDevicesBadGatewayErrorResponseBody": ".types",
    "DevicesGetDevicesGatewayTimeoutErrorResponseBody": ".types",
    "DevicesGetDevicesInternalServerErrorResponseBody": ".types",
    "DevicesGetDevicesMethodNotAllowedErrorResponseBody": ".types",
    "DevicesGetDevicesNotFoundErrorResponseBody": ".types",
    "DevicesGetDevicesNotImplementedErrorResponseBody": ".types",
    "DevicesGetDevicesResponseBody": ".types",
    "DevicesGetDevicesServiceUnavailableErrorResponseBody": ".types",
    "DevicesGetDevicesTooManyRequestsErrorResponseBody": ".types",
    "DevicesGetDevicesUnauthorizedErrorResponseBody": ".types",
    "DistanceDrivenMeters": ".types",
    "DistanceResponseBody": ".types",
    "DistanceTraveledObjectResponseBody": ".types",
    "DistractedDrivingDetectionAlertSettingsObjectResponseBody": ".types",
    "DocumentPdfGenerationResponse": ".types",
    "DocumentPdfGenerationResponseData": ".types",
    "DocumentPdfQueryResponse": ".types",
    "DocumentPdfQueryResponseData": ".types",
    "DocumentPdfQueryResponseDataJobStatus": ".types",
    "DocumentResponseObjectResponseBody": ".types",
    "DocumentResponseObjectResponseBodyState": ".types",
    "DocumentTypesGetDocumentTypesBadGatewayErrorResponseBody": ".types",
    "DocumentTypesGetDocumentTypesGatewayTimeoutErrorResponseBody": ".types",
    "DocumentTypesGetDocumentTypesInternalServerErrorResponseBody": ".types",
    "DocumentTypesGetDocumentTypesMethodNotAllowedErrorResponseBody": ".types",
    "DocumentTypesGetDocumentTypesNotFoundErrorResponseBody": ".types",
    "DocumentTypesGetDocumentTypesNotImplementedErrorResponseBody": ".types",
    "DocumentTypesGetDocumentTypesResponseBody": ".types",
    "DocumentTypesGetDocumentTypesServiceUnavailableErrorResponseBody": ".types",
    "DocumentTypesGetDocumentTypesTooManyRequestsErrorResponseBody": ".types",
    "DocumentTypesGetDocumentTypesUnauthorizedErrorResponseBody": ".types",
    "DocumentsDeleteDocumentBadGatewayErrorResponseBody": ".types",
    "DocumentsDeleteDocumentGatewayTimeoutErrorResponseBody": ".types",
    "DocumentsDeleteDocumentInternalServerErrorResponseBody": ".types",
    "DocumentsDeleteDocumentMethodNotAllowedErrorResponseBody": ".types",
    "DocumentsDeleteDocumentNotFoundErrorResponseBody": ".types",
    "DocumentsDeleteDocumentNotImplementedErrorResponseBody": ".types",
    "DocumentsDeleteDocumentServiceUnavailableErrorResponseBody": ".types",
    "DocumentsDeleteDocumentTooManyRequestsErrorResponseBody": ".types",
    "DocumentsDeleteDocumentUnauthorizedErrorResponseBody": ".types",
    "DocumentsGetDocumentBadGatewayErrorResponseBody": ".types",
    "DocumentsGetDocumentGatewayTimeoutErrorResponseBody": ".types",
    "DocumentsGetDocumentInternalServerErrorResponseBody": ".types",
    "DocumentsGetDocumentMethodNotAllowedErrorResponseBody": ".types",
    "DocumentsGetDocumentNotFoundErrorResponseBody": ".types",
    "DocumentsGetDocumentNotImplementedErrorResponseBody": ".types",
    "DocumentsGetDocumentResponseBody": ".types",
    "DocumentsGetDocumentServiceUnavailableErrorResponseBody": ".types",
    "DocumentsGetDocumentTooManyRequestsErrorResponseBody": ".types",
    "DocumentsGetDocumentUnauthorizedErrorResponseBody": ".types",
    "DocumentsGetDocumentsBadGatewayErrorResponseBody": ".types",
    "DocumentsGetDocumentsGatewayTimeoutErrorResponseBody": ".types",
    "DocumentsGetDocumentsInternalServerErrorResponseBody": ".types",
    "DocumentsGetDocumentsMethodNotAllowedErrorResponseBody": ".types",
    "DocumentsGetDocumentsNotFoundErrorResponseBody": ".types",
    "DocumentsGetDocumentsNotImplementedErrorResponseBody": ".types",
    "DocumentsGetDocumentsResponseBody": ".types",
    "DocumentsGetDocumentsServiceUnavailableErrorResponseBody": ".types",
    "DocumentsGetDocumentsTooManyRequestsErrorResponseBody": ".types",
    "DocumentsGetDocumentsUnauthorizedErrorResponseBody": ".types",
    "DocumentsPostDocumentBadGatewayErrorResponseBody": ".types",
    "DocumentsPostDocumentGatewayTimeoutErrorResponseBody": ".types",
    "DocumentsPostDocumentInternalServerErrorResponseBody": ".types",
    "DocumentsPostDocumentMethodNotAllowedErrorResponseBody": ".types",
    "DocumentsPostDocumentNotFoundErrorResponseBody": ".types",
    "DocumentsPostDocumentNotImplementedErrorResponseBody": ".types",
    "DocumentsPostDocumentRequestBodyState": ".documents",
    "DocumentsPostDocumentResponseBody": ".types",
    "DocumentsPostDocumentServiceUnavailableErrorResponseBody": ".types",
    "DocumentsPostDocumentTooManyRequestsErrorResponseBody": ".types",
    "DocumentsPostDocumentUnauthorizedErrorResponseBody": ".types",
    "DoorOpenResponseBody": ".types",
    "DriveTimeDurationMs": ".types",
    "Driver": ".types",
    "DriverActivationStatus": ".types",
    "DriverAppNotificationObjectRequestBody": ".types",
    "DriverAppNotificationObjectResponseBody": ".types",
    "DriverAppSettingsGamificationConfigTinyObjectRequestBody": ".types",
    "DriverAppSettingsGamificationConfigTinyObjectResponseBody": ".types",
    "DriverAppSettingsResponseObjectResponseBody": ".types",
    "DriverAppSettingsTrailerSelectionConfigTinyObjectRequestBody": ".types",
    "DriverAppSettingsTrailerSelectionConfigTinyObjectResponseBody": ".types",
    "DriverAppSignInResponseBody": ".types",
    "DriverAppSignOutResponseBody": ".types",
    "DriverAssignmentMetadataTinyObjectResponseBody": ".types",
    "DriverAssignmentObjectResponseBody": ".types",
    "DriverAssignmentObjectResponseBodyAssignmentType": ".types",
    "DriverCarrierSettings": ".types",
    "DriverCoachAssignmentsGetDriverCoachAssignmentBadGatewayErrorResponseBody": ".types",
    "DriverCoachAssignmentsGetDriverCoachAssignmentGatewayTimeoutErrorResponseBody": ".types",
    "DriverCoachAssignmentsGetDriverCoachAssignmentInternalServerErrorResponseBody": ".types",
    "DriverCoachAssignmentsGetDriverCoachAssignmentMethodNotAllowedErrorResponseBody": ".types",
    "DriverCoachAssignmentsGetDriverCoachAssignmentNotFoundErrorResponseBody": ".types",
    "DriverCoachAssignmentsGetDriverCoachAssignmentNotImplementedErrorResponseBody": ".types",
    "DriverCoachAssignmentsGetDriverCoachAssignmentResponseBody": ".types",
    "DriverCoachAssignmentsGetDriverCoachAssignmentServiceUnavailableErrorResponseBody": ".types",
    "DriverCoachAssignmentsGetDriverCoachAssignmentTooManyRequestsErrorResponseBody": ".types",
    "DriverCoachAssignmentsGetDriverCoachAssignmentUnauthorizedErrorResponseBody": ".types",
    "DriverCoachAssignmentsPutDriverCoachAssignmentBadGatewayErrorResponseBody": ".types",
    "DriverCoachAssignmentsPutDriverCoachAssignmentGatewayTimeoutErrorResponseBody": ".types",
    "DriverCoachAssignmentsPutDriverCoachAssignmentInternalServerErrorResponseBody": ".types",
    "DriverCoachAssignmentsPutDriverCoachAssignmentMethodNotAllowedErrorResponseBody": ".types",
    "DriverCoachAssignmentsPutDriverCoachAssignmentNotFoundErrorResponseBody": ".types",
    "DriverCoachAssignmentsPutDriverCoachAssignmentNotImplementedErrorResponseBody": ".types",
    "DriverCoachAssignmentsPutDriverCoachAssignmentResponseBody": ".types",
    "DriverCoachAssignmentsPutDriverCoachAssignmentServiceUnavailableErrorResponseBody": ".types",
    "DriverCoachAssignmentsPutDriverCoachAssignmentTooManyRequestsErrorResponseBody": ".types",
    "DriverCoachAssignmentsPutDriverCoachAssignmentUnauthorizedErrorResponseBody": ".types",
    "DriverCreatedAtTime": ".types",
    "DriverDocumentSubmittedDetailsObjectRequestBody": ".types",
    "DriverDocumentSubmittedDetailsObjectResponseBody": ".types",
    "DriverDocumentSubmittedResponseBody": ".types",
    "DriverEfficienciesResponse": ".types",
    "DriverEfficienciesResponseData": ".types",
    "DriverEfficiency": ".types",
    "DriverEfficiencyDataObjectResponseBody": ".types",
    "DriverEfficiencyDifficultyScoreDataObjectResponseBody": ".types",
    "DriverEfficiencyGetDriverEfficiencyByDriversBadGatewayErrorResponseBody": ".types",
    "DriverEfficiencyGetDriverEfficiencyByDriversGatewayTimeoutErrorResponseBody": ".types",
    "DriverEfficiencyGetDriverEfficiencyByDriversInternalServerErrorResponseBody": ".types",
    "DriverEfficiencyGetDriverEfficiencyByDriversMethodNotAllowedErrorResponseBody": ".types",
    "DriverEfficiencyGetDriverEfficiencyByDriversNotFoundErrorResponseBody": ".types",
    "DriverEfficiencyGetDriverEfficiencyByDriversNotImplementedErrorResponseBody": ".types",
    "DriverEfficiencyGetDriverEfficiencyByDriversResponseBody": ".types",
    "DriverEfficiencyGetDriverEfficiencyByDriversServiceUnavailableErrorResponseBody": ".types",
    "DriverEfficiencyGetDriverEfficiencyByDriversTooManyRequestsErrorResponseBody": ".types",
    "DriverEfficiencyGetDriverEfficiencyByDriversUnauthorizedErrorResponseBody": ".types",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesBadGatewayErrorResponseBody": ".types",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesGatewayTimeoutErrorResponseBody": ".types",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesInternalServerErrorResponseBody": ".types",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesMethodNotAllowedErrorResponseBody": ".types",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesNotFoundErrorResponseBody": ".types",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesNotImplementedErrorResponseBody": ".types",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesResponseBody": ".types",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesServiceUnavailableErrorResponseBody": ".types",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesTooManyRequestsErrorResponseBody": ".types",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesUnauthorizedErrorResponseBody": ".types",
    "DriverEfficiencyPercentageDataObjectResponseBody": ".types",
    "DriverEfficiencyRawDataObjectResponseBody": ".types",
    "DriverEldAdverseWeatherExemptionEnabled": ".types",
    "DriverEldBigDayExemptionEnabled": ".types",
    "DriverEldDayStartHour": ".types",
    "DriverEldExempt": ".types",
    "DriverEldExemptReason": ".types",
    "DriverEldPcEnabled": ".types",
    "DriverEldRuleset": ".types",
    "DriverEldRulesetCycle": ".types",
    "DriverEldRulesetJurisdiction": ".types",
    "DriverEldRulesetRestBreak": ".types",
    "DriverEldRulesetRestart": ".types",
    "DriverEldRulesetShift": ".types",
    "DriverEldRulesets": ".types",
    "DriverEldSettings": ".types",
    "DriverEldYmEnabled": ".types",
    "DriverExternalIds": ".types",
    "DriverHasDrivingFeaturesHidden": ".types",
    "DriverHasVehicleUnpinningEnabled": ".types",
    "DriverHeavyHaulExemptionToggleEnabled": ".types",
    "DriverHomeTerminalAddress": ".types",
    "DriverHomeTerminalName": ".types",
    "DriverHosSetting": ".types",
    "DriverId": ".types",
    "DriverIdCardCode": ".types",
    "DriverIsDeactivated": ".types",
    "DriverLicenseNumber": ".types",
    "DriverLicenseState": ".types",
    "DriverLocale": ".types",
    "DriverMessageReceivedResponseBody": ".types",
    "DriverMessageSentResponseBody": ".types",
    "DriverName": ".types",
    "DriverNotes": ".types",
    "DriverObjectResponseBody": ".types",
    "DriverOrTagIdsDetailsRequestBody": ".types",
    "DriverOrTagIdsDetailsResponseBody": ".types",
    "DriverPhone": ".types",
    "DriverProfileImageBase64": ".types",
    "DriverProfileImageUrl": ".types",
    "DriverQrCodesCreateDriverQrCodeBadGatewayErrorResponseBody": ".types",
    "DriverQrCodesCreateDriverQrCodeGatewayTimeoutErrorResponseBody": ".types",
    "DriverQrCodesCreateDriverQrCodeInternalServerErrorResponseBody": ".types",
    "DriverQrCodesCreateDriverQrCodeMethodNotAllowedErrorResponseBody": ".types",
    "DriverQrCodesCreateDriverQrCodeNotFoundErrorResponseBody": ".types",
    "DriverQrCodesCreateDriverQrCodeNotImplementedErrorResponseBody": ".types",
    "DriverQrCodesCreateDriverQrCodeResponseBody": ".types",
    "DriverQrCodesCreateDriverQrCodeServiceUnavailableErrorResponseBody": ".types",
    "DriverQrCodesCreateDriverQrCodeTooManyRequestsErrorResponseBody": ".types",
    "DriverQrCodesCreateDriverQrCodeUnauthorizedErrorResponseBody": ".types",
    "DriverQrCodesDeleteDriverQrCodeBadGatewayErrorResponseBody": ".types",
    "DriverQrCodesDeleteDriverQrCodeGatewayTimeoutErrorResponseBody": ".types",
    "DriverQrCodesDeleteDriverQrCodeInternalServerErrorResponseBody": ".types",
    "DriverQrCodesDeleteDriverQrCodeMethodNotAllowedErrorResponseBody": ".types",
    "DriverQrCodesDeleteDriverQrCodeNotFoundErrorResponseBody": ".types",
    "DriverQrCodesDeleteDriverQrCodeNotImplementedErrorResponseBody": ".types",
    "DriverQrCodesDeleteDriverQrCodeServiceUnavailableErrorResponseBody": ".types",
    "DriverQrCodesDeleteDriverQrCodeTooManyRequestsErrorResponseBody": ".types",
    "DriverQrCodesDeleteDriverQrCodeUnauthorizedErrorResponseBody": ".types",
    "DriverQrCodesGetDriversQrCodesBadGatewayErrorResponseBody": ".types",
    "DriverQrCodesGetDriversQrCodesGatewayTimeoutErrorResponseBody": ".types",
    "DriverQrCodesGetDriversQrCodesInternalServerErrorResponseBody": ".types",
    "DriverQrCodesGetDriversQrCodesMethodNotAllowedErrorResponseBody": ".types",
    "DriverQrCodesGetDriversQrCodesNotFoundErrorResponseBody": ".types",
    "DriverQrCodesGetDriversQrCodesNotImplementedErrorResponseBody": ".types",
    "DriverQrCodesGetDriversQrCodesResponseBody": ".types",
    "DriverQrCodesGetDriversQrCodesServiceUnavailableErrorResponseBody": ".types",
    "DriverQrCodesGetDriversQrCodesTooManyRequestsErrorResponseBody": ".types",
    "DriverQrCodesGetDriversQrCodesUnauthorizedErrorResponseBody": ".types",
    "DriverRecordedResponseBody": ".types",
    "DriverRemoteSignoutPostDriverRemoteSignoutBadGatewayErrorResponseBody": ".types",
    "DriverRemoteSignoutPostDriverRemoteSignoutGatewayTimeoutErrorResponseBody": ".types",
    "DriverRemoteSignoutPostDriverRemoteSignoutInternalServerErrorResponseBody": ".types",
    "DriverRemoteSignoutPostDriverRemoteSignoutMethodNotAllowedErrorResponseBody": ".types",
    "DriverRemoteSignoutPostDriverRemoteSignoutNotFoundErrorResponseBody": ".types",
    "DriverRemoteSignoutPostDriverRemoteSignoutNotImplementedErrorResponseBody": ".types",
    "DriverRemoteSignoutPostDriverRemoteSignoutResponseBody": ".types",
    "DriverRemoteSignoutPostDriverRemoteSignoutServiceUnavailableErrorResponseBody": ".types",
    "DriverRemoteSignoutPostDriverRemoteSignoutTooManyRequestsErrorResponseBody": ".types",
    "DriverRemoteSignoutPostDriverRemoteSignoutUnauthorizedErrorResponseBody": ".types",
    "DriverResponse": ".types",
    "DriverRulesetObjectResponseBody": ".types",
    "DriverRulesetObjectResponseBodyBreak": ".types",
    "DriverRulesetObjectResponseBodyCycle": ".types",
    "DriverRulesetObjectResponseBodyRestart": ".types",
    "DriverRulesetObjectResponseBodyShift": ".types",
    "DriverSafetyScoreResponseBody": ".types",
    "DriverStaticAssignedVehicle": ".types",
    "DriverTachographActivityData": ".types",
    "DriverTachographActivityResponse": ".types",
    "DriverTachographCardNumber": ".types",
    "DriverTags": ".types",
    "DriverTimezone": ".types",
    "DriverTinyResponse": ".types",
    "DriverUpdatedAtTime": ".types",
    "DriverUsername": ".types",
    "DriverVehicleAssignmentV2ObjectResponseBody": ".types",
    "DriverVehicleAssignmentV2ObjectResponseBodyAssignmentType": ".types",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentBadGatewayErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentGatewayTimeoutErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentInternalServerErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentMethodNotAllowedErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentNotFoundErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentNotImplementedErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentResponseBody": ".types",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentServiceUnavailableErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentTooManyRequestsErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentUnauthorizedErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsBadGatewayErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsGatewayTimeoutErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsInternalServerErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsMethodNotAllowedErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsNotFoundErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsNotImplementedErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsServiceUnavailableErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsTooManyRequestsErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsUnauthorizedErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsBadGatewayErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsGatewayTimeoutErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsInternalServerErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsMethodNotAllowedErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsNotFoundErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsNotImplementedErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsResponseBody": ".types",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsServiceUnavailableErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsTooManyRequestsErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsUnauthorizedErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentBadGatewayErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentGatewayTimeoutErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentInternalServerErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentMethodNotAllowedErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentNotFoundErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentNotImplementedErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentResponseBody": ".types",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentServiceUnavailableErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentTooManyRequestsErrorResponseBody": ".types",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentUnauthorizedErrorResponseBody": ".types",
    "DriverVehicleGroupTag": ".types",
    "DriverWaitingTimeDutyStatusEnabled": ".types",
    "DriverWithExternalIdObjectResponseBody": ".types",
    "DriverWithTimezoneEldSettingsObjectResponseBody": ".types",
    "DriversAuthTokenCreateDriverAuthTokenBadGatewayErrorResponseBody": ".types",
    "DriversAuthTokenCreateDriverAuthTokenGatewayTimeoutErrorResponseBody": ".types",
    "DriversAuthTokenCreateDriverAuthTokenInternalServerErrorResponseBody": ".types",
    "DriversAuthTokenCreateDriverAuthTokenMethodNotAllowedErrorResponseBody": ".types",
    "DriversAuthTokenCreateDriverAuthTokenNotFoundErrorResponseBody": ".types",
    "DriversAuthTokenCreateDriverAuthTokenNotImplementedErrorResponseBody": ".types",
    "DriversAuthTokenCreateDriverAuthTokenResponseBody": ".types",
    "DriversAuthTokenCreateDriverAuthTokenServiceUnavailableErrorResponseBody": ".types",
    "DriversAuthTokenCreateDriverAuthTokenTooManyRequestsErrorResponseBody": ".types",
    "DriversAuthTokenCreateDriverAuthTokenUnauthorizedErrorResponseBody": ".types",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsBadGatewayErrorResponseBody": ".types",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsGatewayTimeoutErrorResponseBody": ".types",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsInternalServerErrorResponseBody": ".types",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsMethodNotAllowedErrorResponseBody": ".types",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsNotFoundErrorResponseBody": ".types",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsNotImplementedErrorResponseBody": ".types",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsResponseBody": ".types",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsServiceUnavailableErrorResponseBody": ".types",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsTooManyRequestsErrorResponseBody": ".types",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsUnauthorizedErrorResponseBody": ".types",
    "DriversVehicleAssignmentsObjectResponseBody": ".types",
    "DriversVehicleAssignmentsObjectResponseBodyDriverActivationStatus": ".types",
    "DutyStatusDurationObjectResponseBody": ".types",
    "Dvir": ".types",
    "Dvir2AssignedToPolymorphicUserObjectResponseBody": ".types",
    "Dvir2DeviceObjectResponseBody": ".types",
    "Dvir2FormSubmissionObjectResponseBody": ".types",
    "Dvir2RelatedDeviceObjectResponseBody": ".types",
    "Dvir2RelatedDeviceObjectResponseBodyAssetType": ".types",
    "Dvir2SubmissionResponseObjectResponseBody": ".types",
    "Dvir2SubmissionResponseObjectResponseBodyInspectionType": ".types",
    "DvirAuthorSignature": ".types",
    "DvirDefectGetDefectBadGatewayErrorResponseBody": ".types",
    "DvirDefectGetDefectGatewayTimeoutErrorResponseBody": ".types",
    "DvirDefectGetDefectInternalServerErrorResponseBody": ".types",
    "DvirDefectGetDefectMethodNotAllowedErrorResponseBody": ".types",
    "DvirDefectGetDefectNotFoundErrorResponseBody": ".types",
    "DvirDefectGetDefectNotImplementedErrorResponseBody": ".types",
    "DvirDefectGetDefectResponseBody": ".types",
    "DvirDefectGetDefectServiceUnavailableErrorResponseBody": ".types",
    "DvirDefectGetDefectTooManyRequestsErrorResponseBody": ".types",
    "DvirDefectGetDefectUnauthorizedErrorResponseBody": ".types",
    "DvirDefectStreamDefectsBadGatewayErrorResponseBody": ".types",
    "DvirDefectStreamDefectsGatewayTimeoutErrorResponseBody": ".types",
    "DvirDefectStreamDefectsInternalServerErrorResponseBody": ".types",
    "DvirDefectStreamDefectsMethodNotAllowedErrorResponseBody": ".types",
    "DvirDefectStreamDefectsNotFoundErrorResponseBody": ".types",
    "DvirDefectStreamDefectsNotImplementedErrorResponseBody": ".types",
    "DvirDefectStreamDefectsResponseBody": ".types",
    "DvirDefectStreamDefectsServiceUnavailableErrorResponseBody": ".types",
    "DvirDefectStreamDefectsTooManyRequestsErrorResponseBody": ".types",
    "DvirDefectStreamDefectsUnauthorizedErrorResponseBody": ".types",
    "DvirDefectTypeGetDefectTypesBadGatewayErrorResponseBody": ".types",
    "DvirDefectTypeGetDefectTypesGatewayTimeoutErrorResponseBody": ".types",
    "DvirDefectTypeGetDefectTypesInternalServerErrorResponseBody": ".types",
    "DvirDefectTypeGetDefectTypesMethodNotAllowedErrorResponseBody": ".types",
    "DvirDefectTypeGetDefectTypesNotFoundErrorResponseBody": ".types",
    "DvirDefectTypeGetDefectTypesNotImplementedErrorResponseBody": ".types",
    "DvirDefectTypeGetDefectTypesResponseBody": ".types",
    "DvirDefectTypeGetDefectTypesServiceUnavailableErrorResponseBody": ".types",
    "DvirDefectTypeGetDefectTypesTooManyRequestsErrorResponseBody": ".types",
    "DvirDefectTypeGetDefectTypesUnauthorizedErrorResponseBody": ".types",
    "DvirDefectsObjectV20220913ResponseBody": ".types",
    "DvirDefectsObjectV20220913ResponseBodyDefectSeverity": ".types",
    "DvirGetDvirBadGatewayErrorResponseBody": ".types",
    "DvirGetDvirGatewayTimeoutErrorResponseBody": ".types",
    "DvirGetDvirInternalServerErrorResponseBody": ".types",
    "DvirGetDvirMethodNotAllowedErrorResponseBody": ".types",
    "DvirGetDvirNotFoundErrorResponseBody": ".types",
    "DvirGetDvirNotImplementedErrorResponseBody": ".types",
    "DvirGetDvirResponseBody": ".types",
    "DvirGetDvirResponseBodySafetyStatus": ".types",
    "DvirGetDvirResponseBodyType": ".types",
    "DvirGetDvirServiceUnavailableErrorResponseBody": ".types",
    "DvirGetDvirTooManyRequestsErrorResponseBody": ".types",
    "DvirGetDvirUnauthorizedErrorResponseBody": ".types",
    "DvirGetDvirsBadGatewayErrorResponseBody": ".types",
    "DvirGetDvirsGatewayTimeoutErrorResponseBody": ".types",
    "DvirGetDvirsInternalServerErrorResponseBody": ".types",
    "DvirGetDvirsMethodNotAllowedErrorResponseBody": ".types",
    "DvirGetDvirsNotFoundErrorResponseBody": ".types",
    "DvirGetDvirsNotImplementedErrorResponseBody": ".types",
    "DvirGetDvirsResponseBody": ".types",
    "DvirGetDvirsServiceUnavailableErrorResponseBody": ".types",
    "DvirGetDvirsTooManyRequestsErrorResponseBody": ".types",
    "DvirGetDvirsUnauthorizedErrorResponseBody": ".types",
    "DvirLicensePlate": ".types",
    "DvirLocation": ".types",
    "DvirMechanicNotes": ".types",
    "DvirOdometerMeters": ".types",
    "DvirResolvedByObjectResponseBody": ".types",
    "DvirResolvedByObjectResponseBodyType": ".types",
    "DvirResponse": ".types",
    "DvirSafetyStatus": ".types",
    "DvirSecondSignature": ".types",
    "DvirSignature": ".types",
    "DvirSignatureSignatoryUser": ".types",
    "DvirSignatureType": ".types",
    "DvirStreamResponseDataResponseBody": ".types",
    "DvirStreamResponseDataResponseBodySafetyStatus": ".types",
    "DvirStreamResponseDataResponseBodyType": ".types",
    "DvirSubmittedDeviceTriggerDetailsObjectRequestBody": ".types",
    "DvirSubmittedDeviceTriggerDetailsObjectRequestBodyDvirSubmissionTypesItem": ".types",
    "DvirSubmittedDeviceTriggerDetailsObjectResponseBody": ".types",
    "DvirSubmittedDeviceTriggerDetailsObjectResponseBodyDvirSubmissionTypesItem": ".types",
    "DvirThirdSignature": ".types",
    "DvirTrailer": ".types",
    "DvirTrailerDefects": ".types",
    "DvirTrailerDefectsItems": ".types",
    "DvirTrailerDefectsItemsTrailer": ".types",
    "DvirTrailerDefectsItemsVehicle": ".types",
    "DvirType": ".types",
    "DvirVehicle": ".types",
    "DvirVehicleDefects": ".types",
    "DvirsListResponse": ".types",
    "EldSettingsObjectResponseBody": ".types",
    "EngineIdleDataResponseBody": ".types",
    "EngineIdleTriggerDetailsObjectRequestBody": ".types",
    "EngineIdleTriggerDetailsObjectResponseBody": ".types",
    "EngineImmobilizerGetEngineImmobilizerStatesBadGatewayErrorResponseBody": ".types",
    "EngineImmobilizerGetEngineImmobilizerStatesGatewayTimeoutErrorResponseBody": ".types",
    "EngineImmobilizerGetEngineImmobilizerStatesInternalServerErrorResponseBody": ".types",
    "EngineImmobilizerGetEngineImmobilizerStatesMethodNotAllowedErrorResponseBody": ".types",
    "EngineImmobilizerGetEngineImmobilizerStatesNotFoundErrorResponseBody": ".types",
    "EngineImmobilizerGetEngineImmobilizerStatesNotImplementedErrorResponseBody": ".types",
    "EngineImmobilizerGetEngineImmobilizerStatesResponseBody": ".types",
    "EngineImmobilizerGetEngineImmobilizerStatesServiceUnavailableErrorResponseBody": ".types",
    "EngineImmobilizerGetEngineImmobilizerStatesTooManyRequestsErrorResponseBody": ".types",
    "EngineImmobilizerGetEngineImmobilizerStatesUnauthorizedErrorResponseBody": ".types",
    "EngineImmobilizerRelayStateResponseBody": ".types",
    "EngineImmobilizerRelayStateResponseBodyId": ".types",
    "EngineImmobilizerStateResponseBody": ".types",
    "EngineImmobilizerUpdateEngineImmobilizerStateBadGatewayErrorResponseBody": ".types",
    "EngineImmobilizerUpdateEngineImmobilizerStateGatewayTimeoutErrorResponseBody": ".types",
    "EngineImmobilizerUpdateEngineImmobilizerStateInternalServerErrorResponseBody": ".types",
    "EngineImmobilizerUpdateEngineImmobilizerStateMethodNotAllowedErrorResponseBody": ".types",
    "EngineImmobilizerUpdateEngineImmobilizerStateNotFoundErrorResponseBody": ".types",
    "EngineImmobilizerUpdateEngineImmobilizerStateNotImplementedErrorResponseBody": ".types",
    "EngineImmobilizerUpdateEngineImmobilizerStateServiceUnavailableErrorResponseBody": ".types",
    "EngineImmobilizerUpdateEngineImmobilizerStateTooManyRequestsErrorResponseBody": ".types",
    "EngineImmobilizerUpdateEngineImmobilizerStateUnauthorizedErrorResponseBody": ".types",
    "EngineOffDetailsObjectRequestBody": ".types",
    "EngineOffDetailsObjectResponseBody": ".types",
    "EngineOffResponseBody": ".types",
    "EngineOnDetailsObjectRequestBody": ".types",
    "EngineOnDetailsObjectResponseBody": ".types",
    "EngineOnResponseBody": ".types",
    "EngineStatusResponseBody": ".types",
    "EnumReadingAlertThresholdResponseBody": ".types",
    "EnumValueResponseBody": ".types",
    "EquipmentEngineRpm": ".types",
    "EquipmentEngineSeconds": ".types",
    "EquipmentEngineState": ".types",
    "EquipmentEngineStateValue": ".types",
    "EquipmentEngineTotalIdleTimeMinutes": ".types",
    "EquipmentFuelPercent": ".types",
    "EquipmentGatewayEngineSeconds": ".types",
    "EquipmentGatewayEngineState": ".types",
    "EquipmentGatewayEngineStateValue": ".types",
    "EquipmentGatewayJ1939EngineSeconds": ".types",
    "EquipmentGpsOdometerMeters": ".types",
    "EquipmentHeaderWithAdditionalFieldsResponseBody": ".types",
    "EquipmentId": ".types",
    "EquipmentInstalledGateway": ".types",
    "EquipmentListResponse": ".types",
    "EquipmentLocation": ".types",
    "EquipmentLocationsListResponse": ".types",
    "EquipmentLocationsListResponseData": ".types",
    "EquipmentLocationsResponse": ".types",
    "EquipmentLocationsResponseData": ".types",
    "EquipmentName": ".types",
    "EquipmentObdEngineSeconds": ".types",
    "EquipmentObdEngineState": ".types",
    "EquipmentObdEngineStateValue": ".types",
    "EquipmentObject": ".types",
    "EquipmentPatchEquipmentBadGatewayErrorResponseBody": ".types",
    "EquipmentPatchEquipmentGatewayTimeoutErrorResponseBody": ".types",
    "EquipmentPatchEquipmentInternalServerErrorResponseBody": ".types",
    "EquipmentPatchEquipmentMethodNotAllowedErrorResponseBody": ".types",
    "EquipmentPatchEquipmentNotFoundErrorResponseBody": ".types",
    "EquipmentPatchEquipmentNotImplementedErrorResponseBody": ".types",
    "EquipmentPatchEquipmentResponseBody": ".types",
    "EquipmentPatchEquipmentServiceUnavailableErrorResponseBody": ".types",
    "EquipmentPatchEquipmentTooManyRequestsErrorResponseBody": ".types",
    "EquipmentPatchEquipmentUnauthorizedErrorResponseBody": ".types",
    "EquipmentResponse": ".types",
    "EquipmentStatsGps": ".types",
    "EquipmentStatsListResponse": ".types",
    "EquipmentStatsListResponseData": ".types",
    "EquipmentStatsResponse": ".types",
    "EquipmentStatsResponseData": ".types",
    "EquipmentTime": ".types",
    "EquipmentWithAttributesResponseObjectResponseBody": ".types",
    "EventLocationResponseBody": ".types",
    "ExtendedDriverTinyResponse": ".types",
    "ExtendedDriverTinyResponseExternalIds": ".types",
    "FftSpectraDataPoint": ".types",
    "FftSpectraDataPointFftSpectra": ".types",
    "FieldObjectPostRequestBody": ".types",
    "FieldObjectPostRequestBodyType": ".types",
    "FieldObjectResponseBody": ".types",
    "FieldObjectResponseBodyType": ".types",
    "FieldObjectValueRequestBody": ".types",
    "FieldObjectValueResponseBody": ".types",
    "FieldTypesObjectResponseBody": ".types",
    "FieldTypesObjectResponseBodyFieldType": ".types",
    "FiltersRequestBody": ".types",
    "FiltersResponseBody": ".types",
    "FleetDeviceObjectResponseBody": ".types",
    "FollowingDistanceDetectionAlertSettingsObjectResponseBody": ".types",
    "FormSubmissionPdfExportResponseObjectResponseBody": ".types",
    "FormSubmissionPdfExportResponseObjectResponseBodyJobStatus": ".types",
    "FormSubmissionRequestApprovalDetailsRequestBody": ".types",
    "FormSubmissionRequestAssetObjectRequestBody": ".types",
    "FormSubmissionRequestAssetValueObjectRequestBody": ".types",
    "FormSubmissionRequestAssignedToRequestBody": ".types",
    "FormSubmissionRequestAssignedToRequestBodyType": ".types",
    "FormSubmissionRequestCheckBoxesValueObjectRequestBody": ".types",
    "FormSubmissionRequestDateTimeValueObjectRequestBody": ".types",
    "FormSubmissionRequestFieldInputObjectRequestBody": ".types",
    "FormSubmissionRequestFieldInputObjectRequestBodyType": ".types",
    "FormSubmissionRequestGeofenceObjectRequestBody": ".types",
    "FormSubmissionRequestGeofenceValueObjectRequestBody": ".types",
    "FormSubmissionRequestMediaItemObjectRequestBody": ".types",
    "FormSubmissionRequestMediaValueObjectRequestBody": ".types",
    "FormSubmissionRequestMultipleChoiceValueObjectRequestBody": ".types",
    "FormSubmissionRequestNumberValueObjectRequestBody": ".types",
    "FormSubmissionRequestPersonObjectRequestBody": ".types",
    "FormSubmissionRequestPersonValueObjectRequestBody": ".types",
    "FormSubmissionRequestSignatureValueObjectRequestBody": ".types",
    "FormSubmissionRequestTableCellObjectRequestBody": ".types",
    "FormSubmissionRequestTableCellObjectRequestBodyType": ".types",
    "FormSubmissionRequestTableRowObjectRequestBody": ".types",
    "FormSubmissionRequestTableValueObjectRequestBody": ".types",
    "FormSubmissionRequestTextValueObjectRequestBody": ".types",
    "FormSubmissionResponseObjectResponseBody": ".types",
    "FormSubmissionResponseObjectResponseBodyStatus": ".types",
    "FormSubmissionsGetFormSubmissionsBadGatewayErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsGatewayTimeoutErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsInternalServerErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsMethodNotAllowedErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsNotFoundErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsNotImplementedErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsPdfExportsBadGatewayErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsPdfExportsGatewayTimeoutErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsPdfExportsInternalServerErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsPdfExportsMethodNotAllowedErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsPdfExportsNotFoundErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsPdfExportsNotImplementedErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsPdfExportsResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsPdfExportsServiceUnavailableErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsPdfExportsTooManyRequestsErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsPdfExportsUnauthorizedErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsServiceUnavailableErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsStreamBadGatewayErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsStreamGatewayTimeoutErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsStreamInternalServerErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsStreamMethodNotAllowedErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsStreamNotFoundErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsStreamNotImplementedErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsStreamResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsStreamServiceUnavailableErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsStreamTooManyRequestsErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsStreamUnauthorizedErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsTooManyRequestsErrorResponseBody": ".types",
    "FormSubmissionsGetFormSubmissionsUnauthorizedErrorResponseBody": ".types",
    "FormSubmissionsPatchFormSubmissionBadGatewayErrorResponseBody": ".types",
    "FormSubmissionsPatchFormSubmissionGatewayTimeoutErrorResponseBody": ".types",
    "FormSubmissionsPatchFormSubmissionInternalServerErrorResponseBody": ".types",
    "FormSubmissionsPatchFormSubmissionMethodNotAllowedErrorResponseBody": ".types",
    "FormSubmissionsPatchFormSubmissionNotFoundErrorResponseBody": ".types",
    "FormSubmissionsPatchFormSubmissionNotImplementedErrorResponseBody": ".types",
    "FormSubmissionsPatchFormSubmissionRequestBodyStatus": ".forms",
    "FormSubmissionsPatchFormSubmissionResponseBody": ".types",
    "FormSubmissionsPatchFormSubmissionServiceUnavailableErrorResponseBody": ".types",
    "FormSubmissionsPatchFormSubmissionTooManyRequestsErrorResponseBody": ".types",
    "FormSubmissionsPatchFormSubmissionUnauthorizedErrorResponseBody": ".types",
    "FormSubmissionsPostFormSubmissionBadGatewayErrorResponseBody": ".types",
    "FormSubmissionsPostFormSubmissionGatewayTimeoutErrorResponseBody": ".types",
    "FormSubmissionsPostFormSubmissionInternalServerErrorResponseBody": ".types",
    "FormSubmissionsPostFormSubmissionMethodNotAllowedErrorResponseBody": ".types",
    "FormSubmissionsPostFormSubmissionNotFoundErrorResponseBody": ".types",
    "FormSubmissionsPostFormSubmissionNotImplementedErrorResponseBody": ".types",
    "FormSubmissionsPostFormSubmissionRequestBodyStatus": ".forms",
    "FormSubmissionsPostFormSubmissionResponseBody": ".types",
    "FormSubmissionsPostFormSubmissionServiceUnavailableErrorResponseBody": ".types",
    "FormSubmissionsPostFormSubmissionTooManyRequestsErrorResponseBody": ".types",
    "FormSubmissionsPostFormSubmissionUnauthorizedErrorResponseBody": ".types",
    "FormSubmissionsPostFormSubmissionsPdfExportsBadGatewayErrorResponseBody": ".types",
    "FormSubmissionsPostFormSubmissionsPdfExportsGatewayTimeoutErrorResponseBody": ".types",
    "FormSubmissionsPostFormSubmissionsPdfExportsInternalServerErrorResponseBody": ".types",
    "FormSubmissionsPostFormSubmissionsPdfExportsMethodNotAllowedErrorResponseBody": ".types",
    "FormSubmissionsPostFormSubmissionsPdfExportsNotFoundErrorResponseBody": ".types",
    "FormSubmissionsPostFormSubmissionsPdfExportsNotImplementedErrorResponseBody": ".types",
    "FormSubmissionsPostFormSubmissionsPdfExportsResponseBody": ".types",
    "FormSubmissionsPostFormSubmissionsPdfExportsServiceUnavailableErrorResponseBody": ".types",
    "FormSubmissionsPostFormSubmissionsPdfExportsTooManyRequestsErrorResponseBody": ".types",
    "FormSubmissionsPostFormSubmissionsPdfExportsUnauthorizedErrorResponseBody": ".types",
    "FormSubmittedResponseBody": ".types",
    "FormTemplateReferenceObjectResponseBody": ".types",
    "FormTemplateRequestObjectRequestBody": ".types",
    "FormTemplateResponseObjectResponseBody": ".types",
    "FormTemplateResponseObjectResponseBodyFormCategory": ".types",
    "FormTemplateSectionObjectResponseBody": ".types",
    "FormTemplatesGetFormTemplatesBadGatewayErrorResponseBody": ".types",
    "FormTemplatesGetFormTemplatesGatewayTimeoutErrorResponseBody": ".types",
    "FormTemplatesGetFormTemplatesInternalServerErrorResponseBody": ".types",
    "FormTemplatesGetFormTemplatesMethodNotAllowedErrorResponseBody": ".types",
    "FormTemplatesGetFormTemplatesNotFoundErrorResponseBody": ".types",
    "FormTemplatesGetFormTemplatesNotImplementedErrorResponseBody": ".types",
    "FormTemplatesGetFormTemplatesResponseBody": ".types",
    "FormTemplatesGetFormTemplatesServiceUnavailableErrorResponseBody": ".types",
    "FormTemplatesGetFormTemplatesTooManyRequestsErrorResponseBody": ".types",
    "FormTemplatesGetFormTemplatesUnauthorizedErrorResponseBody": ".types",
    "FormUpdatedResponseBody": ".types",
    "FormsActionObjectResponseBody": ".types",
    "FormsActionObjectResponseBodyType": ".types",
    "FormsApprovalConfigObjectResponseBody": ".types",
    "FormsApprovalConfigObjectResponseBodyType": ".types",
    "FormsAssetObjectResponseBody": ".types",
    "FormsAssetObjectResponseBodyEntryType": ".types",
    "FormsAssetValueObjectResponseBody": ".types",
    "FormsCheckBoxesValueObjectResponseBody": ".types",
    "FormsConditionObjectResponseBody": ".types",
    "FormsConditionObjectResponseBodyType": ".types",
    "FormsConditionalActionObjectResponseBody": ".types",
    "FormsDateTimeValueObjectResponseBody": ".types",
    "FormsDateTimeValueObjectResponseBodyType": ".types",
    "FormsFieldDefinitionObjectResponseBody": ".types",
    "FormsFieldDefinitionObjectResponseBodyAllowedAssetTypesItem": ".types",
    "FormsFieldDefinitionObjectResponseBodyAllowedDateTimeValueType": ".types",
    "FormsFieldDefinitionObjectResponseBodyType": ".types",
    "FormsFieldInputObjectResponseBody": ".types",
    "FormsFieldInputObjectResponseBodyType": ".types",
    "FormsGeofenceObjectResponseBody": ".types",
    "FormsGeofenceObjectResponseBodyEntryType": ".types",
    "FormsGeofenceValueObjectResponseBody": ".types",
    "FormsIssueCreatedByFieldObjectResponseBody": ".types",
    "FormsLocationObjectResponseBody": ".types",
    "FormsMediaRecordObjectResponseBody": ".types",
    "FormsMediaRecordObjectResponseBodyProcessingStatus": ".types",
    "FormsMediaValueObjectResponseBody": ".types",
    "FormsMultipleChoiceValueObjectResponseBody": ".types",
    "FormsNumberValueObjectResponseBody": ".types",
    "FormsPersonObjectResponseBody": ".types",
    "FormsPersonObjectResponseBodyEntryType": ".types",
    "FormsPersonValueObjectResponseBody": ".types",
    "FormsPolymorphicUserObjectResponseBody": ".types",
    "FormsPolymorphicUserObjectResponseBodyType": ".types",
    "FormsProductSubmissionApprovalDetailsObjectResponseBody": ".types",
    "FormsScoreObjectResponseBody": ".types",
    "FormsSelectOptionObjectResponseBody": ".types",
    "FormsSignatureValueObjectResponseBody": ".types",
    "FormsSingleApprovalConfigObjectResponseBody": ".types",
    "FormsTableCellObjectResponseBody": ".types",
    "FormsTableCellObjectResponseBodyType": ".types",
    "FormsTableColumnObjectResponseBody": ".types",
    "FormsTableColumnObjectResponseBodyType": ".types",
    "FormsTableFieldDefinitionObjectResponseBody": ".types",
    "FormsTableFieldDefinitionObjectResponseBodyAllowedDateTimeValueType": ".types",
    "FormsTableFieldDefinitionObjectResponseBodyType": ".types",
    "FormsTableRowObjectResponseBody": ".types",
    "FormsTableValueObjectResponseBody": ".types",
    "FormsTextValueObjectResponseBody": ".types",
    "ForwardCollisionDetectionAlertSettingsObjectResponseBody": ".types",
    "ForwardCollisionDetectionAlertSettingsObjectResponseBodySensitivity": ".types",
    "FuelConsumedMl": ".types",
    "FuelCostObjectResponseBody": ".types",
    "FuelCostObjectResponseBodyCurrency": ".types",
    "FuelEnergyCostResponseResponseBody": ".types",
    "FuelEnergyDriverReportDataObjectResponseBody": ".types",
    "FuelEnergyDriverReportObjectResponseBody": ".types",
    "FuelEnergyGetFuelEnergyDriverReportsBadGatewayErrorResponseBody": ".types",
    "FuelEnergyGetFuelEnergyDriverReportsGatewayTimeoutErrorResponseBody": ".types",
    "FuelEnergyGetFuelEnergyDriverReportsInternalServerErrorResponseBody": ".types",
    "FuelEnergyGetFuelEnergyDriverReportsMethodNotAllowedErrorResponseBody": ".types",
    "FuelEnergyGetFuelEnergyDriverReportsNotFoundErrorResponseBody": ".types",
    "FuelEnergyGetFuelEnergyDriverReportsNotImplementedErrorResponseBody": ".types",
    "FuelEnergyGetFuelEnergyDriverReportsResponseBody": ".types",
    "FuelEnergyGetFuelEnergyDriverReportsServiceUnavailableErrorResponseBody": ".types",
    "FuelEnergyGetFuelEnergyDriverReportsTooManyRequestsErrorResponseBody": ".types",
    "FuelEnergyGetFuelEnergyDriverReportsUnauthorizedErrorResponseBody": ".types",
    "FuelEnergyGetFuelEnergyVehicleReportsBadGatewayErrorResponseBody": ".types",
    "FuelEnergyGetFuelEnergyVehicleReportsGatewayTimeoutErrorResponseBody": ".types",
    "FuelEnergyGetFuelEnergyVehicleReportsInternalServerErrorResponseBody": ".types",
    "FuelEnergyGetFuelEnergyVehicleReportsMethodNotAllowedErrorResponseBody": ".types",
    "FuelEnergyGetFuelEnergyVehicleReportsNotFoundErrorResponseBody": ".types",
    "FuelEnergyGetFuelEnergyVehicleReportsNotImplementedErrorResponseBody": ".types",
    "FuelEnergyGetFuelEnergyVehicleReportsResponseBody": ".types",
    "FuelEnergyGetFuelEnergyVehicleReportsServiceUnavailableErrorResponseBody": ".types",
    "FuelEnergyGetFuelEnergyVehicleReportsTooManyRequestsErrorResponseBody": ".types",
    "FuelEnergyGetFuelEnergyVehicleReportsUnauthorizedErrorResponseBody": ".types",
    "FuelEnergyVehicleObjectResponseBody": ".types",
    "FuelEnergyVehicleObjectResponseBodyEnergyType": ".types",
    "FuelEnergyVehicleReportDataObjectResponseBody": ".types",
    "FuelEnergyVehicleReportObjectResponseBody": ".types",
    "FuelLevelPercentageResponseBody": ".types",
    "FuelLevelTriggerDetailsObjectRequestBody": ".types",
    "FuelLevelTriggerDetailsObjectRequestBodyOperation": ".types",
    "FuelLevelTriggerDetailsObjectResponseBody": ".types",
    "FuelLevelTriggerDetailsObjectResponseBodyOperation": ".types",
    "FuelPurchasePostFuelPurchaseBadGatewayErrorResponseBody": ".types",
    "FuelPurchasePostFuelPurchaseGatewayTimeoutErrorResponseBody": ".types",
    "FuelPurchasePostFuelPurchaseInternalServerErrorResponseBody": ".types",
    "FuelPurchasePostFuelPurchaseMethodNotAllowedErrorResponseBody": ".types",
    "FuelPurchasePostFuelPurchaseNotFoundErrorResponseBody": ".types",
    "FuelPurchasePostFuelPurchaseNotImplementedErrorResponseBody": ".types",
    "FuelPurchasePostFuelPurchaseRequestBodyFuelGrade": ".fuel_and_energy",
    "FuelPurchasePostFuelPurchaseRequestBodyIftaFuelType": ".fuel_and_energy",
    "FuelPurchasePostFuelPurchaseResponseBody": ".types",
    "FuelPurchasePostFuelPurchaseServiceUnavailableErrorResponseBody": ".types",
    "FuelPurchasePostFuelPurchaseTooManyRequestsErrorResponseBody": ".types",
    "FuelPurchasePostFuelPurchaseUnauthorizedErrorResponseBody": ".types",
    "FuelRemainingResponseBody": ".types",
    "FuelVolumeResponseBody": ".types",
    "FuelVolumeResponseBodyUnit": ".types",
    "FunctionCodePackageResponseBody": ".types",
    "FunctionCodePackageResponseBodyStatus": ".types",
    "FunctionConfigResponseBody": ".types",
    "FunctionConfigResponseBodyParams": ".types",
    "FunctionConfigResponseBodySecrets": ".types",
    "FunctionEffectsResponseBody": ".types",
    "FunctionScheduleEntryRequestBody": ".types",
    "FunctionScheduleEntryResponseBody": ".types",
    "FunctionScheduleRequestBody": ".types",
    "FunctionScheduleResponseBody": ".types",
    "FunctionsCreateFunctionBadGatewayErrorResponseBody": ".types",
    "FunctionsCreateFunctionGatewayTimeoutErrorResponseBody": ".types",
    "FunctionsCreateFunctionInternalServerErrorResponseBody": ".types",
    "FunctionsCreateFunctionMethodNotAllowedErrorResponseBody": ".types",
    "FunctionsCreateFunctionNotFoundErrorResponseBody": ".types",
    "FunctionsCreateFunctionNotImplementedErrorResponseBody": ".types",
    "FunctionsCreateFunctionResponseBody": ".types",
    "FunctionsCreateFunctionServiceUnavailableErrorResponseBody": ".types",
    "FunctionsCreateFunctionTooManyRequestsErrorResponseBody": ".types",
    "FunctionsCreateFunctionUnauthorizedErrorResponseBody": ".types",
    "FunctionsDeployFunctionBadGatewayErrorResponseBody": ".types",
    "FunctionsDeployFunctionGatewayTimeoutErrorResponseBody": ".types",
    "FunctionsDeployFunctionInternalServerErrorResponseBody": ".types",
    "FunctionsDeployFunctionMethodNotAllowedErrorResponseBody": ".types",
    "FunctionsDeployFunctionNotFoundErrorResponseBody": ".types",
    "FunctionsDeployFunctionNotImplementedErrorResponseBody": ".types",
    "FunctionsDeployFunctionResponseBody": ".types",
    "FunctionsDeployFunctionServiceUnavailableErrorResponseBody": ".types",
    "FunctionsDeployFunctionTooManyRequestsErrorResponseBody": ".types",
    "FunctionsDeployFunctionUnauthorizedErrorResponseBody": ".types",
    "FunctionsGetFunctionBadGatewayErrorResponseBody": ".types",
    "FunctionsGetFunctionGatewayTimeoutErrorResponseBody": ".types",
    "FunctionsGetFunctionInternalServerErrorResponseBody": ".types",
    "FunctionsGetFunctionMethodNotAllowedErrorResponseBody": ".types",
    "FunctionsGetFunctionNotFoundErrorResponseBody": ".types",
    "FunctionsGetFunctionNotImplementedErrorResponseBody": ".types",
    "FunctionsGetFunctionResponseBody": ".types",
    "FunctionsGetFunctionServiceUnavailableErrorResponseBody": ".types",
    "FunctionsGetFunctionTooManyRequestsErrorResponseBody": ".types",
    "FunctionsGetFunctionUnauthorizedErrorResponseBody": ".types",
    "FunctionsPatchFunctionBadGatewayErrorResponseBody": ".types",
    "FunctionsPatchFunctionGatewayTimeoutErrorResponseBody": ".types",
    "FunctionsPatchFunctionInternalServerErrorResponseBody": ".types",
    "FunctionsPatchFunctionMethodNotAllowedErrorResponseBody": ".types",
    "FunctionsPatchFunctionNotFoundErrorResponseBody": ".types",
    "FunctionsPatchFunctionNotImplementedErrorResponseBody": ".types",
    "FunctionsPatchFunctionResponseBody": ".types",
    "FunctionsPatchFunctionServiceUnavailableErrorResponseBody": ".types",
    "FunctionsPatchFunctionTooManyRequestsErrorResponseBody": ".types",
    "FunctionsPatchFunctionUnauthorizedErrorResponseBody": ".types",
    "FunctionsStartFunctionRunBadGatewayErrorResponseBody": ".types",
    "FunctionsStartFunctionRunGatewayTimeoutErrorResponseBody": ".types",
    "FunctionsStartFunctionRunInternalServerErrorResponseBody": ".types",
    "FunctionsStartFunctionRunMethodNotAllowedErrorResponseBody": ".types",
    "FunctionsStartFunctionRunNotFoundErrorResponseBody": ".types",
    "FunctionsStartFunctionRunNotImplementedErrorResponseBody": ".types",
    "FunctionsStartFunctionRunRequestBodyParamsOverride": ".beta_ap_is",
    "FunctionsStartFunctionRunResponseBody": ".types",
    "FunctionsStartFunctionRunServiceUnavailableErrorResponseBody": ".types",
    "FunctionsStartFunctionRunTooManyRequestsErrorResponseBody": ".types",
    "FunctionsStartFunctionRunUnauthorizedErrorResponseBody": ".types",
    "GaseousFuelCostObjectResponseBody": ".types",
    "GaseousFuelCostObjectResponseBodyCurrency": ".types",
    "GatewayAssetResponseObjectResponseBody": ".types",
    "GatewayDetailsResponseResponseBody": ".types",
    "GatewayDetailsResponseResponseBodyGatewayBatteryState": ".types",
    "GatewayDisconnectedDetailsObjectRequestBody": ".types",
    "GatewayDisconnectedDetailsObjectResponseBody": ".types",
    "GatewayDisconnectedResponseBody": ".types",
    "GatewayResponseObjectResponseBody": ".types",
    "GatewayResponseObjectResponseBodyModel": ".types",
    "GatewayTimeoutError": ".errors",
    "GatewayTiny": ".types",
    "GatewayUnpluggedTriggerDetailsObjectRequestBody": ".types",
    "GatewayUnpluggedTriggerDetailsObjectResponseBody": ".types",
    "GatewayWithVehicleTinyResponseResponseBody": ".types",
    "GatewayWithVehicleTinyResponseResponseBodyModel": ".types",
    "GatewaysDeleteGatewayBadGatewayErrorResponseBody": ".types",
    "GatewaysDeleteGatewayGatewayTimeoutErrorResponseBody": ".types",
    "GatewaysDeleteGatewayInternalServerErrorResponseBody": ".types",
    "GatewaysDeleteGatewayMethodNotAllowedErrorResponseBody": ".types",
    "GatewaysDeleteGatewayNotFoundErrorResponseBody": ".types",
    "GatewaysDeleteGatewayNotImplementedErrorResponseBody": ".types",
    "GatewaysDeleteGatewayServiceUnavailableErrorResponseBody": ".types",
    "GatewaysDeleteGatewayTooManyRequestsErrorResponseBody": ".types",
    "GatewaysDeleteGatewayUnauthorizedErrorResponseBody": ".types",
    "GatewaysGetGatewaysBadGatewayErrorResponseBody": ".types",
    "GatewaysGetGatewaysGatewayTimeoutErrorResponseBody": ".types",
    "GatewaysGetGatewaysInternalServerErrorResponseBody": ".types",
    "GatewaysGetGatewaysMethodNotAllowedErrorResponseBody": ".types",
    "GatewaysGetGatewaysNotFoundErrorResponseBody": ".types",
    "GatewaysGetGatewaysNotImplementedErrorResponseBody": ".types",
    "GatewaysGetGatewaysResponseBody": ".types",
    "GatewaysGetGatewaysServiceUnavailableErrorResponseBody": ".types",
    "GatewaysGetGatewaysTooManyRequestsErrorResponseBody": ".types",
    "GatewaysGetGatewaysUnauthorizedErrorResponseBody": ".types",
    "GatewaysPostGatewayBadGatewayErrorResponseBody": ".types",
    "GatewaysPostGatewayGatewayTimeoutErrorResponseBody": ".types",
    "GatewaysPostGatewayInternalServerErrorResponseBody": ".types",
    "GatewaysPostGatewayMethodNotAllowedErrorResponseBody": ".types",
    "GatewaysPostGatewayNotFoundErrorResponseBody": ".types",
    "GatewaysPostGatewayNotImplementedErrorResponseBody": ".types",
    "GatewaysPostGatewayResponseBody": ".types",
    "GatewaysPostGatewayServiceUnavailableErrorResponseBody": ".types",
    "GatewaysPostGatewayTooManyRequestsErrorResponseBody": ".types",
    "GatewaysPostGatewayUnauthorizedErrorResponseBody": ".types",
    "GeofenceEntryTriggerDetailsObjectRequestBody": ".types",
    "GeofenceEntryTriggerDetailsObjectResponseBody": ".types",
    "GeofenceExitTriggerDetailsObjectRequestBody": ".types",
    "GeofenceExitTriggerDetailsObjectResponseBody": ".types",
    "GeofenceResponseResponseBody": ".types",
    "GetAssetsInputsRequestType": ".beta_ap_is",
    "GetAttributeRequestEntityType": ".attributes",
    "GetAttributesByEntityTypeRequestEntityType": ".attributes",
    "GetAttributesByEntityTypeResponse": ".types",
    "GetConfigurationsRequestStatus": ".alerts",
    "GetDocumentTypeResponseObjectResponseBody": ".types",
    "GetDriverEfficiencyRequestDriverActivationStatus": ".beta_ap_is",
    "GetDriverTrailerAssignmentsResponseBodyResponseBody": ".types",
    "GetDriverVehicleAssignmentsRequestAssignmentType": ".driver_vehicle_assignments",
    "GetDriverVehicleAssignmentsRequestFilterBy": ".driver_vehicle_assignments",
    "GetDriversVehicleAssignmentsRequestDriverActivationStatus": ".legacy_ap_is",
    "GetEquipmentStatsFeedRequestTypesItem": ".equipment",
    "GetEquipmentStatsHistoryRequestTypesItem": ".equipment",
    "GetEquipmentStatsRequestTypesItem": ".equipment",
    "GetFuelEnergyVehicleReportsRequestEnergyType": ".fuel_and_energy",
    "GetFunctionDetailResponseBody": ".types",
    "GetHosDailyLogsRequestDriverActivationStatus": ".hours_of_service",
    "GetHosDailyLogsRequestExpand": ".hours_of_service",
    "GetHosEldEventsRequestDriverActivationStatus": ".beta_ap_is",
    "GetIdlingEventsRequestPtoState": ".idling",
    "GetIftaJurisdictionReportsRequestFuelType": ".ifta",
    "GetIftaJurisdictionReportsRequestMonth": ".ifta",
    "GetIftaJurisdictionReportsRequestQuarter": ".ifta",
    "GetIftaVehicleReportsRequestFuelType": ".ifta",
    "GetIftaVehicleReportsRequestMonth": ".ifta",
    "GetIftaVehicleReportsRequestQuarter": ".ifta",
    "GetJobsRequestStatus": ".beta_ap_is",
    "GetLiveSharingLinksRequestType": ".live_sharing_links",
    "GetMediaRetrievalObjectResponseBody": ".types",
    "GetQualificationRecordsStreamRequestEntityType": ".beta_ap_is",
    "GetQualificationTypesRequestEntityType": ".beta_ap_is",
    "GetReportRunsDataObjectResponseBody": ".types",
    "GetReportRunsDataObjectResponseBodyStatus": ".types",
    "GetResponseWorkflowConfigurationObjectResponseBody": ".types",
    "GetRoutesFeedRequestExpand": ".routes",
    "GetSafetyEventsV2StreamRequestQueryByTimeField": ".safety",
    "GetSpeedingIntervalsRequestQueryBy": ".speeding_intervals",
    "GetTagGroupSafetyScoresRequestScoreType": ".beta_ap_is",
    "GetTagSafetyScoresRequestScoreType": ".beta_ap_is",
    "GetTripsRequestCompletionStatus": ".trips",
    "GetTripsRequestQueryBy": ".trips",
    "GetVehicleStatsFeedRequestDecorationsItem": ".vehicle_stats",
    "GetVehicleStatsFeedRequestTypesItem": ".vehicle_stats",
    "GetVehicleStatsHistoryRequestDecorationsItem": ".vehicle_stats",
    "GetVehicleStatsHistoryRequestTypesItem": ".vehicle_stats",
    "GetVehicleStatsRequestTypesItem": ".vehicle_stats",
    "GetWorkflowIncidentResponseObjectResponseBody": ".types",
    "GoaAddressTinyResponseResponseBody": ".types",
    "GoaAttributeTiny": ".types",
    "GoaAttributeTinyRequestBody": ".types",
    "GoaAttributeTinyResponseBody": ".types",
    "GoaDocumentTinyResponseResponseBody": ".types",
    "GoaDocumentTypeTinyResponseResponseBody": ".types",
    "GoaDriverTinyResponseResponseBody": ".types",
    "GoaFormTinyResponseResponseBody": ".types",
    "GoaGatewayTinyResponseResponseBody": ".types",
    "GoaGatewayTinyResponseResponseBodyModel": ".types",
    "GoaIssueTinyResponseResponseBody": ".types",
    "GoaPaginationResponseResponseBody": ".types",
    "GoaPaginationWithTokensResponseResponseBody": ".types",
    "GoaRouteStopTinyResponseResponseBody": ".types",
    "GoaRouteTinyResponseResponseBody": ".types",
    "GoaTagTinyResponseRequestBody": ".types",
    "GoaTagTinyResponseResponseBody": ".types",
    "GoaTrailerTinyResponseResponseBody": ".types",
    "GoaVehicleTinyResponseResponseBody": ".types",
    "GpsSignalLossDetailsObjectRequestBody": ".types",
    "GpsSignalLossDetailsObjectResponseBody": ".types",
    "GpsSignalLossResponseBody": ".types",
    "GreenBandDrivingDurationMs": ".types",
    "GrossVehicleWeight": ".types",
    "GrossVehicleWeightUnit": ".types",
    "HarshAccelSensitivityGForceSettingsObjectResponseBody": ".types",
    "HarshAccelSensitivityV2SettingsObjectResponseBody": ".types",
    "HarshAccelSensitivityV2SettingsObjectResponseBodyHeavyDuty": ".types",
    "HarshAccelSensitivityV2SettingsObjectResponseBodyLightDuty": ".types",
    "HarshAccelSensitivityV2SettingsObjectResponseBodyPassenger": ".types",
    "HarshBrakeSensitivityGForceSettingsObjectResponseBody": ".types",
    "HarshBrakeSensitivityV2SettingsObjectResponseBody": ".types",
    "HarshBrakeSensitivityV2SettingsObjectResponseBodyHeavyDuty": ".types",
    "HarshBrakeSensitivityV2SettingsObjectResponseBodyLightDuty": ".types",
    "HarshBrakeSensitivityV2SettingsObjectResponseBodyPassenger": ".types",
    "HarshEventDataResponseBody": ".types",
    "HarshEventSensitivitySettingsObjectResponseBody": ".types",
    "HarshEventSensitivityV2SettingsObjectResponseBody": ".types",
    "HarshEventTriggerDetailsObjectRequestBody": ".types",
    "HarshEventTriggerDetailsObjectRequestBodyTypesItem": ".types",
    "HarshEventTriggerDetailsObjectResponseBody": ".types",
    "HarshEventTriggerDetailsObjectResponseBodyTypesItem": ".types",
    "HarshTurnSensitivityGForceSettingsObjectResponseBody": ".types",
    "HarshTurnSensitivityV2SettingsObjectResponseBody": ".types",
    "HarshTurnSensitivityV2SettingsObjectResponseBodyHeavyDuty": ".types",
    "HarshTurnSensitivityV2SettingsObjectResponseBodyLightDuty": ".types",
    "HarshTurnSensitivityV2SettingsObjectResponseBodyPassenger": ".types",
    "HealthDetailsResponseResponseBody": ".types",
    "HealthReasonResponseResponseBody": ".types",
    "HealthReasonResponseResponseBodyHealthReasonCode": ".types",
    "HealthResponseResponseBody": ".types",
    "HealthResponseResponseBodyHealthStatus": ".types",
    "HealthResponseResponseBodyPrimaryHealthReason": ".types",
    "HealthResponseResponseBodyRecommendedAction": ".types",
    "HighTorqueMs": ".types",
    "HosBreak": ".types",
    "HosClocks": ".types",
    "HosClocksForDriver": ".types",
    "HosClocksForDrivers": ".types",
    "HosClocksResponse": ".types",
    "HosCycle": ".types",
    "HosDailyLogsGetHosDailyLogsBadGatewayErrorResponseBody": ".types",
    "HosDailyLogsGetHosDailyLogsGatewayTimeoutErrorResponseBody": ".types",
    "HosDailyLogsGetHosDailyLogsInternalServerErrorResponseBody": ".types",
    "HosDailyLogsGetHosDailyLogsMethodNotAllowedErrorResponseBody": ".types",
    "HosDailyLogsGetHosDailyLogsNotFoundErrorResponseBody": ".types",
    "HosDailyLogsGetHosDailyLogsNotImplementedErrorResponseBody": ".types",
    "HosDailyLogsGetHosDailyLogsResponseBody": ".types",
    "HosDailyLogsGetHosDailyLogsServiceUnavailableErrorResponseBody": ".types",
    "HosDailyLogsGetHosDailyLogsTooManyRequestsErrorResponseBody": ".types",
    "HosDailyLogsGetHosDailyLogsUnauthorizedErrorResponseBody": ".types",
    "HosDailyLogsObjectResponseBody": ".types",
    "HosDailyLogsUpdateShippingDocsBadGatewayErrorResponseBody": ".types",
    "HosDailyLogsUpdateShippingDocsGatewayTimeoutErrorResponseBody": ".types",
    "HosDailyLogsUpdateShippingDocsInternalServerErrorResponseBody": ".types",
    "HosDailyLogsUpdateShippingDocsMethodNotAllowedErrorResponseBody": ".types",
    "HosDailyLogsUpdateShippingDocsNotFoundErrorResponseBody": ".types",
    "HosDailyLogsUpdateShippingDocsNotImplementedErrorResponseBody": ".types",
    "HosDailyLogsUpdateShippingDocsResponseBody": ".types",
    "HosDailyLogsUpdateShippingDocsServiceUnavailableErrorResponseBody": ".types",
    "HosDailyLogsUpdateShippingDocsTooManyRequestsErrorResponseBody": ".types",
    "HosDailyLogsUpdateShippingDocsUnauthorizedErrorResponseBody": ".types",
    "HosDrive": ".types",
    "HosDriversEldEventObjectResponseBody": ".types",
    "HosDriversEldEventObjectResponseBodyDriverActivationStatus": ".types",
    "HosEldEventLocationObjectResponseBody": ".types",
    "HosEldEventObjectResponseBody": ".types",
    "HosEldEventObjectResponseBodyMalfunctionDiagnosticCode": ".types",
    "HosEldEventRemarkObjectResponseBody": ".types",
    "HosEldEventsGetHosEldEventsBadGatewayErrorResponseBody": ".types",
    "HosEldEventsGetHosEldEventsGatewayTimeoutErrorResponseBody": ".types",
    "HosEldEventsGetHosEldEventsInternalServerErrorResponseBody": ".types",
    "HosEldEventsGetHosEldEventsMethodNotAllowedErrorResponseBody": ".types",
    "HosEldEventsGetHosEldEventsNotFoundErrorResponseBody": ".types",
    "HosEldEventsGetHosEldEventsNotImplementedErrorResponseBody": ".types",
    "HosEldEventsGetHosEldEventsResponseBody": ".types",
    "HosEldEventsGetHosEldEventsServiceUnavailableErrorResponseBody": ".types",
    "HosEldEventsGetHosEldEventsTooManyRequestsErrorResponseBody": ".types",
    "HosEldEventsGetHosEldEventsUnauthorizedErrorResponseBody": ".types",
    "HosLogEntry": ".types",
    "HosLogEntryHosStatusType": ".types",
    "HosLogLocation": ".types",
    "HosLogsForDriver": ".types",
    "HosLogsForDrivers": ".types",
    "HosLogsList": ".types",
    "HosLogsResponse": ".types",
    "HosShift": ".types",
    "HosViolationDataResponseBody": ".types",
    "HosViolationDayObjectResponseBody": ".types",
    "HosViolationObjectResponseBody": ".types",
    "HosViolationObjectResponseBodyType": ".types",
    "HosViolationTriggerDetailsObjectRequestBody": ".types",
    "HosViolationTriggerDetailsObjectRequestBodyViolation": ".types",
    "HosViolationTriggerDetailsObjectResponseBody": ".types",
    "HosViolationTriggerDetailsObjectResponseBodyViolation": ".types",
    "HosViolations": ".types",
    "HosViolationsGetHosViolationsBadGatewayErrorResponseBody": ".types",
    "HosViolationsGetHosViolationsGatewayTimeoutErrorResponseBody": ".types",
    "HosViolationsGetHosViolationsInternalServerErrorResponseBody": ".types",
    "HosViolationsGetHosViolationsMethodNotAllowedErrorResponseBody": ".types",
    "HosViolationsGetHosViolationsNotFoundErrorResponseBody": ".types",
    "HosViolationsGetHosViolationsNotImplementedErrorResponseBody": ".types",
    "HosViolationsGetHosViolationsResponseBody": ".types",
    "HosViolationsGetHosViolationsServiceUnavailableErrorResponseBody": ".types",
    "HosViolationsGetHosViolationsTooManyRequestsErrorResponseBody": ".types",
    "HosViolationsGetHosViolationsUnauthorizedErrorResponseBody": ".types",
    "HosViolationsObjectResponseBody": ".types",
    "HubCapacitiesListHubCapacitiesBadGatewayErrorResponseBody": ".types",
    "HubCapacitiesListHubCapacitiesGatewayTimeoutErrorResponseBody": ".types",
    "HubCapacitiesListHubCapacitiesInternalServerErrorResponseBody": ".types",
    "HubCapacitiesListHubCapacitiesMethodNotAllowedErrorResponseBody": ".types",
    "HubCapacitiesListHubCapacitiesNotFoundErrorResponseBody": ".types",
    "HubCapacitiesListHubCapacitiesNotImplementedErrorResponseBody": ".types",
    "HubCapacitiesListHubCapacitiesResponseBody": ".types",
    "HubCapacitiesListHubCapacitiesServiceUnavailableErrorResponseBody": ".types",
    "HubCapacitiesListHubCapacitiesTooManyRequestsErrorResponseBody": ".types",
    "HubCapacitiesListHubCapacitiesUnauthorizedErrorResponseBody": ".types",
    "HubCapacityObjectResponseBody": ".types",
    "HubCustomPropertiesListHubCustomPropertiesBadGatewayErrorResponseBody": ".types",
    "HubCustomPropertiesListHubCustomPropertiesGatewayTimeoutErrorResponseBody": ".types",
    "HubCustomPropertiesListHubCustomPropertiesInternalServerErrorResponseBody": ".types",
    "HubCustomPropertiesListHubCustomPropertiesMethodNotAllowedErrorResponseBody": ".types",
    "HubCustomPropertiesListHubCustomPropertiesNotFoundErrorResponseBody": ".types",
    "HubCustomPropertiesListHubCustomPropertiesNotImplementedErrorResponseBody": ".types",
    "HubCustomPropertiesListHubCustomPropertiesResponseBody": ".types",
    "HubCustomPropertiesListHubCustomPropertiesServiceUnavailableErrorResponseBody": ".types",
    "HubCustomPropertiesListHubCustomPropertiesTooManyRequestsErrorResponseBody": ".types",
    "HubCustomPropertiesListHubCustomPropertiesUnauthorizedErrorResponseBody": ".types",
    "HubCustomPropertyObjectResponseBody": ".types",
    "HubLocationCreatedObjectResponseBody": ".types",
    "HubLocationInputObjectRequestBody": ".types",
    "HubLocationObjectResponseBody": ".types",
    "HubLocationServiceWindowInputRequestBody": ".types",
    "HubLocationUpdatedObjectResponseBody": ".types",
    "HubLocationsCreateHubLocationsBadGatewayErrorResponseBody": ".types",
    "HubLocationsCreateHubLocationsGatewayTimeoutErrorResponseBody": ".types",
    "HubLocationsCreateHubLocationsInternalServerErrorResponseBody": ".types",
    "HubLocationsCreateHubLocationsMethodNotAllowedErrorResponseBody": ".types",
    "HubLocationsCreateHubLocationsNotFoundErrorResponseBody": ".types",
    "HubLocationsCreateHubLocationsNotImplementedErrorResponseBody": ".types",
    "HubLocationsCreateHubLocationsResponseBody": ".types",
    "HubLocationsCreateHubLocationsServiceUnavailableErrorResponseBody": ".types",
    "HubLocationsCreateHubLocationsTooManyRequestsErrorResponseBody": ".types",
    "HubLocationsCreateHubLocationsUnauthorizedErrorResponseBody": ".types",
    "HubLocationsListHubLocationsBadGatewayErrorResponseBody": ".types",
    "HubLocationsListHubLocationsGatewayTimeoutErrorResponseBody": ".types",
    "HubLocationsListHubLocationsInternalServerErrorResponseBody": ".types",
    "HubLocationsListHubLocationsMethodNotAllowedErrorResponseBody": ".types",
    "HubLocationsListHubLocationsNotFoundErrorResponseBody": ".types",
    "HubLocationsListHubLocationsNotImplementedErrorResponseBody": ".types",
    "HubLocationsListHubLocationsResponseBody": ".types",
    "HubLocationsListHubLocationsServiceUnavailableErrorResponseBody": ".types",
    "HubLocationsListHubLocationsTooManyRequestsErrorResponseBody": ".types",
    "HubLocationsListHubLocationsUnauthorizedErrorResponseBody": ".types",
    "HubLocationsUpdateHubLocationBadGatewayErrorResponseBody": ".types",
    "HubLocationsUpdateHubLocationGatewayTimeoutErrorResponseBody": ".types",
    "HubLocationsUpdateHubLocationInternalServerErrorResponseBody": ".types",
    "HubLocationsUpdateHubLocationMethodNotAllowedErrorResponseBody": ".types",
    "HubLocationsUpdateHubLocationNotFoundErrorResponseBody": ".types",
    "HubLocationsUpdateHubLocationNotImplementedErrorResponseBody": ".types",
    "HubLocationsUpdateHubLocationResponseBody": ".types",
    "HubLocationsUpdateHubLocationServiceUnavailableErrorResponseBody": ".types",
    "HubLocationsUpdateHubLocationTooManyRequestsErrorResponseBody": ".types",
    "HubLocationsUpdateHubLocationUnauthorizedErrorResponseBody": ".types",
    "HubObjectResponseBody": ".types",
    "HubPlanRoutesListHubPlanRoutesBadGatewayErrorResponseBody": ".types",
    "HubPlanRoutesListHubPlanRoutesGatewayTimeoutErrorResponseBody": ".types",
    "HubPlanRoutesListHubPlanRoutesInternalServerErrorResponseBody": ".types",
    "HubPlanRoutesListHubPlanRoutesMethodNotAllowedErrorResponseBody": ".types",
    "HubPlanRoutesListHubPlanRoutesNotFoundErrorResponseBody": ".types",
    "HubPlanRoutesListHubPlanRoutesNotImplementedErrorResponseBody": ".types",
    "HubPlanRoutesListHubPlanRoutesResponseBody": ".types",
    "HubPlanRoutesListHubPlanRoutesServiceUnavailableErrorResponseBody": ".types",
    "HubPlanRoutesListHubPlanRoutesTooManyRequestsErrorResponseBody": ".types",
    "HubPlanRoutesListHubPlanRoutesUnauthorizedErrorResponseBody": ".types",
    "HubPlansCreateHubPlanBadGatewayErrorResponseBody": ".types",
    "HubPlansCreateHubPlanGatewayTimeoutErrorResponseBody": ".types",
    "HubPlansCreateHubPlanInternalServerErrorResponseBody": ".types",
    "HubPlansCreateHubPlanMethodNotAllowedErrorResponseBody": ".types",
    "HubPlansCreateHubPlanNotFoundErrorResponseBody": ".types",
    "HubPlansCreateHubPlanNotImplementedErrorResponseBody": ".types",
    "HubPlansCreateHubPlanResponseBody": ".types",
    "HubPlansCreateHubPlanServiceUnavailableErrorResponseBody": ".types",
    "HubPlansCreateHubPlanTooManyRequestsErrorResponseBody": ".types",
    "HubPlansCreateHubPlanUnauthorizedErrorResponseBody": ".types",
    "HubPlansListHubPlansBadGatewayErrorResponseBody": ".types",
    "HubPlansListHubPlansGatewayTimeoutErrorResponseBody": ".types",
    "HubPlansListHubPlansInternalServerErrorResponseBody": ".types",
    "HubPlansListHubPlansMethodNotAllowedErrorResponseBody": ".types",
    "HubPlansListHubPlansNotFoundErrorResponseBody": ".types",
    "HubPlansListHubPlansNotImplementedErrorResponseBody": ".types",
    "HubPlansListHubPlansResponseBody": ".types",
    "HubPlansListHubPlansServiceUnavailableErrorResponseBody": ".types",
    "HubPlansListHubPlansTooManyRequestsErrorResponseBody": ".types",
    "HubPlansListHubPlansUnauthorizedErrorResponseBody": ".types",
    "HubSkillObjectResponseBody": ".types",
    "HubSkillsListHubSkillsBadGatewayErrorResponseBody": ".types",
    "HubSkillsListHubSkillsGatewayTimeoutErrorResponseBody": ".types",
    "HubSkillsListHubSkillsInternalServerErrorResponseBody": ".types",
    "HubSkillsListHubSkillsMethodNotAllowedErrorResponseBody": ".types",
    "HubSkillsListHubSkillsNotFoundErrorResponseBody": ".types",
    "HubSkillsListHubSkillsNotImplementedErrorResponseBody": ".types",
    "HubSkillsListHubSkillsResponseBody": ".types",
    "HubSkillsListHubSkillsServiceUnavailableErrorResponseBody": ".types",
    "HubSkillsListHubSkillsTooManyRequestsErrorResponseBody": ".types",
    "HubSkillsListHubSkillsUnauthorizedErrorResponseBody": ".types",
    "HubsListHubsBadGatewayErrorResponseBody": ".types",
    "HubsListHubsGatewayTimeoutErrorResponseBody": ".types",
    "HubsListHubsInternalServerErrorResponseBody": ".types",
    "HubsListHubsMethodNotAllowedErrorResponseBody": ".types",
    "HubsListHubsNotFoundErrorResponseBody": ".types",
    "HubsListHubsNotImplementedErrorResponseBody": ".types",
    "HubsListHubsResponseBody": ".types",
    "HubsListHubsServiceUnavailableErrorResponseBody": ".types",
    "HubsListHubsTooManyRequestsErrorResponseBody": ".types",
    "HubsListHubsUnauthorizedErrorResponseBody": ".types",
    "IdleTimeDurationMs": ".types",
    "IdlingEventAddressObjectResponseBody": ".types",
    "IdlingEventAddressObjectResponseBodyAddressTypesItem": ".types",
    "IdlingEventAssetObjectResponseBody": ".types",
    "IdlingEventObjectV20251023ResponseBody": ".types",
    "IdlingEventObjectV20251023ResponseBodyPtoState": ".types",
    "IdlingEventOperatorObjectResponseBody": ".types",
    "IdlingReportEventAddressResponseBody": ".types",
    "IdlingReportEventResponseBody": ".types",
    "IdlingReportsGetVehicleIdlingReportsBadGatewayErrorResponseBody": ".types",
    "IdlingReportsGetVehicleIdlingReportsGatewayTimeoutErrorResponseBody": ".types",
    "IdlingReportsGetVehicleIdlingReportsInternalServerErrorResponseBody": ".types",
    "IdlingReportsGetVehicleIdlingReportsMethodNotAllowedErrorResponseBody": ".types",
    "IdlingReportsGetVehicleIdlingReportsNotFoundErrorResponseBody": ".types",
    "IdlingReportsGetVehicleIdlingReportsNotImplementedErrorResponseBody": ".types",
    "IdlingReportsGetVehicleIdlingReportsResponseBody": ".types",
    "IdlingReportsGetVehicleIdlingReportsServiceUnavailableErrorResponseBody": ".types",
    "IdlingReportsGetVehicleIdlingReportsTooManyRequestsErrorResponseBody": ".types",
    "IdlingReportsGetVehicleIdlingReportsUnauthorizedErrorResponseBody": ".types",
    "IftaCreateIftaDetailJobBadGatewayErrorResponseBody": ".types",
    "IftaCreateIftaDetailJobGatewayTimeoutErrorResponseBody": ".types",
    "IftaCreateIftaDetailJobInternalServerErrorResponseBody": ".types",
    "IftaCreateIftaDetailJobMethodNotAllowedErrorResponseBody": ".types",
    "IftaCreateIftaDetailJobNotFoundErrorResponseBody": ".types",
    "IftaCreateIftaDetailJobNotImplementedErrorResponseBody": ".types",
    "IftaCreateIftaDetailJobResponseBody": ".types",
    "IftaCreateIftaDetailJobServiceUnavailableErrorResponseBody": ".types",
    "IftaCreateIftaDetailJobTooManyRequestsErrorResponseBody": ".types",
    "IftaCreateIftaDetailJobUnauthorizedErrorResponseBody": ".types",
    "IftaDetailJobArgsResponseBody": ".types",
    "IftaDetailJobOutputResponseBody": ".types",
    "IftaDetailJobResponseBody": ".types",
    "IftaDetailJobResponseBodyJobStatus": ".types",
    "IftaGetIftaDetailJobBadGatewayErrorResponseBody": ".types",
    "IftaGetIftaDetailJobGatewayTimeoutErrorResponseBody": ".types",
    "IftaGetIftaDetailJobInternalServerErrorResponseBody": ".types",
    "IftaGetIftaDetailJobMethodNotAllowedErrorResponseBody": ".types",
    "IftaGetIftaDetailJobNotFoundErrorResponseBody": ".types",
    "IftaGetIftaDetailJobNotImplementedErrorResponseBody": ".types",
    "IftaGetIftaDetailJobResponseBody": ".types",
    "IftaGetIftaDetailJobServiceUnavailableErrorResponseBody": ".types",
    "IftaGetIftaDetailJobTooManyRequestsErrorResponseBody": ".types",
    "IftaGetIftaDetailJobUnauthorizedErrorResponseBody": ".types",
    "IftaGetIftaJurisdictionReportsBadGatewayErrorResponseBody": ".types",
    "IftaGetIftaJurisdictionReportsGatewayTimeoutErrorResponseBody": ".types",
    "IftaGetIftaJurisdictionReportsInternalServerErrorResponseBody": ".types",
    "IftaGetIftaJurisdictionReportsMethodNotAllowedErrorResponseBody": ".types",
    "IftaGetIftaJurisdictionReportsNotFoundErrorResponseBody": ".types",
    "IftaGetIftaJurisdictionReportsNotImplementedErrorResponseBody": ".types",
    "IftaGetIftaJurisdictionReportsResponseBody": ".types",
    "IftaGetIftaJurisdictionReportsServiceUnavailableErrorResponseBody": ".types",
    "IftaGetIftaJurisdictionReportsTooManyRequestsErrorResponseBody": ".types",
    "IftaGetIftaJurisdictionReportsUnauthorizedErrorResponseBody": ".types",
    "IftaGetIftaVehicleReportsBadGatewayErrorResponseBody": ".types",
    "IftaGetIftaVehicleReportsGatewayTimeoutErrorResponseBody": ".types",
    "IftaGetIftaVehicleReportsInternalServerErrorResponseBody": ".types",
    "IftaGetIftaVehicleReportsMethodNotAllowedErrorResponseBody": ".types",
    "IftaGetIftaVehicleReportsNotFoundErrorResponseBody": ".types",
    "IftaGetIftaVehicleReportsNotImplementedErrorResponseBody": ".types",
    "IftaGetIftaVehicleReportsResponseBody": ".types",
    "IftaGetIftaVehicleReportsServiceUnavailableErrorResponseBody": ".types",
    "IftaGetIftaVehicleReportsTooManyRequestsErrorResponseBody": ".types",
    "IftaGetIftaVehicleReportsUnauthorizedErrorResponseBody": ".types",
    "IftaJurisdictionReportDataObjectResponseBody": ".types",
    "IftaJurisdictionSummaryObjectResponseBody": ".types",
    "IftaReportTroubleshootingObjectResponseBody": ".types",
    "IftaVehicleReportDataObjectResponseBody": ".types",
    "IftaVehicleReportObjectResponseBody": ".types",
    "InAppNotificationOptionsObjectRequestBody": ".types",
    "InAppNotificationOptionsObjectResponseBody": ".types",
    "InactivityResponseBody": ".types",
    "InattentiveDrivingDetectionAlertSettingsObjectResponseBody": ".types",
    "InattentiveDrivingDetectionAlertSettingsObjectResponseBodySeverity": ".types",
    "IndustrialAssetObjectResponseBody": ".types",
    "InlineObject6FillMissing": ".sensors",
    "InlineResponse200": ".types",
    "InlineResponse2001": ".types",
    "InlineResponse2002": ".types",
    "InlineResponse2003": ".types",
    "InlineResponse2004": ".types",
    "InlineResponse2005": ".types",
    "InlineResponse2006": ".types",
    "InlineResponse2007": ".types",
    "InlineResponse2008": ".types",
    "InlineResponse2009": ".types",
    "InsideGeofenceDataResponseBody": ".types",
    "InsideGeofenceTriggerDetailsObjectRequestBody": ".types",
    "InsideGeofenceTriggerDetailsObjectResponseBody": ".types",
    "InternalServerError": ".errors",
    "InvoiceScanFileRequestBody": ".types",
    "IssueCreatedResponseBody": ".types",
    "IssueResponseObjectResponseBody": ".types",
    "IssueResponseObjectResponseBodyPriority": ".types",
    "IssueResponseObjectResponseBodyStatus": ".types",
    "IssueSourceObjectResponseBody": ".types",
    "IssueSourceObjectResponseBodyType": ".types",
    "IssuesGetIssuesBadGatewayErrorResponseBody": ".types",
    "IssuesGetIssuesGatewayTimeoutErrorResponseBody": ".types",
    "IssuesGetIssuesInternalServerErrorResponseBody": ".types",
    "IssuesGetIssuesMethodNotAllowedErrorResponseBody": ".types",
    "IssuesGetIssuesNotFoundErrorResponseBody": ".types",
    "IssuesGetIssuesNotImplementedErrorResponseBody": ".types",
    "IssuesGetIssuesResponseBody": ".types",
    "IssuesGetIssuesServiceUnavailableErrorResponseBody": ".types",
    "IssuesGetIssuesStreamBadGatewayErrorResponseBody": ".types",
    "IssuesGetIssuesStreamGatewayTimeoutErrorResponseBody": ".types",
    "IssuesGetIssuesStreamInternalServerErrorResponseBody": ".types",
    "IssuesGetIssuesStreamMethodNotAllowedErrorResponseBody": ".types",
    "IssuesGetIssuesStreamNotFoundErrorResponseBody": ".types",
    "IssuesGetIssuesStreamNotImplementedErrorResponseBody": ".types",
    "IssuesGetIssuesStreamResponseBody": ".types",
    "IssuesGetIssuesStreamServiceUnavailableErrorResponseBody": ".types",
    "IssuesGetIssuesStreamTooManyRequestsErrorResponseBody": ".types",
    "IssuesGetIssuesStreamUnauthorizedErrorResponseBody": ".types",
    "IssuesGetIssuesTooManyRequestsErrorResponseBody": ".types",
    "IssuesGetIssuesUnauthorizedErrorResponseBody": ".types",
    "IssuesPatchIssueBadGatewayErrorResponseBody": ".types",
    "IssuesPatchIssueGatewayTimeoutErrorResponseBody": ".types",
    "IssuesPatchIssueInternalServerErrorResponseBody": ".types",
    "IssuesPatchIssueMethodNotAllowedErrorResponseBody": ".types",
    "IssuesPatchIssueNotFoundErrorResponseBody": ".types",
    "IssuesPatchIssueNotImplementedErrorResponseBody": ".types",
    "IssuesPatchIssueRequestBodyStatus": ".issues",
    "IssuesPatchIssueResponseBody": ".types",
    "IssuesPatchIssueServiceUnavailableErrorResponseBody": ".types",
    "IssuesPatchIssueTooManyRequestsErrorResponseBody": ".types",
    "IssuesPatchIssueUnauthorizedErrorResponseBody": ".types",
    "J1939D1StatusDataPoint": ".types",
    "J1939D1StatusDataPointValue": ".types",
    "JammingDetectedResponseBody": ".types",
    "JobLocationResponseObjectResponseBody": ".types",
    "JobResponseObjectResponseBody": ".types",
    "JobResponseObjectResponseBodyStatus": ".types",
    "JobsCreateJobBadGatewayErrorResponseBody": ".types",
    "JobsCreateJobGatewayTimeoutErrorResponseBody": ".types",
    "JobsCreateJobInternalServerErrorResponseBody": ".types",
    "JobsCreateJobMethodNotAllowedErrorResponseBody": ".types",
    "JobsCreateJobNotFoundErrorResponseBody": ".types",
    "JobsCreateJobNotImplementedErrorResponseBody": ".types",
    "JobsCreateJobResponseBody": ".types",
    "JobsCreateJobServiceUnavailableErrorResponseBody": ".types",
    "JobsCreateJobTooManyRequestsErrorResponseBody": ".types",
    "JobsCreateJobUnauthorizedErrorResponseBody": ".types",
    "JobsDeleteJobBadGatewayErrorResponseBody": ".types",
    "JobsDeleteJobGatewayTimeoutErrorResponseBody": ".types",
    "JobsDeleteJobInternalServerErrorResponseBody": ".types",
    "JobsDeleteJobMethodNotAllowedErrorResponseBody": ".types",
    "JobsDeleteJobNotFoundErrorResponseBody": ".types",
    "JobsDeleteJobNotImplementedErrorResponseBody": ".types",
    "JobsDeleteJobResponseBody": ".types",
    "JobsDeleteJobServiceUnavailableErrorResponseBody": ".types",
    "JobsDeleteJobTooManyRequestsErrorResponseBody": ".types",
    "JobsDeleteJobUnauthorizedErrorResponseBody": ".types",
    "JobsGetJobsBadGatewayErrorResponseBody": ".types",
    "JobsGetJobsGatewayTimeoutErrorResponseBody": ".types",
    "JobsGetJobsInternalServerErrorResponseBody": ".types",
    "JobsGetJobsMethodNotAllowedErrorResponseBody": ".types",
    "JobsGetJobsNotFoundErrorResponseBody": ".types",
    "JobsGetJobsNotImplementedErrorResponseBody": ".types",
    "JobsGetJobsResponseBody": ".types",
    "JobsGetJobsServiceUnavailableErrorResponseBody": ".types",
    "JobsGetJobsTooManyRequestsErrorResponseBody": ".types",
    "JobsGetJobsUnauthorizedErrorResponseBody": ".types",
    "JobsPatchJobBadGatewayErrorResponseBody": ".types",
    "JobsPatchJobGatewayTimeoutErrorResponseBody": ".types",
    "JobsPatchJobInternalServerErrorResponseBody": ".types",
    "JobsPatchJobMethodNotAllowedErrorResponseBody": ".types",
    "JobsPatchJobNotFoundErrorResponseBody": ".types",
    "JobsPatchJobNotImplementedErrorResponseBody": ".types",
    "JobsPatchJobResponseBody": ".types",
    "JobsPatchJobServiceUnavailableErrorResponseBody": ".types",
    "JobsPatchJobTooManyRequestsErrorResponseBody": ".types",
    "JobsPatchJobUnauthorizedErrorResponseBody": ".types",
    "LastKnownLocationResponseResponseBody": ".types",
    "Latitude": ".types",
    "ListAddressesResponse": ".types",
    "ListAssetsRequestType": ".assets",
    "ListCarbCtcVehiclesRequestTestStatusItem": ".beta_ap_is",
    "ListCarrierProposedAssignmentResponse": ".types",
    "ListContactsResponse": ".types",
    "ListDriversRequestDriverActivationStatus": ".drivers",
    "ListDriversResponse": ".types",
    "ListHubCapacitiesResponsePaginationResponseBody": ".types",
    "ListHubCustomPropertiesResponsePaginationResponseBody": ".types",
    "ListHubLocationsResponsePaginationResponseBody": ".types",
    "ListHubPlanRoutesResponsePaginationResponseBody": ".types",
    "ListHubPlansResponsePaginationResponseBody": ".types",
    "ListHubSkillsResponsePaginationResponseBody": ".types",
    "ListHubsResponsePaginationResponseBody": ".types",
    "ListIndustrialAssetsResponse": ".types",
    "ListTagsResponse": ".types",
    "ListUploadedMediaObjectResponseBody": ".types",
    "ListUploadedMediaRequestInputsItem": ".media",
    "ListUploadedMediaRequestMediaTypesItem": ".media",
    "ListUploadedMediaRequestTriggerReasonsItem": ".media",
    "ListUserRolesResponse": ".types",
    "ListUsersResponse": ".types",
    "LiveSharingLinkFullResponseObjectResponseBody": ".types",
    "LiveSharingLinkFullResponseObjectResponseBodyType": ".types",
    "LiveSharingLinkResponseObjectResponseBody": ".types",
    "LiveSharingLinksCreateLiveSharingLinkBadGatewayErrorResponseBody": ".types",
    "LiveSharingLinksCreateLiveSharingLinkGatewayTimeoutErrorResponseBody": ".types",
    "LiveSharingLinksCreateLiveSharingLinkInternalServerErrorResponseBody": ".types",
    "LiveSharingLinksCreateLiveSharingLinkMethodNotAllowedErrorResponseBody": ".types",
    "LiveSharingLinksCreateLiveSharingLinkNotFoundErrorResponseBody": ".types",
    "LiveSharingLinksCreateLiveSharingLinkNotImplementedErrorResponseBody": ".types",
    "LiveSharingLinksCreateLiveSharingLinkRequestBodyType": ".live_sharing_links",
    "LiveSharingLinksCreateLiveSharingLinkResponseBody": ".types",
    "LiveSharingLinksCreateLiveSharingLinkServiceUnavailableErrorResponseBody": ".types",
    "LiveSharingLinksCreateLiveSharingLinkTooManyRequestsErrorResponseBody": ".types",
    "LiveSharingLinksCreateLiveSharingLinkUnauthorizedErrorResponseBody": ".types",
    "LiveSharingLinksDeleteLiveSharingLinkBadGatewayErrorResponseBody": ".types",
    "LiveSharingLinksDeleteLiveSharingLinkGatewayTimeoutErrorResponseBody": ".types",
    "LiveSharingLinksDeleteLiveSharingLinkInternalServerErrorResponseBody": ".types",
    "LiveSharingLinksDeleteLiveSharingLinkMethodNotAllowedErrorResponseBody": ".types",
    "LiveSharingLinksDeleteLiveSharingLinkNotFoundErrorResponseBody": ".types",
    "LiveSharingLinksDeleteLiveSharingLinkNotImplementedErrorResponseBody": ".types",
    "LiveSharingLinksDeleteLiveSharingLinkServiceUnavailableErrorResponseBody": ".types",
    "LiveSharingLinksDeleteLiveSharingLinkTooManyRequestsErrorResponseBody": ".types",
    "LiveSharingLinksDeleteLiveSharingLinkUnauthorizedErrorResponseBody": ".types",
    "LiveSharingLinksGetLiveSharingLinksBadGatewayErrorResponseBody": ".types",
    "LiveSharingLinksGetLiveSharingLinksGatewayTimeoutErrorResponseBody": ".types",
    "LiveSharingLinksGetLiveSharingLinksInternalServerErrorResponseBody": ".types",
    "LiveSharingLinksGetLiveSharingLinksMethodNotAllowedErrorResponseBody": ".types",
    "LiveSharingLinksGetLiveSharingLinksNotFoundErrorResponseBody": ".types",
    "LiveSharingLinksGetLiveSharingLinksNotImplementedErrorResponseBody": ".types",
    "LiveSharingLinksGetLiveSharingLinksResponseBody": ".types",
    "LiveSharingLinksGetLiveSharingLinksServiceUnavailableErrorResponseBody": ".types",
    "LiveSharingLinksGetLiveSharingLinksTooManyRequestsErrorResponseBody": ".types",
    "LiveSharingLinksGetLiveSharingLinksUnauthorizedErrorResponseBody": ".types",
    "LiveSharingLinksUpdateLiveSharingLinkBadGatewayErrorResponseBody": ".types",
    "LiveSharingLinksUpdateLiveSharingLinkGatewayTimeoutErrorResponseBody": ".types",
    "LiveSharingLinksUpdateLiveSharingLinkInternalServerErrorResponseBody": ".types",
    "LiveSharingLinksUpdateLiveSharingLinkMethodNotAllowedErrorResponseBody": ".types",
    "LiveSharingLinksUpdateLiveSharingLinkNotFoundErrorResponseBody": ".types",
    "LiveSharingLinksUpdateLiveSharingLinkNotImplementedErrorResponseBody": ".types",
    "LiveSharingLinksUpdateLiveSharingLinkResponseBody": ".types",
    "LiveSharingLinksUpdateLiveSharingLinkServiceUnavailableErrorResponseBody": ".types",
    "LiveSharingLinksUpdateLiveSharingLinkTooManyRequestsErrorResponseBody": ".types",
    "LiveSharingLinksUpdateLiveSharingLinkUnauthorizedErrorResponseBody": ".types",
    "Location": ".types",
    "LocationAndSpeedGetLocationAndSpeedBadGatewayErrorResponseBody": ".types",
    "LocationAndSpeedGetLocationAndSpeedGatewayTimeoutErrorResponseBody": ".types",
    "LocationAndSpeedGetLocationAndSpeedInternalServerErrorResponseBody": ".types",
    "LocationAndSpeedGetLocationAndSpeedMethodNotAllowedErrorResponseBody": ".types",
    "LocationAndSpeedGetLocationAndSpeedNotFoundErrorResponseBody": ".types",
    "LocationAndSpeedGetLocationAndSpeedNotImplementedErrorResponseBody": ".types",
    "LocationAndSpeedGetLocationAndSpeedResponseBody": ".types",
    "LocationAndSpeedGetLocationAndSpeedServiceUnavailableErrorResponseBody": ".types",
    "LocationAndSpeedGetLocationAndSpeedTooManyRequestsErrorResponseBody": ".types",
    "LocationAndSpeedGetLocationAndSpeedUnauthorizedErrorResponseBody": ".types",
    "LocationAndSpeedResponseResponseBody": ".types",
    "LocationDataPoint": ".types",
    "LocationDataPointGpsLocation": ".types",
    "LocationDataPointGpsLocationPlace": ".types",
    "LocationObjectRequestBody": ".types",
    "LocationObjectRequestBodyAddressTypesItem": ".types",
    "LocationObjectResponseBody": ".types",
    "LocationObjectResponseBodyAddressTypesItem": ".types",
    "LocationResponseBody": ".types",
    "LocationResponseResponseBody": ".types",
    "LocationType": ".types",
    "LogMetaDataObjectResponseBody": ".types",
    "Longitude": ".types",
    "MaintenanceVendorsListMaintenanceVendorsBadGatewayErrorResponseBody": ".types",
    "MaintenanceVendorsListMaintenanceVendorsGatewayTimeoutErrorResponseBody": ".types",
    "MaintenanceVendorsListMaintenanceVendorsInternalServerErrorResponseBody": ".types",
    "MaintenanceVendorsListMaintenanceVendorsMethodNotAllowedErrorResponseBody": ".types",
    "MaintenanceVendorsListMaintenanceVendorsNotFoundErrorResponseBody": ".types",
    "MaintenanceVendorsListMaintenanceVendorsNotImplementedErrorResponseBody": ".types",
    "MaintenanceVendorsListMaintenanceVendorsResponseBody": ".types",
    "MaintenanceVendorsListMaintenanceVendorsServiceUnavailableErrorResponseBody": ".types",
    "MaintenanceVendorsListMaintenanceVendorsTooManyRequestsErrorResponseBody": ".types",
    "MaintenanceVendorsListMaintenanceVendorsUnauthorizedErrorResponseBody": ".types",
    "MaintenanceVendorsListVendorCategoriesBadGatewayErrorResponseBody": ".types",
    "MaintenanceVendorsListVendorCategoriesGatewayTimeoutErrorResponseBody": ".types",
    "MaintenanceVendorsListVendorCategoriesInternalServerErrorResponseBody": ".types",
    "MaintenanceVendorsListVendorCategoriesMethodNotAllowedErrorResponseBody": ".types",
    "MaintenanceVendorsListVendorCategoriesNotFoundErrorResponseBody": ".types",
    "MaintenanceVendorsListVendorCategoriesNotImplementedErrorResponseBody": ".types",
    "MaintenanceVendorsListVendorCategoriesResponseBody": ".types",
    "MaintenanceVendorsListVendorCategoriesServiceUnavailableErrorResponseBody": ".types",
    "MaintenanceVendorsListVendorCategoriesTooManyRequestsErrorResponseBody": ".types",
    "MaintenanceVendorsListVendorCategoriesUnauthorizedErrorResponseBody": ".types",
    "MediaObjectResponseBody": ".types",
    "MediaObjectResponseBodyCameraRole": ".types",
    "MediaObjectResponseBodyInput": ".types",
    "MediaObjectResponseBodyMediaType": ".types",
    "MediaObjectResponseBodyStatus": ".types",
    "MediaRetrievalGetMediaRetrievalBadGatewayErrorResponseBody": ".types",
    "MediaRetrievalGetMediaRetrievalGatewayTimeoutErrorResponseBody": ".types",
    "MediaRetrievalGetMediaRetrievalInternalServerErrorResponseBody": ".types",
    "MediaRetrievalGetMediaRetrievalMethodNotAllowedErrorResponseBody": ".types",
    "MediaRetrievalGetMediaRetrievalNotFoundErrorResponseBody": ".types",
    "MediaRetrievalGetMediaRetrievalNotImplementedErrorResponseBody": ".types",
    "MediaRetrievalGetMediaRetrievalResponseBody": ".types",
    "MediaRetrievalGetMediaRetrievalServiceUnavailableErrorResponseBody": ".types",
    "MediaRetrievalGetMediaRetrievalTooManyRequestsErrorResponseBody": ".types",
    "MediaRetrievalGetMediaRetrievalUnauthorizedErrorResponseBody": ".types",
    "MediaRetrievalListUploadedMediaBadGatewayErrorResponseBody": ".types",
    "MediaRetrievalListUploadedMediaGatewayTimeoutErrorResponseBody": ".types",
    "MediaRetrievalListUploadedMediaInternalServerErrorResponseBody": ".types",
    "MediaRetrievalListUploadedMediaMethodNotAllowedErrorResponseBody": ".types",
    "MediaRetrievalListUploadedMediaNotFoundErrorResponseBody": ".types",
    "MediaRetrievalListUploadedMediaNotImplementedErrorResponseBody": ".types",
    "MediaRetrievalListUploadedMediaResponseBody": ".types",
    "MediaRetrievalListUploadedMediaServiceUnavailableErrorResponseBody": ".types",
    "MediaRetrievalListUploadedMediaTooManyRequestsErrorResponseBody": ".types",
    "MediaRetrievalListUploadedMediaUnauthorizedErrorResponseBody": ".types",
    "MediaRetrievalPostMediaRetrievalBadGatewayErrorResponseBody": ".types",
    "MediaRetrievalPostMediaRetrievalGatewayTimeoutErrorResponseBody": ".types",
    "MediaRetrievalPostMediaRetrievalInternalServerErrorResponseBody": ".types",
    "MediaRetrievalPostMediaRetrievalMethodNotAllowedErrorResponseBody": ".types",
    "MediaRetrievalPostMediaRetrievalNotFoundErrorResponseBody": ".types",
    "MediaRetrievalPostMediaRetrievalNotImplementedErrorResponseBody": ".types",
    "MediaRetrievalPostMediaRetrievalRequestBodyInputsItem": ".media",
    "MediaRetrievalPostMediaRetrievalRequestBodyMediaType": ".media",
    "MediaRetrievalPostMediaRetrievalResponseBody": ".types",
    "MediaRetrievalPostMediaRetrievalServiceUnavailableErrorResponseBody": ".types",
    "MediaRetrievalPostMediaRetrievalTooManyRequestsErrorResponseBody": ".types",
    "MediaRetrievalPostMediaRetrievalUnauthorizedErrorResponseBody": ".types",
    "MethodNotAllowedError": ".errors",
    "MinimalRouteAuditLogsResponseBody": ".types",
    "MinimalRouteStopAuditLogsResponseBody": ".types",
    "MinimalRouteStopAuditLogsResponseBodyState": ".types",
    "MinimalRouteStopResponseBody": ".types",
    "MinimalRouteStopResponseBodyState": ".types",
    "MissingDvirPastDueResponseBody": ".types",
    "MissingStateResponseBody": ".types",
    "MissingStateResponseBodyUpdateSource": ".types",
    "MobileUsageDetectionAlertSettingsObjectResponseBody": ".types",
    "MotionDetectedResponseBody": ".types",
    "MultipleChoiceFieldTypeMetaDataObjectResponseBody": ".types",
    "MultipleChoiceValueObjectRequestBody": ".types",
    "MultipleChoiceValueObjectResponseBody": ".types",
    "NotFoundError": ".errors",
    "NotImplementedError": ".errors",
    "NotificationRecipientRequestBody": ".types",
    "NotificationRecipientRequestBodyNotificationTypesItem": ".types",
    "NotificationRecipientResponseResponseBody": ".types",
    "NotificationRecipientResponseResponseBodyNotificationTypesItem": ".types",
    "NumberDataPoint": ".types",
    "NumberFieldTypeMetaDataObjectResponseBody": ".types",
    "OperationalSettingsObjectRequestBody": ".types",
    "OperationalSettingsObjectRequestBodyTimeRangeType": ".types",
    "OperationalSettingsObjectResponseBody": ".types",
    "OperationalSettingsObjectResponseBodyTimeRangeType": ".types",
    "OrderCustomPropertyInputRequestBody": ".types",
    "OrderCustomPropertyResponseBody": ".types",
    "OrderInputObjectRequestBody": ".types",
    "OrderObjectResponseBody": ".types",
    "OrderQuantityInputRequestBody": ".types",
    "OrderQuantityResponseBody": ".types",
    "OrderTaskCustomPropertyObjectResponseBody": ".types",
    "OrderTaskObjectResponseBody": ".types",
    "OrderTaskRequestBody": ".types",
    "OrderTaskRequestBodyPosition": ".types",
    "OrderTaskResponseBody": ".types",
    "OrderTaskResponseBodyPosition": ".types",
    "OrderTaskSkillObjectResponseBody": ".types",
    "OrganizationInfoCarrierSettings": ".types",
    "OrganizationInfoObject": ".types",
    "OrganizationInfoResponse": ".types",
    "OutOfRouteDetailsObjectRequestBody": ".types",
    "OutOfRouteDetailsObjectResponseBody": ".types",
    "OutOfRouteResponseBody": ".types",
    "OutsideGeofenceDataResponseBody": ".types",
    "OutsideGeofenceTriggerDetailsObjectRequestBody": ".types",
    "OutsideGeofenceTriggerDetailsObjectResponseBody": ".types",
    "OverSpeedMs": ".types",
    "PaginationResponse": ".types",
    "PanicButtonDetailsObjectRequestBody": ".types",
    "PanicButtonDetailsObjectResponseBody": ".types",
    "PanicButtonResponseBody": ".types",
    "ParentId": ".types",
    "ParentTag": ".types",
    "ParentTagId": ".types",
    "ParentTagName": ".types",
    "PartInstanceInputObjectRequestBody": ".types",
    "PartInstanceObjectResponseBody": ".types",
    "PatchAssetDataOutputsSingleResponseResponseBody": ".types",
    "PatchDriverTrailerAssignmentsResponseBodyResponseBody": ".types",
    "PatchDriverVehicleAssignmentsV2RequestBodyMetadataRequestBody": ".types",
    "PatchDriverVehicleAssignmentsV2ResponseBodyResponseBody": ".types",
    "PatchFunctionDetailResponseBody": ".types",
    "PatchFunctionRequestConfigRequestBody": ".types",
    "PatchFunctionRequestConfigRequestBodyParams": ".types",
    "PatchFunctionRequestConfigRequestBodySecrets": ".types",
    "PatchIssueRequestBodyAssignedToRequestBody": ".types",
    "PatchIssueRequestBodyAssignedToRequestBodyType": ".types",
    "PatchJobObjectRequestBody": ".types",
    "PatchJobObjectjobLocationRequestObjectRequestBody": ".types",
    "PatchResponseWorkflowConfigurationObjectResponseBody": ".types",
    "PatchSafetyEventsDismissalReasonBodyRequestBody": ".types",
    "PatchSafetyEventsDismissalReasonBodyRequestBodyCode": ".types",
    "PatchSafetyEventsResponseItemDataResponseBody": ".types",
    "PatchSafetyEventsResponseItemResponseBody": ".types",
    "PatchShippingDocsResponseBodyResponseBody": ".types",
    "PendingDutyStatusDurationsObjectResponseBody": ".types",
    "PersonDetectedResponseBody": ".types",
    "PhotoValueObjectRequestBody": ".types",
    "PhotoValueObjectResponseBody": ".types",
    "PlanObjectResponseBody": ".types",
    "PlanOrdersCreatePlanOrdersBadGatewayErrorResponseBody": ".types",
    "PlanOrdersCreatePlanOrdersGatewayTimeoutErrorResponseBody": ".types",
    "PlanOrdersCreatePlanOrdersInternalServerErrorResponseBody": ".types",
    "PlanOrdersCreatePlanOrdersMethodNotAllowedErrorResponseBody": ".types",
    "PlanOrdersCreatePlanOrdersNotFoundErrorResponseBody": ".types",
    "PlanOrdersCreatePlanOrdersNotImplementedErrorResponseBody": ".types",
    "PlanOrdersCreatePlanOrdersResponseBody": ".types",
    "PlanOrdersCreatePlanOrdersServiceUnavailableErrorResponseBody": ".types",
    "PlanOrdersCreatePlanOrdersTooManyRequestsErrorResponseBody": ".types",
    "PlanOrdersCreatePlanOrdersUnauthorizedErrorResponseBody": ".types",
    "PolicyViolationsDetectionAlertSettingsObjectResponseBody": ".types",
    "PolicyViolationsDetectionAlertSettingsObjectResponseBodyEventsAvailableForTestingItem": ".types",
    "PolicyViolationsDetectionAlertSettingsObjectResponseBodyEventsToCoachItem": ".types",
    "PolygonRequestBody": ".types",
    "PolygonResponseBody": ".types",
    "PostDriverTrailerAssignmentsResponseBodyResponseBody": ".types",
    "PostDriverVehicleAssignmentsV2RequestBodyMetadataRequestBody": ".types",
    "PostDriverVehicleAssignmentsV2ResponseBodyResponseBody": ".types",
    "PostFuelPurchaseRequestBodyDiscountRequestBody": ".types",
    "PostFuelPurchaseRequestBodyDiscountRequestBodyCurrency": ".types",
    "PostFuelPurchaseRequestBodyPriceRequestBody": ".types",
    "PostFuelPurchaseRequestBodyPriceRequestBodyCurrency": ".types",
    "PostFuelPurchaseResponseBodyResponseBody": ".types",
    "PostInvoiceScanResponseDataResponseBody": ".types",
    "PostJobObjectRequestBody": ".types",
    "PostJobObjectjobLocationRequestObjectRequestBody": ".types",
    "PostMediaRetrievalObjectResponseBody": ".types",
    "PostResponseResWorkflowConfigurationObjectResponseBody": ".types",
    "PowerTakeOffDurationMs": ".types",
    "PrimaryTimeRangeRequestBody": ".types",
    "PrimaryTimeRangeResponseBody": ".types",
    "PushNotificationOptionsObjectRequestBody": ".types",
    "PushNotificationOptionsObjectResponseBody": ".types",
    "QrCodeResponseObjectResponseBody": ".types",
    "QualificationFieldInputObjectResponseBody": ".types",
    "QualificationFieldInputObjectResponseBodyType": ".types",
    "QualificationOwnerObjectResponseBody": ".types",
    "QualificationOwnerObjectResponseBodyEntityType": ".types",
    "QualificationOwnerRequestObjectRequestBody": ".types",
    "QualificationOwnerRequestObjectRequestBodyEntityType": ".types",
    "QualificationRecordRequestFieldInputObjectRequestBody": ".types",
    "QualificationRecordRequestFieldInputObjectRequestBodyType": ".types",
    "QualificationRecordResponseObjectResponseBody": ".types",
    "QualificationRecordResponseObjectResponseBodyRecordStatus": ".types",
    "QualificationTypeReferenceObjectResponseBody": ".types",
    "QualificationTypeRequestObjectRequestBody": ".types",
    "QualificationTypeResponseObjectResponseBody": ".types",
    "QualificationTypeResponseObjectResponseBodyEntityType": ".types",
    "QualificationsArchiveQualificationRecordBadGatewayErrorResponseBody": ".types",
    "QualificationsArchiveQualificationRecordGatewayTimeoutErrorResponseBody": ".types",
    "QualificationsArchiveQualificationRecordInternalServerErrorResponseBody": ".types",
    "QualificationsArchiveQualificationRecordMethodNotAllowedErrorResponseBody": ".types",
    "QualificationsArchiveQualificationRecordNotFoundErrorResponseBody": ".types",
    "QualificationsArchiveQualificationRecordNotImplementedErrorResponseBody": ".types",
    "QualificationsArchiveQualificationRecordServiceUnavailableErrorResponseBody": ".types",
    "QualificationsArchiveQualificationRecordTooManyRequestsErrorResponseBody": ".types",
    "QualificationsArchiveQualificationRecordUnauthorizedErrorResponseBody": ".types",
    "QualificationsDeleteQualificationRecordBadGatewayErrorResponseBody": ".types",
    "QualificationsDeleteQualificationRecordGatewayTimeoutErrorResponseBody": ".types",
    "QualificationsDeleteQualificationRecordInternalServerErrorResponseBody": ".types",
    "QualificationsDeleteQualificationRecordMethodNotAllowedErrorResponseBody": ".types",
    "QualificationsDeleteQualificationRecordNotFoundErrorResponseBody": ".types",
    "QualificationsDeleteQualificationRecordNotImplementedErrorResponseBody": ".types",
    "QualificationsDeleteQualificationRecordServiceUnavailableErrorResponseBody": ".types",
    "QualificationsDeleteQualificationRecordTooManyRequestsErrorResponseBody": ".types",
    "QualificationsDeleteQualificationRecordUnauthorizedErrorResponseBody": ".types",
    "QualificationsGetQualificationRecordsBadGatewayErrorResponseBody": ".types",
    "QualificationsGetQualificationRecordsGatewayTimeoutErrorResponseBody": ".types",
    "QualificationsGetQualificationRecordsInternalServerErrorResponseBody": ".types",
    "QualificationsGetQualificationRecordsMethodNotAllowedErrorResponseBody": ".types",
    "QualificationsGetQualificationRecordsNotFoundErrorResponseBody": ".types",
    "QualificationsGetQualificationRecordsNotImplementedErrorResponseBody": ".types",
    "QualificationsGetQualificationRecordsResponseBody": ".types",
    "QualificationsGetQualificationRecordsServiceUnavailableErrorResponseBody": ".types",
    "QualificationsGetQualificationRecordsStreamBadGatewayErrorResponseBody": ".types",
    "QualificationsGetQualificationRecordsStreamGatewayTimeoutErrorResponseBody": ".types",
    "QualificationsGetQualificationRecordsStreamInternalServerErrorResponseBody": ".types",
    "QualificationsGetQualificationRecordsStreamMethodNotAllowedErrorResponseBody": ".types",
    "QualificationsGetQualificationRecordsStreamNotFoundErrorResponseBody": ".types",
    "QualificationsGetQualificationRecordsStreamNotImplementedErrorResponseBody": ".types",
    "QualificationsGetQualificationRecordsStreamResponseBody": ".types",
    "QualificationsGetQualificationRecordsStreamServiceUnavailableErrorResponseBody": ".types",
    "QualificationsGetQualificationRecordsStreamTooManyRequestsErrorResponseBody": ".types",
    "QualificationsGetQualificationRecordsStreamUnauthorizedErrorResponseBody": ".types",
    "QualificationsGetQualificationRecordsTooManyRequestsErrorResponseBody": ".types",
    "QualificationsGetQualificationRecordsUnauthorizedErrorResponseBody": ".types",
    "QualificationsGetQualificationTypesBadGatewayErrorResponseBody": ".types",
    "QualificationsGetQualificationTypesGatewayTimeoutErrorResponseBody": ".types",
    "QualificationsGetQualificationTypesInternalServerErrorResponseBody": ".types",
    "QualificationsGetQualificationTypesMethodNotAllowedErrorResponseBody": ".types",
    "QualificationsGetQualificationTypesNotFoundErrorResponseBody": ".types",
    "QualificationsGetQualificationTypesNotImplementedErrorResponseBody": ".types",
    "QualificationsGetQualificationTypesResponseBody": ".types",
    "QualificationsGetQualificationTypesServiceUnavailableErrorResponseBody": ".types",
    "QualificationsGetQualificationTypesTooManyRequestsErrorResponseBody": ".types",
    "QualificationsGetQualificationTypesUnauthorizedErrorResponseBody": ".types",
    "QualificationsPatchQualificationRecordBadGatewayErrorResponseBody": ".types",
    "QualificationsPatchQualificationRecordGatewayTimeoutErrorResponseBody": ".types",
    "QualificationsPatchQualificationRecordInternalServerErrorResponseBody": ".types",
    "QualificationsPatchQualificationRecordMethodNotAllowedErrorResponseBody": ".types",
    "QualificationsPatchQualificationRecordNotFoundErrorResponseBody": ".types",
    "QualificationsPatchQualificationRecordNotImplementedErrorResponseBody": ".types",
    "QualificationsPatchQualificationRecordResponseBody": ".types",
    "QualificationsPatchQualificationRecordServiceUnavailableErrorResponseBody": ".types",
    "QualificationsPatchQualificationRecordTooManyRequestsErrorResponseBody": ".types",
    "QualificationsPatchQualificationRecordUnauthorizedErrorResponseBody": ".types",
    "QualificationsPostQualificationRecordBadGatewayErrorResponseBody": ".types",
    "QualificationsPostQualificationRecordGatewayTimeoutErrorResponseBody": ".types",
    "QualificationsPostQualificationRecordInternalServerErrorResponseBody": ".types",
    "QualificationsPostQualificationRecordMethodNotAllowedErrorResponseBody": ".types",
    "QualificationsPostQualificationRecordNotFoundErrorResponseBody": ".types",
    "QualificationsPostQualificationRecordNotImplementedErrorResponseBody": ".types",
    "QualificationsPostQualificationRecordResponseBody": ".types",
    "QualificationsPostQualificationRecordServiceUnavailableErrorResponseBody": ".types",
    "QualificationsPostQualificationRecordTooManyRequestsErrorResponseBody": ".types",
    "QualificationsPostQualificationRecordUnauthorizedErrorResponseBody": ".types",
    "QualificationsUnarchiveQualificationRecordBadGatewayErrorResponseBody": ".types",
    "QualificationsUnarchiveQualificationRecordGatewayTimeoutErrorResponseBody": ".types",
    "QualificationsUnarchiveQualificationRecordInternalServerErrorResponseBody": ".types",
    "QualificationsUnarchiveQualificationRecordMethodNotAllowedErrorResponseBody": ".types",
    "QualificationsUnarchiveQualificationRecordNotFoundErrorResponseBody": ".types",
    "QualificationsUnarchiveQualificationRecordNotImplementedErrorResponseBody": ".types",
    "QualificationsUnarchiveQualificationRecordServiceUnavailableErrorResponseBody": ".types",
    "QualificationsUnarchiveQualificationRecordTooManyRequestsErrorResponseBody": ".types",
    "QualificationsUnarchiveQualificationRecordUnauthorizedErrorResponseBody": ".types",
    "QuantityObjectResponseBody": ".types",
    "ReadingDatapointRequestBody": ".types",
    "ReadingDatapointRequestBodyEntityType": ".types",
    "ReadingDefinitionResponseBody": ".types",
    "ReadingHistoryResponseBody": ".types",
    "ReadingSnapshotResponseBody": ".types",
    "ReadingTriggerContinuousValueObjectRequestBody": ".types",
    "ReadingTriggerContinuousValueObjectRequestBodyOperation": ".types",
    "ReadingTriggerContinuousValueObjectRequestBodyUnit": ".types",
    "ReadingTriggerContinuousValueObjectResponseBody": ".types",
    "ReadingTriggerContinuousValueObjectResponseBodyOperation": ".types",
    "ReadingTriggerContinuousValueObjectResponseBodyUnit": ".types",
    "ReadingTriggerDetailsObjectRequestBody": ".types",
    "ReadingTriggerDetailsObjectResponseBody": ".types",
    "ReadingTriggerDetailsResponseBody": ".types",
    "ReadingTriggerEnumValueObjectRequestBody": ".types",
    "ReadingTriggerEnumValueObjectResponseBody": ".types",
    "ReadingsGetReadingsHistoryBadGatewayErrorResponseBody": ".types",
    "ReadingsGetReadingsHistoryGatewayTimeoutErrorResponseBody": ".types",
    "ReadingsGetReadingsHistoryInternalServerErrorResponseBody": ".types",
    "ReadingsGetReadingsHistoryMethodNotAllowedErrorResponseBody": ".types",
    "ReadingsGetReadingsHistoryNotFoundErrorResponseBody": ".types",
    "ReadingsGetReadingsHistoryNotImplementedErrorResponseBody": ".types",
    "ReadingsGetReadingsHistoryResponseBody": ".types",
    "ReadingsGetReadingsHistoryServiceUnavailableErrorResponseBody": ".types",
    "ReadingsGetReadingsHistoryTooManyRequestsErrorResponseBody": ".types",
    "ReadingsGetReadingsHistoryUnauthorizedErrorResponseBody": ".types",
    "ReadingsGetReadingsSnapshotBadGatewayErrorResponseBody": ".types",
    "ReadingsGetReadingsSnapshotGatewayTimeoutErrorResponseBody": ".types",
    "ReadingsGetReadingsSnapshotInternalServerErrorResponseBody": ".types",
    "ReadingsGetReadingsSnapshotMethodNotAllowedErrorResponseBody": ".types",
    "ReadingsGetReadingsSnapshotNotFoundErrorResponseBody": ".types",
    "ReadingsGetReadingsSnapshotNotImplementedErrorResponseBody": ".types",
    "ReadingsGetReadingsSnapshotResponseBody": ".types",
    "ReadingsGetReadingsSnapshotServiceUnavailableErrorResponseBody": ".types",
    "ReadingsGetReadingsSnapshotTooManyRequestsErrorResponseBody": ".types",
    "ReadingsGetReadingsSnapshotUnauthorizedErrorResponseBody": ".types",
    "ReadingsListReadingsDefinitionsBadGatewayErrorResponseBody": ".types",
    "ReadingsListReadingsDefinitionsGatewayTimeoutErrorResponseBody": ".types",
    "ReadingsListReadingsDefinitionsInternalServerErrorResponseBody": ".types",
    "ReadingsListReadingsDefinitionsMethodNotAllowedErrorResponseBody": ".types",
    "ReadingsListReadingsDefinitionsNotFoundErrorResponseBody": ".types",
    "ReadingsListReadingsDefinitionsNotImplementedErrorResponseBody": ".types",
    "ReadingsListReadingsDefinitionsResponseBody": ".types",
    "ReadingsListReadingsDefinitionsServiceUnavailableErrorResponseBody": ".types",
    "ReadingsListReadingsDefinitionsTooManyRequestsErrorResponseBody": ".types",
    "ReadingsListReadingsDefinitionsUnauthorizedErrorResponseBody": ".types",
    "ReadingsPostReadingsBadGatewayErrorResponseBody": ".types",
    "ReadingsPostReadingsGatewayTimeoutErrorResponseBody": ".types",
    "ReadingsPostReadingsInternalServerErrorResponseBody": ".types",
    "ReadingsPostReadingsMethodNotAllowedErrorResponseBody": ".types",
    "ReadingsPostReadingsNotFoundErrorResponseBody": ".types",
    "ReadingsPostReadingsNotImplementedErrorResponseBody": ".types",
    "ReadingsPostReadingsServiceUnavailableErrorResponseBody": ".types",
    "ReadingsPostReadingsTooManyRequestsErrorResponseBody": ".types",
    "ReadingsPostReadingsUnauthorizedErrorResponseBody": ".types",
    "RecipientObjectRequestBody": ".types",
    "RecipientObjectRequestBodyNotificationTypesItem": ".types",
    "RecipientObjectRequestBodyType": ".types",
    "RecipientObjectResponseBody": ".types",
    "RecipientObjectResponseBodyNotificationTypesItem": ".types",
    "RecipientObjectResponseBodyType": ".types",
    "RecoveryPhotoResponseBody": ".types",
    "RecoveryPhotoResponseBodyStatus": ".types",
    "RecoveryStateResponseBody": ".types",
    "RecoveryStateResponseBodyUpdateSource": ".types",
    "ReeferTemperatureResponseBody": ".types",
    "ReportColumnsObjectResponseBody": ".types",
    "ReportColumnsObjectResponseBodyDataType": ".types",
    "ReportColumnsObjectResponseBodyUnit": ".types",
    "ReportConfigObjectResponseBody": ".types",
    "ReportRunObjectResponseBody": ".types",
    "ReportRunObjectResponseBodyStatus": ".types",
    "ReportsCreateReportRunBadGatewayErrorResponseBody": ".types",
    "ReportsCreateReportRunGatewayTimeoutErrorResponseBody": ".types",
    "ReportsCreateReportRunInternalServerErrorResponseBody": ".types",
    "ReportsCreateReportRunMethodNotAllowedErrorResponseBody": ".types",
    "ReportsCreateReportRunNotFoundErrorResponseBody": ".types",
    "ReportsCreateReportRunNotImplementedErrorResponseBody": ".types",
    "ReportsCreateReportRunResponseBody": ".types",
    "ReportsCreateReportRunServiceUnavailableErrorResponseBody": ".types",
    "ReportsCreateReportRunTooManyRequestsErrorResponseBody": ".types",
    "ReportsCreateReportRunUnauthorizedErrorResponseBody": ".types",
    "ReportsDatasetFieldResponseBody": ".types",
    "ReportsDatasetFieldResponseBodyDataType": ".types",
    "ReportsDatasetFieldResponseBodyUnit": ".types",
    "ReportsDatasetResponseBody": ".types",
    "ReportsGetDatasetsBadGatewayErrorResponseBody": ".types",
    "ReportsGetDatasetsGatewayTimeoutErrorResponseBody": ".types",
    "ReportsGetDatasetsInternalServerErrorResponseBody": ".types",
    "ReportsGetDatasetsMethodNotAllowedErrorResponseBody": ".types",
    "ReportsGetDatasetsNotFoundErrorResponseBody": ".types",
    "ReportsGetDatasetsNotImplementedErrorResponseBody": ".types",
    "ReportsGetDatasetsResponseBody": ".types",
    "ReportsGetDatasetsServiceUnavailableErrorResponseBody": ".types",
    "ReportsGetDatasetsTooManyRequestsErrorResponseBody": ".types",
    "ReportsGetDatasetsUnauthorizedErrorResponseBody": ".types",
    "ReportsGetReportConfigsBadGatewayErrorResponseBody": ".types",
    "ReportsGetReportConfigsGatewayTimeoutErrorResponseBody": ".types",
    "ReportsGetReportConfigsInternalServerErrorResponseBody": ".types",
    "ReportsGetReportConfigsMethodNotAllowedErrorResponseBody": ".types",
    "ReportsGetReportConfigsNotFoundErrorResponseBody": ".types",
    "ReportsGetReportConfigsNotImplementedErrorResponseBody": ".types",
    "ReportsGetReportConfigsResponseBody": ".types",
    "ReportsGetReportConfigsServiceUnavailableErrorResponseBody": ".types",
    "ReportsGetReportConfigsTooManyRequestsErrorResponseBody": ".types",
    "ReportsGetReportConfigsUnauthorizedErrorResponseBody": ".types",
    "ReportsGetReportRunDataBadGatewayErrorResponseBody": ".types",
    "ReportsGetReportRunDataGatewayTimeoutErrorResponseBody": ".types",
    "ReportsGetReportRunDataInternalServerErrorResponseBody": ".types",
    "ReportsGetReportRunDataMethodNotAllowedErrorResponseBody": ".types",
    "ReportsGetReportRunDataNotFoundErrorResponseBody": ".types",
    "ReportsGetReportRunDataNotImplementedErrorResponseBody": ".types",
    "ReportsGetReportRunDataResponseBody": ".types",
    "ReportsGetReportRunDataServiceUnavailableErrorResponseBody": ".types",
    "ReportsGetReportRunDataTooManyRequestsErrorResponseBody": ".types",
    "ReportsGetReportRunDataUnauthorizedErrorResponseBody": ".types",
    "ReportsGetReportRunsBadGatewayErrorResponseBody": ".types",
    "ReportsGetReportRunsGatewayTimeoutErrorResponseBody": ".types",
    "ReportsGetReportRunsInternalServerErrorResponseBody": ".types",
    "ReportsGetReportRunsMethodNotAllowedErrorResponseBody": ".types",
    "ReportsGetReportRunsNotFoundErrorResponseBody": ".types",
    "ReportsGetReportRunsNotImplementedErrorResponseBody": ".types",
    "ReportsGetReportRunsResponseBody": ".types",
    "ReportsGetReportRunsServiceUnavailableErrorResponseBody": ".types",
    "ReportsGetReportRunsTooManyRequestsErrorResponseBody": ".types",
    "ReportsGetReportRunsUnauthorizedErrorResponseBody": ".types",
    "ResolveAssignmentByDetailsResolveAssignmentByDetailsBadGatewayErrorResponseBody": ".types",
    "ResolveAssignmentByDetailsResolveAssignmentByDetailsGatewayTimeoutErrorResponseBody": ".types",
    "ResolveAssignmentByDetailsResolveAssignmentByDetailsInternalServerErrorResponseBody": ".types",
    "ResolveAssignmentByDetailsResolveAssignmentByDetailsMethodNotAllowedErrorResponseBody": ".types",
    "ResolveAssignmentByDetailsResolveAssignmentByDetailsNotFoundErrorResponseBody": ".types",
    "ResolveAssignmentByDetailsResolveAssignmentByDetailsNotImplementedErrorResponseBody": ".types",
    "ResolveAssignmentByDetailsResolveAssignmentByDetailsResponseBody": ".types",
    "ResolveAssignmentByDetailsResolveAssignmentByDetailsServiceUnavailableErrorResponseBody": ".types",
    "ResolveAssignmentByDetailsResolveAssignmentByDetailsTooManyRequestsErrorResponseBody": ".types",
    "ResolveAssignmentByDetailsResolveAssignmentByDetailsUnauthorizedErrorResponseBody": ".types",
    "ResolveAssignmentByDetailsResponseBodyResponseBody": ".types",
    "ResolvedBy": ".types",
    "ResolvedByType": ".types",
    "ReverseGeo": ".types",
    "ReverseGeoObjectResponseBody": ".types",
    "RidershipAccountObjectResponseBody": ".types",
    "RidershipAccountsCreateRidershipAccountBadGatewayErrorResponseBody": ".types",
    "RidershipAccountsCreateRidershipAccountGatewayTimeoutErrorResponseBody": ".types",
    "RidershipAccountsCreateRidershipAccountInternalServerErrorResponseBody": ".types",
    "RidershipAccountsCreateRidershipAccountMethodNotAllowedErrorResponseBody": ".types",
    "RidershipAccountsCreateRidershipAccountNotFoundErrorResponseBody": ".types",
    "RidershipAccountsCreateRidershipAccountNotImplementedErrorResponseBody": ".types",
    "RidershipAccountsCreateRidershipAccountResponseBody": ".types",
    "RidershipAccountsCreateRidershipAccountServiceUnavailableErrorResponseBody": ".types",
    "RidershipAccountsCreateRidershipAccountTooManyRequestsErrorResponseBody": ".types",
    "RidershipAccountsCreateRidershipAccountUnauthorizedErrorResponseBody": ".types",
    "RidershipAccountsDeleteRidershipAccountBadGatewayErrorResponseBody": ".types",
    "RidershipAccountsDeleteRidershipAccountGatewayTimeoutErrorResponseBody": ".types",
    "RidershipAccountsDeleteRidershipAccountInternalServerErrorResponseBody": ".types",
    "RidershipAccountsDeleteRidershipAccountMethodNotAllowedErrorResponseBody": ".types",
    "RidershipAccountsDeleteRidershipAccountNotFoundErrorResponseBody": ".types",
    "RidershipAccountsDeleteRidershipAccountNotImplementedErrorResponseBody": ".types",
    "RidershipAccountsDeleteRidershipAccountServiceUnavailableErrorResponseBody": ".types",
    "RidershipAccountsDeleteRidershipAccountTooManyRequestsErrorResponseBody": ".types",
    "RidershipAccountsDeleteRidershipAccountUnauthorizedErrorResponseBody": ".types",
    "RidershipAccountsGetRidershipAccountBadGatewayErrorResponseBody": ".types",
    "RidershipAccountsGetRidershipAccountGatewayTimeoutErrorResponseBody": ".types",
    "RidershipAccountsGetRidershipAccountInternalServerErrorResponseBody": ".types",
    "RidershipAccountsGetRidershipAccountMethodNotAllowedErrorResponseBody": ".types",
    "RidershipAccountsGetRidershipAccountNotFoundErrorResponseBody": ".types",
    "RidershipAccountsGetRidershipAccountNotImplementedErrorResponseBody": ".types",
    "RidershipAccountsGetRidershipAccountResponseBody": ".types",
    "RidershipAccountsGetRidershipAccountServiceUnavailableErrorResponseBody": ".types",
    "RidershipAccountsGetRidershipAccountTooManyRequestsErrorResponseBody": ".types",
    "RidershipAccountsGetRidershipAccountUnauthorizedErrorResponseBody": ".types",
    "RidershipAccountsListRidershipAccountsBadGatewayErrorResponseBody": ".types",
    "RidershipAccountsListRidershipAccountsGatewayTimeoutErrorResponseBody": ".types",
    "RidershipAccountsListRidershipAccountsInternalServerErrorResponseBody": ".types",
    "RidershipAccountsListRidershipAccountsMethodNotAllowedErrorResponseBody": ".types",
    "RidershipAccountsListRidershipAccountsNotFoundErrorResponseBody": ".types",
    "RidershipAccountsListRidershipAccountsNotImplementedErrorResponseBody": ".types",
    "RidershipAccountsListRidershipAccountsResponseBody": ".types",
    "RidershipAccountsListRidershipAccountsServiceUnavailableErrorResponseBody": ".types",
    "RidershipAccountsListRidershipAccountsTooManyRequestsErrorResponseBody": ".types",
    "RidershipAccountsListRidershipAccountsUnauthorizedErrorResponseBody": ".types",
    "RidershipAccountsUpdateRidershipAccountBadGatewayErrorResponseBody": ".types",
    "RidershipAccountsUpdateRidershipAccountGatewayTimeoutErrorResponseBody": ".types",
    "RidershipAccountsUpdateRidershipAccountInternalServerErrorResponseBody": ".types",
    "RidershipAccountsUpdateRidershipAccountMethodNotAllowedErrorResponseBody": ".types",
    "RidershipAccountsUpdateRidershipAccountNotFoundErrorResponseBody": ".types",
    "RidershipAccountsUpdateRidershipAccountNotImplementedErrorResponseBody": ".types",
    "RidershipAccountsUpdateRidershipAccountResponseBody": ".types",
    "RidershipAccountsUpdateRidershipAccountServiceUnavailableErrorResponseBody": ".types",
    "RidershipAccountsUpdateRidershipAccountTooManyRequestsErrorResponseBody": ".types",
    "RidershipAccountsUpdateRidershipAccountUnauthorizedErrorResponseBody": ".types",
    "RidershipPassengerIdentifierInputRequestBody": ".types",
    "RidershipPassengerIdentifierInputRequestBodyStatus": ".types",
    "RidershipPassengerIdentifierInputRequestBodyType": ".types",
    "RidershipPassengerIdentifierObjectResponseBody": ".types",
    "RidershipPassengerIdentifierObjectResponseBodyStatus": ".types",
    "RidershipPassengerIdentifierObjectResponseBodyType": ".types",
    "RidershipPassengerObjectResponseBody": ".types",
    "RidershipPassengerSpecialInstructionsInputRequestBody": ".types",
    "RidershipPassengerSpecialInstructionsObjectResponseBody": ".types",
    "RidershipPassengersCreateRidershipPassengerBadGatewayErrorResponseBody": ".types",
    "RidershipPassengersCreateRidershipPassengerGatewayTimeoutErrorResponseBody": ".types",
    "RidershipPassengersCreateRidershipPassengerInternalServerErrorResponseBody": ".types",
    "RidershipPassengersCreateRidershipPassengerMethodNotAllowedErrorResponseBody": ".types",
    "RidershipPassengersCreateRidershipPassengerNotFoundErrorResponseBody": ".types",
    "RidershipPassengersCreateRidershipPassengerNotImplementedErrorResponseBody": ".types",
    "RidershipPassengersCreateRidershipPassengerRequestBodyClassification": ".beta_ap_is",
    "RidershipPassengersCreateRidershipPassengerResponseBody": ".types",
    "RidershipPassengersCreateRidershipPassengerServiceUnavailableErrorResponseBody": ".types",
    "RidershipPassengersCreateRidershipPassengerTooManyRequestsErrorResponseBody": ".types",
    "RidershipPassengersCreateRidershipPassengerUnauthorizedErrorResponseBody": ".types",
    "RidershipPassengersDeleteRidershipPassengerBadGatewayErrorResponseBody": ".types",
    "RidershipPassengersDeleteRidershipPassengerGatewayTimeoutErrorResponseBody": ".types",
    "RidershipPassengersDeleteRidershipPassengerInternalServerErrorResponseBody": ".types",
    "RidershipPassengersDeleteRidershipPassengerMethodNotAllowedErrorResponseBody": ".types",
    "RidershipPassengersDeleteRidershipPassengerNotFoundErrorResponseBody": ".types",
    "RidershipPassengersDeleteRidershipPassengerNotImplementedErrorResponseBody": ".types",
    "RidershipPassengersDeleteRidershipPassengerServiceUnavailableErrorResponseBody": ".types",
    "RidershipPassengersDeleteRidershipPassengerTooManyRequestsErrorResponseBody": ".types",
    "RidershipPassengersDeleteRidershipPassengerUnauthorizedErrorResponseBody": ".types",
    "RidershipPassengersGetRidershipPassengerBadGatewayErrorResponseBody": ".types",
    "RidershipPassengersGetRidershipPassengerGatewayTimeoutErrorResponseBody": ".types",
    "RidershipPassengersGetRidershipPassengerInternalServerErrorResponseBody": ".types",
    "RidershipPassengersGetRidershipPassengerMethodNotAllowedErrorResponseBody": ".types",
    "RidershipPassengersGetRidershipPassengerNotFoundErrorResponseBody": ".types",
    "RidershipPassengersGetRidershipPassengerNotImplementedErrorResponseBody": ".types",
    "RidershipPassengersGetRidershipPassengerResponseBody": ".types",
    "RidershipPassengersGetRidershipPassengerServiceUnavailableErrorResponseBody": ".types",
    "RidershipPassengersGetRidershipPassengerTooManyRequestsErrorResponseBody": ".types",
    "RidershipPassengersGetRidershipPassengerUnauthorizedErrorResponseBody": ".types",
    "RidershipPassengersListRidershipPassengersBadGatewayErrorResponseBody": ".types",
    "RidershipPassengersListRidershipPassengersGatewayTimeoutErrorResponseBody": ".types",
    "RidershipPassengersListRidershipPassengersInternalServerErrorResponseBody": ".types",
    "RidershipPassengersListRidershipPassengersMethodNotAllowedErrorResponseBody": ".types",
    "RidershipPassengersListRidershipPassengersNotFoundErrorResponseBody": ".types",
    "RidershipPassengersListRidershipPassengersNotImplementedErrorResponseBody": ".types",
    "RidershipPassengersListRidershipPassengersResponseBody": ".types",
    "RidershipPassengersListRidershipPassengersServiceUnavailableErrorResponseBody": ".types",
    "RidershipPassengersListRidershipPassengersTooManyRequestsErrorResponseBody": ".types",
    "RidershipPassengersListRidershipPassengersUnauthorizedErrorResponseBody": ".types",
    "RidershipPassengersUpdateRidershipPassengerBadGatewayErrorResponseBody": ".types",
    "RidershipPassengersUpdateRidershipPassengerGatewayTimeoutErrorResponseBody": ".types",
    "RidershipPassengersUpdateRidershipPassengerInternalServerErrorResponseBody": ".types",
    "RidershipPassengersUpdateRidershipPassengerMethodNotAllowedErrorResponseBody": ".types",
    "RidershipPassengersUpdateRidershipPassengerNotFoundErrorResponseBody": ".types",
    "RidershipPassengersUpdateRidershipPassengerNotImplementedErrorResponseBody": ".types",
    "RidershipPassengersUpdateRidershipPassengerRequestBodyClassification": ".beta_ap_is",
    "RidershipPassengersUpdateRidershipPassengerResponseBody": ".types",
    "RidershipPassengersUpdateRidershipPassengerServiceUnavailableErrorResponseBody": ".types",
    "RidershipPassengersUpdateRidershipPassengerTooManyRequestsErrorResponseBody": ".types",
    "RidershipPassengersUpdateRidershipPassengerUnauthorizedErrorResponseBody": ".types",
    "RidershipRouteSetupObjectResponseBody": ".types",
    "RidershipRouteSetupPassengerInputRequestBody": ".types",
    "RidershipRouteSetupPassengerObjectResponseBody": ".types",
    "RidershipRouteSetupsCreateRidershipRouteSetupBadGatewayErrorResponseBody": ".types",
    "RidershipRouteSetupsCreateRidershipRouteSetupGatewayTimeoutErrorResponseBody": ".types",
    "RidershipRouteSetupsCreateRidershipRouteSetupInternalServerErrorResponseBody": ".types",
    "RidershipRouteSetupsCreateRidershipRouteSetupMethodNotAllowedErrorResponseBody": ".types",
    "RidershipRouteSetupsCreateRidershipRouteSetupNotFoundErrorResponseBody": ".types",
    "RidershipRouteSetupsCreateRidershipRouteSetupNotImplementedErrorResponseBody": ".types",
    "RidershipRouteSetupsCreateRidershipRouteSetupResponseBody": ".types",
    "RidershipRouteSetupsCreateRidershipRouteSetupServiceUnavailableErrorResponseBody": ".types",
    "RidershipRouteSetupsCreateRidershipRouteSetupTooManyRequestsErrorResponseBody": ".types",
    "RidershipRouteSetupsCreateRidershipRouteSetupUnauthorizedErrorResponseBody": ".types",
    "RidershipRouteSetupsDeleteRidershipRouteSetupBadGatewayErrorResponseBody": ".types",
    "RidershipRouteSetupsDeleteRidershipRouteSetupGatewayTimeoutErrorResponseBody": ".types",
    "RidershipRouteSetupsDeleteRidershipRouteSetupInternalServerErrorResponseBody": ".types",
    "RidershipRouteSetupsDeleteRidershipRouteSetupMethodNotAllowedErrorResponseBody": ".types",
    "RidershipRouteSetupsDeleteRidershipRouteSetupNotFoundErrorResponseBody": ".types",
    "RidershipRouteSetupsDeleteRidershipRouteSetupNotImplementedErrorResponseBody": ".types",
    "RidershipRouteSetupsDeleteRidershipRouteSetupServiceUnavailableErrorResponseBody": ".types",
    "RidershipRouteSetupsDeleteRidershipRouteSetupTooManyRequestsErrorResponseBody": ".types",
    "RidershipRouteSetupsDeleteRidershipRouteSetupUnauthorizedErrorResponseBody": ".types",
    "RidershipRouteSetupsGetRidershipRouteSetupBadGatewayErrorResponseBody": ".types",
    "RidershipRouteSetupsGetRidershipRouteSetupGatewayTimeoutErrorResponseBody": ".types",
    "RidershipRouteSetupsGetRidershipRouteSetupInternalServerErrorResponseBody": ".types",
    "RidershipRouteSetupsGetRidershipRouteSetupMethodNotAllowedErrorResponseBody": ".types",
    "RidershipRouteSetupsGetRidershipRouteSetupNotFoundErrorResponseBody": ".types",
    "RidershipRouteSetupsGetRidershipRouteSetupNotImplementedErrorResponseBody": ".types",
    "RidershipRouteSetupsGetRidershipRouteSetupResponseBody": ".types",
    "RidershipRouteSetupsGetRidershipRouteSetupServiceUnavailableErrorResponseBody": ".types",
    "RidershipRouteSetupsGetRidershipRouteSetupTooManyRequestsErrorResponseBody": ".types",
    "RidershipRouteSetupsGetRidershipRouteSetupUnauthorizedErrorResponseBody": ".types",
    "RidershipRouteSetupsListRidershipRouteSetupsBadGatewayErrorResponseBody": ".types",
    "RidershipRouteSetupsListRidershipRouteSetupsGatewayTimeoutErrorResponseBody": ".types",
    "RidershipRouteSetupsListRidershipRouteSetupsInternalServerErrorResponseBody": ".types",
    "RidershipRouteSetupsListRidershipRouteSetupsMethodNotAllowedErrorResponseBody": ".types",
    "RidershipRouteSetupsListRidershipRouteSetupsNotFoundErrorResponseBody": ".types",
    "RidershipRouteSetupsListRidershipRouteSetupsNotImplementedErrorResponseBody": ".types",
    "RidershipRouteSetupsListRidershipRouteSetupsResponseBody": ".types",
    "RidershipRouteSetupsListRidershipRouteSetupsServiceUnavailableErrorResponseBody": ".types",
    "RidershipRouteSetupsListRidershipRouteSetupsTooManyRequestsErrorResponseBody": ".types",
    "RidershipRouteSetupsListRidershipRouteSetupsUnauthorizedErrorResponseBody": ".types",
    "RidershipRouteSetupsUpdateRidershipRouteSetupBadGatewayErrorResponseBody": ".types",
    "RidershipRouteSetupsUpdateRidershipRouteSetupGatewayTimeoutErrorResponseBody": ".types",
    "RidershipRouteSetupsUpdateRidershipRouteSetupInternalServerErrorResponseBody": ".types",
    "RidershipRouteSetupsUpdateRidershipRouteSetupMethodNotAllowedErrorResponseBody": ".types",
    "RidershipRouteSetupsUpdateRidershipRouteSetupNotFoundErrorResponseBody": ".types",
    "RidershipRouteSetupsUpdateRidershipRouteSetupNotImplementedErrorResponseBody": ".types",
    "RidershipRouteSetupsUpdateRidershipRouteSetupResponseBody": ".types",
    "RidershipRouteSetupsUpdateRidershipRouteSetupServiceUnavailableErrorResponseBody": ".types",
    "RidershipRouteSetupsUpdateRidershipRouteSetupTooManyRequestsErrorResponseBody": ".types",
    "RidershipRouteSetupsUpdateRidershipRouteSetupUnauthorizedErrorResponseBody": ".types",
    "RollingStopDetectionAlertSettingsObjectResponseBody": ".types",
    "RouteChangesResponseBody": ".types",
    "RouteEventDetailsResponseBody": ".types",
    "RouteEventResponseResponseBody": ".types",
    "RouteEventResponseResponseBodyEventType": ".types",
    "RouteEventRouteResponseResponseBody": ".types",
    "RouteEventStopResponseResponseBody": ".types",
    "RouteFeedObjectResponseBody": ".types",
    "RouteFeedObjectResponseBodyOperation": ".types",
    "RouteFeedObjectResponseBodySource": ".types",
    "RouteFeedObjectResponseBodyType": ".types",
    "RouteObjectResponseBody": ".types",
    "RouteSettingsRequestBody": ".types",
    "RouteSettingsRequestBodyRouteCompletionCondition": ".types",
    "RouteSettingsRequestBodyRouteStartingCondition": ".types",
    "RouteSettingsRequestBodySequencingMethod": ".types",
    "RouteSettingsResponseBody": ".types",
    "RouteSettingsResponseBodyRouteCompletionCondition": ".types",
    "RouteSettingsResponseBodyRouteStartingCondition": ".types",
    "RouteSettingsResponseBodySequencingMethod": ".types",
    "RouteStopDetailsObjectResponseBody": ".types",
    "RouteStopDetailsObjectResponseBodyOperation": ".types",
    "RouteStopDetailsObjectResponseBodyType": ".types",
    "RouteStopEstimatedArrivalDetailsObjectRequestBody": ".types",
    "RouteStopEstimatedArrivalDetailsObjectResponseBody": ".types",
    "RouteStopEtaResponseBody": ".types",
    "RouteStopObjectResponseBody": ".types",
    "RoutesCreateRouteBadGatewayErrorResponseBody": ".types",
    "RoutesCreateRouteGatewayTimeoutErrorResponseBody": ".types",
    "RoutesCreateRouteInternalServerErrorResponseBody": ".types",
    "RoutesCreateRouteMethodNotAllowedErrorResponseBody": ".types",
    "RoutesCreateRouteNotFoundErrorResponseBody": ".types",
    "RoutesCreateRouteNotImplementedErrorResponseBody": ".types",
    "RoutesCreateRouteResponseBody": ".types",
    "RoutesCreateRouteServiceUnavailableErrorResponseBody": ".types",
    "RoutesCreateRouteTooManyRequestsErrorResponseBody": ".types",
    "RoutesCreateRouteUnauthorizedErrorResponseBody": ".types",
    "RoutesDeleteRouteBadGatewayErrorResponseBody": ".types",
    "RoutesDeleteRouteGatewayTimeoutErrorResponseBody": ".types",
    "RoutesDeleteRouteInternalServerErrorResponseBody": ".types",
    "RoutesDeleteRouteMethodNotAllowedErrorResponseBody": ".types",
    "RoutesDeleteRouteNotFoundErrorResponseBody": ".types",
    "RoutesDeleteRouteNotImplementedErrorResponseBody": ".types",
    "RoutesDeleteRouteServiceUnavailableErrorResponseBody": ".types",
    "RoutesDeleteRouteTooManyRequestsErrorResponseBody": ".types",
    "RoutesDeleteRouteUnauthorizedErrorResponseBody": ".types",
    "RoutesFetchRouteBadGatewayErrorResponseBody": ".types",
    "RoutesFetchRouteGatewayTimeoutErrorResponseBody": ".types",
    "RoutesFetchRouteInternalServerErrorResponseBody": ".types",
    "RoutesFetchRouteMethodNotAllowedErrorResponseBody": ".types",
    "RoutesFetchRouteNotFoundErrorResponseBody": ".types",
    "RoutesFetchRouteNotImplementedErrorResponseBody": ".types",
    "RoutesFetchRouteResponseBody": ".types",
    "RoutesFetchRouteServiceUnavailableErrorResponseBody": ".types",
    "RoutesFetchRouteTooManyRequestsErrorResponseBody": ".types",
    "RoutesFetchRouteUnauthorizedErrorResponseBody": ".types",
    "RoutesFetchRoutesBadGatewayErrorResponseBody": ".types",
    "RoutesFetchRoutesGatewayTimeoutErrorResponseBody": ".types",
    "RoutesFetchRoutesInternalServerErrorResponseBody": ".types",
    "RoutesFetchRoutesMethodNotAllowedErrorResponseBody": ".types",
    "RoutesFetchRoutesNotFoundErrorResponseBody": ".types",
    "RoutesFetchRoutesNotImplementedErrorResponseBody": ".types",
    "RoutesFetchRoutesResponseBody": ".types",
    "RoutesFetchRoutesServiceUnavailableErrorResponseBody": ".types",
    "RoutesFetchRoutesTooManyRequestsErrorResponseBody": ".types",
    "RoutesFetchRoutesUnauthorizedErrorResponseBody": ".types",
    "RoutesGetRouteEventsStreamBadGatewayErrorResponseBody": ".types",
    "RoutesGetRouteEventsStreamGatewayTimeoutErrorResponseBody": ".types",
    "RoutesGetRouteEventsStreamInternalServerErrorResponseBody": ".types",
    "RoutesGetRouteEventsStreamMethodNotAllowedErrorResponseBody": ".types",
    "RoutesGetRouteEventsStreamNotFoundErrorResponseBody": ".types",
    "RoutesGetRouteEventsStreamNotImplementedErrorResponseBody": ".types",
    "RoutesGetRouteEventsStreamResponseBody": ".types",
    "RoutesGetRouteEventsStreamServiceUnavailableErrorResponseBody": ".types",
    "RoutesGetRouteEventsStreamTooManyRequestsErrorResponseBody": ".types",
    "RoutesGetRouteEventsStreamUnauthorizedErrorResponseBody": ".types",
    "RoutesGetRoutesFeedBadGatewayErrorResponseBody": ".types",
    "RoutesGetRoutesFeedGatewayTimeoutErrorResponseBody": ".types",
    "RoutesGetRoutesFeedInternalServerErrorResponseBody": ".types",
    "RoutesGetRoutesFeedMethodNotAllowedErrorResponseBody": ".types",
    "RoutesGetRoutesFeedNotFoundErrorResponseBody": ".types",
    "RoutesGetRoutesFeedNotImplementedErrorResponseBody": ".types",
    "RoutesGetRoutesFeedResponseBody": ".types",
    "RoutesGetRoutesFeedServiceUnavailableErrorResponseBody": ".types",
    "RoutesGetRoutesFeedTooManyRequestsErrorResponseBody": ".types",
    "RoutesGetRoutesFeedUnauthorizedErrorResponseBody": ".types",
    "RoutesPatchRouteBadGatewayErrorResponseBody": ".types",
    "RoutesPatchRouteGatewayTimeoutErrorResponseBody": ".types",
    "RoutesPatchRouteInternalServerErrorResponseBody": ".types",
    "RoutesPatchRouteMethodNotAllowedErrorResponseBody": ".types",
    "RoutesPatchRouteNotFoundErrorResponseBody": ".types",
    "RoutesPatchRouteNotImplementedErrorResponseBody": ".types",
    "RoutesPatchRouteResponseBody": ".types",
    "RoutesPatchRouteServiceUnavailableErrorResponseBody": ".types",
    "RoutesPatchRouteTooManyRequestsErrorResponseBody": ".types",
    "RoutesPatchRouteUnauthorizedErrorResponseBody": ".types",
    "RoutesSingleUseAddressObjectRequestBody": ".types",
    "RoutesSingleUseAddressObjectResponseBody": ".types",
    "RoutesStopResponseObjectResponseBody": ".types",
    "RoutesStopResponseObjectResponseBodyState": ".types",
    "SafetyBehaviorTriggerDetailsObjectRequestBody": ".types",
    "SafetyBehaviorTriggerDetailsObjectRequestBodyBehaviorsItem": ".types",
    "SafetyBehaviorTriggerDetailsObjectRequestBodySeveritiesItem": ".types",
    "SafetyBehaviorTriggerDetailsObjectRequestBodyStatusesItem": ".types",
    "SafetyBehaviorTriggerDetailsObjectResponseBody": ".types",
    "SafetyBehaviorTriggerDetailsObjectResponseBodyBehaviorsItem": ".types",
    "SafetyBehaviorTriggerDetailsObjectResponseBodySeveritiesItem": ".types",
    "SafetyBehaviorTriggerDetailsObjectResponseBodyStatusesItem": ".types",
    "SafetyEvent": ".types",
    "SafetyEventActivityFeedItemResponseBody": ".types",
    "SafetyEventActivityFeedItemResponseBodyType": ".types",
    "SafetyEventBehaviorLabel": ".types",
    "SafetyEventBehaviorLabelName": ".types",
    "SafetyEventBehaviorLabelSource": ".types",
    "SafetyEventBehaviorLabelType": ".types",
    "SafetyEventBehaviorLabels": ".types",
    "SafetyEventBehaviorLabelsResponseBody": ".types",
    "SafetyEventBehaviorLabelsResponseBodyType": ".types",
    "SafetyEventCoachingState": ".types",
    "SafetyEventDismissalReasonResponseBody": ".types",
    "SafetyEventDismissalReasonResponseBodyCode": ".types",
    "SafetyEventDownloadForwardVideoUrl": ".types",
    "SafetyEventDownloadInwardVideoUrl": ".types",
    "SafetyEventDownloadTrackedInwardVideoUrl": ".types",
    "SafetyEventDriverObjectResponseBody": ".types",
    "SafetyEventId": ".types",
    "SafetyEventMaxAccelerationGForce": ".types",
    "SafetyEventObjectResponseBody": ".types",
    "SafetyEventSpeedingMetadataResponseBody": ".types",
    "SafetyEventTime": ".types",
    "SafetyEventV2AssetObjectResponseBody": ".types",
    "SafetyEventV2AssetObjectResponseBodyType": ".types",
    "SafetyEventV2BehaviorLabelsResponseBody": ".types",
    "SafetyEventV2BehaviorLabelsResponseBodyLabel": ".types",
    "SafetyEventV2BehaviorLabelsResponseBodySource": ".types",
    "SafetyEventV2ContextLabelsResponseBody": ".types",
    "SafetyEventV2DriverObjectResponseBody": ".types",
    "SafetyEventV2MediaResponseBody": ".types",
    "SafetyEventV2MediaResponseBodyCameraRole": ".types",
    "SafetyEventV2MediaResponseBodyInput": ".types",
    "SafetyEventV2ObjectResponseBody": ".types",
    "SafetyEventV2ObjectResponseBodyEventState": ".types",
    "SafetyEventVehicleObjectResponseBody": ".types",
    "SafetyEventsGetSafetyActivityEventFeedBadGatewayErrorResponseBody": ".types",
    "SafetyEventsGetSafetyActivityEventFeedGatewayTimeoutErrorResponseBody": ".types",
    "SafetyEventsGetSafetyActivityEventFeedInternalServerErrorResponseBody": ".types",
    "SafetyEventsGetSafetyActivityEventFeedMethodNotAllowedErrorResponseBody": ".types",
    "SafetyEventsGetSafetyActivityEventFeedNotFoundErrorResponseBody": ".types",
    "SafetyEventsGetSafetyActivityEventFeedNotImplementedErrorResponseBody": ".types",
    "SafetyEventsGetSafetyActivityEventFeedResponseBody": ".types",
    "SafetyEventsGetSafetyActivityEventFeedServiceUnavailableErrorResponseBody": ".types",
    "SafetyEventsGetSafetyActivityEventFeedTooManyRequestsErrorResponseBody": ".types",
    "SafetyEventsGetSafetyActivityEventFeedUnauthorizedErrorResponseBody": ".types",
    "SafetyEventsListResponse": ".types",
    "SafetyEventsV2GetSafetyEventsV2BadGatewayErrorResponseBody": ".types",
    "SafetyEventsV2GetSafetyEventsV2GatewayTimeoutErrorResponseBody": ".types",
    "SafetyEventsV2GetSafetyEventsV2InternalServerErrorResponseBody": ".types",
    "SafetyEventsV2GetSafetyEventsV2MethodNotAllowedErrorResponseBody": ".types",
    "SafetyEventsV2GetSafetyEventsV2NotFoundErrorResponseBody": ".types",
    "SafetyEventsV2GetSafetyEventsV2NotImplementedErrorResponseBody": ".types",
    "SafetyEventsV2GetSafetyEventsV2ResponseBody": ".types",
    "SafetyEventsV2GetSafetyEventsV2ServiceUnavailableErrorResponseBody": ".types",
    "SafetyEventsV2GetSafetyEventsV2StreamBadGatewayErrorResponseBody": ".types",
    "SafetyEventsV2GetSafetyEventsV2StreamGatewayTimeoutErrorResponseBody": ".types",
    "SafetyEventsV2GetSafetyEventsV2StreamInternalServerErrorResponseBody": ".types",
    "SafetyEventsV2GetSafetyEventsV2StreamMethodNotAllowedErrorResponseBody": ".types",
    "SafetyEventsV2GetSafetyEventsV2StreamNotFoundErrorResponseBody": ".types",
    "SafetyEventsV2GetSafetyEventsV2StreamNotImplementedErrorResponseBody": ".types",
    "SafetyEventsV2GetSafetyEventsV2StreamResponseBody": ".types",
    "SafetyEventsV2GetSafetyEventsV2StreamServiceUnavailableErrorResponseBody": ".types",
    "SafetyEventsV2GetSafetyEventsV2StreamTooManyRequestsErrorResponseBody": ".types",
    "SafetyEventsV2GetSafetyEventsV2StreamUnauthorizedErrorResponseBody": ".types",
    "SafetyEventsV2GetSafetyEventsV2TooManyRequestsErrorResponseBody": ".types",
    "SafetyEventsV2GetSafetyEventsV2UnauthorizedErrorResponseBody": ".types",
    "SafetyEventsV2PatchSafetyEventsV2BatchBadGatewayErrorResponseBody": ".types",
    "SafetyEventsV2PatchSafetyEventsV2BatchGatewayTimeoutErrorResponseBody": ".types",
    "SafetyEventsV2PatchSafetyEventsV2BatchInternalServerErrorResponseBody": ".types",
    "SafetyEventsV2PatchSafetyEventsV2BatchMethodNotAllowedErrorResponseBody": ".types",
    "SafetyEventsV2PatchSafetyEventsV2BatchNotFoundErrorResponseBody": ".types",
    "SafetyEventsV2PatchSafetyEventsV2BatchNotImplementedErrorResponseBody": ".types",
    "SafetyEventsV2PatchSafetyEventsV2BatchRequestBodyContextLabelsToAddItem": ".preview_ap_is",
    "SafetyEventsV2PatchSafetyEventsV2BatchRequestBodyContextLabelsToRemoveItem": ".preview_ap_is",
    "SafetyEventsV2PatchSafetyEventsV2BatchRequestBodyEventState": ".preview_ap_is",
    "SafetyEventsV2PatchSafetyEventsV2BatchResponseBody": ".types",
    "SafetyEventsV2PatchSafetyEventsV2BatchServiceUnavailableErrorResponseBody": ".types",
    "SafetyEventsV2PatchSafetyEventsV2BatchTooManyRequestsErrorResponseBody": ".types",
    "SafetyEventsV2PatchSafetyEventsV2BatchUnauthorizedErrorResponseBody": ".types",
    "SafetyScoreBehaviorObjectResponseBody": ".types",
    "SafetyScoreBehaviorObjectResponseBodyBehaviorType": ".types",
    "SafetyScoreConfigurationSettingsObjectResponseBody": ".types",
    "SafetyScoreDetailsRequestBody": ".types",
    "SafetyScoreDetailsRequestBodyComparison": ".types",
    "SafetyScoreDetailsResponseBody": ".types",
    "SafetyScoreDetailsResponseBodyComparison": ".types",
    "SafetyScoreSpeedingObjectResponseBody": ".types",
    "SafetyScoreSpeedingObjectResponseBodySpeedingType": ".types",
    "SafetyScoresGetDriverSafetyScoreTripsBadGatewayErrorResponseBody": ".types",
    "SafetyScoresGetDriverSafetyScoreTripsGatewayTimeoutErrorResponseBody": ".types",
    "SafetyScoresGetDriverSafetyScoreTripsInternalServerErrorResponseBody": ".types",
    "SafetyScoresGetDriverSafetyScoreTripsMethodNotAllowedErrorResponseBody": ".types",
    "SafetyScoresGetDriverSafetyScoreTripsNotFoundErrorResponseBody": ".types",
    "SafetyScoresGetDriverSafetyScoreTripsNotImplementedErrorResponseBody": ".types",
    "SafetyScoresGetDriverSafetyScoreTripsResponseBody": ".types",
    "SafetyScoresGetDriverSafetyScoreTripsServiceUnavailableErrorResponseBody": ".types",
    "SafetyScoresGetDriverSafetyScoreTripsTooManyRequestsErrorResponseBody": ".types",
    "SafetyScoresGetDriverSafetyScoreTripsUnauthorizedErrorResponseBody": ".types",
    "SafetyScoresGetDriverSafetyScoresBadGatewayErrorResponseBody": ".types",
    "SafetyScoresGetDriverSafetyScoresGatewayTimeoutErrorResponseBody": ".types",
    "SafetyScoresGetDriverSafetyScoresInternalServerErrorResponseBody": ".types",
    "SafetyScoresGetDriverSafetyScoresMethodNotAllowedErrorResponseBody": ".types",
    "SafetyScoresGetDriverSafetyScoresNotFoundErrorResponseBody": ".types",
    "SafetyScoresGetDriverSafetyScoresNotImplementedErrorResponseBody": ".types",
    "SafetyScoresGetDriverSafetyScoresResponseBody": ".types",
    "SafetyScoresGetDriverSafetyScoresServiceUnavailableErrorResponseBody": ".types",
    "SafetyScoresGetDriverSafetyScoresTooManyRequestsErrorResponseBody": ".types",
    "SafetyScoresGetDriverSafetyScoresUnauthorizedErrorResponseBody": ".types",
    "SafetyScoresGetTagGroupSafetyScoresBadGatewayErrorResponseBody": ".types",
    "SafetyScoresGetTagGroupSafetyScoresGatewayTimeoutErrorResponseBody": ".types",
    "SafetyScoresGetTagGroupSafetyScoresInternalServerErrorResponseBody": ".types",
    "SafetyScoresGetTagGroupSafetyScoresMethodNotAllowedErrorResponseBody": ".types",
    "SafetyScoresGetTagGroupSafetyScoresNotFoundErrorResponseBody": ".types",
    "SafetyScoresGetTagGroupSafetyScoresNotImplementedErrorResponseBody": ".types",
    "SafetyScoresGetTagGroupSafetyScoresResponseBody": ".types",
    "SafetyScoresGetTagGroupSafetyScoresServiceUnavailableErrorResponseBody": ".types",
    "SafetyScoresGetTagGroupSafetyScoresTooManyRequestsErrorResponseBody": ".types",
    "SafetyScoresGetTagGroupSafetyScoresUnauthorizedErrorResponseBody": ".types",
    "SafetyScoresGetTagSafetyScoresBadGatewayErrorResponseBody": ".types",
    "SafetyScoresGetTagSafetyScoresGatewayTimeoutErrorResponseBody": ".types",
    "SafetyScoresGetTagSafetyScoresInternalServerErrorResponseBody": ".types",
    "SafetyScoresGetTagSafetyScoresMethodNotAllowedErrorResponseBody": ".types",
    "SafetyScoresGetTagSafetyScoresNotFoundErrorResponseBody": ".types",
    "SafetyScoresGetTagSafetyScoresNotImplementedErrorResponseBody": ".types",
    "SafetyScoresGetTagSafetyScoresResponseBody": ".types",
    "SafetyScoresGetTagSafetyScoresServiceUnavailableErrorResponseBody": ".types",
    "SafetyScoresGetTagSafetyScoresTooManyRequestsErrorResponseBody": ".types",
    "SafetyScoresGetTagSafetyScoresUnauthorizedErrorResponseBody": ".types",
    "SafetyScoresGetVehicleSafetyScoreTripsBadGatewayErrorResponseBody": ".types",
    "SafetyScoresGetVehicleSafetyScoreTripsGatewayTimeoutErrorResponseBody": ".types",
    "SafetyScoresGetVehicleSafetyScoreTripsInternalServerErrorResponseBody": ".types",
    "SafetyScoresGetVehicleSafetyScoreTripsMethodNotAllowedErrorResponseBody": ".types",
    "SafetyScoresGetVehicleSafetyScoreTripsNotFoundErrorResponseBody": ".types",
    "SafetyScoresGetVehicleSafetyScoreTripsNotImplementedErrorResponseBody": ".types",
    "SafetyScoresGetVehicleSafetyScoreTripsResponseBody": ".types",
    "SafetyScoresGetVehicleSafetyScoreTripsServiceUnavailableErrorResponseBody": ".types",
    "SafetyScoresGetVehicleSafetyScoreTripsTooManyRequestsErrorResponseBody": ".types",
    "SafetyScoresGetVehicleSafetyScoreTripsUnauthorizedErrorResponseBody": ".types",
    "SafetyScoresGetVehicleSafetyScoresBadGatewayErrorResponseBody": ".types",
    "SafetyScoresGetVehicleSafetyScoresGatewayTimeoutErrorResponseBody": ".types",
    "SafetyScoresGetVehicleSafetyScoresInternalServerErrorResponseBody": ".types",
    "SafetyScoresGetVehicleSafetyScoresMethodNotAllowedErrorResponseBody": ".types",
    "SafetyScoresGetVehicleSafetyScoresNotFoundErrorResponseBody": ".types",
    "SafetyScoresGetVehicleSafetyScoresNotImplementedErrorResponseBody": ".types",
    "SafetyScoresGetVehicleSafetyScoresResponseBody": ".types",
    "SafetyScoresGetVehicleSafetyScoresServiceUnavailableErrorResponseBody": ".types",
    "SafetyScoresGetVehicleSafetyScoresTooManyRequestsErrorResponseBody": ".types",
    "SafetyScoresGetVehicleSafetyScoresUnauthorizedErrorResponseBody": ".types",
    "SafetySettingsGetSafetySettingsBadGatewayErrorResponseBody": ".types",
    "SafetySettingsGetSafetySettingsGatewayTimeoutErrorResponseBody": ".types",
    "SafetySettingsGetSafetySettingsInternalServerErrorResponseBody": ".types",
    "SafetySettingsGetSafetySettingsMethodNotAllowedErrorResponseBody": ".types",
    "SafetySettingsGetSafetySettingsNotFoundErrorResponseBody": ".types",
    "SafetySettingsGetSafetySettingsNotImplementedErrorResponseBody": ".types",
    "SafetySettingsGetSafetySettingsResponseBody": ".types",
    "SafetySettingsGetSafetySettingsServiceUnavailableErrorResponseBody": ".types",
    "SafetySettingsGetSafetySettingsTooManyRequestsErrorResponseBody": ".types",
    "SafetySettingsGetSafetySettingsUnauthorizedErrorResponseBody": ".types",
    "SafetySettingsObjectResponseBody": ".types",
    "SafetySettingsObjectResponseBodyDefaultVehicleType": ".types",
    "Samsara": ".client",
    "SamsaraEnvironment": ".environment",
    "ScannedDocumentValueObjectRequestBody": ".types",
    "ScannedDocumentValueObjectResponseBody": ".types",
    "ScheduledMaintenanceByEngineHoursDetailsObjectRequestBody": ".types",
    "ScheduledMaintenanceByEngineHoursDetailsObjectResponseBody": ".types",
    "ScheduledMaintenanceByEngineHoursResponseBody": ".types",
    "ScheduledMaintenanceDataResponseBody": ".types",
    "ScheduledMaintenanceOdometerDataResponseBody": ".types",
    "ScheduledMaintenanceOdometerTriggerDetailsObjectRequestBody": ".types",
    "ScheduledMaintenanceOdometerTriggerDetailsObjectResponseBody": ".types",
    "ScheduledMaintenanceTriggerDetailsObjectRequestBody": ".types",
    "ScheduledMaintenanceTriggerDetailsObjectResponseBody": ".types",
    "ScopeObjectRequestBody": ".types",
    "ScopeObjectResponseBody": ".types",
    "Sensor": ".types",
    "SensorResponseBody": ".types",
    "Serial": ".types",
    "ServiceTaskDefinitionObjectResponseBody": ".types",
    "ServiceTaskInstanceInputObjectRequestBody": ".types",
    "ServiceTaskInstanceInputObjectRequestBodyStatus": ".types",
    "ServiceTaskInstanceObjectResponseBody": ".types",
    "ServiceTaskInstanceObjectResponseBodyStatus": ".types",
    "ServiceUnavailableError": ".errors",
    "ServiceWindowObjectResponseBody": ".types",
    "SettingsComplianceResponseObjectResponseBody": ".types",
    "SettingsGetComplianceSettingsBadGatewayErrorResponseBody": ".types",
    "SettingsGetComplianceSettingsGatewayTimeoutErrorResponseBody": ".types",
    "SettingsGetComplianceSettingsInternalServerErrorResponseBody": ".types",
    "SettingsGetComplianceSettingsMethodNotAllowedErrorResponseBody": ".types",
    "SettingsGetComplianceSettingsNotFoundErrorResponseBody": ".types",
    "SettingsGetComplianceSettingsNotImplementedErrorResponseBody": ".types",
    "SettingsGetComplianceSettingsResponseBody": ".types",
    "SettingsGetComplianceSettingsServiceUnavailableErrorResponseBody": ".types",
    "SettingsGetComplianceSettingsTooManyRequestsErrorResponseBody": ".types",
    "SettingsGetComplianceSettingsUnauthorizedErrorResponseBody": ".types",
    "SettingsGetDriverAppSettingsBadGatewayErrorResponseBody": ".types",
    "SettingsGetDriverAppSettingsGatewayTimeoutErrorResponseBody": ".types",
    "SettingsGetDriverAppSettingsInternalServerErrorResponseBody": ".types",
    "SettingsGetDriverAppSettingsMethodNotAllowedErrorResponseBody": ".types",
    "SettingsGetDriverAppSettingsNotFoundErrorResponseBody": ".types",
    "SettingsGetDriverAppSettingsNotImplementedErrorResponseBody": ".types",
    "SettingsGetDriverAppSettingsResponseBody": ".types",
    "SettingsGetDriverAppSettingsServiceUnavailableErrorResponseBody": ".types",
    "SettingsGetDriverAppSettingsTooManyRequestsErrorResponseBody": ".types",
    "SettingsGetDriverAppSettingsUnauthorizedErrorResponseBody": ".types",
    "SettingsPatchComplianceSettingsBadGatewayErrorResponseBody": ".types",
    "SettingsPatchComplianceSettingsGatewayTimeoutErrorResponseBody": ".types",
    "SettingsPatchComplianceSettingsInternalServerErrorResponseBody": ".types",
    "SettingsPatchComplianceSettingsMethodNotAllowedErrorResponseBody": ".types",
    "SettingsPatchComplianceSettingsNotFoundErrorResponseBody": ".types",
    "SettingsPatchComplianceSettingsNotImplementedErrorResponseBody": ".types",
    "SettingsPatchComplianceSettingsResponseBody": ".types",
    "SettingsPatchComplianceSettingsServiceUnavailableErrorResponseBody": ".types",
    "SettingsPatchComplianceSettingsTooManyRequestsErrorResponseBody": ".types",
    "SettingsPatchComplianceSettingsUnauthorizedErrorResponseBody": ".types",
    "SettingsPatchDriverAppSettingsBadGatewayErrorResponseBody": ".types",
    "SettingsPatchDriverAppSettingsGatewayTimeoutErrorResponseBody": ".types",
    "SettingsPatchDriverAppSettingsInternalServerErrorResponseBody": ".types",
    "SettingsPatchDriverAppSettingsMethodNotAllowedErrorResponseBody": ".types",
    "SettingsPatchDriverAppSettingsNotFoundErrorResponseBody": ".types",
    "SettingsPatchDriverAppSettingsNotImplementedErrorResponseBody": ".types",
    "SettingsPatchDriverAppSettingsResponseBody": ".types",
    "SettingsPatchDriverAppSettingsServiceUnavailableErrorResponseBody": ".types",
    "SettingsPatchDriverAppSettingsTooManyRequestsErrorResponseBody": ".types",
    "SettingsPatchDriverAppSettingsUnauthorizedErrorResponseBody": ".types",
    "SettingsResponseBody": ".types",
    "SevereSpeedingStartedObjectResponseBody": ".types",
    "SevereSpeedingStartedResponseObjectResponseBody": ".types",
    "SignatoryUserObjectResponseBody": ".types",
    "SignatureFieldTypeMetaDataObjectResponseBody": ".types",
    "SignatureValueObjectRequestBody": ".types",
    "SignatureValueObjectResponseBody": ".types",
    "SingleApprovalRequirementsObjectResponseBody": ".types",
    "SingleDriverEfficiencyByDriverDataObjectResponseBody": ".types",
    "SingleDriverEfficiencyByVehicleDataObjectResponseBody": ".types",
    "SingleUseLocationObjectResponseBody": ".types",
    "SiteGatewayDisconnectedResponseBody": ".types",
    "SkillObjectResponseBody": ".types",
    "SpecificVehicleFaultCodeObjectRequestBody": ".types",
    "SpecificVehicleFaultCodeObjectRequestBodyType": ".types",
    "SpecificVehicleFaultCodeObjectResponseBody": ".types",
    "SpecificVehicleFaultCodeObjectResponseBodyType": ".types",
    "SpeedDataResponseBody": ".types",
    "SpeedDataResponseBodyOperation": ".types",
    "SpeedResponseResponseBody": ".types",
    "SpeedTriggerDetailsObjectRequestBody": ".types",
    "SpeedTriggerDetailsObjectRequestBodyOperation": ".types",
    "SpeedTriggerDetailsObjectResponseBody": ".types",
    "SpeedTriggerDetailsObjectResponseBodyOperation": ".types",
    "SpeedingIntervalLocationResponseResponseBody": ".types",
    "SpeedingIntervalResponseBody": ".types",
    "SpeedingIntervalResponseBodySeverityLevel": ".types",
    "SpeedingIntervalsGetSpeedingIntervalsBadGatewayErrorResponseBody": ".types",
    "SpeedingIntervalsGetSpeedingIntervalsGatewayTimeoutErrorResponseBody": ".types",
    "SpeedingIntervalsGetSpeedingIntervalsInternalServerErrorResponseBody": ".types",
    "SpeedingIntervalsGetSpeedingIntervalsMethodNotAllowedErrorResponseBody": ".types",
    "SpeedingIntervalsGetSpeedingIntervalsNotFoundErrorResponseBody": ".types",
    "SpeedingIntervalsGetSpeedingIntervalsNotImplementedErrorResponseBody": ".types",
    "SpeedingIntervalsGetSpeedingIntervalsResponseBody": ".types",
    "SpeedingIntervalsGetSpeedingIntervalsServiceUnavailableErrorResponseBody": ".types",
    "SpeedingIntervalsGetSpeedingIntervalsTooManyRequestsErrorResponseBody": ".types",
    "SpeedingIntervalsGetSpeedingIntervalsUnauthorizedErrorResponseBody": ".types",
    "SpeedingSettingsObjectResponseBody": ".types",
    "SpeedingSettingsObjectResponseBodyUnit": ".types",
    "SpeedingSeverityLevelResponseBody": ".types",
    "SpeedingSeverityLevelResponseBodySeverityLevel": ".types",
    "StartFunctionRunResponseBodyResponseBody": ".types",
    "StopEtaUpdatedEventDetailsResponseBody": ".types",
    "StopTaskCompletedEventDetailsResponseBody": ".types",
    "StopTaskCompletedEventDetailsResponseBodyTaskType": ".types",
    "StopTaskSkippedEventDetailsResponseBody": ".types",
    "StopTaskSkippedEventDetailsResponseBodyTaskType": ".types",
    "StreamWorkOrdersRequestWorkOrderStatusesItem": ".work_orders",
    "StringDataPoint": ".types",
    "SuddenFuelLevelDropResponseBody": ".types",
    "SuddenFuelLevelDropTriggerDetailsObjectRequestBody": ".types",
    "SuddenFuelLevelDropTriggerDetailsObjectResponseBody": ".types",
    "SuddenFuelLevelRiseResponseBody": ".types",
    "SuddenFuelLevelRiseTriggerDetailsObjectRequestBody": ".types",
    "SuddenFuelLevelRiseTriggerDetailsObjectResponseBody": ".types",
    "TachographActivity": ".types",
    "TachographActivityList": ".types",
    "TachographActivityListWrapper": ".types",
    "TachographActivityState": ".types",
    "TachographDriverFile": ".types",
    "TachographDriverFileData": ".types",
    "TachographDriverFileList": ".types",
    "TachographDriverFileListWrapper": ".types",
    "TachographDriverFilesResponse": ".types",
    "TachographVehicleFile": ".types",
    "TachographVehicleFileData": ".types",
    "TachographVehicleFileList": ".types",
    "TachographVehicleFileListWrapper": ".types",
    "TachographVehicleFilesResponse": ".types",
    "Tag": ".types",
    "TagAllOf": ".types",
    "TagAllOfExternalIds": ".types",
    "TagGroupSafetyScoreResponseBody": ".types",
    "TagId": ".types",
    "TagIds": ".types",
    "TagName": ".types",
    "TagResponse": ".types",
    "TagSafetyScoreResponseBody": ".types",
    "TagTinyResponse": ".types",
    "TaggedObject": ".types",
    "TaggedObjectId": ".types",
    "TaggedObjectName": ".types",
    "TamperingDetectedResponseBody": ".types",
    "Time": ".types",
    "TimeRangeObjectRequestBody": ".types",
    "TimeRangeObjectRequestBodyDaysOfWeekItem": ".types",
    "TimeRangeObjectResponseBody": ".types",
    "TimeRangeObjectResponseBodyDaysOfWeekItem": ".types",
    "TinyAssetObjectRequestBody": ".types",
    "TinyAssetObjectRequestBodyAssetType": ".types",
    "TinyAssetObjectResponseBody": ".types",
    "TinyAssetObjectResponseBodyAssetType": ".types",
    "TinyDriverObjectRequestBody": ".types",
    "TinyDriverObjectResponseBody": ".types",
    "TinyTag": ".types",
    "TinyWidgetObjectRequestBody": ".types",
    "TinyWidgetObjectResponseBody": ".types",
    "TireFaultCodeDetailsObjectRequestBody": ".types",
    "TireFaultCodeDetailsObjectRequestBodyManufacturer": ".types",
    "TireFaultCodeDetailsObjectRequestBodySpecificTireFaultCodesItem": ".types",
    "TireFaultCodeDetailsObjectResponseBody": ".types",
    "TireFaultCodeDetailsObjectResponseBodyManufacturer": ".types",
    "TireFaultCodeDetailsObjectResponseBodySpecificTireFaultCodesItem": ".types",
    "TireFaultsResponseBody": ".types",
    "TooManyRequestsError": ".errors",
    "TotalBrakeEventCount": ".types",
    "TrailerAssignmentsCreateDriverTrailerAssignmentBadGatewayErrorResponseBody": ".types",
    "TrailerAssignmentsCreateDriverTrailerAssignmentGatewayTimeoutErrorResponseBody": ".types",
    "TrailerAssignmentsCreateDriverTrailerAssignmentInternalServerErrorResponseBody": ".types",
    "TrailerAssignmentsCreateDriverTrailerAssignmentMethodNotAllowedErrorResponseBody": ".types",
    "TrailerAssignmentsCreateDriverTrailerAssignmentNotFoundErrorResponseBody": ".types",
    "TrailerAssignmentsCreateDriverTrailerAssignmentNotImplementedErrorResponseBody": ".types",
    "TrailerAssignmentsCreateDriverTrailerAssignmentResponseBody": ".types",
    "TrailerAssignmentsCreateDriverTrailerAssignmentServiceUnavailableErrorResponseBody": ".types",
    "TrailerAssignmentsCreateDriverTrailerAssignmentTooManyRequestsErrorResponseBody": ".types",
    "TrailerAssignmentsCreateDriverTrailerAssignmentUnauthorizedErrorResponseBody": ".types",
    "TrailerAssignmentsGetDriverTrailerAssignmentsBadGatewayErrorResponseBody": ".types",
    "TrailerAssignmentsGetDriverTrailerAssignmentsGatewayTimeoutErrorResponseBody": ".types",
    "TrailerAssignmentsGetDriverTrailerAssignmentsInternalServerErrorResponseBody": ".types",
    "TrailerAssignmentsGetDriverTrailerAssignmentsMethodNotAllowedErrorResponseBody": ".types",
    "TrailerAssignmentsGetDriverTrailerAssignmentsNotFoundErrorResponseBody": ".types",
    "TrailerAssignmentsGetDriverTrailerAssignmentsNotImplementedErrorResponseBody": ".types",
    "TrailerAssignmentsGetDriverTrailerAssignmentsResponseBody": ".types",
    "TrailerAssignmentsGetDriverTrailerAssignmentsServiceUnavailableErrorResponseBody": ".types",
    "TrailerAssignmentsGetDriverTrailerAssignmentsTooManyRequestsErrorResponseBody": ".types",
    "TrailerAssignmentsGetDriverTrailerAssignmentsUnauthorizedErrorResponseBody": ".types",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentBadGatewayErrorResponseBody": ".types",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentGatewayTimeoutErrorResponseBody": ".types",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentInternalServerErrorResponseBody": ".types",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentMethodNotAllowedErrorResponseBody": ".types",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentNotFoundErrorResponseBody": ".types",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentNotImplementedErrorResponseBody": ".types",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentResponseBody": ".types",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentServiceUnavailableErrorResponseBody": ".types",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentTooManyRequestsErrorResponseBody": ".types",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentUnauthorizedErrorResponseBody": ".types",
    "TrailerDvirObjectResponseBody": ".types",
    "TrailerGoaGatewayTinyResponseResponseBody": ".types",
    "TrailerGoaGatewayTinyResponseResponseBodyModel": ".types",
    "TrailerObjectResponseBody": ".types",
    "TrailerResponseObjectResponseBody": ".types",
    "TrailerStatDecorationResponseBody": ".types",
    "TrailerStatGpsOdometerMetersTypeResponseBody": ".types",
    "TrailerStatGpsOdometerMetersWithDecorationsTypeResponseBody": ".types",
    "TrailerStatGpsTypeResponseBody": ".types",
    "TrailerStatGpsWithDecorationsTypeResponseBody": ".types",
    "TrailerStatReeferAlarmResponseBody": ".types",
    "TrailerStatReeferAlarmTypeResponseBody": ".types",
    "TrailerStatReeferAlarmWithDecorationsTypeResponseBody": ".types",
    "TrailerStatReeferAmbientAirTemperatureMilliCTypeResponseBody": ".types",
    "TrailerStatReeferAmbientAirTemperatureWithDecorationsTypeResponseBody": ".types",
    "TrailerStatReeferDoorStateZone1TypeResponseBody": ".types",
    "TrailerStatReeferDoorStateZone1TypeResponseBodyValue": ".types",
    "TrailerStatReeferDoorStateZone1WithDecorationsTypeResponseBody": ".types",
    "TrailerStatReeferDoorStateZone1WithDecorationsTypeResponseBodyValue": ".types",
    "TrailerStatReeferDoorStateZone2TypeResponseBody": ".types",
    "TrailerStatReeferDoorStateZone2TypeResponseBodyValue": ".types",
    "TrailerStatReeferDoorStateZone2WithDecorationsTypeResponseBody": ".types",
    "TrailerStatReeferDoorStateZone2WithDecorationsTypeResponseBodyValue": ".types",
    "TrailerStatReeferDoorStateZone3TypeResponseBody": ".types",
    "TrailerStatReeferDoorStateZone3TypeResponseBodyValue": ".types",
    "TrailerStatReeferDoorStateZone3WithDecorationsTypeResponseBody": ".types",
    "TrailerStatReeferDoorStateZone3WithDecorationsTypeResponseBodyValue": ".types",
    "TrailerStatReeferFuelPercentTypeResponseBody": ".types",
    "TrailerStatReeferFuelPercentWithDecorationsTypeResponseBody": ".types",
    "TrailerStatReeferObdEngineSecondsTypeResponseBody": ".types",
    "TrailerStatReeferObdEngineSecondsWithDecorationsTypeResponseBody": ".types",
    "TrailerStatReeferReturnAirTemperatureMilliCZone1TypeResponseBody": ".types",
    "TrailerStatReeferReturnAirTemperatureMilliCZone1WithDecorationsTypeResponseBody": ".types",
    "TrailerStatReeferReturnAirTemperatureMilliCZone2TypeResponseBody": ".types",
    "TrailerStatReeferReturnAirTemperatureMilliCZone2WithDecorationsTypeResponseBody": ".types",
    "TrailerStatReeferReturnAirTemperatureMilliCZone3TypeResponseBody": ".types",
    "TrailerStatReeferReturnAirTemperatureMilliCZone3WithDecorationsTypeResponseBody": ".types",
    "TrailerStatReeferRunModeTypeResponseBody": ".types",
    "TrailerStatReeferRunModeWithDecorationsTypeResponseBody": ".types",
    "TrailerStatReeferSetPointTemperatureMilliCZone1TypeResponseBody": ".types",
    "TrailerStatReeferSetPointTemperatureMilliCZone1WithDecorationsTypeResponseBody": ".types",
    "TrailerStatReeferSetPointTemperatureMilliCZone2TypeResponseBody": ".types",
    "TrailerStatReeferSetPointTemperatureMilliCZone2WithDecorationsTypeResponseBody": ".types",
    "TrailerStatReeferSetPointTemperatureMilliCZone3TypeResponseBody": ".types",
    "TrailerStatReeferSetPointTemperatureMilliCZone3WithDecorationsTypeResponseBody": ".types",
    "TrailerStatReeferStateTypeResponseBody": ".types",
    "TrailerStatReeferStateWithDecorationsTypeResponseBody": ".types",
    "TrailerStatReeferStateZone1TypeResponseBody": ".types",
    "TrailerStatReeferStateZone1WithDecorationsTypeResponseBody": ".types",
    "TrailerStatReeferStateZone2TypeResponseBody": ".types",
    "TrailerStatReeferStateZone2WithDecorationsTypeResponseBody": ".types",
    "TrailerStatReeferStateZone3TypeResponseBody": ".types",
    "TrailerStatReeferStateZone3WithDecorationsTypeResponseBody": ".types",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone1TypeResponseBody": ".types",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone1WithDecorationsTypeResponseBody": ".types",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone2TypeResponseBody": ".types",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone2WithDecorationsTypeResponseBody": ".types",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone3TypeResponseBody": ".types",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone3WithDecorationsTypeResponseBody": ".types",
    "TrailerStatsGetTrailerStatsFeedBadGatewayErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsFeedGatewayTimeoutErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsFeedInternalServerErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsFeedMethodNotAllowedErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsFeedNotFoundErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsFeedNotImplementedErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsFeedResponseBody": ".types",
    "TrailerStatsGetTrailerStatsFeedServiceUnavailableErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsFeedTooManyRequestsErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsFeedUnauthorizedErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsHistoryBadGatewayErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsHistoryGatewayTimeoutErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsHistoryInternalServerErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsHistoryMethodNotAllowedErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsHistoryNotFoundErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsHistoryNotImplementedErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsHistoryResponseBody": ".types",
    "TrailerStatsGetTrailerStatsHistoryServiceUnavailableErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsHistoryTooManyRequestsErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsHistoryUnauthorizedErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsSnapshotBadGatewayErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsSnapshotGatewayTimeoutErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsSnapshotInternalServerErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsSnapshotMethodNotAllowedErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsSnapshotNotFoundErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsSnapshotNotImplementedErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsSnapshotResponseBody": ".types",
    "TrailerStatsGetTrailerStatsSnapshotServiceUnavailableErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsSnapshotTooManyRequestsErrorResponseBody": ".types",
    "TrailerStatsGetTrailerStatsSnapshotUnauthorizedErrorResponseBody": ".types",
    "TrailerStatsObjectResponseBody": ".types",
    "TrailerStatsSnapshotObjectResponseBody": ".types",
    "TrailerTinyResponse": ".types",
    "TrailerWithAttributesResponseObjectResponseBody": ".types",
    "TrailersCreateTrailerBadGatewayErrorResponseBody": ".types",
    "TrailersCreateTrailerGatewayTimeoutErrorResponseBody": ".types",
    "TrailersCreateTrailerInternalServerErrorResponseBody": ".types",
    "TrailersCreateTrailerMethodNotAllowedErrorResponseBody": ".types",
    "TrailersCreateTrailerNotFoundErrorResponseBody": ".types",
    "TrailersCreateTrailerNotImplementedErrorResponseBody": ".types",
    "TrailersCreateTrailerResponseBody": ".types",
    "TrailersCreateTrailerServiceUnavailableErrorResponseBody": ".types",
    "TrailersCreateTrailerTooManyRequestsErrorResponseBody": ".types",
    "TrailersCreateTrailerUnauthorizedErrorResponseBody": ".types",
    "TrailersDeleteTrailerBadGatewayErrorResponseBody": ".types",
    "TrailersDeleteTrailerGatewayTimeoutErrorResponseBody": ".types",
    "TrailersDeleteTrailerInternalServerErrorResponseBody": ".types",
    "TrailersDeleteTrailerMethodNotAllowedErrorResponseBody": ".types",
    "TrailersDeleteTrailerNotFoundErrorResponseBody": ".types",
    "TrailersDeleteTrailerNotImplementedErrorResponseBody": ".types",
    "TrailersDeleteTrailerServiceUnavailableErrorResponseBody": ".types",
    "TrailersDeleteTrailerTooManyRequestsErrorResponseBody": ".types",
    "TrailersDeleteTrailerUnauthorizedErrorResponseBody": ".types",
    "TrailersGetTrailerBadGatewayErrorResponseBody": ".types",
    "TrailersGetTrailerGatewayTimeoutErrorResponseBody": ".types",
    "TrailersGetTrailerInternalServerErrorResponseBody": ".types",
    "TrailersGetTrailerMethodNotAllowedErrorResponseBody": ".types",
    "TrailersGetTrailerNotFoundErrorResponseBody": ".types",
    "TrailersGetTrailerNotImplementedErrorResponseBody": ".types",
    "TrailersGetTrailerResponseBody": ".types",
    "TrailersGetTrailerServiceUnavailableErrorResponseBody": ".types",
    "TrailersGetTrailerTooManyRequestsErrorResponseBody": ".types",
    "TrailersGetTrailerUnauthorizedErrorResponseBody": ".types",
    "TrailersListTrailersBadGatewayErrorResponseBody": ".types",
    "TrailersListTrailersGatewayTimeoutErrorResponseBody": ".types",
    "TrailersListTrailersInternalServerErrorResponseBody": ".types",
    "TrailersListTrailersMethodNotAllowedErrorResponseBody": ".types",
    "TrailersListTrailersNotFoundErrorResponseBody": ".types",
    "TrailersListTrailersNotImplementedErrorResponseBody": ".types",
    "TrailersListTrailersResponseBody": ".types",
    "TrailersListTrailersServiceUnavailableErrorResponseBody": ".types",
    "TrailersListTrailersTooManyRequestsErrorResponseBody": ".types",
    "TrailersListTrailersUnauthorizedErrorResponseBody": ".types",
    "TrailersUpdateTrailerBadGatewayErrorResponseBody": ".types",
    "TrailersUpdateTrailerGatewayTimeoutErrorResponseBody": ".types",
    "TrailersUpdateTrailerInternalServerErrorResponseBody": ".types",
    "TrailersUpdateTrailerMethodNotAllowedErrorResponseBody": ".types",
    "TrailersUpdateTrailerNotFoundErrorResponseBody": ".types",
    "TrailersUpdateTrailerNotImplementedErrorResponseBody": ".types",
    "TrailersUpdateTrailerResponseBody": ".types",
    "TrailersUpdateTrailerServiceUnavailableErrorResponseBody": ".types",
    "TrailersUpdateTrailerTooManyRequestsErrorResponseBody": ".types",
    "TrailersUpdateTrailerUnauthorizedErrorResponseBody": ".types",
    "TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectRequestBody": ".types",
    "TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectRequestBodyAssignmentGroupType": ".types",
    "TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectResponseBody": ".types",
    "TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectResponseBodyAssignmentGroupType": ".types",
    "TrainingAssignmentNearDueDateTriggerDetailsObjectRequestBody": ".types",
    "TrainingAssignmentNearDueDateTriggerDetailsObjectRequestBodyConditionUnits": ".types",
    "TrainingAssignmentNearDueDateTriggerDetailsObjectResponseBody": ".types",
    "TrainingAssignmentNearDueDateTriggerDetailsObjectResponseBodyConditionUnits": ".types",
    "TrainingAssignmentPostResponseObjectResponseBody": ".types",
    "TrainingAssignmentResponseObjectResponseBody": ".types",
    "TrainingAssignmentResponseObjectResponseBodyStatus": ".types",
    "TrainingAssignmentsDeleteTrainingAssignmentsBadGatewayErrorResponseBody": ".types",
    "TrainingAssignmentsDeleteTrainingAssignmentsGatewayTimeoutErrorResponseBody": ".types",
    "TrainingAssignmentsDeleteTrainingAssignmentsInternalServerErrorResponseBody": ".types",
    "TrainingAssignmentsDeleteTrainingAssignmentsMethodNotAllowedErrorResponseBody": ".types",
    "TrainingAssignmentsDeleteTrainingAssignmentsNotFoundErrorResponseBody": ".types",
    "TrainingAssignmentsDeleteTrainingAssignmentsNotImplementedErrorResponseBody": ".types",
    "TrainingAssignmentsDeleteTrainingAssignmentsServiceUnavailableErrorResponseBody": ".types",
    "TrainingAssignmentsDeleteTrainingAssignmentsTooManyRequestsErrorResponseBody": ".types",
    "TrainingAssignmentsDeleteTrainingAssignmentsUnauthorizedErrorResponseBody": ".types",
    "TrainingAssignmentsGetTrainingAssignmentsStreamBadGatewayErrorResponseBody": ".types",
    "TrainingAssignmentsGetTrainingAssignmentsStreamGatewayTimeoutErrorResponseBody": ".types",
    "TrainingAssignmentsGetTrainingAssignmentsStreamInternalServerErrorResponseBody": ".types",
    "TrainingAssignmentsGetTrainingAssignmentsStreamMethodNotAllowedErrorResponseBody": ".types",
    "TrainingAssignmentsGetTrainingAssignmentsStreamNotFoundErrorResponseBody": ".types",
    "TrainingAssignmentsGetTrainingAssignmentsStreamNotImplementedErrorResponseBody": ".types",
    "TrainingAssignmentsGetTrainingAssignmentsStreamResponseBody": ".types",
    "TrainingAssignmentsGetTrainingAssignmentsStreamServiceUnavailableErrorResponseBody": ".types",
    "TrainingAssignmentsGetTrainingAssignmentsStreamTooManyRequestsErrorResponseBody": ".types",
    "TrainingAssignmentsGetTrainingAssignmentsStreamUnauthorizedErrorResponseBody": ".types",
    "TrainingAssignmentsPatchTrainingAssignmentsBadGatewayErrorResponseBody": ".types",
    "TrainingAssignmentsPatchTrainingAssignmentsGatewayTimeoutErrorResponseBody": ".types",
    "TrainingAssignmentsPatchTrainingAssignmentsInternalServerErrorResponseBody": ".types",
    "TrainingAssignmentsPatchTrainingAssignmentsMethodNotAllowedErrorResponseBody": ".types",
    "TrainingAssignmentsPatchTrainingAssignmentsNotFoundErrorResponseBody": ".types",
    "TrainingAssignmentsPatchTrainingAssignmentsNotImplementedErrorResponseBody": ".types",
    "TrainingAssignmentsPatchTrainingAssignmentsResponseBody": ".types",
    "TrainingAssignmentsPatchTrainingAssignmentsServiceUnavailableErrorResponseBody": ".types",
    "TrainingAssignmentsPatchTrainingAssignmentsTooManyRequestsErrorResponseBody": ".types",
    "TrainingAssignmentsPatchTrainingAssignmentsUnauthorizedErrorResponseBody": ".types",
    "TrainingAssignmentsPostTrainingAssignmentsBadGatewayErrorResponseBody": ".types",
    "TrainingAssignmentsPostTrainingAssignmentsGatewayTimeoutErrorResponseBody": ".types",
    "TrainingAssignmentsPostTrainingAssignmentsInternalServerErrorResponseBody": ".types",
    "TrainingAssignmentsPostTrainingAssignmentsMethodNotAllowedErrorResponseBody": ".types",
    "TrainingAssignmentsPostTrainingAssignmentsNotFoundErrorResponseBody": ".types",
    "TrainingAssignmentsPostTrainingAssignmentsNotImplementedErrorResponseBody": ".types",
    "TrainingAssignmentsPostTrainingAssignmentsResponseBody": ".types",
    "TrainingAssignmentsPostTrainingAssignmentsServiceUnavailableErrorResponseBody": ".types",
    "TrainingAssignmentsPostTrainingAssignmentsTooManyRequestsErrorResponseBody": ".types",
    "TrainingAssignmentsPostTrainingAssignmentsUnauthorizedErrorResponseBody": ".types",
    "TrainingCategoryObjectResponseBody": ".types",
    "TrainingCourseLabelObjectResponseBody": ".types",
    "TrainingCourseObjectResponseBody": ".types",
    "TrainingCourseResponseObjectResponseBody": ".types",
    "TrainingCourseResponseObjectResponseBodyStatus": ".types",
    "TrainingCoursesGetTrainingCoursesBadGatewayErrorResponseBody": ".types",
    "TrainingCoursesGetTrainingCoursesGatewayTimeoutErrorResponseBody": ".types",
    "TrainingCoursesGetTrainingCoursesInternalServerErrorResponseBody": ".types",
    "TrainingCoursesGetTrainingCoursesMethodNotAllowedErrorResponseBody": ".types",
    "TrainingCoursesGetTrainingCoursesNotFoundErrorResponseBody": ".types",
    "TrainingCoursesGetTrainingCoursesNotImplementedErrorResponseBody": ".types",
    "TrainingCoursesGetTrainingCoursesResponseBody": ".types",
    "TrainingCoursesGetTrainingCoursesServiceUnavailableErrorResponseBody": ".types",
    "TrainingCoursesGetTrainingCoursesTooManyRequestsErrorResponseBody": ".types",
    "TrainingCoursesGetTrainingCoursesUnauthorizedErrorResponseBody": ".types",
    "TrainingLearnerObjectResponseBody": ".types",
    "TrainingLearnerObjectResponseBodyType": ".types",
    "TriggerParamsObjectRequestBody": ".types",
    "TriggerParamsObjectResponseBody": ".types",
    "TripAssetResponseBody": ".types",
    "TripAssetResponseBodyType": ".types",
    "TripResponseBody": ".types",
    "TripResponseBodyCompletionStatus": ".types",
    "TripSpeedingIntervalsResponseBody": ".types",
    "TripsBreakdownResponseBody": ".types",
    "TripsGetTripsBadGatewayErrorResponseBody": ".types",
    "TripsGetTripsGatewayTimeoutErrorResponseBody": ".types",
    "TripsGetTripsInternalServerErrorResponseBody": ".types",
    "TripsGetTripsMethodNotAllowedErrorResponseBody": ".types",
    "TripsGetTripsNotFoundErrorResponseBody": ".types",
    "TripsGetTripsNotImplementedErrorResponseBody": ".types",
    "TripsGetTripsResponseBody": ".types",
    "TripsGetTripsServiceUnavailableErrorResponseBody": ".types",
    "TripsGetTripsTooManyRequestsErrorResponseBody": ".types",
    "TripsGetTripsUnauthorizedErrorResponseBody": ".types",
    "UnassignedDrivingDataResponseBody": ".types",
    "UnassignedDrivingTriggerDetailsObjectRequestBody": ".types",
    "UnassignedDrivingTriggerDetailsObjectResponseBody": ".types",
    "UnauthorizedError": ".errors",
    "UpdateAddressRequestAddressTypesItem": ".addresses",
    "UpdateAddressRequestGeofence": ".types",
    "UpdateAttributeRequestAttributeType": ".attributes",
    "UpdateAttributeRequestEntityType": ".attributes",
    "UpdateDriverRequestAttributes": ".types",
    "UpdateDriverRequestDriverActivationStatus": ".drivers",
    "UpdateDriverRequestHosSetting": ".types",
    "UpdateDriverRequestLocale": ".drivers",
    "UpdateEngineImmobilizerRelayStateRequestBodyRequestBody": ".types",
    "UpdateEngineImmobilizerRelayStateRequestBodyRequestBodyId": ".types",
    "UpdateHubLocationRequestBodyRequestBody": ".types",
    "UpdateRoutesStopRequestObjectRequestBody": ".types",
    "UpdateUserRequestAuthType": ".users",
    "UpdateVehicleRequestAuxInputType1": ".vehicles",
    "UpdateVehicleRequestAuxInputType10": ".vehicles",
    "UpdateVehicleRequestAuxInputType11": ".vehicles",
    "UpdateVehicleRequestAuxInputType12": ".vehicles",
    "UpdateVehicleRequestAuxInputType13": ".vehicles",
    "UpdateVehicleRequestAuxInputType2": ".vehicles",
    "UpdateVehicleRequestAuxInputType3": ".vehicles",
    "UpdateVehicleRequestAuxInputType4": ".vehicles",
    "UpdateVehicleRequestAuxInputType5": ".vehicles",
    "UpdateVehicleRequestAuxInputType6": ".vehicles",
    "UpdateVehicleRequestAuxInputType7": ".vehicles",
    "UpdateVehicleRequestAuxInputType8": ".vehicles",
    "UpdateVehicleRequestAuxInputType9": ".vehicles",
    "UpdateVehicleRequestHarshAccelerationSettingType": ".vehicles",
    "UploadedMediaObjectResponseBody": ".types",
    "UploadedMediaObjectResponseBodyCameraRole": ".types",
    "UploadedMediaObjectResponseBodyInput": ".types",
    "UploadedMediaObjectResponseBodyMediaType": ".types",
    "UploadedMediaObjectResponseBodyTriggerReason": ".types",
    "UrlInfoObjectResponseBody": ".types",
    "UsDriverRulesetOverride": ".types",
    "UsDriverRulesetOverrideCycle": ".types",
    "UsDriverRulesetOverrideRestart": ".types",
    "UsDriverRulesetOverrideRestbreak": ".types",
    "UsDriverRulesetOverrideUsStateToOverride": ".types",
    "User": ".types",
    "UserAuthType": ".types",
    "UserEmail": ".types",
    "UserExpireAt": ".types",
    "UserId": ".types",
    "UserIdentifierSerial": ".types",
    "UserName": ".types",
    "UserResponse": ".types",
    "UserRole": ".types",
    "UserRoleAssignment": ".types",
    "UserRoles": ".types",
    "UserTinyResponse": ".types",
    "V1Asset": ".types",
    "V1AssetCable": ".types",
    "V1AssetCurrentLocation": ".types",
    "V1AssetCurrentLocationsResponse": ".types",
    "V1AssetLocationResponse": ".types",
    "V1AssetLocationResponseItem": ".types",
    "V1AssetReeferResponse": ".types",
    "V1AssetReeferResponseReeferStats": ".types",
    "V1AssetReeferResponseReeferStatsAlarms": ".types",
    "V1AssetReeferResponseReeferStatsAlarms1": ".types",
    "V1AssetReeferResponseReeferStatsEngineHours": ".types",
    "V1AssetReeferResponseReeferStatsFuelPercentage": ".types",
    "V1AssetReeferResponseReeferStatsPowerStatus": ".types",
    "V1AssetReeferResponseReeferStatsReturnAirTemp": ".types",
    "V1AssetReeferResponseReeferStatsSetPoint": ".types",
    "V1AssetsReefer": ".types",
    "V1AssetsReeferReeferStats": ".types",
    "V1AssetsReeferReeferStatsAmbientAirTemperature": ".types",
    "V1AssetsReeferReeferStatsDischargeAirTemperature": ".types",
    "V1AssetsReeferReeferStatsPowerStatus": ".types",
    "V1AssetsReeferReeferStatsPowerStatusStatus": ".types",
    "V1CargoResponse": ".types",
    "V1CargoResponseSensors": ".types",
    "V1DoorResponse": ".types",
    "V1DoorResponseSensors": ".types",
    "V1DriverSafetyScoreResponse": ".types",
    "V1HosAuthenticationLogsResponse": ".types",
    "V1HosAuthenticationLogsResponseAuthenticationLogs": ".types",
    "V1HumidityResponse": ".types",
    "V1HumidityResponseSensors": ".types",
    "V1Machine": ".types",
    "V1MachineHistoryResponse": ".types",
    "V1MachineHistoryResponseMachines": ".types",
    "V1MachineHistoryResponseVibrations": ".types",
    "V1Message": ".types",
    "V1MessageResponse": ".types",
    "V1MessageSender": ".types",
    "V1Messages": ".types",
    "V1MessagesResponse": ".types",
    "V1Pagination": ".types",
    "V1ProgramsForTheCameraResponse": ".types",
    "V1ProgramsForTheCameraResponseItem": ".types",
    "V1SafetyReportHarshEvent": ".types",
    "V1Sensor": ".types",
    "V1SensorHistoryResponse": ".types",
    "V1SensorHistoryResponseResults": ".types",
    "V1SensorsHistorySeries": ".types",
    "V1SensorsHistorySeriesField": ".types",
    "V1TemperatureResponse": ".types",
    "V1TemperatureResponseSensors": ".types",
    "V1TrailerAssignmentResponse": ".types",
    "V1TrailerAssignmentsResponse": ".types",
    "V1TrailerAssignmentsResponseAllOf": ".types",
    "V1TrailerBase": ".types",
    "V1TripResponse": ".types",
    "V1TripResponseEndAddress": ".types",
    "V1TripResponseEndCoordinates": ".types",
    "V1TripResponseStartAddress": ".types",
    "V1TripResponseStartCoordinates": ".types",
    "V1TripResponseTrips": ".types",
    "V1VehicleHarshEventResponse": ".types",
    "V1VehicleHarshEventResponseLocation": ".types",
    "V1VehicleMaintenance": ".types",
    "V1VehicleMaintenanceJ1939": ".types",
    "V1VehicleMaintenanceJ1939CheckEngineLight": ".types",
    "V1VehicleMaintenanceJ1939DiagnosticTroubleCodes": ".types",
    "V1VehicleMaintenancePassenger": ".types",
    "V1VehicleMaintenancePassengerCheckEngineLight": ".types",
    "V1VehicleMaintenancePassengerDiagnosticTroubleCodes": ".types",
    "V1VehicleSafetyScoreResponse": ".types",
    "V1VisionCamerasResponse": ".types",
    "V1VisionCamerasResponseItem": ".types",
    "V1VisionRunByCameraResponse": ".types",
    "V1VisionRunByCameraResponseInspectionResults": ".types",
    "V1VisionRunByCameraResponseProgram": ".types",
    "V1VisionRunByCameraResponseRunSummary": ".types",
    "V1VisionRunsByCameraAndProgramResponse": ".types",
    "V1VisionRunsByCameraResponse": ".types",
    "V1VisionRunsByCameraResponseItem": ".types",
    "V1VisionRunsByCameraResponseItemProgram": ".types",
    "V1VisionRunsByCameraResponseItemReportMetadata": ".types",
    "V1VisionRunsResponse": ".types",
    "V1VisionRunsResponseReportMetadata": ".types",
    "V1VisionRunsResponseVisionRuns": ".types",
    "V1VisionStepResults": ".types",
    "V1VisionStepResultsItem": ".types",
    "V1VisionStepResultsItemAngleCheck": ".types",
    "V1VisionStepResultsItemAngleCheckAngleConfigured": ".types",
    "V1VisionStepResultsItemBarcodeItem": ".types",
    "V1VisionStepResultsItemBooleanLogic": ".types",
    "V1VisionStepResultsItemBooleanLogicStepsItem": ".types",
    "V1VisionStepResultsItemCaliper": ".types",
    "V1VisionStepResultsItemCaliperAngleRange": ".types",
    "V1VisionStepResultsItemCaliperContrastRange": ".types",
    "V1VisionStepResultsItemCaliperFilterPolarity": ".types",
    "V1VisionStepResultsItemCaliperSharpnessRange": ".types",
    "V1VisionStepResultsItemCaliperStraightnessRange": ".types",
    "V1VisionStepResultsItemContour": ".types",
    "V1VisionStepResultsItemDistance": ".types",
    "V1VisionStepResultsItemExpirationDate": ".types",
    "V1VisionStepResultsItemFindCopies": ".types",
    "V1VisionStepResultsItemFindEdge": ".types",
    "V1VisionStepResultsItemFindEdgeAngleRange": ".types",
    "V1VisionStepResultsItemFindEdgeContrastRange": ".types",
    "V1VisionStepResultsItemFindEdgeSharpnessRange": ".types",
    "V1VisionStepResultsItemFindEdgeStraightnessRange": ".types",
    "V1VisionStepResultsItemFindShapes": ".types",
    "V1VisionStepResultsItemFixture": ".types",
    "V1VisionStepResultsItemFixtureCoordinates": ".types",
    "V1VisionStepResultsItemLabelMatch": ".types",
    "V1VisionStepResultsItemPresenceAbsence": ".types",
    "V1VisionStepResultsItemPresenceAbsenceBlueRange": ".types",
    "V1VisionStepResultsItemPresenceAbsenceGrayscaleRange": ".types",
    "V1VisionStepResultsItemPresenceAbsenceGreenRange": ".types",
    "V1VisionStepResultsItemPresenceAbsenceHueRange": ".types",
    "V1VisionStepResultsItemPresenceAbsenceRedRange": ".types",
    "V1VisionStepResultsItemPresenceAbsenceSaturationRange": ".types",
    "V1VisionStepResultsItemPresenceAbsenceValueRange": ".types",
    "V1VisionStepResultsItemTextMatch": ".types",
    "Vehicle": ".types",
    "VehicleAssignmentObjectResponseBody": ".types",
    "VehicleAssignmentObjectResponseBodyAssignmentType": ".types",
    "VehicleAuxInputName": ".types",
    "VehicleAuxInputType": ".types",
    "VehicleBatterVoltageDetailsObjectRequestBody": ".types",
    "VehicleBatterVoltageDetailsObjectRequestBodyOperation": ".types",
    "VehicleBatterVoltageDetailsObjectResponseBody": ".types",
    "VehicleBatterVoltageDetailsObjectResponseBodyOperation": ".types",
    "VehicleBatteryVoltageResponseBody": ".types",
    "VehicleDefLevelPercentageResponseBody": ".types",
    "VehicleDetectedResponseBody": ".types",
    "VehicleDvirObjectResponseBody": ".types",
    "VehicleEsn": ".types",
    "VehicleExternalIds": ".types",
    "VehicleFaultCodeDetailsObjectRequestBody": ".types",
    "VehicleFaultCodeDetailsObjectResponseBody": ".types",
    "VehicleFaultsResponseBody": ".types",
    "VehicleHarshAccelerationSettingType": ".types",
    "VehicleId": ".types",
    "VehicleLicensePlate": ".types",
    "VehicleLocation": ".types",
    "VehicleLocationAddress": ".types",
    "VehicleLocationHeading": ".types",
    "VehicleLocationIsEcuSpeed": ".types",
    "VehicleLocationLatitude": ".types",
    "VehicleLocationLongitude": ".types",
    "VehicleLocationSpeed": ".types",
    "VehicleLocationsListResponse": ".types",
    "VehicleLocationsListResponseData": ".types",
    "VehicleLocationsResponse": ".types",
    "VehicleLocationsResponseData": ".types",
    "VehicleMake": ".types",
    "VehicleModel": ".types",
    "VehicleName": ".types",
    "VehicleNotes": ".types",
    "VehicleRegulationMode": ".types",
    "VehicleResponse": ".types",
    "VehicleResponseObjectResponseBody": ".types",
    "VehicleResponseObjectResponseBodyVehicleRegulationMode": ".types",
    "VehicleResponseObjectResponseBodyVehicleType": ".types",
    "VehicleResponseResponseBody": ".types",
    "VehicleResponseResponseBodyAssetType": ".types",
    "VehicleSafetyScoreResponseBody": ".types",
    "VehicleSensorConfiguration": ".types",
    "VehicleSensorConfigurationArea": ".types",
    "VehicleSensorConfigurationAreaPosition": ".types",
    "VehicleSensorConfigurationAreaResponseBody": ".types",
    "VehicleSensorConfigurationAreaResponseBodyPosition": ".types",
    "VehicleSensorConfigurationDoor": ".types",
    "VehicleSensorConfigurationDoorPosition": ".types",
    "VehicleSensorConfigurationDoorResponseBody": ".types",
    "VehicleSensorConfigurationDoorResponseBodyPosition": ".types",
    "VehicleSensorConfigurationResponseBody": ".types",
    "VehicleStatsAmbientAirTempMilliC": ".types",
    "VehicleStatsAmbientAirTempMilliCValue": ".types",
    "VehicleStatsAmbientAirTempMilliCWithDecoration": ".types",
    "VehicleStatsAuxInput": ".types",
    "VehicleStatsAuxInputDecoration": ".types",
    "VehicleStatsAuxInputTime": ".types",
    "VehicleStatsAuxInputValue": ".types",
    "VehicleStatsAuxInputWithDecoration": ".types",
    "VehicleStatsBarometricPressurePa": ".types",
    "VehicleStatsBarometricPressurePaValue": ".types",
    "VehicleStatsBarometricPressurePaWithDecoration": ".types",
    "VehicleStatsBatteryMilliVoltsValue": ".types",
    "VehicleStatsBatteryVoltage": ".types",
    "VehicleStatsBatteryVoltageWithDecoration": ".types",
    "VehicleStatsDecorations": ".types",
    "VehicleStatsDecorationsAmbientAirTemperatureMilliC": ".types",
    "VehicleStatsDecorationsBarometricPressurePa": ".types",
    "VehicleStatsDecorationsBatteryMilliVolts": ".types",
    "VehicleStatsDecorationsDefLevelMilliPercent": ".types",
    "VehicleStatsDecorationsEcuSpeedMph": ".types",
    "VehicleStatsDecorationsEngineCoolantTemperatureMilliC": ".types",
    "VehicleStatsDecorationsEngineLoadPercent": ".types",
    "VehicleStatsDecorationsEngineOilPressureKPa": ".types",
    "VehicleStatsDecorationsEngineRpm": ".types",
    "VehicleStatsDecorationsEngineStates": ".types",
    "VehicleStatsDecorationsEngineStatesValue": ".types",
    "VehicleStatsDecorationsFuelConsumedMilliliters": ".types",
    "VehicleStatsDecorationsFuelPercents": ".types",
    "VehicleStatsDecorationsGps": ".types",
    "VehicleStatsDecorationsGpsDistanceMeters": ".types",
    "VehicleStatsDecorationsGpsOdometerMeters": ".types",
    "VehicleStatsDecorationsIdlingDurationMilliseconds": ".types",
    "VehicleStatsDecorationsIntakeManifoldTemperatureMilliC": ".types",
    "VehicleStatsDecorationsObdEngineSeconds": ".types",
    "VehicleStatsDecorationsObdOdometerMeters": ".types",
    "VehicleStatsDefLevelMilliPercent": ".types",
    "VehicleStatsDefLevelMilliPercentValue": ".types",
    "VehicleStatsDefLevelMilliPercentWithDecoration": ".types",
    "VehicleStatsEcuDoorStatus": ".types",
    "VehicleStatsEcuDoorStatusValue": ".types",
    "VehicleStatsEcuSpeedMph": ".types",
    "VehicleStatsEcuSpeedMphValue": ".types",
    "VehicleStatsEcuSpeedMphWithDecoration": ".types",
    "VehicleStatsEngineCoolantTempMilliC": ".types",
    "VehicleStatsEngineCoolantTempMilliCValue": ".types",
    "VehicleStatsEngineCoolantTempMilliCWithDecoration": ".types",
    "VehicleStatsEngineImmobilizer": ".types",
    "VehicleStatsEngineImmobilizerState": ".types",
    "VehicleStatsEngineImmobilizerWithDecoration": ".types",
    "VehicleStatsEngineImmobilizerWithDecorationState": ".types",
    "VehicleStatsEngineLoadPercent": ".types",
    "VehicleStatsEngineLoadPercentValue": ".types",
    "VehicleStatsEngineLoadPercentWithDecoration": ".types",
    "VehicleStatsEngineOilPressureKPa": ".types",
    "VehicleStatsEngineOilPressureKPaValue": ".types",
    "VehicleStatsEngineOilPressureKPaWithDecoration": ".types",
    "VehicleStatsEngineRpm": ".types",
    "VehicleStatsEngineRpmValue": ".types",
    "VehicleStatsEngineRpmWithDecoration": ".types",
    "VehicleStatsEngineState": ".types",
    "VehicleStatsEngineStateSetting": ".types",
    "VehicleStatsEngineStateWithDecoration": ".types",
    "VehicleStatsEvAverageBatteryTemperatureMilliCelsius": ".types",
    "VehicleStatsEvBatteryCurrentMilliAmp": ".types",
    "VehicleStatsEvBatteryStateOfHealthMilliPercent": ".types",
    "VehicleStatsEvBatteryVoltageMilliVolt": ".types",
    "VehicleStatsEvChargingCurrentMilliAmp": ".types",
    "VehicleStatsEvChargingEnergyMicroWh": ".types",
    "VehicleStatsEvChargingStatus": ".types",
    "VehicleStatsEvChargingVoltageMilliVolt": ".types",
    "VehicleStatsEvConsumedEnergyMicroWh": ".types",
    "VehicleStatsEvDistanceDrivenMeters": ".types",
    "VehicleStatsEvRegeneratedEnergyMicroWh": ".types",
    "VehicleStatsEvStateOfChargeMilliPercent": ".types",
    "VehicleStatsFaultCodes": ".types",
    "VehicleStatsFaultCodesCanBusType": ".types",
    "VehicleStatsFaultCodesIgnitionType": ".types",
    "VehicleStatsFaultCodesJ1939": ".types",
    "VehicleStatsFaultCodesJ1939Lights": ".types",
    "VehicleStatsFaultCodesJ1939TroubleCode": ".types",
    "VehicleStatsFaultCodesJ1939TroubleCodes": ".types",
    "VehicleStatsFaultCodesObdii": ".types",
    "VehicleStatsFaultCodesObdiiTroubleCode": ".types",
    "VehicleStatsFaultCodesOem": ".types",
    "VehicleStatsFaultCodesOemTroubleCode": ".types",
    "VehicleStatsFaultCodesOemTroubleCodes": ".types",
    "VehicleStatsFaultCodesPassengerDtc": ".types",
    "VehicleStatsFaultCodesPassengerMonitorStatus": ".types",
    "VehicleStatsFaultCodesPassengerMonitorStatusValue": ".types",
    "VehicleStatsFaultCodesTxId": ".types",
    "VehicleStatsFaultCodesValue": ".types",
    "VehicleStatsFaultCodesValueJ1939": ".types",
    "VehicleStatsFaultCodesValueJ1939CheckEngineLights": ".types",
    "VehicleStatsFaultCodesValueJ1939DiagnosticTroubleCodes": ".types",
    "VehicleStatsFaultCodesValueJ1939VendorSpecificFields": ".types",
    "VehicleStatsFaultCodesValueObdii": ".types",
    "VehicleStatsFaultCodesValueObdiiConfirmedDtcs": ".types",
    "VehicleStatsFaultCodesValueObdiiDiagnosticTroubleCodes": ".types",
    "VehicleStatsFaultCodesValueObdiiDiagnosticTroubleCodesIgnitionType": ".types",
    "VehicleStatsFaultCodesValueObdiiMonitorStatus": ".types",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusCatalyst": ".types",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusComprehensive": ".types",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusEgr": ".types",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusEvapSystem": ".types",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusFuel": ".types",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusHeatedCatalyst": ".types",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusHeatedO2Sensor": ".types",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusIsoSaeReserved": ".types",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusMisfire": ".types",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusO2Sensor": ".types",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusSecondaryAir": ".types",
    "VehicleStatsFaultCodesValueOem": ".types",
    "VehicleStatsFaultCodesValueOemDiagnosticTroubleCodes": ".types",
    "VehicleStatsFaultCodesVendorSpecificFields": ".types",
    "VehicleStatsFaultCodesWithDecoration": ".types",
    "VehicleStatsFuelConsumedMilliliters": ".types",
    "VehicleStatsFuelConsumedMillilitersValue": ".types",
    "VehicleStatsFuelConsumedMillilitersWithDecoration": ".types",
    "VehicleStatsFuelPercent": ".types",
    "VehicleStatsFuelPercentValue": ".types",
    "VehicleStatsFuelPercentWithDecoration": ".types",
    "VehicleStatsGps": ".types",
    "VehicleStatsGpsDistanceMeters": ".types",
    "VehicleStatsGpsDistanceMetersValue": ".types",
    "VehicleStatsGpsDistanceMetersWithDecoration": ".types",
    "VehicleStatsGpsOdometerMeters": ".types",
    "VehicleStatsGpsOdometerMetersValue": ".types",
    "VehicleStatsGpsOdometerMetersWithDecoration": ".types",
    "VehicleStatsIdlingDurationMilliseconds": ".types",
    "VehicleStatsIdlingDurationMillisecondsValue": ".types",
    "VehicleStatsIdlingDurationMillisecondsWithDecoration": ".types",
    "VehicleStatsIntakeManifoldTempMilliC": ".types",
    "VehicleStatsIntakeManifoldTempMilliCValue": ".types",
    "VehicleStatsIntakeManifoldTempMilliCWithDecoration": ".types",
    "VehicleStatsListGps": ".types",
    "VehicleStatsListResponse": ".types",
    "VehicleStatsListResponseData": ".types",
    "VehicleStatsListSyntheticEngineSeconds": ".types",
    "VehicleStatsNfcCardScan": ".types",
    "VehicleStatsNfcCardScanCard": ".types",
    "VehicleStatsNfcCardScanWithDecoration": ".types",
    "VehicleStatsObdEngineSeconds": ".types",
    "VehicleStatsObdEngineSecondsValue": ".types",
    "VehicleStatsObdEngineSecondsWithDecoration": ".types",
    "VehicleStatsObdOdometerMeters": ".types",
    "VehicleStatsObdOdometerMetersValue": ".types",
    "VehicleStatsObdOdometerMetersWithDecoration": ".types",
    "VehicleStatsResponse": ".types",
    "VehicleStatsResponseData": ".types",
    "VehicleStatsResponseEcuDoorStatus": ".types",
    "VehicleStatsResponseEcuDoorStatusValue": ".types",
    "VehicleStatsResponseEvAverageBatteryTemperatureMilliCelsius": ".types",
    "VehicleStatsResponseEvBatteryCurrentMilliAmp": ".types",
    "VehicleStatsResponseEvBatteryStateOfHealthMilliPercent": ".types",
    "VehicleStatsResponseEvBatteryVoltageMilliVolt": ".types",
    "VehicleStatsResponseEvChargingCurrentMilliAmp": ".types",
    "VehicleStatsResponseEvChargingEnergyMicroWh": ".types",
    "VehicleStatsResponseEvChargingStatus": ".types",
    "VehicleStatsResponseEvChargingVoltageMilliVolt": ".types",
    "VehicleStatsResponseEvConsumedEnergyMicroWh": ".types",
    "VehicleStatsResponseEvDistanceDrivenMeters": ".types",
    "VehicleStatsResponseEvRegeneratedEnergyMicroWh": ".types",
    "VehicleStatsResponseEvStateOfChargeMilliPercent": ".types",
    "VehicleStatsResponseSeatbeltDriver": ".types",
    "VehicleStatsResponseSeatbeltDriverValue": ".types",
    "VehicleStatsResponseSpreaderActive": ".types",
    "VehicleStatsResponseSpreaderActiveValue": ".types",
    "VehicleStatsResponseSpreaderAirTemp": ".types",
    "VehicleStatsResponseSpreaderBlastState": ".types",
    "VehicleStatsResponseSpreaderBlastStateValue": ".types",
    "VehicleStatsResponseSpreaderGranularName": ".types",
    "VehicleStatsResponseSpreaderGranularRate": ".types",
    "VehicleStatsResponseSpreaderLiquidName": ".types",
    "VehicleStatsResponseSpreaderLiquidRate": ".types",
    "VehicleStatsResponseSpreaderOnState": ".types",
    "VehicleStatsResponseSpreaderOnStateValue": ".types",
    "VehicleStatsResponseSpreaderPlowStatus": ".types",
    "VehicleStatsResponseSpreaderPlowStatusValue": ".types",
    "VehicleStatsResponseSpreaderPrewetName": ".types",
    "VehicleStatsResponseSpreaderPrewetRate": ".types",
    "VehicleStatsResponseSpreaderRoadTemp": ".types",
    "VehicleStatsSeatbeltDriver": ".types",
    "VehicleStatsSeatbeltDriverValue": ".types",
    "VehicleStatsSpreaderActive": ".types",
    "VehicleStatsSpreaderActiveValue": ".types",
    "VehicleStatsSpreaderAirTemp": ".types",
    "VehicleStatsSpreaderBlastState": ".types",
    "VehicleStatsSpreaderBlastStateValue": ".types",
    "VehicleStatsSpreaderGranularName": ".types",
    "VehicleStatsSpreaderGranularRate": ".types",
    "VehicleStatsSpreaderLiquidName": ".types",
    "VehicleStatsSpreaderLiquidRate": ".types",
    "VehicleStatsSpreaderOnState": ".types",
    "VehicleStatsSpreaderOnStateValue": ".types",
    "VehicleStatsSpreaderPlowStatus": ".types",
    "VehicleStatsSpreaderPlowStatusValue": ".types",
    "VehicleStatsSpreaderPrewetName": ".types",
    "VehicleStatsSpreaderPrewetRate": ".types",
    "VehicleStatsSpreaderRoadTemp": ".types",
    "VehicleStatsSyntheticEngineSeconds": ".types",
    "VehicleStatsSyntheticEngineSecondsValue": ".types",
    "VehicleStatsTirePressures": ".types",
    "VehicleSummary": ".types",
    "VehicleTags": ".types",
    "VehicleTinyResponse": ".types",
    "VehicleType": ".types",
    "VehicleVin": ".types",
    "VehicleWithGatewayTinyResponseResponseBody": ".types",
    "VehicleWithGatewayTinyResponseResponseBodyAssetType": ".types",
    "VehicleYear": ".types",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsBadGatewayErrorResponseBody": ".types",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsGatewayTimeoutErrorResponseBody": ".types",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsInternalServerErrorResponseBody": ".types",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsMethodNotAllowedErrorResponseBody": ".types",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsNotFoundErrorResponseBody": ".types",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsNotImplementedErrorResponseBody": ".types",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsResponseBody": ".types",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsServiceUnavailableErrorResponseBody": ".types",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsTooManyRequestsErrorResponseBody": ".types",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsUnauthorizedErrorResponseBody": ".types",
    "VehiclesDriverAssignmentsObjectResponseBody": ".types",
    "VehiclesListVehiclesBadGatewayErrorResponseBody": ".types",
    "VehiclesListVehiclesGatewayTimeoutErrorResponseBody": ".types",
    "VehiclesListVehiclesInternalServerErrorResponseBody": ".types",
    "VehiclesListVehiclesMethodNotAllowedErrorResponseBody": ".types",
    "VehiclesListVehiclesNotFoundErrorResponseBody": ".types",
    "VehiclesListVehiclesNotImplementedErrorResponseBody": ".types",
    "VehiclesListVehiclesResponseBody": ".types",
    "VehiclesListVehiclesServiceUnavailableErrorResponseBody": ".types",
    "VehiclesListVehiclesTooManyRequestsErrorResponseBody": ".types",
    "VehiclesListVehiclesUnauthorizedErrorResponseBody": ".types",
    "VehiclesLockLockVehicleBadGatewayErrorResponseBody": ".types",
    "VehiclesLockLockVehicleGatewayTimeoutErrorResponseBody": ".types",
    "VehiclesLockLockVehicleInternalServerErrorResponseBody": ".types",
    "VehiclesLockLockVehicleMethodNotAllowedErrorResponseBody": ".types",
    "VehiclesLockLockVehicleNotFoundErrorResponseBody": ".types",
    "VehiclesLockLockVehicleNotImplementedErrorResponseBody": ".types",
    "VehiclesLockLockVehicleServiceUnavailableErrorResponseBody": ".types",
    "VehiclesLockLockVehicleTooManyRequestsErrorResponseBody": ".types",
    "VehiclesLockLockVehicleUnauthorizedErrorResponseBody": ".types",
    "VehiclesLockUnlockVehicleBadGatewayErrorResponseBody": ".types",
    "VehiclesLockUnlockVehicleGatewayTimeoutErrorResponseBody": ".types",
    "VehiclesLockUnlockVehicleInternalServerErrorResponseBody": ".types",
    "VehiclesLockUnlockVehicleMethodNotAllowedErrorResponseBody": ".types",
    "VehiclesLockUnlockVehicleNotFoundErrorResponseBody": ".types",
    "VehiclesLockUnlockVehicleNotImplementedErrorResponseBody": ".types",
    "VehiclesLockUnlockVehicleServiceUnavailableErrorResponseBody": ".types",
    "VehiclesLockUnlockVehicleTooManyRequestsErrorResponseBody": ".types",
    "VehiclesLockUnlockVehicleUnauthorizedErrorResponseBody": ".types",
    "VendorCategoryObjectResponseBody": ".types",
    "VendorObjectResponseBody": ".types",
    "VertexRequestBody": ".types",
    "VertexResponseBody": ".types",
    "VoiceCoachingSettingsObjectResponseBody": ".types",
    "VoiceCoachingSettingsObjectResponseBodyEventsToCoachItem": ".types",
    "VoiceCoachingSettingsObjectResponseBodyLanguage": ".types",
    "WalkaroundPhotoObjectResponseBody": ".types",
    "WebhookParamsObjectRequestBody": ".types",
    "WebhookParamsObjectRequestBodyPayloadType": ".types",
    "WebhookParamsObjectResponseBody": ".types",
    "WebhookParamsObjectResponseBodyPayloadType": ".types",
    "WebhookResponseResponseBody": ".types",
    "WebhookResponseResponseBodyEventTypesItem": ".types",
    "WebhookResponseResponseBodyVersion": ".types",
    "WebhookRouteResponseObjectResponseBody": ".types",
    "WebhooksDeleteWebhookBadGatewayErrorResponseBody": ".types",
    "WebhooksDeleteWebhookGatewayTimeoutErrorResponseBody": ".types",
    "WebhooksDeleteWebhookInternalServerErrorResponseBody": ".types",
    "WebhooksDeleteWebhookMethodNotAllowedErrorResponseBody": ".types",
    "WebhooksDeleteWebhookNotFoundErrorResponseBody": ".types",
    "WebhooksDeleteWebhookNotImplementedErrorResponseBody": ".types",
    "WebhooksDeleteWebhookServiceUnavailableErrorResponseBody": ".types",
    "WebhooksDeleteWebhookTooManyRequestsErrorResponseBody": ".types",
    "WebhooksDeleteWebhookUnauthorizedErrorResponseBody": ".types",
    "WebhooksGetWebhookBadGatewayErrorResponseBody": ".types",
    "WebhooksGetWebhookGatewayTimeoutErrorResponseBody": ".types",
    "WebhooksGetWebhookInternalServerErrorResponseBody": ".types",
    "WebhooksGetWebhookMethodNotAllowedErrorResponseBody": ".types",
    "WebhooksGetWebhookNotFoundErrorResponseBody": ".types",
    "WebhooksGetWebhookNotImplementedErrorResponseBody": ".types",
    "WebhooksGetWebhookResponseBody": ".types",
    "WebhooksGetWebhookResponseBodyEventTypesItem": ".types",
    "WebhooksGetWebhookResponseBodyVersion": ".types",
    "WebhooksGetWebhookServiceUnavailableErrorResponseBody": ".types",
    "WebhooksGetWebhookTooManyRequestsErrorResponseBody": ".types",
    "WebhooksGetWebhookUnauthorizedErrorResponseBody": ".types",
    "WebhooksListWebhooksBadGatewayErrorResponseBody": ".types",
    "WebhooksListWebhooksGatewayTimeoutErrorResponseBody": ".types",
    "WebhooksListWebhooksInternalServerErrorResponseBody": ".types",
    "WebhooksListWebhooksMethodNotAllowedErrorResponseBody": ".types",
    "WebhooksListWebhooksNotFoundErrorResponseBody": ".types",
    "WebhooksListWebhooksNotImplementedErrorResponseBody": ".types",
    "WebhooksListWebhooksResponseBody": ".types",
    "WebhooksListWebhooksServiceUnavailableErrorResponseBody": ".types",
    "WebhooksListWebhooksTooManyRequestsErrorResponseBody": ".types",
    "WebhooksListWebhooksUnauthorizedErrorResponseBody": ".types",
    "WebhooksPatchWebhookBadGatewayErrorResponseBody": ".types",
    "WebhooksPatchWebhookGatewayTimeoutErrorResponseBody": ".types",
    "WebhooksPatchWebhookInternalServerErrorResponseBody": ".types",
    "WebhooksPatchWebhookMethodNotAllowedErrorResponseBody": ".types",
    "WebhooksPatchWebhookNotFoundErrorResponseBody": ".types",
    "WebhooksPatchWebhookNotImplementedErrorResponseBody": ".types",
    "WebhooksPatchWebhookRequestBodyVersion": ".webhooks",
    "WebhooksPatchWebhookResponseBody": ".types",
    "WebhooksPatchWebhookResponseBodyEventTypesItem": ".types",
    "WebhooksPatchWebhookResponseBodyVersion": ".types",
    "WebhooksPatchWebhookServiceUnavailableErrorResponseBody": ".types",
    "WebhooksPatchWebhookTooManyRequestsErrorResponseBody": ".types",
    "WebhooksPatchWebhookUnauthorizedErrorResponseBody": ".types",
    "WebhooksPostWebhooksBadGatewayErrorResponseBody": ".types",
    "WebhooksPostWebhooksGatewayTimeoutErrorResponseBody": ".types",
    "WebhooksPostWebhooksInternalServerErrorResponseBody": ".types",
    "WebhooksPostWebhooksMethodNotAllowedErrorResponseBody": ".types",
    "WebhooksPostWebhooksNotFoundErrorResponseBody": ".types",
    "WebhooksPostWebhooksNotImplementedErrorResponseBody": ".types",
    "WebhooksPostWebhooksRequestBodyEventTypesItem": ".webhooks",
    "WebhooksPostWebhooksRequestBodyVersion": ".webhooks",
    "WebhooksPostWebhooksResponseBody": ".types",
    "WebhooksPostWebhooksResponseBodyEventTypesItem": ".types",
    "WebhooksPostWebhooksResponseBodyVersion": ".types",
    "WebhooksPostWebhooksServiceUnavailableErrorResponseBody": ".types",
    "WebhooksPostWebhooksTooManyRequestsErrorResponseBody": ".types",
    "WebhooksPostWebhooksUnauthorizedErrorResponseBody": ".types",
    "WorkOrderAttachmentObjectResponseBody": ".types",
    "WorkOrderAttachmentObjectResponseBodyProcessingStatus": ".types",
    "WorkOrderDiscountObjectRequestBody": ".types",
    "WorkOrderDiscountObjectResponseBody": ".types",
    "WorkOrderItemObjectRequestBody": ".types",
    "WorkOrderItemObjectRequestBodyType": ".types",
    "WorkOrderItemObjectResponseBody": ".types",
    "WorkOrderItemObjectResponseBodyType": ".types",
    "WorkOrderMoneyObjectRequestBody": ".types",
    "WorkOrderMoneyObjectRequestBodyCurrency": ".types",
    "WorkOrderMoneyObjectResponseBody": ".types",
    "WorkOrderMoneyObjectResponseBodyCurrency": ".types",
    "WorkOrderObjectResponseBody": ".types",
    "WorkOrderObjectResponseBodyPriority": ".types",
    "WorkOrderObjectResponseBodyStatus": ".types",
    "WorkOrderTaxCreateObjectRequestBody": ".types",
    "WorkOrderTaxObjectRequestBody": ".types",
    "WorkOrderTaxObjectResponseBody": ".types",
    "WorkOrderUnallocatedLaborObjectResponseBody": ".types",
    "WorkOrdersDeleteWorkOrdersBadGatewayErrorResponseBody": ".types",
    "WorkOrdersDeleteWorkOrdersGatewayTimeoutErrorResponseBody": ".types",
    "WorkOrdersDeleteWorkOrdersInternalServerErrorResponseBody": ".types",
    "WorkOrdersDeleteWorkOrdersMethodNotAllowedErrorResponseBody": ".types",
    "WorkOrdersDeleteWorkOrdersNotFoundErrorResponseBody": ".types",
    "WorkOrdersDeleteWorkOrdersNotImplementedErrorResponseBody": ".types",
    "WorkOrdersDeleteWorkOrdersServiceUnavailableErrorResponseBody": ".types",
    "WorkOrdersDeleteWorkOrdersTooManyRequestsErrorResponseBody": ".types",
    "WorkOrdersDeleteWorkOrdersUnauthorizedErrorResponseBody": ".types",
    "WorkOrdersGetServiceTasksBadGatewayErrorResponseBody": ".types",
    "WorkOrdersGetServiceTasksGatewayTimeoutErrorResponseBody": ".types",
    "WorkOrdersGetServiceTasksInternalServerErrorResponseBody": ".types",
    "WorkOrdersGetServiceTasksMethodNotAllowedErrorResponseBody": ".types",
    "WorkOrdersGetServiceTasksNotFoundErrorResponseBody": ".types",
    "WorkOrdersGetServiceTasksNotImplementedErrorResponseBody": ".types",
    "WorkOrdersGetServiceTasksResponseBody": ".types",
    "WorkOrdersGetServiceTasksServiceUnavailableErrorResponseBody": ".types",
    "WorkOrdersGetServiceTasksTooManyRequestsErrorResponseBody": ".types",
    "WorkOrdersGetServiceTasksUnauthorizedErrorResponseBody": ".types",
    "WorkOrdersGetWorkOrdersBadGatewayErrorResponseBody": ".types",
    "WorkOrdersGetWorkOrdersGatewayTimeoutErrorResponseBody": ".types",
    "WorkOrdersGetWorkOrdersInternalServerErrorResponseBody": ".types",
    "WorkOrdersGetWorkOrdersMethodNotAllowedErrorResponseBody": ".types",
    "WorkOrdersGetWorkOrdersNotFoundErrorResponseBody": ".types",
    "WorkOrdersGetWorkOrdersNotImplementedErrorResponseBody": ".types",
    "WorkOrdersGetWorkOrdersResponseBody": ".types",
    "WorkOrdersGetWorkOrdersServiceUnavailableErrorResponseBody": ".types",
    "WorkOrdersGetWorkOrdersTooManyRequestsErrorResponseBody": ".types",
    "WorkOrdersGetWorkOrdersUnauthorizedErrorResponseBody": ".types",
    "WorkOrdersPatchWorkOrdersBadGatewayErrorResponseBody": ".types",
    "WorkOrdersPatchWorkOrdersGatewayTimeoutErrorResponseBody": ".types",
    "WorkOrdersPatchWorkOrdersInternalServerErrorResponseBody": ".types",
    "WorkOrdersPatchWorkOrdersMethodNotAllowedErrorResponseBody": ".types",
    "WorkOrdersPatchWorkOrdersNotFoundErrorResponseBody": ".types",
    "WorkOrdersPatchWorkOrdersNotImplementedErrorResponseBody": ".types",
    "WorkOrdersPatchWorkOrdersRequestBodyPriority": ".work_orders",
    "WorkOrdersPatchWorkOrdersRequestBodyStatus": ".work_orders",
    "WorkOrdersPatchWorkOrdersResponseBody": ".types",
    "WorkOrdersPatchWorkOrdersServiceUnavailableErrorResponseBody": ".types",
    "WorkOrdersPatchWorkOrdersTooManyRequestsErrorResponseBody": ".types",
    "WorkOrdersPatchWorkOrdersUnauthorizedErrorResponseBody": ".types",
    "WorkOrdersPostInvoiceScanBadGatewayErrorResponseBody": ".types",
    "WorkOrdersPostInvoiceScanGatewayTimeoutErrorResponseBody": ".types",
    "WorkOrdersPostInvoiceScanInternalServerErrorResponseBody": ".types",
    "WorkOrdersPostInvoiceScanMethodNotAllowedErrorResponseBody": ".types",
    "WorkOrdersPostInvoiceScanNotFoundErrorResponseBody": ".types",
    "WorkOrdersPostInvoiceScanNotImplementedErrorResponseBody": ".types",
    "WorkOrdersPostInvoiceScanResponseBody": ".types",
    "WorkOrdersPostInvoiceScanServiceUnavailableErrorResponseBody": ".types",
    "WorkOrdersPostInvoiceScanTooManyRequestsErrorResponseBody": ".types",
    "WorkOrdersPostInvoiceScanUnauthorizedErrorResponseBody": ".types",
    "WorkOrdersPostWorkOrdersBadGatewayErrorResponseBody": ".types",
    "WorkOrdersPostWorkOrdersGatewayTimeoutErrorResponseBody": ".types",
    "WorkOrdersPostWorkOrdersInternalServerErrorResponseBody": ".types",
    "WorkOrdersPostWorkOrdersMethodNotAllowedErrorResponseBody": ".types",
    "WorkOrdersPostWorkOrdersNotFoundErrorResponseBody": ".types",
    "WorkOrdersPostWorkOrdersNotImplementedErrorResponseBody": ".types",
    "WorkOrdersPostWorkOrdersRequestBodyPriority": ".work_orders",
    "WorkOrdersPostWorkOrdersResponseBody": ".types",
    "WorkOrdersPostWorkOrdersServiceUnavailableErrorResponseBody": ".types",
    "WorkOrdersPostWorkOrdersTooManyRequestsErrorResponseBody": ".types",
    "WorkOrdersPostWorkOrdersUnauthorizedErrorResponseBody": ".types",
    "WorkOrdersStreamWorkOrdersBadGatewayErrorResponseBody": ".types",
    "WorkOrdersStreamWorkOrdersGatewayTimeoutErrorResponseBody": ".types",
    "WorkOrdersStreamWorkOrdersInternalServerErrorResponseBody": ".types",
    "WorkOrdersStreamWorkOrdersMethodNotAllowedErrorResponseBody": ".types",
    "WorkOrdersStreamWorkOrdersNotFoundErrorResponseBody": ".types",
    "WorkOrdersStreamWorkOrdersNotImplementedErrorResponseBody": ".types",
    "WorkOrdersStreamWorkOrdersResponseBody": ".types",
    "WorkOrdersStreamWorkOrdersServiceUnavailableErrorResponseBody": ".types",
    "WorkOrdersStreamWorkOrdersTooManyRequestsErrorResponseBody": ".types",
    "WorkOrdersStreamWorkOrdersUnauthorizedErrorResponseBody": ".types",
    "WorkerSafetySosDataResponseBody": ".types",
    "WorkerSafetySosDataResponseBodySourceType": ".types",
    "WorkflowAddressEventWithGeofenceObjectResponseBody": ".types",
    "WorkflowAuthorSignatureObjectResponseBody": ".types",
    "WorkflowAuthorSignatureObjectResponseBodyType": ".types",
    "WorkflowCircleResponseBody": ".types",
    "WorkflowDvirObjectResponseBody": ".types",
    "WorkflowDvirObjectResponseBodySafetyStatus": ".types",
    "WorkflowDvirObjectResponseBodyType": ".types",
    "WorkflowDvirSubmittedResponseObjectResponseBody": ".types",
    "WorkflowGeofenceEventResponseObjectResponseBody": ".types",
    "WorkflowGeofenceResponseBody": ".types",
    "WorkflowIncidentConditionObjectResponseBody": ".types",
    "WorkflowIncidentDetailsObjectResponseBody": ".types",
    "WorkflowPolygonResponseBody": ".types",
    "WorkflowSignatoryUserObjectResponseBody": ".types",
    "WorkflowTriggerObjectRequestBody": ".types",
    "WorkflowTriggerObjectResponseBody": ".types",
    "__version__": ".version",
    "addresses": ".addresses",
    "alerts": ".alerts",
    "assets": ".assets",
    "attributes": ".attributes",
    "auth_token_for_driver": ".auth_token_for_driver",
    "beta_ap_is": ".beta_ap_is",
    "carrier_proposed_assignments": ".carrier_proposed_assignments",
    "coaching": ".coaching",
    "contacts": ".contacts",
    "documents": ".documents",
    "driver_qr_codes": ".driver_qr_codes",
    "driver_trailer_assignments": ".driver_trailer_assignments",
    "driver_vehicle_assignments": ".driver_vehicle_assignments",
    "drivers": ".drivers",
    "equipment": ".equipment",
    "fleet": ".fleet",
    "forms": ".forms",
    "fuel_and_energy": ".fuel_and_energy",
    "gateways": ".gateways",
    "hours_of_service": ".hours_of_service",
    "hubs": ".hubs",
    "idling": ".idling",
    "ifta": ".ifta",
    "industrial": ".industrial",
    "issues": ".issues",
    "legacy": ".legacy",
    "legacy_ap_is": ".legacy_ap_is",
    "live_sharing_links": ".live_sharing_links",
    "location_and_speed": ".location_and_speed",
    "maintenance": ".maintenance",
    "media": ".media",
    "messages": ".messages",
    "organization_info": ".organization_info",
    "plans": ".plans",
    "preview_ap_is": ".preview_ap_is",
    "route_events": ".route_events",
    "routes": ".routes",
    "safety": ".safety",
    "sensors": ".sensors",
    "settings": ".settings",
    "speeding_intervals": ".speeding_intervals",
    "tachograph_eu_only": ".tachograph_eu_only",
    "tags": ".tags",
    "trailer_assignments": ".trailer_assignments",
    "trailers": ".trailers",
    "training_assignments": ".training_assignments",
    "training_courses": ".training_courses",
    "trips": ".trips",
    "users": ".users",
    "vehicle_locations": ".vehicle_locations",
    "vehicle_stats": ".vehicle_stats",
    "vehicles": ".vehicles",
    "webhooks": ".webhooks",
    "work_orders": ".work_orders",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AccessoryResponseObjectResponseBody",
    "ActionObjectRequestBody",
    "ActionObjectResponseBody",
    "ActionParamsObjectRequestBody",
    "ActionParamsObjectResponseBody",
    "Address",
    "AddressAddressTypesItem",
    "AddressExternalIds",
    "AddressGeofence",
    "AddressGeofenceCircle",
    "AddressGeofencePolygon",
    "AddressGeofencePolygonVertices",
    "AddressGeofenceSettings",
    "AddressResponse",
    "AddressResponseResponseBody",
    "AddressTinyResponse",
    "AdvancedIdlingGetIdlingEventsBadGatewayErrorResponseBody",
    "AdvancedIdlingGetIdlingEventsGatewayTimeoutErrorResponseBody",
    "AdvancedIdlingGetIdlingEventsInternalServerErrorResponseBody",
    "AdvancedIdlingGetIdlingEventsMethodNotAllowedErrorResponseBody",
    "AdvancedIdlingGetIdlingEventsNotFoundErrorResponseBody",
    "AdvancedIdlingGetIdlingEventsNotImplementedErrorResponseBody",
    "AdvancedIdlingGetIdlingEventsResponseBody",
    "AdvancedIdlingGetIdlingEventsServiceUnavailableErrorResponseBody",
    "AdvancedIdlingGetIdlingEventsTooManyRequestsErrorResponseBody",
    "AdvancedIdlingGetIdlingEventsUnauthorizedErrorResponseBody",
    "AempEquipmentGetAempEquipmentListBadGatewayErrorResponseBody",
    "AempEquipmentGetAempEquipmentListGatewayTimeoutErrorResponseBody",
    "AempEquipmentGetAempEquipmentListInternalServerErrorResponseBody",
    "AempEquipmentGetAempEquipmentListMethodNotAllowedErrorResponseBody",
    "AempEquipmentGetAempEquipmentListNotFoundErrorResponseBody",
    "AempEquipmentGetAempEquipmentListNotImplementedErrorResponseBody",
    "AempEquipmentGetAempEquipmentListResponseBody",
    "AempEquipmentGetAempEquipmentListServiceUnavailableErrorResponseBody",
    "AempEquipmentGetAempEquipmentListTooManyRequestsErrorResponseBody",
    "AempEquipmentGetAempEquipmentListUnauthorizedErrorResponseBody",
    "AempEquipmentWithAdditionalFieldsResponseBody",
    "AempFleetListResponseBody",
    "AempLinkResponseBody",
    "AlertObjectAssetResponseBody",
    "AlertObjectAssetResponseBodyType",
    "AlertObjectDriverResponseBody",
    "AlertObjectMachineInputResponseBody",
    "AlertObjectOnvifCameraStreamResponseBody",
    "AlertObjectProductResponseBody",
    "AlertObjectSensorResponseBody",
    "AlertObjectSitesResponseBody",
    "AlertObjectTrailerResponseBody",
    "AlertObjectVehicleResponseBody",
    "AlertObjectWorkforceCameraDeviceResponseBody",
    "AlertsDeleteConfigurationsBadGatewayErrorResponseBody",
    "AlertsDeleteConfigurationsGatewayTimeoutErrorResponseBody",
    "AlertsDeleteConfigurationsInternalServerErrorResponseBody",
    "AlertsDeleteConfigurationsMethodNotAllowedErrorResponseBody",
    "AlertsDeleteConfigurationsNotFoundErrorResponseBody",
    "AlertsDeleteConfigurationsNotImplementedErrorResponseBody",
    "AlertsDeleteConfigurationsServiceUnavailableErrorResponseBody",
    "AlertsDeleteConfigurationsTooManyRequestsErrorResponseBody",
    "AlertsDeleteConfigurationsUnauthorizedErrorResponseBody",
    "AlertsGetConfigurationsBadGatewayErrorResponseBody",
    "AlertsGetConfigurationsGatewayTimeoutErrorResponseBody",
    "AlertsGetConfigurationsInternalServerErrorResponseBody",
    "AlertsGetConfigurationsMethodNotAllowedErrorResponseBody",
    "AlertsGetConfigurationsNotFoundErrorResponseBody",
    "AlertsGetConfigurationsNotImplementedErrorResponseBody",
    "AlertsGetConfigurationsResponseBody",
    "AlertsGetConfigurationsServiceUnavailableErrorResponseBody",
    "AlertsGetConfigurationsTooManyRequestsErrorResponseBody",
    "AlertsGetConfigurationsUnauthorizedErrorResponseBody",
    "AlertsGetIncidentsBadGatewayErrorResponseBody",
    "AlertsGetIncidentsGatewayTimeoutErrorResponseBody",
    "AlertsGetIncidentsInternalServerErrorResponseBody",
    "AlertsGetIncidentsMethodNotAllowedErrorResponseBody",
    "AlertsGetIncidentsNotFoundErrorResponseBody",
    "AlertsGetIncidentsNotImplementedErrorResponseBody",
    "AlertsGetIncidentsResponseBody",
    "AlertsGetIncidentsServiceUnavailableErrorResponseBody",
    "AlertsGetIncidentsTooManyRequestsErrorResponseBody",
    "AlertsGetIncidentsUnauthorizedErrorResponseBody",
    "AlertsPatchConfigurationsBadGatewayErrorResponseBody",
    "AlertsPatchConfigurationsGatewayTimeoutErrorResponseBody",
    "AlertsPatchConfigurationsInternalServerErrorResponseBody",
    "AlertsPatchConfigurationsMethodNotAllowedErrorResponseBody",
    "AlertsPatchConfigurationsNotFoundErrorResponseBody",
    "AlertsPatchConfigurationsNotImplementedErrorResponseBody",
    "AlertsPatchConfigurationsResponseBody",
    "AlertsPatchConfigurationsServiceUnavailableErrorResponseBody",
    "AlertsPatchConfigurationsTooManyRequestsErrorResponseBody",
    "AlertsPatchConfigurationsUnauthorizedErrorResponseBody",
    "AlertsPostConfigurationsBadGatewayErrorResponseBody",
    "AlertsPostConfigurationsGatewayTimeoutErrorResponseBody",
    "AlertsPostConfigurationsInternalServerErrorResponseBody",
    "AlertsPostConfigurationsMethodNotAllowedErrorResponseBody",
    "AlertsPostConfigurationsNotFoundErrorResponseBody",
    "AlertsPostConfigurationsNotImplementedErrorResponseBody",
    "AlertsPostConfigurationsResponseBody",
    "AlertsPostConfigurationsServiceUnavailableErrorResponseBody",
    "AlertsPostConfigurationsTooManyRequestsErrorResponseBody",
    "AlertsPostConfigurationsUnauthorizedErrorResponseBody",
    "AmbientTemperatureDetailsObjectRequestBody",
    "AmbientTemperatureDetailsObjectRequestBodyOperation",
    "AmbientTemperatureDetailsObjectResponseBody",
    "AmbientTemperatureDetailsObjectResponseBodyOperation",
    "AmbientTemperatureResponseBody",
    "AnticipationBrakeEventCount",
    "AppointmentWindowRequestBody",
    "AppointmentWindowResponseBody",
    "AssetDataInput",
    "AssetDataInputLastPoint",
    "AssetDataOutput",
    "AssetDataOutputsPatchAssetDataOutputsBadGatewayErrorResponseBody",
    "AssetDataOutputsPatchAssetDataOutputsGatewayTimeoutErrorResponseBody",
    "AssetDataOutputsPatchAssetDataOutputsInternalServerErrorResponseBody",
    "AssetDataOutputsPatchAssetDataOutputsMethodNotAllowedErrorResponseBody",
    "AssetDataOutputsPatchAssetDataOutputsNotFoundErrorResponseBody",
    "AssetDataOutputsPatchAssetDataOutputsNotImplementedErrorResponseBody",
    "AssetDataOutputsPatchAssetDataOutputsResponseBody",
    "AssetDataOutputsPatchAssetDataOutputsServiceUnavailableErrorResponseBody",
    "AssetDataOutputsPatchAssetDataOutputsTooManyRequestsErrorResponseBody",
    "AssetDataOutputsPatchAssetDataOutputsUnauthorizedErrorResponseBody",
    "AssetLocation",
    "AssetLocationHeading",
    "AssetLocationSpeed",
    "AssetName",
    "AssetResponse",
    "AssetResponseBody",
    "AssetResponseBodyRegulationMode",
    "AssetResponseBodyType",
    "AssetResponseLocationDataInput",
    "AssetResponseParentAsset",
    "AssetResponseResponseBody",
    "AssetResponseRunningStatusDataInput",
    "AssetsCreateAssetBadGatewayErrorResponseBody",
    "AssetsCreateAssetGatewayTimeoutErrorResponseBody",
    "AssetsCreateAssetInternalServerErrorResponseBody",
    "AssetsCreateAssetMethodNotAllowedErrorResponseBody",
    "AssetsCreateAssetNotFoundErrorResponseBody",
    "AssetsCreateAssetNotImplementedErrorResponseBody",
    "AssetsCreateAssetRequestBodyRegulationMode",
    "AssetsCreateAssetRequestBodyType",
    "AssetsCreateAssetResponseBody",
    "AssetsCreateAssetServiceUnavailableErrorResponseBody",
    "AssetsCreateAssetTooManyRequestsErrorResponseBody",
    "AssetsCreateAssetUnauthorizedErrorResponseBody",
    "AssetsDeleteAssetBadGatewayErrorResponseBody",
    "AssetsDeleteAssetGatewayTimeoutErrorResponseBody",
    "AssetsDeleteAssetInternalServerErrorResponseBody",
    "AssetsDeleteAssetMethodNotAllowedErrorResponseBody",
    "AssetsDeleteAssetNotFoundErrorResponseBody",
    "AssetsDeleteAssetNotImplementedErrorResponseBody",
    "AssetsDeleteAssetServiceUnavailableErrorResponseBody",
    "AssetsDeleteAssetTooManyRequestsErrorResponseBody",
    "AssetsDeleteAssetUnauthorizedErrorResponseBody",
    "AssetsInputsAssetResponseResponseBody",
    "AssetsInputsAuxInputResponseBody",
    "AssetsInputsGetAssetsInputsBadGatewayErrorResponseBody",
    "AssetsInputsGetAssetsInputsGatewayTimeoutErrorResponseBody",
    "AssetsInputsGetAssetsInputsInternalServerErrorResponseBody",
    "AssetsInputsGetAssetsInputsMethodNotAllowedErrorResponseBody",
    "AssetsInputsGetAssetsInputsNotFoundErrorResponseBody",
    "AssetsInputsGetAssetsInputsNotImplementedErrorResponseBody",
    "AssetsInputsGetAssetsInputsResponseBody",
    "AssetsInputsGetAssetsInputsServiceUnavailableErrorResponseBody",
    "AssetsInputsGetAssetsInputsTooManyRequestsErrorResponseBody",
    "AssetsInputsGetAssetsInputsUnauthorizedErrorResponseBody",
    "AssetsInputsResponseResponseBody",
    "AssetsInputsResponseResponseBodyUnits",
    "AssetsListAssetsBadGatewayErrorResponseBody",
    "AssetsListAssetsGatewayTimeoutErrorResponseBody",
    "AssetsListAssetsInternalServerErrorResponseBody",
    "AssetsListAssetsMethodNotAllowedErrorResponseBody",
    "AssetsListAssetsNotFoundErrorResponseBody",
    "AssetsListAssetsNotImplementedErrorResponseBody",
    "AssetsListAssetsResponseBody",
    "AssetsListAssetsServiceUnavailableErrorResponseBody",
    "AssetsListAssetsTooManyRequestsErrorResponseBody",
    "AssetsListAssetsUnauthorizedErrorResponseBody",
    "AssetsLocationLinkConfigAddressDetailsObject",
    "AssetsLocationLinkConfigAddressDetailsObjectResponseBody",
    "AssetsLocationLinkRequestConfigObject",
    "AssetsLocationLinkResponseConfigObjectResponseBody",
    "AssetsNearLocationLinkConfigObject",
    "AssetsNearLocationLinkConfigObjectResponseBody",
    "AssetsOnRouteLinkConfigObject",
    "AssetsOnRouteLinkConfigObjectResponseBody",
    "AssetsUpdateAssetBadGatewayErrorResponseBody",
    "AssetsUpdateAssetGatewayTimeoutErrorResponseBody",
    "AssetsUpdateAssetInternalServerErrorResponseBody",
    "AssetsUpdateAssetMethodNotAllowedErrorResponseBody",
    "AssetsUpdateAssetNotFoundErrorResponseBody",
    "AssetsUpdateAssetNotImplementedErrorResponseBody",
    "AssetsUpdateAssetRequestBodyRegulationMode",
    "AssetsUpdateAssetRequestBodyType",
    "AssetsUpdateAssetResponseBody",
    "AssetsUpdateAssetServiceUnavailableErrorResponseBody",
    "AssetsUpdateAssetTooManyRequestsErrorResponseBody",
    "AssetsUpdateAssetUnauthorizedErrorResponseBody",
    "AssociationResponseBody",
    "AssociationsListAssociationsBadGatewayErrorResponseBody",
    "AssociationsListAssociationsGatewayTimeoutErrorResponseBody",
    "AssociationsListAssociationsInternalServerErrorResponseBody",
    "AssociationsListAssociationsMethodNotAllowedErrorResponseBody",
    "AssociationsListAssociationsNotFoundErrorResponseBody",
    "AssociationsListAssociationsNotImplementedErrorResponseBody",
    "AssociationsListAssociationsResponseBody",
    "AssociationsListAssociationsServiceUnavailableErrorResponseBody",
    "AssociationsListAssociationsTooManyRequestsErrorResponseBody",
    "AssociationsListAssociationsUnauthorizedErrorResponseBody",
    "AsyncSamsara",
    "Attribute",
    "AttributeAttributeType",
    "AttributeEntity",
    "AttributeEntityExternalIds",
    "AttributeEntityType",
    "AttributeExpanded",
    "AttributeExpandedAllOf",
    "AttributeExpandedResponse",
    "AttributeTiny",
    "AttributeUnit",
    "AttributeValueTiny",
    "AuthTokenAuthTokenBadGatewayErrorResponseBody",
    "AuthTokenAuthTokenGatewayTimeoutErrorResponseBody",
    "AuthTokenAuthTokenInternalServerErrorResponseBody",
    "AuthTokenAuthTokenMethodNotAllowedErrorResponseBody",
    "AuthTokenAuthTokenNotFoundErrorResponseBody",
    "AuthTokenAuthTokenNotImplementedErrorResponseBody",
    "AuthTokenAuthTokenResponseBody",
    "AuthTokenAuthTokenServiceUnavailableErrorResponseBody",
    "AuthTokenAuthTokenTooManyRequestsErrorResponseBody",
    "AuthTokenAuthTokenUnauthorizedErrorResponseBody",
    "AuthTokenForDriverResponseResponseBody",
    "AuthorSignatureObjectResponseBody",
    "AuthorSignatureObjectResponseBodyType",
    "BadGatewayError",
    "BarcodeValueObjectRequestBody",
    "BarcodeValueObjectResponseBody",
    "BaseRouteResponseObjectResponseBody",
    "BehaviorCountDetailsRequestBody",
    "BehaviorCountDetailsRequestBodyComparison",
    "BehaviorCountDetailsResponseBody",
    "BehaviorCountDetailsResponseBodyComparison",
    "BehaviorResponseBody",
    "BehaviorResponseBodyCoachableBehaviorType",
    "CameraConnectorDisconectedResponseBody",
    "CameraDetailsResponseResponseBody",
    "CameraSerial",
    "CameraStreamIssueResponseBody",
    "CarbCtcListCarbCtcVehicleHistoryBadGatewayErrorResponseBody",
    "CarbCtcListCarbCtcVehicleHistoryGatewayTimeoutErrorResponseBody",
    "CarbCtcListCarbCtcVehicleHistoryInternalServerErrorResponseBody",
    "CarbCtcListCarbCtcVehicleHistoryMethodNotAllowedErrorResponseBody",
    "CarbCtcListCarbCtcVehicleHistoryNotFoundErrorResponseBody",
    "CarbCtcListCarbCtcVehicleHistoryNotImplementedErrorResponseBody",
    "CarbCtcListCarbCtcVehicleHistoryResponseBody",
    "CarbCtcListCarbCtcVehicleHistoryServiceUnavailableErrorResponseBody",
    "CarbCtcListCarbCtcVehicleHistoryTooManyRequestsErrorResponseBody",
    "CarbCtcListCarbCtcVehicleHistoryUnauthorizedErrorResponseBody",
    "CarbCtcListCarbCtcVehiclesBadGatewayErrorResponseBody",
    "CarbCtcListCarbCtcVehiclesGatewayTimeoutErrorResponseBody",
    "CarbCtcListCarbCtcVehiclesInternalServerErrorResponseBody",
    "CarbCtcListCarbCtcVehiclesMethodNotAllowedErrorResponseBody",
    "CarbCtcListCarbCtcVehiclesNotFoundErrorResponseBody",
    "CarbCtcListCarbCtcVehiclesNotImplementedErrorResponseBody",
    "CarbCtcListCarbCtcVehiclesResponseBody",
    "CarbCtcListCarbCtcVehiclesServiceUnavailableErrorResponseBody",
    "CarbCtcListCarbCtcVehiclesTooManyRequestsErrorResponseBody",
    "CarbCtcListCarbCtcVehiclesUnauthorizedErrorResponseBody",
    "CarbCtcVehicleHistoryObjectResponseBody",
    "CarbCtcVehicleHistoryObjectResponseBodyTestResult",
    "CarbCtcVehicleObjectResponseBody",
    "CarbCtcVehicleObjectResponseBodyTestStatus",
    "CarrierProposedAssignment",
    "CarrierProposedAssignmentAcceptedTime",
    "CarrierProposedAssignmentActiveTime",
    "CarrierProposedAssignmentDriver",
    "CarrierProposedAssignmentDriverAllOf",
    "CarrierProposedAssignmentDriverAllOf2ExternalIds",
    "CarrierProposedAssignmentFirstSeenTime",
    "CarrierProposedAssignmentId",
    "CarrierProposedAssignmentRejectedTime",
    "CarrierProposedAssignmentResponse",
    "CarrierProposedAssignmentShippingDocs",
    "CarrierProposedAssignmentTrailer",
    "CarrierProposedAssignmentTrailers",
    "CarrierProposedAssignmentVehicle",
    "CellConnectivityResponseResponseBody",
    "CellConnectivityResponseResponseBodySignalBar",
    "CellSignalLossDetailsObjectRequestBody",
    "CellSignalLossDetailsObjectResponseBody",
    "CellSignalLossResponseBody",
    "CircleRequestBody",
    "CircleResponseBody",
    "CloudBackupUploadIssueResponseBody",
    "CoachAssignmentWithDriverExternalIdsResponseResponseBody",
    "CoachAssignmentWithoutDriverExternalIdsResponseResponseBody",
    "CoachableEventResponseBody",
    "CoachingSessionsGetCoachingSessionsBadGatewayErrorResponseBody",
    "CoachingSessionsGetCoachingSessionsGatewayTimeoutErrorResponseBody",
    "CoachingSessionsGetCoachingSessionsInternalServerErrorResponseBody",
    "CoachingSessionsGetCoachingSessionsMethodNotAllowedErrorResponseBody",
    "CoachingSessionsGetCoachingSessionsNotFoundErrorResponseBody",
    "CoachingSessionsGetCoachingSessionsNotImplementedErrorResponseBody",
    "CoachingSessionsGetCoachingSessionsResponseBody",
    "CoachingSessionsGetCoachingSessionsServiceUnavailableErrorResponseBody",
    "CoachingSessionsGetCoachingSessionsTooManyRequestsErrorResponseBody",
    "CoachingSessionsGetCoachingSessionsUnauthorizedErrorResponseBody",
    "CoachingSessionsResponseResponseBody",
    "CoachingSessionsResponseResponseBodyCoachingType",
    "CoachingSessionsResponseResponseBodySessionStatus",
    "CoastingDurationMs",
    "ColumnResponseBody",
    "ColumnResponseBodyDataType",
    "ColumnResponseBodyUnit",
    "ConditionalFieldSectionObjectResponseBody",
    "ConnectionStatusResponseObjectResponseBody",
    "ConnectionStatusResponseObjectResponseBodyHealthStatus",
    "Contact",
    "ContactEmail",
    "ContactFirstName",
    "ContactId",
    "ContactLastName",
    "ContactPhone",
    "ContactResponse",
    "ContactTinyResponse",
    "ContinuousReadingAlertThresholdResponseBody",
    "ContinuousReadingAlertThresholdResponseBodyOperation",
    "ContinuousReadingAlertThresholdResponseBodyUnit",
    "CreateAddressRequestAddressTypesItem",
    "CreateAddressRequestGeofence",
    "CreateAddressRequestGeofenceSettings",
    "CreateAttributeRequestAttributeType",
    "CreateAttributeRequestEntities",
    "CreateAttributeRequestEntityType",
    "CreateAttributeRequestUnit",
    "CreateDriverAuthTokenResponseResponseBody",
    "CreateDriverRequestAttributes",
    "CreateDriverRequestLocale",
    "CreateDvirRequestSafetyStatus",
    "CreateDvirRequestType",
    "CreateFunctionDetailResponseBody",
    "CreateFunctionRequestConfigRequestBody",
    "CreateFunctionRequestConfigRequestBodyParams",
    "CreateFunctionRequestConfigRequestBodySecrets",
    "CreateReportConfigColumnRequestBody",
    "CreateReportConfigObjectRequestBody",
    "CreateRoutesStopRequestObjectRequestBody",
    "CreateUserRequestAuthType",
    "CreateUserRequestRoles",
    "CruiseControlDurationMs",
    "CumulativeOperatingHoursResponseBody",
    "CurrentDutyStatus",
    "CurrentDutyStatusHosStatusType",
    "CustomHeadersObjectRequestBody",
    "CustomHeadersObjectResponseBody",
    "CustomMetadata",
    "DashcamDisconnectedResponseBody",
    "DataInputListResponse",
    "DataInputResponse",
    "DataInputResponseAllOf",
    "DataInputSnapshot",
    "DataInputSnapshotAllOf",
    "DataInputSnapshotResponse",
    "DataInputTinyResponse",
    "DataInputValueResponseBody",
    "DataInputsTinyResponse",
    "DataUsageResponseObjectResponseBody",
    "DateTimeValueObjectRequestBody",
    "DateTimeValueObjectResponseBody",
    "DefLevelTriggerDetailsObjectRequestBody",
    "DefLevelTriggerDetailsObjectRequestBodyOperation",
    "DefLevelTriggerDetailsObjectResponseBody",
    "DefLevelTriggerDetailsObjectResponseBodyOperation",
    "DefRemainingResponseBody",
    "Defect",
    "DefectPhotoResponseResponseBody",
    "DefectResolvedBy",
    "DefectResolvedByType",
    "DefectResponse",
    "DefectTrailer",
    "DefectTrailerResponseResponseBody",
    "DefectTypesResponseDataResponseBody",
    "DefectTypesResponseDataResponseBodySectionType",
    "DefectTypesResponseDataResponseBodySeverity",
    "DefectVehicle",
    "DefectVehicleResponseResponseBody",
    "DefectsResponse",
    "DefectsResponseDataResponseBody",
    "DeleteAttributesRequestEntityType",
    "DeployFunctionDetailResponseBody",
    "DepreciationGetDepreciationTransactionsBadGatewayErrorResponseBody",
    "DepreciationGetDepreciationTransactionsGatewayTimeoutErrorResponseBody",
    "DepreciationGetDepreciationTransactionsInternalServerErrorResponseBody",
    "DepreciationGetDepreciationTransactionsMethodNotAllowedErrorResponseBody",
    "DepreciationGetDepreciationTransactionsNotFoundErrorResponseBody",
    "DepreciationGetDepreciationTransactionsNotImplementedErrorResponseBody",
    "DepreciationGetDepreciationTransactionsResponseBody",
    "DepreciationGetDepreciationTransactionsServiceUnavailableErrorResponseBody",
    "DepreciationGetDepreciationTransactionsTooManyRequestsErrorResponseBody",
    "DepreciationGetDepreciationTransactionsUnauthorizedErrorResponseBody",
    "DepreciationTransactionMoneyObjectResponseBody",
    "DepreciationTransactionMoneyObjectResponseBodyCurrency",
    "DepreciationTransactionObjectResponseBody",
    "DepreciationTransactionObjectResponseBodyTransactionType",
    "DetectionLogAssetObjectResponseBody",
    "DetectionLogDetectionObjectResponseBody",
    "DetectionLogDetectionObjectResponseBodyTriggerDetectionLabel",
    "DetectionLogDriverObjectResponseBody",
    "DetectionLogGetDetectionsBadGatewayErrorResponseBody",
    "DetectionLogGetDetectionsGatewayTimeoutErrorResponseBody",
    "DetectionLogGetDetectionsInternalServerErrorResponseBody",
    "DetectionLogGetDetectionsMethodNotAllowedErrorResponseBody",
    "DetectionLogGetDetectionsNotFoundErrorResponseBody",
    "DetectionLogGetDetectionsNotImplementedErrorResponseBody",
    "DetectionLogGetDetectionsResponseBody",
    "DetectionLogGetDetectionsServiceUnavailableErrorResponseBody",
    "DetectionLogGetDetectionsTooManyRequestsErrorResponseBody",
    "DetectionLogGetDetectionsUnauthorizedErrorResponseBody",
    "DetectionLogSafetyEventObjectResponseBody",
    "DetectionLogSafetyEventObjectResponseBodyInboxFilterReason",
    "DeviceAssetResponseResponseBody",
    "DeviceMovementDataResponseBody",
    "DeviceMovementStoppedDataResponseBody",
    "DeviceMovementTriggerDetailsObjectRequestBody",
    "DeviceMovementTriggerDetailsObjectResponseBody",
    "DeviceRecoveryListDeviceRecoveryMissingAssetsBadGatewayErrorResponseBody",
    "DeviceRecoveryListDeviceRecoveryMissingAssetsGatewayTimeoutErrorResponseBody",
    "DeviceRecoveryListDeviceRecoveryMissingAssetsInternalServerErrorResponseBody",
    "DeviceRecoveryListDeviceRecoveryMissingAssetsMethodNotAllowedErrorResponseBody",
    "DeviceRecoveryListDeviceRecoveryMissingAssetsNotFoundErrorResponseBody",
    "DeviceRecoveryListDeviceRecoveryMissingAssetsNotImplementedErrorResponseBody",
    "DeviceRecoveryListDeviceRecoveryMissingAssetsResponseBody",
    "DeviceRecoveryListDeviceRecoveryMissingAssetsServiceUnavailableErrorResponseBody",
    "DeviceRecoveryListDeviceRecoveryMissingAssetsTooManyRequestsErrorResponseBody",
    "DeviceRecoveryListDeviceRecoveryMissingAssetsUnauthorizedErrorResponseBody",
    "DeviceRecoveryMarkAssetMissingBadGatewayErrorResponseBody",
    "DeviceRecoveryMarkAssetMissingGatewayTimeoutErrorResponseBody",
    "DeviceRecoveryMarkAssetMissingInternalServerErrorResponseBody",
    "DeviceRecoveryMarkAssetMissingMethodNotAllowedErrorResponseBody",
    "DeviceRecoveryMarkAssetMissingNotFoundErrorResponseBody",
    "DeviceRecoveryMarkAssetMissingNotImplementedErrorResponseBody",
    "DeviceRecoveryMarkAssetMissingResponseBody",
    "DeviceRecoveryMarkAssetMissingServiceUnavailableErrorResponseBody",
    "DeviceRecoveryMarkAssetMissingTooManyRequestsErrorResponseBody",
    "DeviceRecoveryMarkAssetMissingUnauthorizedErrorResponseBody",
    "DeviceRecoveryRecoverAssetBadGatewayErrorResponseBody",
    "DeviceRecoveryRecoverAssetGatewayTimeoutErrorResponseBody",
    "DeviceRecoveryRecoverAssetInternalServerErrorResponseBody",
    "DeviceRecoveryRecoverAssetMethodNotAllowedErrorResponseBody",
    "DeviceRecoveryRecoverAssetNotFoundErrorResponseBody",
    "DeviceRecoveryRecoverAssetNotImplementedErrorResponseBody",
    "DeviceRecoveryRecoverAssetRequestBodyMissingReason",
    "DeviceRecoveryRecoverAssetRequestBodyRecoveryStatus",
    "DeviceRecoveryRecoverAssetRequestBodyStatus",
    "DeviceRecoveryRecoverAssetResponseBody",
    "DeviceRecoveryRecoverAssetServiceUnavailableErrorResponseBody",
    "DeviceRecoveryRecoverAssetTooManyRequestsErrorResponseBody",
    "DeviceRecoveryRecoverAssetUnauthorizedErrorResponseBody",
    "DeviceResponseResponseBody",
    "DeviceResponseResponseBodyModel",
    "DevicesGetDevicesBadGatewayErrorResponseBody",
    "DevicesGetDevicesGatewayTimeoutErrorResponseBody",
    "DevicesGetDevicesInternalServerErrorResponseBody",
    "DevicesGetDevicesMethodNotAllowedErrorResponseBody",
    "DevicesGetDevicesNotFoundErrorResponseBody",
    "DevicesGetDevicesNotImplementedErrorResponseBody",
    "DevicesGetDevicesResponseBody",
    "DevicesGetDevicesServiceUnavailableErrorResponseBody",
    "DevicesGetDevicesTooManyRequestsErrorResponseBody",
    "DevicesGetDevicesUnauthorizedErrorResponseBody",
    "DistanceDrivenMeters",
    "DistanceResponseBody",
    "DistanceTraveledObjectResponseBody",
    "DistractedDrivingDetectionAlertSettingsObjectResponseBody",
    "DocumentPdfGenerationResponse",
    "DocumentPdfGenerationResponseData",
    "DocumentPdfQueryResponse",
    "DocumentPdfQueryResponseData",
    "DocumentPdfQueryResponseDataJobStatus",
    "DocumentResponseObjectResponseBody",
    "DocumentResponseObjectResponseBodyState",
    "DocumentTypesGetDocumentTypesBadGatewayErrorResponseBody",
    "DocumentTypesGetDocumentTypesGatewayTimeoutErrorResponseBody",
    "DocumentTypesGetDocumentTypesInternalServerErrorResponseBody",
    "DocumentTypesGetDocumentTypesMethodNotAllowedErrorResponseBody",
    "DocumentTypesGetDocumentTypesNotFoundErrorResponseBody",
    "DocumentTypesGetDocumentTypesNotImplementedErrorResponseBody",
    "DocumentTypesGetDocumentTypesResponseBody",
    "DocumentTypesGetDocumentTypesServiceUnavailableErrorResponseBody",
    "DocumentTypesGetDocumentTypesTooManyRequestsErrorResponseBody",
    "DocumentTypesGetDocumentTypesUnauthorizedErrorResponseBody",
    "DocumentsDeleteDocumentBadGatewayErrorResponseBody",
    "DocumentsDeleteDocumentGatewayTimeoutErrorResponseBody",
    "DocumentsDeleteDocumentInternalServerErrorResponseBody",
    "DocumentsDeleteDocumentMethodNotAllowedErrorResponseBody",
    "DocumentsDeleteDocumentNotFoundErrorResponseBody",
    "DocumentsDeleteDocumentNotImplementedErrorResponseBody",
    "DocumentsDeleteDocumentServiceUnavailableErrorResponseBody",
    "DocumentsDeleteDocumentTooManyRequestsErrorResponseBody",
    "DocumentsDeleteDocumentUnauthorizedErrorResponseBody",
    "DocumentsGetDocumentBadGatewayErrorResponseBody",
    "DocumentsGetDocumentGatewayTimeoutErrorResponseBody",
    "DocumentsGetDocumentInternalServerErrorResponseBody",
    "DocumentsGetDocumentMethodNotAllowedErrorResponseBody",
    "DocumentsGetDocumentNotFoundErrorResponseBody",
    "DocumentsGetDocumentNotImplementedErrorResponseBody",
    "DocumentsGetDocumentResponseBody",
    "DocumentsGetDocumentServiceUnavailableErrorResponseBody",
    "DocumentsGetDocumentTooManyRequestsErrorResponseBody",
    "DocumentsGetDocumentUnauthorizedErrorResponseBody",
    "DocumentsGetDocumentsBadGatewayErrorResponseBody",
    "DocumentsGetDocumentsGatewayTimeoutErrorResponseBody",
    "DocumentsGetDocumentsInternalServerErrorResponseBody",
    "DocumentsGetDocumentsMethodNotAllowedErrorResponseBody",
    "DocumentsGetDocumentsNotFoundErrorResponseBody",
    "DocumentsGetDocumentsNotImplementedErrorResponseBody",
    "DocumentsGetDocumentsResponseBody",
    "DocumentsGetDocumentsServiceUnavailableErrorResponseBody",
    "DocumentsGetDocumentsTooManyRequestsErrorResponseBody",
    "DocumentsGetDocumentsUnauthorizedErrorResponseBody",
    "DocumentsPostDocumentBadGatewayErrorResponseBody",
    "DocumentsPostDocumentGatewayTimeoutErrorResponseBody",
    "DocumentsPostDocumentInternalServerErrorResponseBody",
    "DocumentsPostDocumentMethodNotAllowedErrorResponseBody",
    "DocumentsPostDocumentNotFoundErrorResponseBody",
    "DocumentsPostDocumentNotImplementedErrorResponseBody",
    "DocumentsPostDocumentRequestBodyState",
    "DocumentsPostDocumentResponseBody",
    "DocumentsPostDocumentServiceUnavailableErrorResponseBody",
    "DocumentsPostDocumentTooManyRequestsErrorResponseBody",
    "DocumentsPostDocumentUnauthorizedErrorResponseBody",
    "DoorOpenResponseBody",
    "DriveTimeDurationMs",
    "Driver",
    "DriverActivationStatus",
    "DriverAppNotificationObjectRequestBody",
    "DriverAppNotificationObjectResponseBody",
    "DriverAppSettingsGamificationConfigTinyObjectRequestBody",
    "DriverAppSettingsGamificationConfigTinyObjectResponseBody",
    "DriverAppSettingsResponseObjectResponseBody",
    "DriverAppSettingsTrailerSelectionConfigTinyObjectRequestBody",
    "DriverAppSettingsTrailerSelectionConfigTinyObjectResponseBody",
    "DriverAppSignInResponseBody",
    "DriverAppSignOutResponseBody",
    "DriverAssignmentMetadataTinyObjectResponseBody",
    "DriverAssignmentObjectResponseBody",
    "DriverAssignmentObjectResponseBodyAssignmentType",
    "DriverCarrierSettings",
    "DriverCoachAssignmentsGetDriverCoachAssignmentBadGatewayErrorResponseBody",
    "DriverCoachAssignmentsGetDriverCoachAssignmentGatewayTimeoutErrorResponseBody",
    "DriverCoachAssignmentsGetDriverCoachAssignmentInternalServerErrorResponseBody",
    "DriverCoachAssignmentsGetDriverCoachAssignmentMethodNotAllowedErrorResponseBody",
    "DriverCoachAssignmentsGetDriverCoachAssignmentNotFoundErrorResponseBody",
    "DriverCoachAssignmentsGetDriverCoachAssignmentNotImplementedErrorResponseBody",
    "DriverCoachAssignmentsGetDriverCoachAssignmentResponseBody",
    "DriverCoachAssignmentsGetDriverCoachAssignmentServiceUnavailableErrorResponseBody",
    "DriverCoachAssignmentsGetDriverCoachAssignmentTooManyRequestsErrorResponseBody",
    "DriverCoachAssignmentsGetDriverCoachAssignmentUnauthorizedErrorResponseBody",
    "DriverCoachAssignmentsPutDriverCoachAssignmentBadGatewayErrorResponseBody",
    "DriverCoachAssignmentsPutDriverCoachAssignmentGatewayTimeoutErrorResponseBody",
    "DriverCoachAssignmentsPutDriverCoachAssignmentInternalServerErrorResponseBody",
    "DriverCoachAssignmentsPutDriverCoachAssignmentMethodNotAllowedErrorResponseBody",
    "DriverCoachAssignmentsPutDriverCoachAssignmentNotFoundErrorResponseBody",
    "DriverCoachAssignmentsPutDriverCoachAssignmentNotImplementedErrorResponseBody",
    "DriverCoachAssignmentsPutDriverCoachAssignmentResponseBody",
    "DriverCoachAssignmentsPutDriverCoachAssignmentServiceUnavailableErrorResponseBody",
    "DriverCoachAssignmentsPutDriverCoachAssignmentTooManyRequestsErrorResponseBody",
    "DriverCoachAssignmentsPutDriverCoachAssignmentUnauthorizedErrorResponseBody",
    "DriverCreatedAtTime",
    "DriverDocumentSubmittedDetailsObjectRequestBody",
    "DriverDocumentSubmittedDetailsObjectResponseBody",
    "DriverDocumentSubmittedResponseBody",
    "DriverEfficienciesResponse",
    "DriverEfficienciesResponseData",
    "DriverEfficiency",
    "DriverEfficiencyDataObjectResponseBody",
    "DriverEfficiencyDifficultyScoreDataObjectResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByDriversBadGatewayErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByDriversGatewayTimeoutErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByDriversInternalServerErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByDriversMethodNotAllowedErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByDriversNotFoundErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByDriversNotImplementedErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByDriversResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByDriversServiceUnavailableErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByDriversTooManyRequestsErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByDriversUnauthorizedErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesBadGatewayErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesGatewayTimeoutErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesInternalServerErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesMethodNotAllowedErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesNotFoundErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesNotImplementedErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesServiceUnavailableErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesTooManyRequestsErrorResponseBody",
    "DriverEfficiencyGetDriverEfficiencyByVehiclesUnauthorizedErrorResponseBody",
    "DriverEfficiencyPercentageDataObjectResponseBody",
    "DriverEfficiencyRawDataObjectResponseBody",
    "DriverEldAdverseWeatherExemptionEnabled",
    "DriverEldBigDayExemptionEnabled",
    "DriverEldDayStartHour",
    "DriverEldExempt",
    "DriverEldExemptReason",
    "DriverEldPcEnabled",
    "DriverEldRuleset",
    "DriverEldRulesetCycle",
    "DriverEldRulesetJurisdiction",
    "DriverEldRulesetRestBreak",
    "DriverEldRulesetRestart",
    "DriverEldRulesetShift",
    "DriverEldRulesets",
    "DriverEldSettings",
    "DriverEldYmEnabled",
    "DriverExternalIds",
    "DriverHasDrivingFeaturesHidden",
    "DriverHasVehicleUnpinningEnabled",
    "DriverHeavyHaulExemptionToggleEnabled",
    "DriverHomeTerminalAddress",
    "DriverHomeTerminalName",
    "DriverHosSetting",
    "DriverId",
    "DriverIdCardCode",
    "DriverIsDeactivated",
    "DriverLicenseNumber",
    "DriverLicenseState",
    "DriverLocale",
    "DriverMessageReceivedResponseBody",
    "DriverMessageSentResponseBody",
    "DriverName",
    "DriverNotes",
    "DriverObjectResponseBody",
    "DriverOrTagIdsDetailsRequestBody",
    "DriverOrTagIdsDetailsResponseBody",
    "DriverPhone",
    "DriverProfileImageBase64",
    "DriverProfileImageUrl",
    "DriverQrCodesCreateDriverQrCodeBadGatewayErrorResponseBody",
    "DriverQrCodesCreateDriverQrCodeGatewayTimeoutErrorResponseBody",
    "DriverQrCodesCreateDriverQrCodeInternalServerErrorResponseBody",
    "DriverQrCodesCreateDriverQrCodeMethodNotAllowedErrorResponseBody",
    "DriverQrCodesCreateDriverQrCodeNotFoundErrorResponseBody",
    "DriverQrCodesCreateDriverQrCodeNotImplementedErrorResponseBody",
    "DriverQrCodesCreateDriverQrCodeResponseBody",
    "DriverQrCodesCreateDriverQrCodeServiceUnavailableErrorResponseBody",
    "DriverQrCodesCreateDriverQrCodeTooManyRequestsErrorResponseBody",
    "DriverQrCodesCreateDriverQrCodeUnauthorizedErrorResponseBody",
    "DriverQrCodesDeleteDriverQrCodeBadGatewayErrorResponseBody",
    "DriverQrCodesDeleteDriverQrCodeGatewayTimeoutErrorResponseBody",
    "DriverQrCodesDeleteDriverQrCodeInternalServerErrorResponseBody",
    "DriverQrCodesDeleteDriverQrCodeMethodNotAllowedErrorResponseBody",
    "DriverQrCodesDeleteDriverQrCodeNotFoundErrorResponseBody",
    "DriverQrCodesDeleteDriverQrCodeNotImplementedErrorResponseBody",
    "DriverQrCodesDeleteDriverQrCodeServiceUnavailableErrorResponseBody",
    "DriverQrCodesDeleteDriverQrCodeTooManyRequestsErrorResponseBody",
    "DriverQrCodesDeleteDriverQrCodeUnauthorizedErrorResponseBody",
    "DriverQrCodesGetDriversQrCodesBadGatewayErrorResponseBody",
    "DriverQrCodesGetDriversQrCodesGatewayTimeoutErrorResponseBody",
    "DriverQrCodesGetDriversQrCodesInternalServerErrorResponseBody",
    "DriverQrCodesGetDriversQrCodesMethodNotAllowedErrorResponseBody",
    "DriverQrCodesGetDriversQrCodesNotFoundErrorResponseBody",
    "DriverQrCodesGetDriversQrCodesNotImplementedErrorResponseBody",
    "DriverQrCodesGetDriversQrCodesResponseBody",
    "DriverQrCodesGetDriversQrCodesServiceUnavailableErrorResponseBody",
    "DriverQrCodesGetDriversQrCodesTooManyRequestsErrorResponseBody",
    "DriverQrCodesGetDriversQrCodesUnauthorizedErrorResponseBody",
    "DriverRecordedResponseBody",
    "DriverRemoteSignoutPostDriverRemoteSignoutBadGatewayErrorResponseBody",
    "DriverRemoteSignoutPostDriverRemoteSignoutGatewayTimeoutErrorResponseBody",
    "DriverRemoteSignoutPostDriverRemoteSignoutInternalServerErrorResponseBody",
    "DriverRemoteSignoutPostDriverRemoteSignoutMethodNotAllowedErrorResponseBody",
    "DriverRemoteSignoutPostDriverRemoteSignoutNotFoundErrorResponseBody",
    "DriverRemoteSignoutPostDriverRemoteSignoutNotImplementedErrorResponseBody",
    "DriverRemoteSignoutPostDriverRemoteSignoutResponseBody",
    "DriverRemoteSignoutPostDriverRemoteSignoutServiceUnavailableErrorResponseBody",
    "DriverRemoteSignoutPostDriverRemoteSignoutTooManyRequestsErrorResponseBody",
    "DriverRemoteSignoutPostDriverRemoteSignoutUnauthorizedErrorResponseBody",
    "DriverResponse",
    "DriverRulesetObjectResponseBody",
    "DriverRulesetObjectResponseBodyBreak",
    "DriverRulesetObjectResponseBodyCycle",
    "DriverRulesetObjectResponseBodyRestart",
    "DriverRulesetObjectResponseBodyShift",
    "DriverSafetyScoreResponseBody",
    "DriverStaticAssignedVehicle",
    "DriverTachographActivityData",
    "DriverTachographActivityResponse",
    "DriverTachographCardNumber",
    "DriverTags",
    "DriverTimezone",
    "DriverTinyResponse",
    "DriverUpdatedAtTime",
    "DriverUsername",
    "DriverVehicleAssignmentV2ObjectResponseBody",
    "DriverVehicleAssignmentV2ObjectResponseBodyAssignmentType",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentBadGatewayErrorResponseBody",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentGatewayTimeoutErrorResponseBody",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentInternalServerErrorResponseBody",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentMethodNotAllowedErrorResponseBody",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentNotFoundErrorResponseBody",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentNotImplementedErrorResponseBody",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentResponseBody",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentServiceUnavailableErrorResponseBody",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentTooManyRequestsErrorResponseBody",
    "DriverVehicleAssignmentsV2CreateDriverVehicleAssignmentUnauthorizedErrorResponseBody",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsBadGatewayErrorResponseBody",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsGatewayTimeoutErrorResponseBody",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsInternalServerErrorResponseBody",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsMethodNotAllowedErrorResponseBody",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsNotFoundErrorResponseBody",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsNotImplementedErrorResponseBody",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsServiceUnavailableErrorResponseBody",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsTooManyRequestsErrorResponseBody",
    "DriverVehicleAssignmentsV2DeleteDriverVehicleAssignmentsUnauthorizedErrorResponseBody",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsBadGatewayErrorResponseBody",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsGatewayTimeoutErrorResponseBody",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsInternalServerErrorResponseBody",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsMethodNotAllowedErrorResponseBody",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsNotFoundErrorResponseBody",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsNotImplementedErrorResponseBody",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsResponseBody",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsServiceUnavailableErrorResponseBody",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsTooManyRequestsErrorResponseBody",
    "DriverVehicleAssignmentsV2GetDriverVehicleAssignmentsUnauthorizedErrorResponseBody",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentBadGatewayErrorResponseBody",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentGatewayTimeoutErrorResponseBody",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentInternalServerErrorResponseBody",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentMethodNotAllowedErrorResponseBody",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentNotFoundErrorResponseBody",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentNotImplementedErrorResponseBody",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentResponseBody",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentServiceUnavailableErrorResponseBody",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentTooManyRequestsErrorResponseBody",
    "DriverVehicleAssignmentsV2UpdateDriverVehicleAssignmentUnauthorizedErrorResponseBody",
    "DriverVehicleGroupTag",
    "DriverWaitingTimeDutyStatusEnabled",
    "DriverWithExternalIdObjectResponseBody",
    "DriverWithTimezoneEldSettingsObjectResponseBody",
    "DriversAuthTokenCreateDriverAuthTokenBadGatewayErrorResponseBody",
    "DriversAuthTokenCreateDriverAuthTokenGatewayTimeoutErrorResponseBody",
    "DriversAuthTokenCreateDriverAuthTokenInternalServerErrorResponseBody",
    "DriversAuthTokenCreateDriverAuthTokenMethodNotAllowedErrorResponseBody",
    "DriversAuthTokenCreateDriverAuthTokenNotFoundErrorResponseBody",
    "DriversAuthTokenCreateDriverAuthTokenNotImplementedErrorResponseBody",
    "DriversAuthTokenCreateDriverAuthTokenResponseBody",
    "DriversAuthTokenCreateDriverAuthTokenServiceUnavailableErrorResponseBody",
    "DriversAuthTokenCreateDriverAuthTokenTooManyRequestsErrorResponseBody",
    "DriversAuthTokenCreateDriverAuthTokenUnauthorizedErrorResponseBody",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsBadGatewayErrorResponseBody",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsGatewayTimeoutErrorResponseBody",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsInternalServerErrorResponseBody",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsMethodNotAllowedErrorResponseBody",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsNotFoundErrorResponseBody",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsNotImplementedErrorResponseBody",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsResponseBody",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsServiceUnavailableErrorResponseBody",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsTooManyRequestsErrorResponseBody",
    "DriversVehicleAssignmentsGetDriversVehicleAssignmentsUnauthorizedErrorResponseBody",
    "DriversVehicleAssignmentsObjectResponseBody",
    "DriversVehicleAssignmentsObjectResponseBodyDriverActivationStatus",
    "DutyStatusDurationObjectResponseBody",
    "Dvir",
    "Dvir2AssignedToPolymorphicUserObjectResponseBody",
    "Dvir2DeviceObjectResponseBody",
    "Dvir2FormSubmissionObjectResponseBody",
    "Dvir2RelatedDeviceObjectResponseBody",
    "Dvir2RelatedDeviceObjectResponseBodyAssetType",
    "Dvir2SubmissionResponseObjectResponseBody",
    "Dvir2SubmissionResponseObjectResponseBodyInspectionType",
    "DvirAuthorSignature",
    "DvirDefectGetDefectBadGatewayErrorResponseBody",
    "DvirDefectGetDefectGatewayTimeoutErrorResponseBody",
    "DvirDefectGetDefectInternalServerErrorResponseBody",
    "DvirDefectGetDefectMethodNotAllowedErrorResponseBody",
    "DvirDefectGetDefectNotFoundErrorResponseBody",
    "DvirDefectGetDefectNotImplementedErrorResponseBody",
    "DvirDefectGetDefectResponseBody",
    "DvirDefectGetDefectServiceUnavailableErrorResponseBody",
    "DvirDefectGetDefectTooManyRequestsErrorResponseBody",
    "DvirDefectGetDefectUnauthorizedErrorResponseBody",
    "DvirDefectStreamDefectsBadGatewayErrorResponseBody",
    "DvirDefectStreamDefectsGatewayTimeoutErrorResponseBody",
    "DvirDefectStreamDefectsInternalServerErrorResponseBody",
    "DvirDefectStreamDefectsMethodNotAllowedErrorResponseBody",
    "DvirDefectStreamDefectsNotFoundErrorResponseBody",
    "DvirDefectStreamDefectsNotImplementedErrorResponseBody",
    "DvirDefectStreamDefectsResponseBody",
    "DvirDefectStreamDefectsServiceUnavailableErrorResponseBody",
    "DvirDefectStreamDefectsTooManyRequestsErrorResponseBody",
    "DvirDefectStreamDefectsUnauthorizedErrorResponseBody",
    "DvirDefectTypeGetDefectTypesBadGatewayErrorResponseBody",
    "DvirDefectTypeGetDefectTypesGatewayTimeoutErrorResponseBody",
    "DvirDefectTypeGetDefectTypesInternalServerErrorResponseBody",
    "DvirDefectTypeGetDefectTypesMethodNotAllowedErrorResponseBody",
    "DvirDefectTypeGetDefectTypesNotFoundErrorResponseBody",
    "DvirDefectTypeGetDefectTypesNotImplementedErrorResponseBody",
    "DvirDefectTypeGetDefectTypesResponseBody",
    "DvirDefectTypeGetDefectTypesServiceUnavailableErrorResponseBody",
    "DvirDefectTypeGetDefectTypesTooManyRequestsErrorResponseBody",
    "DvirDefectTypeGetDefectTypesUnauthorizedErrorResponseBody",
    "DvirDefectsObjectV20220913ResponseBody",
    "DvirDefectsObjectV20220913ResponseBodyDefectSeverity",
    "DvirGetDvirBadGatewayErrorResponseBody",
    "DvirGetDvirGatewayTimeoutErrorResponseBody",
    "DvirGetDvirInternalServerErrorResponseBody",
    "DvirGetDvirMethodNotAllowedErrorResponseBody",
    "DvirGetDvirNotFoundErrorResponseBody",
    "DvirGetDvirNotImplementedErrorResponseBody",
    "DvirGetDvirResponseBody",
    "DvirGetDvirResponseBodySafetyStatus",
    "DvirGetDvirResponseBodyType",
    "DvirGetDvirServiceUnavailableErrorResponseBody",
    "DvirGetDvirTooManyRequestsErrorResponseBody",
    "DvirGetDvirUnauthorizedErrorResponseBody",
    "DvirGetDvirsBadGatewayErrorResponseBody",
    "DvirGetDvirsGatewayTimeoutErrorResponseBody",
    "DvirGetDvirsInternalServerErrorResponseBody",
    "DvirGetDvirsMethodNotAllowedErrorResponseBody",
    "DvirGetDvirsNotFoundErrorResponseBody",
    "DvirGetDvirsNotImplementedErrorResponseBody",
    "DvirGetDvirsResponseBody",
    "DvirGetDvirsServiceUnavailableErrorResponseBody",
    "DvirGetDvirsTooManyRequestsErrorResponseBody",
    "DvirGetDvirsUnauthorizedErrorResponseBody",
    "DvirLicensePlate",
    "DvirLocation",
    "DvirMechanicNotes",
    "DvirOdometerMeters",
    "DvirResolvedByObjectResponseBody",
    "DvirResolvedByObjectResponseBodyType",
    "DvirResponse",
    "DvirSafetyStatus",
    "DvirSecondSignature",
    "DvirSignature",
    "DvirSignatureSignatoryUser",
    "DvirSignatureType",
    "DvirStreamResponseDataResponseBody",
    "DvirStreamResponseDataResponseBodySafetyStatus",
    "DvirStreamResponseDataResponseBodyType",
    "DvirSubmittedDeviceTriggerDetailsObjectRequestBody",
    "DvirSubmittedDeviceTriggerDetailsObjectRequestBodyDvirSubmissionTypesItem",
    "DvirSubmittedDeviceTriggerDetailsObjectResponseBody",
    "DvirSubmittedDeviceTriggerDetailsObjectResponseBodyDvirSubmissionTypesItem",
    "DvirThirdSignature",
    "DvirTrailer",
    "DvirTrailerDefects",
    "DvirTrailerDefectsItems",
    "DvirTrailerDefectsItemsTrailer",
    "DvirTrailerDefectsItemsVehicle",
    "DvirType",
    "DvirVehicle",
    "DvirVehicleDefects",
    "DvirsListResponse",
    "EldSettingsObjectResponseBody",
    "EngineIdleDataResponseBody",
    "EngineIdleTriggerDetailsObjectRequestBody",
    "EngineIdleTriggerDetailsObjectResponseBody",
    "EngineImmobilizerGetEngineImmobilizerStatesBadGatewayErrorResponseBody",
    "EngineImmobilizerGetEngineImmobilizerStatesGatewayTimeoutErrorResponseBody",
    "EngineImmobilizerGetEngineImmobilizerStatesInternalServerErrorResponseBody",
    "EngineImmobilizerGetEngineImmobilizerStatesMethodNotAllowedErrorResponseBody",
    "EngineImmobilizerGetEngineImmobilizerStatesNotFoundErrorResponseBody",
    "EngineImmobilizerGetEngineImmobilizerStatesNotImplementedErrorResponseBody",
    "EngineImmobilizerGetEngineImmobilizerStatesResponseBody",
    "EngineImmobilizerGetEngineImmobilizerStatesServiceUnavailableErrorResponseBody",
    "EngineImmobilizerGetEngineImmobilizerStatesTooManyRequestsErrorResponseBody",
    "EngineImmobilizerGetEngineImmobilizerStatesUnauthorizedErrorResponseBody",
    "EngineImmobilizerRelayStateResponseBody",
    "EngineImmobilizerRelayStateResponseBodyId",
    "EngineImmobilizerStateResponseBody",
    "EngineImmobilizerUpdateEngineImmobilizerStateBadGatewayErrorResponseBody",
    "EngineImmobilizerUpdateEngineImmobilizerStateGatewayTimeoutErrorResponseBody",
    "EngineImmobilizerUpdateEngineImmobilizerStateInternalServerErrorResponseBody",
    "EngineImmobilizerUpdateEngineImmobilizerStateMethodNotAllowedErrorResponseBody",
    "EngineImmobilizerUpdateEngineImmobilizerStateNotFoundErrorResponseBody",
    "EngineImmobilizerUpdateEngineImmobilizerStateNotImplementedErrorResponseBody",
    "EngineImmobilizerUpdateEngineImmobilizerStateServiceUnavailableErrorResponseBody",
    "EngineImmobilizerUpdateEngineImmobilizerStateTooManyRequestsErrorResponseBody",
    "EngineImmobilizerUpdateEngineImmobilizerStateUnauthorizedErrorResponseBody",
    "EngineOffDetailsObjectRequestBody",
    "EngineOffDetailsObjectResponseBody",
    "EngineOffResponseBody",
    "EngineOnDetailsObjectRequestBody",
    "EngineOnDetailsObjectResponseBody",
    "EngineOnResponseBody",
    "EngineStatusResponseBody",
    "EnumReadingAlertThresholdResponseBody",
    "EnumValueResponseBody",
    "EquipmentEngineRpm",
    "EquipmentEngineSeconds",
    "EquipmentEngineState",
    "EquipmentEngineStateValue",
    "EquipmentEngineTotalIdleTimeMinutes",
    "EquipmentFuelPercent",
    "EquipmentGatewayEngineSeconds",
    "EquipmentGatewayEngineState",
    "EquipmentGatewayEngineStateValue",
    "EquipmentGatewayJ1939EngineSeconds",
    "EquipmentGpsOdometerMeters",
    "EquipmentHeaderWithAdditionalFieldsResponseBody",
    "EquipmentId",
    "EquipmentInstalledGateway",
    "EquipmentListResponse",
    "EquipmentLocation",
    "EquipmentLocationsListResponse",
    "EquipmentLocationsListResponseData",
    "EquipmentLocationsResponse",
    "EquipmentLocationsResponseData",
    "EquipmentName",
    "EquipmentObdEngineSeconds",
    "EquipmentObdEngineState",
    "EquipmentObdEngineStateValue",
    "EquipmentObject",
    "EquipmentPatchEquipmentBadGatewayErrorResponseBody",
    "EquipmentPatchEquipmentGatewayTimeoutErrorResponseBody",
    "EquipmentPatchEquipmentInternalServerErrorResponseBody",
    "EquipmentPatchEquipmentMethodNotAllowedErrorResponseBody",
    "EquipmentPatchEquipmentNotFoundErrorResponseBody",
    "EquipmentPatchEquipmentNotImplementedErrorResponseBody",
    "EquipmentPatchEquipmentResponseBody",
    "EquipmentPatchEquipmentServiceUnavailableErrorResponseBody",
    "EquipmentPatchEquipmentTooManyRequestsErrorResponseBody",
    "EquipmentPatchEquipmentUnauthorizedErrorResponseBody",
    "EquipmentResponse",
    "EquipmentStatsGps",
    "EquipmentStatsListResponse",
    "EquipmentStatsListResponseData",
    "EquipmentStatsResponse",
    "EquipmentStatsResponseData",
    "EquipmentTime",
    "EquipmentWithAttributesResponseObjectResponseBody",
    "EventLocationResponseBody",
    "ExtendedDriverTinyResponse",
    "ExtendedDriverTinyResponseExternalIds",
    "FftSpectraDataPoint",
    "FftSpectraDataPointFftSpectra",
    "FieldObjectPostRequestBody",
    "FieldObjectPostRequestBodyType",
    "FieldObjectResponseBody",
    "FieldObjectResponseBodyType",
    "FieldObjectValueRequestBody",
    "FieldObjectValueResponseBody",
    "FieldTypesObjectResponseBody",
    "FieldTypesObjectResponseBodyFieldType",
    "FiltersRequestBody",
    "FiltersResponseBody",
    "FleetDeviceObjectResponseBody",
    "FollowingDistanceDetectionAlertSettingsObjectResponseBody",
    "FormSubmissionPdfExportResponseObjectResponseBody",
    "FormSubmissionPdfExportResponseObjectResponseBodyJobStatus",
    "FormSubmissionRequestApprovalDetailsRequestBody",
    "FormSubmissionRequestAssetObjectRequestBody",
    "FormSubmissionRequestAssetValueObjectRequestBody",
    "FormSubmissionRequestAssignedToRequestBody",
    "FormSubmissionRequestAssignedToRequestBodyType",
    "FormSubmissionRequestCheckBoxesValueObjectRequestBody",
    "FormSubmissionRequestDateTimeValueObjectRequestBody",
    "FormSubmissionRequestFieldInputObjectRequestBody",
    "FormSubmissionRequestFieldInputObjectRequestBodyType",
    "FormSubmissionRequestGeofenceObjectRequestBody",
    "FormSubmissionRequestGeofenceValueObjectRequestBody",
    "FormSubmissionRequestMediaItemObjectRequestBody",
    "FormSubmissionRequestMediaValueObjectRequestBody",
    "FormSubmissionRequestMultipleChoiceValueObjectRequestBody",
    "FormSubmissionRequestNumberValueObjectRequestBody",
    "FormSubmissionRequestPersonObjectRequestBody",
    "FormSubmissionRequestPersonValueObjectRequestBody",
    "FormSubmissionRequestSignatureValueObjectRequestBody",
    "FormSubmissionRequestTableCellObjectRequestBody",
    "FormSubmissionRequestTableCellObjectRequestBodyType",
    "FormSubmissionRequestTableRowObjectRequestBody",
    "FormSubmissionRequestTableValueObjectRequestBody",
    "FormSubmissionRequestTextValueObjectRequestBody",
    "FormSubmissionResponseObjectResponseBody",
    "FormSubmissionResponseObjectResponseBodyStatus",
    "FormSubmissionsGetFormSubmissionsBadGatewayErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsGatewayTimeoutErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsInternalServerErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsMethodNotAllowedErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsNotFoundErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsNotImplementedErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsPdfExportsBadGatewayErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsPdfExportsGatewayTimeoutErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsPdfExportsInternalServerErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsPdfExportsMethodNotAllowedErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsPdfExportsNotFoundErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsPdfExportsNotImplementedErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsPdfExportsResponseBody",
    "FormSubmissionsGetFormSubmissionsPdfExportsServiceUnavailableErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsPdfExportsTooManyRequestsErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsPdfExportsUnauthorizedErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsResponseBody",
    "FormSubmissionsGetFormSubmissionsServiceUnavailableErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsStreamBadGatewayErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsStreamGatewayTimeoutErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsStreamInternalServerErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsStreamMethodNotAllowedErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsStreamNotFoundErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsStreamNotImplementedErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsStreamResponseBody",
    "FormSubmissionsGetFormSubmissionsStreamServiceUnavailableErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsStreamTooManyRequestsErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsStreamUnauthorizedErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsTooManyRequestsErrorResponseBody",
    "FormSubmissionsGetFormSubmissionsUnauthorizedErrorResponseBody",
    "FormSubmissionsPatchFormSubmissionBadGatewayErrorResponseBody",
    "FormSubmissionsPatchFormSubmissionGatewayTimeoutErrorResponseBody",
    "FormSubmissionsPatchFormSubmissionInternalServerErrorResponseBody",
    "FormSubmissionsPatchFormSubmissionMethodNotAllowedErrorResponseBody",
    "FormSubmissionsPatchFormSubmissionNotFoundErrorResponseBody",
    "FormSubmissionsPatchFormSubmissionNotImplementedErrorResponseBody",
    "FormSubmissionsPatchFormSubmissionRequestBodyStatus",
    "FormSubmissionsPatchFormSubmissionResponseBody",
    "FormSubmissionsPatchFormSubmissionServiceUnavailableErrorResponseBody",
    "FormSubmissionsPatchFormSubmissionTooManyRequestsErrorResponseBody",
    "FormSubmissionsPatchFormSubmissionUnauthorizedErrorResponseBody",
    "FormSubmissionsPostFormSubmissionBadGatewayErrorResponseBody",
    "FormSubmissionsPostFormSubmissionGatewayTimeoutErrorResponseBody",
    "FormSubmissionsPostFormSubmissionInternalServerErrorResponseBody",
    "FormSubmissionsPostFormSubmissionMethodNotAllowedErrorResponseBody",
    "FormSubmissionsPostFormSubmissionNotFoundErrorResponseBody",
    "FormSubmissionsPostFormSubmissionNotImplementedErrorResponseBody",
    "FormSubmissionsPostFormSubmissionRequestBodyStatus",
    "FormSubmissionsPostFormSubmissionResponseBody",
    "FormSubmissionsPostFormSubmissionServiceUnavailableErrorResponseBody",
    "FormSubmissionsPostFormSubmissionTooManyRequestsErrorResponseBody",
    "FormSubmissionsPostFormSubmissionUnauthorizedErrorResponseBody",
    "FormSubmissionsPostFormSubmissionsPdfExportsBadGatewayErrorResponseBody",
    "FormSubmissionsPostFormSubmissionsPdfExportsGatewayTimeoutErrorResponseBody",
    "FormSubmissionsPostFormSubmissionsPdfExportsInternalServerErrorResponseBody",
    "FormSubmissionsPostFormSubmissionsPdfExportsMethodNotAllowedErrorResponseBody",
    "FormSubmissionsPostFormSubmissionsPdfExportsNotFoundErrorResponseBody",
    "FormSubmissionsPostFormSubmissionsPdfExportsNotImplementedErrorResponseBody",
    "FormSubmissionsPostFormSubmissionsPdfExportsResponseBody",
    "FormSubmissionsPostFormSubmissionsPdfExportsServiceUnavailableErrorResponseBody",
    "FormSubmissionsPostFormSubmissionsPdfExportsTooManyRequestsErrorResponseBody",
    "FormSubmissionsPostFormSubmissionsPdfExportsUnauthorizedErrorResponseBody",
    "FormSubmittedResponseBody",
    "FormTemplateReferenceObjectResponseBody",
    "FormTemplateRequestObjectRequestBody",
    "FormTemplateResponseObjectResponseBody",
    "FormTemplateResponseObjectResponseBodyFormCategory",
    "FormTemplateSectionObjectResponseBody",
    "FormTemplatesGetFormTemplatesBadGatewayErrorResponseBody",
    "FormTemplatesGetFormTemplatesGatewayTimeoutErrorResponseBody",
    "FormTemplatesGetFormTemplatesInternalServerErrorResponseBody",
    "FormTemplatesGetFormTemplatesMethodNotAllowedErrorResponseBody",
    "FormTemplatesGetFormTemplatesNotFoundErrorResponseBody",
    "FormTemplatesGetFormTemplatesNotImplementedErrorResponseBody",
    "FormTemplatesGetFormTemplatesResponseBody",
    "FormTemplatesGetFormTemplatesServiceUnavailableErrorResponseBody",
    "FormTemplatesGetFormTemplatesTooManyRequestsErrorResponseBody",
    "FormTemplatesGetFormTemplatesUnauthorizedErrorResponseBody",
    "FormUpdatedResponseBody",
    "FormsActionObjectResponseBody",
    "FormsActionObjectResponseBodyType",
    "FormsApprovalConfigObjectResponseBody",
    "FormsApprovalConfigObjectResponseBodyType",
    "FormsAssetObjectResponseBody",
    "FormsAssetObjectResponseBodyEntryType",
    "FormsAssetValueObjectResponseBody",
    "FormsCheckBoxesValueObjectResponseBody",
    "FormsConditionObjectResponseBody",
    "FormsConditionObjectResponseBodyType",
    "FormsConditionalActionObjectResponseBody",
    "FormsDateTimeValueObjectResponseBody",
    "FormsDateTimeValueObjectResponseBodyType",
    "FormsFieldDefinitionObjectResponseBody",
    "FormsFieldDefinitionObjectResponseBodyAllowedAssetTypesItem",
    "FormsFieldDefinitionObjectResponseBodyAllowedDateTimeValueType",
    "FormsFieldDefinitionObjectResponseBodyType",
    "FormsFieldInputObjectResponseBody",
    "FormsFieldInputObjectResponseBodyType",
    "FormsGeofenceObjectResponseBody",
    "FormsGeofenceObjectResponseBodyEntryType",
    "FormsGeofenceValueObjectResponseBody",
    "FormsIssueCreatedByFieldObjectResponseBody",
    "FormsLocationObjectResponseBody",
    "FormsMediaRecordObjectResponseBody",
    "FormsMediaRecordObjectResponseBodyProcessingStatus",
    "FormsMediaValueObjectResponseBody",
    "FormsMultipleChoiceValueObjectResponseBody",
    "FormsNumberValueObjectResponseBody",
    "FormsPersonObjectResponseBody",
    "FormsPersonObjectResponseBodyEntryType",
    "FormsPersonValueObjectResponseBody",
    "FormsPolymorphicUserObjectResponseBody",
    "FormsPolymorphicUserObjectResponseBodyType",
    "FormsProductSubmissionApprovalDetailsObjectResponseBody",
    "FormsScoreObjectResponseBody",
    "FormsSelectOptionObjectResponseBody",
    "FormsSignatureValueObjectResponseBody",
    "FormsSingleApprovalConfigObjectResponseBody",
    "FormsTableCellObjectResponseBody",
    "FormsTableCellObjectResponseBodyType",
    "FormsTableColumnObjectResponseBody",
    "FormsTableColumnObjectResponseBodyType",
    "FormsTableFieldDefinitionObjectResponseBody",
    "FormsTableFieldDefinitionObjectResponseBodyAllowedDateTimeValueType",
    "FormsTableFieldDefinitionObjectResponseBodyType",
    "FormsTableRowObjectResponseBody",
    "FormsTableValueObjectResponseBody",
    "FormsTextValueObjectResponseBody",
    "ForwardCollisionDetectionAlertSettingsObjectResponseBody",
    "ForwardCollisionDetectionAlertSettingsObjectResponseBodySensitivity",
    "FuelConsumedMl",
    "FuelCostObjectResponseBody",
    "FuelCostObjectResponseBodyCurrency",
    "FuelEnergyCostResponseResponseBody",
    "FuelEnergyDriverReportDataObjectResponseBody",
    "FuelEnergyDriverReportObjectResponseBody",
    "FuelEnergyGetFuelEnergyDriverReportsBadGatewayErrorResponseBody",
    "FuelEnergyGetFuelEnergyDriverReportsGatewayTimeoutErrorResponseBody",
    "FuelEnergyGetFuelEnergyDriverReportsInternalServerErrorResponseBody",
    "FuelEnergyGetFuelEnergyDriverReportsMethodNotAllowedErrorResponseBody",
    "FuelEnergyGetFuelEnergyDriverReportsNotFoundErrorResponseBody",
    "FuelEnergyGetFuelEnergyDriverReportsNotImplementedErrorResponseBody",
    "FuelEnergyGetFuelEnergyDriverReportsResponseBody",
    "FuelEnergyGetFuelEnergyDriverReportsServiceUnavailableErrorResponseBody",
    "FuelEnergyGetFuelEnergyDriverReportsTooManyRequestsErrorResponseBody",
    "FuelEnergyGetFuelEnergyDriverReportsUnauthorizedErrorResponseBody",
    "FuelEnergyGetFuelEnergyVehicleReportsBadGatewayErrorResponseBody",
    "FuelEnergyGetFuelEnergyVehicleReportsGatewayTimeoutErrorResponseBody",
    "FuelEnergyGetFuelEnergyVehicleReportsInternalServerErrorResponseBody",
    "FuelEnergyGetFuelEnergyVehicleReportsMethodNotAllowedErrorResponseBody",
    "FuelEnergyGetFuelEnergyVehicleReportsNotFoundErrorResponseBody",
    "FuelEnergyGetFuelEnergyVehicleReportsNotImplementedErrorResponseBody",
    "FuelEnergyGetFuelEnergyVehicleReportsResponseBody",
    "FuelEnergyGetFuelEnergyVehicleReportsServiceUnavailableErrorResponseBody",
    "FuelEnergyGetFuelEnergyVehicleReportsTooManyRequestsErrorResponseBody",
    "FuelEnergyGetFuelEnergyVehicleReportsUnauthorizedErrorResponseBody",
    "FuelEnergyVehicleObjectResponseBody",
    "FuelEnergyVehicleObjectResponseBodyEnergyType",
    "FuelEnergyVehicleReportDataObjectResponseBody",
    "FuelEnergyVehicleReportObjectResponseBody",
    "FuelLevelPercentageResponseBody",
    "FuelLevelTriggerDetailsObjectRequestBody",
    "FuelLevelTriggerDetailsObjectRequestBodyOperation",
    "FuelLevelTriggerDetailsObjectResponseBody",
    "FuelLevelTriggerDetailsObjectResponseBodyOperation",
    "FuelPurchasePostFuelPurchaseBadGatewayErrorResponseBody",
    "FuelPurchasePostFuelPurchaseGatewayTimeoutErrorResponseBody",
    "FuelPurchasePostFuelPurchaseInternalServerErrorResponseBody",
    "FuelPurchasePostFuelPurchaseMethodNotAllowedErrorResponseBody",
    "FuelPurchasePostFuelPurchaseNotFoundErrorResponseBody",
    "FuelPurchasePostFuelPurchaseNotImplementedErrorResponseBody",
    "FuelPurchasePostFuelPurchaseRequestBodyFuelGrade",
    "FuelPurchasePostFuelPurchaseRequestBodyIftaFuelType",
    "FuelPurchasePostFuelPurchaseResponseBody",
    "FuelPurchasePostFuelPurchaseServiceUnavailableErrorResponseBody",
    "FuelPurchasePostFuelPurchaseTooManyRequestsErrorResponseBody",
    "FuelPurchasePostFuelPurchaseUnauthorizedErrorResponseBody",
    "FuelRemainingResponseBody",
    "FuelVolumeResponseBody",
    "FuelVolumeResponseBodyUnit",
    "FunctionCodePackageResponseBody",
    "FunctionCodePackageResponseBodyStatus",
    "FunctionConfigResponseBody",
    "FunctionConfigResponseBodyParams",
    "FunctionConfigResponseBodySecrets",
    "FunctionEffectsResponseBody",
    "FunctionScheduleEntryRequestBody",
    "FunctionScheduleEntryResponseBody",
    "FunctionScheduleRequestBody",
    "FunctionScheduleResponseBody",
    "FunctionsCreateFunctionBadGatewayErrorResponseBody",
    "FunctionsCreateFunctionGatewayTimeoutErrorResponseBody",
    "FunctionsCreateFunctionInternalServerErrorResponseBody",
    "FunctionsCreateFunctionMethodNotAllowedErrorResponseBody",
    "FunctionsCreateFunctionNotFoundErrorResponseBody",
    "FunctionsCreateFunctionNotImplementedErrorResponseBody",
    "FunctionsCreateFunctionResponseBody",
    "FunctionsCreateFunctionServiceUnavailableErrorResponseBody",
    "FunctionsCreateFunctionTooManyRequestsErrorResponseBody",
    "FunctionsCreateFunctionUnauthorizedErrorResponseBody",
    "FunctionsDeployFunctionBadGatewayErrorResponseBody",
    "FunctionsDeployFunctionGatewayTimeoutErrorResponseBody",
    "FunctionsDeployFunctionInternalServerErrorResponseBody",
    "FunctionsDeployFunctionMethodNotAllowedErrorResponseBody",
    "FunctionsDeployFunctionNotFoundErrorResponseBody",
    "FunctionsDeployFunctionNotImplementedErrorResponseBody",
    "FunctionsDeployFunctionResponseBody",
    "FunctionsDeployFunctionServiceUnavailableErrorResponseBody",
    "FunctionsDeployFunctionTooManyRequestsErrorResponseBody",
    "FunctionsDeployFunctionUnauthorizedErrorResponseBody",
    "FunctionsGetFunctionBadGatewayErrorResponseBody",
    "FunctionsGetFunctionGatewayTimeoutErrorResponseBody",
    "FunctionsGetFunctionInternalServerErrorResponseBody",
    "FunctionsGetFunctionMethodNotAllowedErrorResponseBody",
    "FunctionsGetFunctionNotFoundErrorResponseBody",
    "FunctionsGetFunctionNotImplementedErrorResponseBody",
    "FunctionsGetFunctionResponseBody",
    "FunctionsGetFunctionServiceUnavailableErrorResponseBody",
    "FunctionsGetFunctionTooManyRequestsErrorResponseBody",
    "FunctionsGetFunctionUnauthorizedErrorResponseBody",
    "FunctionsPatchFunctionBadGatewayErrorResponseBody",
    "FunctionsPatchFunctionGatewayTimeoutErrorResponseBody",
    "FunctionsPatchFunctionInternalServerErrorResponseBody",
    "FunctionsPatchFunctionMethodNotAllowedErrorResponseBody",
    "FunctionsPatchFunctionNotFoundErrorResponseBody",
    "FunctionsPatchFunctionNotImplementedErrorResponseBody",
    "FunctionsPatchFunctionResponseBody",
    "FunctionsPatchFunctionServiceUnavailableErrorResponseBody",
    "FunctionsPatchFunctionTooManyRequestsErrorResponseBody",
    "FunctionsPatchFunctionUnauthorizedErrorResponseBody",
    "FunctionsStartFunctionRunBadGatewayErrorResponseBody",
    "FunctionsStartFunctionRunGatewayTimeoutErrorResponseBody",
    "FunctionsStartFunctionRunInternalServerErrorResponseBody",
    "FunctionsStartFunctionRunMethodNotAllowedErrorResponseBody",
    "FunctionsStartFunctionRunNotFoundErrorResponseBody",
    "FunctionsStartFunctionRunNotImplementedErrorResponseBody",
    "FunctionsStartFunctionRunRequestBodyParamsOverride",
    "FunctionsStartFunctionRunResponseBody",
    "FunctionsStartFunctionRunServiceUnavailableErrorResponseBody",
    "FunctionsStartFunctionRunTooManyRequestsErrorResponseBody",
    "FunctionsStartFunctionRunUnauthorizedErrorResponseBody",
    "GaseousFuelCostObjectResponseBody",
    "GaseousFuelCostObjectResponseBodyCurrency",
    "GatewayAssetResponseObjectResponseBody",
    "GatewayDetailsResponseResponseBody",
    "GatewayDetailsResponseResponseBodyGatewayBatteryState",
    "GatewayDisconnectedDetailsObjectRequestBody",
    "GatewayDisconnectedDetailsObjectResponseBody",
    "GatewayDisconnectedResponseBody",
    "GatewayResponseObjectResponseBody",
    "GatewayResponseObjectResponseBodyModel",
    "GatewayTimeoutError",
    "GatewayTiny",
    "GatewayUnpluggedTriggerDetailsObjectRequestBody",
    "GatewayUnpluggedTriggerDetailsObjectResponseBody",
    "GatewayWithVehicleTinyResponseResponseBody",
    "GatewayWithVehicleTinyResponseResponseBodyModel",
    "GatewaysDeleteGatewayBadGatewayErrorResponseBody",
    "GatewaysDeleteGatewayGatewayTimeoutErrorResponseBody",
    "GatewaysDeleteGatewayInternalServerErrorResponseBody",
    "GatewaysDeleteGatewayMethodNotAllowedErrorResponseBody",
    "GatewaysDeleteGatewayNotFoundErrorResponseBody",
    "GatewaysDeleteGatewayNotImplementedErrorResponseBody",
    "GatewaysDeleteGatewayServiceUnavailableErrorResponseBody",
    "GatewaysDeleteGatewayTooManyRequestsErrorResponseBody",
    "GatewaysDeleteGatewayUnauthorizedErrorResponseBody",
    "GatewaysGetGatewaysBadGatewayErrorResponseBody",
    "GatewaysGetGatewaysGatewayTimeoutErrorResponseBody",
    "GatewaysGetGatewaysInternalServerErrorResponseBody",
    "GatewaysGetGatewaysMethodNotAllowedErrorResponseBody",
    "GatewaysGetGatewaysNotFoundErrorResponseBody",
    "GatewaysGetGatewaysNotImplementedErrorResponseBody",
    "GatewaysGetGatewaysResponseBody",
    "GatewaysGetGatewaysServiceUnavailableErrorResponseBody",
    "GatewaysGetGatewaysTooManyRequestsErrorResponseBody",
    "GatewaysGetGatewaysUnauthorizedErrorResponseBody",
    "GatewaysPostGatewayBadGatewayErrorResponseBody",
    "GatewaysPostGatewayGatewayTimeoutErrorResponseBody",
    "GatewaysPostGatewayInternalServerErrorResponseBody",
    "GatewaysPostGatewayMethodNotAllowedErrorResponseBody",
    "GatewaysPostGatewayNotFoundErrorResponseBody",
    "GatewaysPostGatewayNotImplementedErrorResponseBody",
    "GatewaysPostGatewayResponseBody",
    "GatewaysPostGatewayServiceUnavailableErrorResponseBody",
    "GatewaysPostGatewayTooManyRequestsErrorResponseBody",
    "GatewaysPostGatewayUnauthorizedErrorResponseBody",
    "GeofenceEntryTriggerDetailsObjectRequestBody",
    "GeofenceEntryTriggerDetailsObjectResponseBody",
    "GeofenceExitTriggerDetailsObjectRequestBody",
    "GeofenceExitTriggerDetailsObjectResponseBody",
    "GeofenceResponseResponseBody",
    "GetAssetsInputsRequestType",
    "GetAttributeRequestEntityType",
    "GetAttributesByEntityTypeRequestEntityType",
    "GetAttributesByEntityTypeResponse",
    "GetConfigurationsRequestStatus",
    "GetDocumentTypeResponseObjectResponseBody",
    "GetDriverEfficiencyRequestDriverActivationStatus",
    "GetDriverTrailerAssignmentsResponseBodyResponseBody",
    "GetDriverVehicleAssignmentsRequestAssignmentType",
    "GetDriverVehicleAssignmentsRequestFilterBy",
    "GetDriversVehicleAssignmentsRequestDriverActivationStatus",
    "GetEquipmentStatsFeedRequestTypesItem",
    "GetEquipmentStatsHistoryRequestTypesItem",
    "GetEquipmentStatsRequestTypesItem",
    "GetFuelEnergyVehicleReportsRequestEnergyType",
    "GetFunctionDetailResponseBody",
    "GetHosDailyLogsRequestDriverActivationStatus",
    "GetHosDailyLogsRequestExpand",
    "GetHosEldEventsRequestDriverActivationStatus",
    "GetIdlingEventsRequestPtoState",
    "GetIftaJurisdictionReportsRequestFuelType",
    "GetIftaJurisdictionReportsRequestMonth",
    "GetIftaJurisdictionReportsRequestQuarter",
    "GetIftaVehicleReportsRequestFuelType",
    "GetIftaVehicleReportsRequestMonth",
    "GetIftaVehicleReportsRequestQuarter",
    "GetJobsRequestStatus",
    "GetLiveSharingLinksRequestType",
    "GetMediaRetrievalObjectResponseBody",
    "GetQualificationRecordsStreamRequestEntityType",
    "GetQualificationTypesRequestEntityType",
    "GetReportRunsDataObjectResponseBody",
    "GetReportRunsDataObjectResponseBodyStatus",
    "GetResponseWorkflowConfigurationObjectResponseBody",
    "GetRoutesFeedRequestExpand",
    "GetSafetyEventsV2StreamRequestQueryByTimeField",
    "GetSpeedingIntervalsRequestQueryBy",
    "GetTagGroupSafetyScoresRequestScoreType",
    "GetTagSafetyScoresRequestScoreType",
    "GetTripsRequestCompletionStatus",
    "GetTripsRequestQueryBy",
    "GetVehicleStatsFeedRequestDecorationsItem",
    "GetVehicleStatsFeedRequestTypesItem",
    "GetVehicleStatsHistoryRequestDecorationsItem",
    "GetVehicleStatsHistoryRequestTypesItem",
    "GetVehicleStatsRequestTypesItem",
    "GetWorkflowIncidentResponseObjectResponseBody",
    "GoaAddressTinyResponseResponseBody",
    "GoaAttributeTiny",
    "GoaAttributeTinyRequestBody",
    "GoaAttributeTinyResponseBody",
    "GoaDocumentTinyResponseResponseBody",
    "GoaDocumentTypeTinyResponseResponseBody",
    "GoaDriverTinyResponseResponseBody",
    "GoaFormTinyResponseResponseBody",
    "GoaGatewayTinyResponseResponseBody",
    "GoaGatewayTinyResponseResponseBodyModel",
    "GoaIssueTinyResponseResponseBody",
    "GoaPaginationResponseResponseBody",
    "GoaPaginationWithTokensResponseResponseBody",
    "GoaRouteStopTinyResponseResponseBody",
    "GoaRouteTinyResponseResponseBody",
    "GoaTagTinyResponseRequestBody",
    "GoaTagTinyResponseResponseBody",
    "GoaTrailerTinyResponseResponseBody",
    "GoaVehicleTinyResponseResponseBody",
    "GpsSignalLossDetailsObjectRequestBody",
    "GpsSignalLossDetailsObjectResponseBody",
    "GpsSignalLossResponseBody",
    "GreenBandDrivingDurationMs",
    "GrossVehicleWeight",
    "GrossVehicleWeightUnit",
    "HarshAccelSensitivityGForceSettingsObjectResponseBody",
    "HarshAccelSensitivityV2SettingsObjectResponseBody",
    "HarshAccelSensitivityV2SettingsObjectResponseBodyHeavyDuty",
    "HarshAccelSensitivityV2SettingsObjectResponseBodyLightDuty",
    "HarshAccelSensitivityV2SettingsObjectResponseBodyPassenger",
    "HarshBrakeSensitivityGForceSettingsObjectResponseBody",
    "HarshBrakeSensitivityV2SettingsObjectResponseBody",
    "HarshBrakeSensitivityV2SettingsObjectResponseBodyHeavyDuty",
    "HarshBrakeSensitivityV2SettingsObjectResponseBodyLightDuty",
    "HarshBrakeSensitivityV2SettingsObjectResponseBodyPassenger",
    "HarshEventDataResponseBody",
    "HarshEventSensitivitySettingsObjectResponseBody",
    "HarshEventSensitivityV2SettingsObjectResponseBody",
    "HarshEventTriggerDetailsObjectRequestBody",
    "HarshEventTriggerDetailsObjectRequestBodyTypesItem",
    "HarshEventTriggerDetailsObjectResponseBody",
    "HarshEventTriggerDetailsObjectResponseBodyTypesItem",
    "HarshTurnSensitivityGForceSettingsObjectResponseBody",
    "HarshTurnSensitivityV2SettingsObjectResponseBody",
    "HarshTurnSensitivityV2SettingsObjectResponseBodyHeavyDuty",
    "HarshTurnSensitivityV2SettingsObjectResponseBodyLightDuty",
    "HarshTurnSensitivityV2SettingsObjectResponseBodyPassenger",
    "HealthDetailsResponseResponseBody",
    "HealthReasonResponseResponseBody",
    "HealthReasonResponseResponseBodyHealthReasonCode",
    "HealthResponseResponseBody",
    "HealthResponseResponseBodyHealthStatus",
    "HealthResponseResponseBodyPrimaryHealthReason",
    "HealthResponseResponseBodyRecommendedAction",
    "HighTorqueMs",
    "HosBreak",
    "HosClocks",
    "HosClocksForDriver",
    "HosClocksForDrivers",
    "HosClocksResponse",
    "HosCycle",
    "HosDailyLogsGetHosDailyLogsBadGatewayErrorResponseBody",
    "HosDailyLogsGetHosDailyLogsGatewayTimeoutErrorResponseBody",
    "HosDailyLogsGetHosDailyLogsInternalServerErrorResponseBody",
    "HosDailyLogsGetHosDailyLogsMethodNotAllowedErrorResponseBody",
    "HosDailyLogsGetHosDailyLogsNotFoundErrorResponseBody",
    "HosDailyLogsGetHosDailyLogsNotImplementedErrorResponseBody",
    "HosDailyLogsGetHosDailyLogsResponseBody",
    "HosDailyLogsGetHosDailyLogsServiceUnavailableErrorResponseBody",
    "HosDailyLogsGetHosDailyLogsTooManyRequestsErrorResponseBody",
    "HosDailyLogsGetHosDailyLogsUnauthorizedErrorResponseBody",
    "HosDailyLogsObjectResponseBody",
    "HosDailyLogsUpdateShippingDocsBadGatewayErrorResponseBody",
    "HosDailyLogsUpdateShippingDocsGatewayTimeoutErrorResponseBody",
    "HosDailyLogsUpdateShippingDocsInternalServerErrorResponseBody",
    "HosDailyLogsUpdateShippingDocsMethodNotAllowedErrorResponseBody",
    "HosDailyLogsUpdateShippingDocsNotFoundErrorResponseBody",
    "HosDailyLogsUpdateShippingDocsNotImplementedErrorResponseBody",
    "HosDailyLogsUpdateShippingDocsResponseBody",
    "HosDailyLogsUpdateShippingDocsServiceUnavailableErrorResponseBody",
    "HosDailyLogsUpdateShippingDocsTooManyRequestsErrorResponseBody",
    "HosDailyLogsUpdateShippingDocsUnauthorizedErrorResponseBody",
    "HosDrive",
    "HosDriversEldEventObjectResponseBody",
    "HosDriversEldEventObjectResponseBodyDriverActivationStatus",
    "HosEldEventLocationObjectResponseBody",
    "HosEldEventObjectResponseBody",
    "HosEldEventObjectResponseBodyMalfunctionDiagnosticCode",
    "HosEldEventRemarkObjectResponseBody",
    "HosEldEventsGetHosEldEventsBadGatewayErrorResponseBody",
    "HosEldEventsGetHosEldEventsGatewayTimeoutErrorResponseBody",
    "HosEldEventsGetHosEldEventsInternalServerErrorResponseBody",
    "HosEldEventsGetHosEldEventsMethodNotAllowedErrorResponseBody",
    "HosEldEventsGetHosEldEventsNotFoundErrorResponseBody",
    "HosEldEventsGetHosEldEventsNotImplementedErrorResponseBody",
    "HosEldEventsGetHosEldEventsResponseBody",
    "HosEldEventsGetHosEldEventsServiceUnavailableErrorResponseBody",
    "HosEldEventsGetHosEldEventsTooManyRequestsErrorResponseBody",
    "HosEldEventsGetHosEldEventsUnauthorizedErrorResponseBody",
    "HosLogEntry",
    "HosLogEntryHosStatusType",
    "HosLogLocation",
    "HosLogsForDriver",
    "HosLogsForDrivers",
    "HosLogsList",
    "HosLogsResponse",
    "HosShift",
    "HosViolationDataResponseBody",
    "HosViolationDayObjectResponseBody",
    "HosViolationObjectResponseBody",
    "HosViolationObjectResponseBodyType",
    "HosViolationTriggerDetailsObjectRequestBody",
    "HosViolationTriggerDetailsObjectRequestBodyViolation",
    "HosViolationTriggerDetailsObjectResponseBody",
    "HosViolationTriggerDetailsObjectResponseBodyViolation",
    "HosViolations",
    "HosViolationsGetHosViolationsBadGatewayErrorResponseBody",
    "HosViolationsGetHosViolationsGatewayTimeoutErrorResponseBody",
    "HosViolationsGetHosViolationsInternalServerErrorResponseBody",
    "HosViolationsGetHosViolationsMethodNotAllowedErrorResponseBody",
    "HosViolationsGetHosViolationsNotFoundErrorResponseBody",
    "HosViolationsGetHosViolationsNotImplementedErrorResponseBody",
    "HosViolationsGetHosViolationsResponseBody",
    "HosViolationsGetHosViolationsServiceUnavailableErrorResponseBody",
    "HosViolationsGetHosViolationsTooManyRequestsErrorResponseBody",
    "HosViolationsGetHosViolationsUnauthorizedErrorResponseBody",
    "HosViolationsObjectResponseBody",
    "HubCapacitiesListHubCapacitiesBadGatewayErrorResponseBody",
    "HubCapacitiesListHubCapacitiesGatewayTimeoutErrorResponseBody",
    "HubCapacitiesListHubCapacitiesInternalServerErrorResponseBody",
    "HubCapacitiesListHubCapacitiesMethodNotAllowedErrorResponseBody",
    "HubCapacitiesListHubCapacitiesNotFoundErrorResponseBody",
    "HubCapacitiesListHubCapacitiesNotImplementedErrorResponseBody",
    "HubCapacitiesListHubCapacitiesResponseBody",
    "HubCapacitiesListHubCapacitiesServiceUnavailableErrorResponseBody",
    "HubCapacitiesListHubCapacitiesTooManyRequestsErrorResponseBody",
    "HubCapacitiesListHubCapacitiesUnauthorizedErrorResponseBody",
    "HubCapacityObjectResponseBody",
    "HubCustomPropertiesListHubCustomPropertiesBadGatewayErrorResponseBody",
    "HubCustomPropertiesListHubCustomPropertiesGatewayTimeoutErrorResponseBody",
    "HubCustomPropertiesListHubCustomPropertiesInternalServerErrorResponseBody",
    "HubCustomPropertiesListHubCustomPropertiesMethodNotAllowedErrorResponseBody",
    "HubCustomPropertiesListHubCustomPropertiesNotFoundErrorResponseBody",
    "HubCustomPropertiesListHubCustomPropertiesNotImplementedErrorResponseBody",
    "HubCustomPropertiesListHubCustomPropertiesResponseBody",
    "HubCustomPropertiesListHubCustomPropertiesServiceUnavailableErrorResponseBody",
    "HubCustomPropertiesListHubCustomPropertiesTooManyRequestsErrorResponseBody",
    "HubCustomPropertiesListHubCustomPropertiesUnauthorizedErrorResponseBody",
    "HubCustomPropertyObjectResponseBody",
    "HubLocationCreatedObjectResponseBody",
    "HubLocationInputObjectRequestBody",
    "HubLocationObjectResponseBody",
    "HubLocationServiceWindowInputRequestBody",
    "HubLocationUpdatedObjectResponseBody",
    "HubLocationsCreateHubLocationsBadGatewayErrorResponseBody",
    "HubLocationsCreateHubLocationsGatewayTimeoutErrorResponseBody",
    "HubLocationsCreateHubLocationsInternalServerErrorResponseBody",
    "HubLocationsCreateHubLocationsMethodNotAllowedErrorResponseBody",
    "HubLocationsCreateHubLocationsNotFoundErrorResponseBody",
    "HubLocationsCreateHubLocationsNotImplementedErrorResponseBody",
    "HubLocationsCreateHubLocationsResponseBody",
    "HubLocationsCreateHubLocationsServiceUnavailableErrorResponseBody",
    "HubLocationsCreateHubLocationsTooManyRequestsErrorResponseBody",
    "HubLocationsCreateHubLocationsUnauthorizedErrorResponseBody",
    "HubLocationsListHubLocationsBadGatewayErrorResponseBody",
    "HubLocationsListHubLocationsGatewayTimeoutErrorResponseBody",
    "HubLocationsListHubLocationsInternalServerErrorResponseBody",
    "HubLocationsListHubLocationsMethodNotAllowedErrorResponseBody",
    "HubLocationsListHubLocationsNotFoundErrorResponseBody",
    "HubLocationsListHubLocationsNotImplementedErrorResponseBody",
    "HubLocationsListHubLocationsResponseBody",
    "HubLocationsListHubLocationsServiceUnavailableErrorResponseBody",
    "HubLocationsListHubLocationsTooManyRequestsErrorResponseBody",
    "HubLocationsListHubLocationsUnauthorizedErrorResponseBody",
    "HubLocationsUpdateHubLocationBadGatewayErrorResponseBody",
    "HubLocationsUpdateHubLocationGatewayTimeoutErrorResponseBody",
    "HubLocationsUpdateHubLocationInternalServerErrorResponseBody",
    "HubLocationsUpdateHubLocationMethodNotAllowedErrorResponseBody",
    "HubLocationsUpdateHubLocationNotFoundErrorResponseBody",
    "HubLocationsUpdateHubLocationNotImplementedErrorResponseBody",
    "HubLocationsUpdateHubLocationResponseBody",
    "HubLocationsUpdateHubLocationServiceUnavailableErrorResponseBody",
    "HubLocationsUpdateHubLocationTooManyRequestsErrorResponseBody",
    "HubLocationsUpdateHubLocationUnauthorizedErrorResponseBody",
    "HubObjectResponseBody",
    "HubPlanRoutesListHubPlanRoutesBadGatewayErrorResponseBody",
    "HubPlanRoutesListHubPlanRoutesGatewayTimeoutErrorResponseBody",
    "HubPlanRoutesListHubPlanRoutesInternalServerErrorResponseBody",
    "HubPlanRoutesListHubPlanRoutesMethodNotAllowedErrorResponseBody",
    "HubPlanRoutesListHubPlanRoutesNotFoundErrorResponseBody",
    "HubPlanRoutesListHubPlanRoutesNotImplementedErrorResponseBody",
    "HubPlanRoutesListHubPlanRoutesResponseBody",
    "HubPlanRoutesListHubPlanRoutesServiceUnavailableErrorResponseBody",
    "HubPlanRoutesListHubPlanRoutesTooManyRequestsErrorResponseBody",
    "HubPlanRoutesListHubPlanRoutesUnauthorizedErrorResponseBody",
    "HubPlansCreateHubPlanBadGatewayErrorResponseBody",
    "HubPlansCreateHubPlanGatewayTimeoutErrorResponseBody",
    "HubPlansCreateHubPlanInternalServerErrorResponseBody",
    "HubPlansCreateHubPlanMethodNotAllowedErrorResponseBody",
    "HubPlansCreateHubPlanNotFoundErrorResponseBody",
    "HubPlansCreateHubPlanNotImplementedErrorResponseBody",
    "HubPlansCreateHubPlanResponseBody",
    "HubPlansCreateHubPlanServiceUnavailableErrorResponseBody",
    "HubPlansCreateHubPlanTooManyRequestsErrorResponseBody",
    "HubPlansCreateHubPlanUnauthorizedErrorResponseBody",
    "HubPlansListHubPlansBadGatewayErrorResponseBody",
    "HubPlansListHubPlansGatewayTimeoutErrorResponseBody",
    "HubPlansListHubPlansInternalServerErrorResponseBody",
    "HubPlansListHubPlansMethodNotAllowedErrorResponseBody",
    "HubPlansListHubPlansNotFoundErrorResponseBody",
    "HubPlansListHubPlansNotImplementedErrorResponseBody",
    "HubPlansListHubPlansResponseBody",
    "HubPlansListHubPlansServiceUnavailableErrorResponseBody",
    "HubPlansListHubPlansTooManyRequestsErrorResponseBody",
    "HubPlansListHubPlansUnauthorizedErrorResponseBody",
    "HubSkillObjectResponseBody",
    "HubSkillsListHubSkillsBadGatewayErrorResponseBody",
    "HubSkillsListHubSkillsGatewayTimeoutErrorResponseBody",
    "HubSkillsListHubSkillsInternalServerErrorResponseBody",
    "HubSkillsListHubSkillsMethodNotAllowedErrorResponseBody",
    "HubSkillsListHubSkillsNotFoundErrorResponseBody",
    "HubSkillsListHubSkillsNotImplementedErrorResponseBody",
    "HubSkillsListHubSkillsResponseBody",
    "HubSkillsListHubSkillsServiceUnavailableErrorResponseBody",
    "HubSkillsListHubSkillsTooManyRequestsErrorResponseBody",
    "HubSkillsListHubSkillsUnauthorizedErrorResponseBody",
    "HubsListHubsBadGatewayErrorResponseBody",
    "HubsListHubsGatewayTimeoutErrorResponseBody",
    "HubsListHubsInternalServerErrorResponseBody",
    "HubsListHubsMethodNotAllowedErrorResponseBody",
    "HubsListHubsNotFoundErrorResponseBody",
    "HubsListHubsNotImplementedErrorResponseBody",
    "HubsListHubsResponseBody",
    "HubsListHubsServiceUnavailableErrorResponseBody",
    "HubsListHubsTooManyRequestsErrorResponseBody",
    "HubsListHubsUnauthorizedErrorResponseBody",
    "IdleTimeDurationMs",
    "IdlingEventAddressObjectResponseBody",
    "IdlingEventAddressObjectResponseBodyAddressTypesItem",
    "IdlingEventAssetObjectResponseBody",
    "IdlingEventObjectV20251023ResponseBody",
    "IdlingEventObjectV20251023ResponseBodyPtoState",
    "IdlingEventOperatorObjectResponseBody",
    "IdlingReportEventAddressResponseBody",
    "IdlingReportEventResponseBody",
    "IdlingReportsGetVehicleIdlingReportsBadGatewayErrorResponseBody",
    "IdlingReportsGetVehicleIdlingReportsGatewayTimeoutErrorResponseBody",
    "IdlingReportsGetVehicleIdlingReportsInternalServerErrorResponseBody",
    "IdlingReportsGetVehicleIdlingReportsMethodNotAllowedErrorResponseBody",
    "IdlingReportsGetVehicleIdlingReportsNotFoundErrorResponseBody",
    "IdlingReportsGetVehicleIdlingReportsNotImplementedErrorResponseBody",
    "IdlingReportsGetVehicleIdlingReportsResponseBody",
    "IdlingReportsGetVehicleIdlingReportsServiceUnavailableErrorResponseBody",
    "IdlingReportsGetVehicleIdlingReportsTooManyRequestsErrorResponseBody",
    "IdlingReportsGetVehicleIdlingReportsUnauthorizedErrorResponseBody",
    "IftaCreateIftaDetailJobBadGatewayErrorResponseBody",
    "IftaCreateIftaDetailJobGatewayTimeoutErrorResponseBody",
    "IftaCreateIftaDetailJobInternalServerErrorResponseBody",
    "IftaCreateIftaDetailJobMethodNotAllowedErrorResponseBody",
    "IftaCreateIftaDetailJobNotFoundErrorResponseBody",
    "IftaCreateIftaDetailJobNotImplementedErrorResponseBody",
    "IftaCreateIftaDetailJobResponseBody",
    "IftaCreateIftaDetailJobServiceUnavailableErrorResponseBody",
    "IftaCreateIftaDetailJobTooManyRequestsErrorResponseBody",
    "IftaCreateIftaDetailJobUnauthorizedErrorResponseBody",
    "IftaDetailJobArgsResponseBody",
    "IftaDetailJobOutputResponseBody",
    "IftaDetailJobResponseBody",
    "IftaDetailJobResponseBodyJobStatus",
    "IftaGetIftaDetailJobBadGatewayErrorResponseBody",
    "IftaGetIftaDetailJobGatewayTimeoutErrorResponseBody",
    "IftaGetIftaDetailJobInternalServerErrorResponseBody",
    "IftaGetIftaDetailJobMethodNotAllowedErrorResponseBody",
    "IftaGetIftaDetailJobNotFoundErrorResponseBody",
    "IftaGetIftaDetailJobNotImplementedErrorResponseBody",
    "IftaGetIftaDetailJobResponseBody",
    "IftaGetIftaDetailJobServiceUnavailableErrorResponseBody",
    "IftaGetIftaDetailJobTooManyRequestsErrorResponseBody",
    "IftaGetIftaDetailJobUnauthorizedErrorResponseBody",
    "IftaGetIftaJurisdictionReportsBadGatewayErrorResponseBody",
    "IftaGetIftaJurisdictionReportsGatewayTimeoutErrorResponseBody",
    "IftaGetIftaJurisdictionReportsInternalServerErrorResponseBody",
    "IftaGetIftaJurisdictionReportsMethodNotAllowedErrorResponseBody",
    "IftaGetIftaJurisdictionReportsNotFoundErrorResponseBody",
    "IftaGetIftaJurisdictionReportsNotImplementedErrorResponseBody",
    "IftaGetIftaJurisdictionReportsResponseBody",
    "IftaGetIftaJurisdictionReportsServiceUnavailableErrorResponseBody",
    "IftaGetIftaJurisdictionReportsTooManyRequestsErrorResponseBody",
    "IftaGetIftaJurisdictionReportsUnauthorizedErrorResponseBody",
    "IftaGetIftaVehicleReportsBadGatewayErrorResponseBody",
    "IftaGetIftaVehicleReportsGatewayTimeoutErrorResponseBody",
    "IftaGetIftaVehicleReportsInternalServerErrorResponseBody",
    "IftaGetIftaVehicleReportsMethodNotAllowedErrorResponseBody",
    "IftaGetIftaVehicleReportsNotFoundErrorResponseBody",
    "IftaGetIftaVehicleReportsNotImplementedErrorResponseBody",
    "IftaGetIftaVehicleReportsResponseBody",
    "IftaGetIftaVehicleReportsServiceUnavailableErrorResponseBody",
    "IftaGetIftaVehicleReportsTooManyRequestsErrorResponseBody",
    "IftaGetIftaVehicleReportsUnauthorizedErrorResponseBody",
    "IftaJurisdictionReportDataObjectResponseBody",
    "IftaJurisdictionSummaryObjectResponseBody",
    "IftaReportTroubleshootingObjectResponseBody",
    "IftaVehicleReportDataObjectResponseBody",
    "IftaVehicleReportObjectResponseBody",
    "InAppNotificationOptionsObjectRequestBody",
    "InAppNotificationOptionsObjectResponseBody",
    "InactivityResponseBody",
    "InattentiveDrivingDetectionAlertSettingsObjectResponseBody",
    "InattentiveDrivingDetectionAlertSettingsObjectResponseBodySeverity",
    "IndustrialAssetObjectResponseBody",
    "InlineObject6FillMissing",
    "InlineResponse200",
    "InlineResponse2001",
    "InlineResponse2002",
    "InlineResponse2003",
    "InlineResponse2004",
    "InlineResponse2005",
    "InlineResponse2006",
    "InlineResponse2007",
    "InlineResponse2008",
    "InlineResponse2009",
    "InsideGeofenceDataResponseBody",
    "InsideGeofenceTriggerDetailsObjectRequestBody",
    "InsideGeofenceTriggerDetailsObjectResponseBody",
    "InternalServerError",
    "InvoiceScanFileRequestBody",
    "IssueCreatedResponseBody",
    "IssueResponseObjectResponseBody",
    "IssueResponseObjectResponseBodyPriority",
    "IssueResponseObjectResponseBodyStatus",
    "IssueSourceObjectResponseBody",
    "IssueSourceObjectResponseBodyType",
    "IssuesGetIssuesBadGatewayErrorResponseBody",
    "IssuesGetIssuesGatewayTimeoutErrorResponseBody",
    "IssuesGetIssuesInternalServerErrorResponseBody",
    "IssuesGetIssuesMethodNotAllowedErrorResponseBody",
    "IssuesGetIssuesNotFoundErrorResponseBody",
    "IssuesGetIssuesNotImplementedErrorResponseBody",
    "IssuesGetIssuesResponseBody",
    "IssuesGetIssuesServiceUnavailableErrorResponseBody",
    "IssuesGetIssuesStreamBadGatewayErrorResponseBody",
    "IssuesGetIssuesStreamGatewayTimeoutErrorResponseBody",
    "IssuesGetIssuesStreamInternalServerErrorResponseBody",
    "IssuesGetIssuesStreamMethodNotAllowedErrorResponseBody",
    "IssuesGetIssuesStreamNotFoundErrorResponseBody",
    "IssuesGetIssuesStreamNotImplementedErrorResponseBody",
    "IssuesGetIssuesStreamResponseBody",
    "IssuesGetIssuesStreamServiceUnavailableErrorResponseBody",
    "IssuesGetIssuesStreamTooManyRequestsErrorResponseBody",
    "IssuesGetIssuesStreamUnauthorizedErrorResponseBody",
    "IssuesGetIssuesTooManyRequestsErrorResponseBody",
    "IssuesGetIssuesUnauthorizedErrorResponseBody",
    "IssuesPatchIssueBadGatewayErrorResponseBody",
    "IssuesPatchIssueGatewayTimeoutErrorResponseBody",
    "IssuesPatchIssueInternalServerErrorResponseBody",
    "IssuesPatchIssueMethodNotAllowedErrorResponseBody",
    "IssuesPatchIssueNotFoundErrorResponseBody",
    "IssuesPatchIssueNotImplementedErrorResponseBody",
    "IssuesPatchIssueRequestBodyStatus",
    "IssuesPatchIssueResponseBody",
    "IssuesPatchIssueServiceUnavailableErrorResponseBody",
    "IssuesPatchIssueTooManyRequestsErrorResponseBody",
    "IssuesPatchIssueUnauthorizedErrorResponseBody",
    "J1939D1StatusDataPoint",
    "J1939D1StatusDataPointValue",
    "JammingDetectedResponseBody",
    "JobLocationResponseObjectResponseBody",
    "JobResponseObjectResponseBody",
    "JobResponseObjectResponseBodyStatus",
    "JobsCreateJobBadGatewayErrorResponseBody",
    "JobsCreateJobGatewayTimeoutErrorResponseBody",
    "JobsCreateJobInternalServerErrorResponseBody",
    "JobsCreateJobMethodNotAllowedErrorResponseBody",
    "JobsCreateJobNotFoundErrorResponseBody",
    "JobsCreateJobNotImplementedErrorResponseBody",
    "JobsCreateJobResponseBody",
    "JobsCreateJobServiceUnavailableErrorResponseBody",
    "JobsCreateJobTooManyRequestsErrorResponseBody",
    "JobsCreateJobUnauthorizedErrorResponseBody",
    "JobsDeleteJobBadGatewayErrorResponseBody",
    "JobsDeleteJobGatewayTimeoutErrorResponseBody",
    "JobsDeleteJobInternalServerErrorResponseBody",
    "JobsDeleteJobMethodNotAllowedErrorResponseBody",
    "JobsDeleteJobNotFoundErrorResponseBody",
    "JobsDeleteJobNotImplementedErrorResponseBody",
    "JobsDeleteJobResponseBody",
    "JobsDeleteJobServiceUnavailableErrorResponseBody",
    "JobsDeleteJobTooManyRequestsErrorResponseBody",
    "JobsDeleteJobUnauthorizedErrorResponseBody",
    "JobsGetJobsBadGatewayErrorResponseBody",
    "JobsGetJobsGatewayTimeoutErrorResponseBody",
    "JobsGetJobsInternalServerErrorResponseBody",
    "JobsGetJobsMethodNotAllowedErrorResponseBody",
    "JobsGetJobsNotFoundErrorResponseBody",
    "JobsGetJobsNotImplementedErrorResponseBody",
    "JobsGetJobsResponseBody",
    "JobsGetJobsServiceUnavailableErrorResponseBody",
    "JobsGetJobsTooManyRequestsErrorResponseBody",
    "JobsGetJobsUnauthorizedErrorResponseBody",
    "JobsPatchJobBadGatewayErrorResponseBody",
    "JobsPatchJobGatewayTimeoutErrorResponseBody",
    "JobsPatchJobInternalServerErrorResponseBody",
    "JobsPatchJobMethodNotAllowedErrorResponseBody",
    "JobsPatchJobNotFoundErrorResponseBody",
    "JobsPatchJobNotImplementedErrorResponseBody",
    "JobsPatchJobResponseBody",
    "JobsPatchJobServiceUnavailableErrorResponseBody",
    "JobsPatchJobTooManyRequestsErrorResponseBody",
    "JobsPatchJobUnauthorizedErrorResponseBody",
    "LastKnownLocationResponseResponseBody",
    "Latitude",
    "ListAddressesResponse",
    "ListAssetsRequestType",
    "ListCarbCtcVehiclesRequestTestStatusItem",
    "ListCarrierProposedAssignmentResponse",
    "ListContactsResponse",
    "ListDriversRequestDriverActivationStatus",
    "ListDriversResponse",
    "ListHubCapacitiesResponsePaginationResponseBody",
    "ListHubCustomPropertiesResponsePaginationResponseBody",
    "ListHubLocationsResponsePaginationResponseBody",
    "ListHubPlanRoutesResponsePaginationResponseBody",
    "ListHubPlansResponsePaginationResponseBody",
    "ListHubSkillsResponsePaginationResponseBody",
    "ListHubsResponsePaginationResponseBody",
    "ListIndustrialAssetsResponse",
    "ListTagsResponse",
    "ListUploadedMediaObjectResponseBody",
    "ListUploadedMediaRequestInputsItem",
    "ListUploadedMediaRequestMediaTypesItem",
    "ListUploadedMediaRequestTriggerReasonsItem",
    "ListUserRolesResponse",
    "ListUsersResponse",
    "LiveSharingLinkFullResponseObjectResponseBody",
    "LiveSharingLinkFullResponseObjectResponseBodyType",
    "LiveSharingLinkResponseObjectResponseBody",
    "LiveSharingLinksCreateLiveSharingLinkBadGatewayErrorResponseBody",
    "LiveSharingLinksCreateLiveSharingLinkGatewayTimeoutErrorResponseBody",
    "LiveSharingLinksCreateLiveSharingLinkInternalServerErrorResponseBody",
    "LiveSharingLinksCreateLiveSharingLinkMethodNotAllowedErrorResponseBody",
    "LiveSharingLinksCreateLiveSharingLinkNotFoundErrorResponseBody",
    "LiveSharingLinksCreateLiveSharingLinkNotImplementedErrorResponseBody",
    "LiveSharingLinksCreateLiveSharingLinkRequestBodyType",
    "LiveSharingLinksCreateLiveSharingLinkResponseBody",
    "LiveSharingLinksCreateLiveSharingLinkServiceUnavailableErrorResponseBody",
    "LiveSharingLinksCreateLiveSharingLinkTooManyRequestsErrorResponseBody",
    "LiveSharingLinksCreateLiveSharingLinkUnauthorizedErrorResponseBody",
    "LiveSharingLinksDeleteLiveSharingLinkBadGatewayErrorResponseBody",
    "LiveSharingLinksDeleteLiveSharingLinkGatewayTimeoutErrorResponseBody",
    "LiveSharingLinksDeleteLiveSharingLinkInternalServerErrorResponseBody",
    "LiveSharingLinksDeleteLiveSharingLinkMethodNotAllowedErrorResponseBody",
    "LiveSharingLinksDeleteLiveSharingLinkNotFoundErrorResponseBody",
    "LiveSharingLinksDeleteLiveSharingLinkNotImplementedErrorResponseBody",
    "LiveSharingLinksDeleteLiveSharingLinkServiceUnavailableErrorResponseBody",
    "LiveSharingLinksDeleteLiveSharingLinkTooManyRequestsErrorResponseBody",
    "LiveSharingLinksDeleteLiveSharingLinkUnauthorizedErrorResponseBody",
    "LiveSharingLinksGetLiveSharingLinksBadGatewayErrorResponseBody",
    "LiveSharingLinksGetLiveSharingLinksGatewayTimeoutErrorResponseBody",
    "LiveSharingLinksGetLiveSharingLinksInternalServerErrorResponseBody",
    "LiveSharingLinksGetLiveSharingLinksMethodNotAllowedErrorResponseBody",
    "LiveSharingLinksGetLiveSharingLinksNotFoundErrorResponseBody",
    "LiveSharingLinksGetLiveSharingLinksNotImplementedErrorResponseBody",
    "LiveSharingLinksGetLiveSharingLinksResponseBody",
    "LiveSharingLinksGetLiveSharingLinksServiceUnavailableErrorResponseBody",
    "LiveSharingLinksGetLiveSharingLinksTooManyRequestsErrorResponseBody",
    "LiveSharingLinksGetLiveSharingLinksUnauthorizedErrorResponseBody",
    "LiveSharingLinksUpdateLiveSharingLinkBadGatewayErrorResponseBody",
    "LiveSharingLinksUpdateLiveSharingLinkGatewayTimeoutErrorResponseBody",
    "LiveSharingLinksUpdateLiveSharingLinkInternalServerErrorResponseBody",
    "LiveSharingLinksUpdateLiveSharingLinkMethodNotAllowedErrorResponseBody",
    "LiveSharingLinksUpdateLiveSharingLinkNotFoundErrorResponseBody",
    "LiveSharingLinksUpdateLiveSharingLinkNotImplementedErrorResponseBody",
    "LiveSharingLinksUpdateLiveSharingLinkResponseBody",
    "LiveSharingLinksUpdateLiveSharingLinkServiceUnavailableErrorResponseBody",
    "LiveSharingLinksUpdateLiveSharingLinkTooManyRequestsErrorResponseBody",
    "LiveSharingLinksUpdateLiveSharingLinkUnauthorizedErrorResponseBody",
    "Location",
    "LocationAndSpeedGetLocationAndSpeedBadGatewayErrorResponseBody",
    "LocationAndSpeedGetLocationAndSpeedGatewayTimeoutErrorResponseBody",
    "LocationAndSpeedGetLocationAndSpeedInternalServerErrorResponseBody",
    "LocationAndSpeedGetLocationAndSpeedMethodNotAllowedErrorResponseBody",
    "LocationAndSpeedGetLocationAndSpeedNotFoundErrorResponseBody",
    "LocationAndSpeedGetLocationAndSpeedNotImplementedErrorResponseBody",
    "LocationAndSpeedGetLocationAndSpeedResponseBody",
    "LocationAndSpeedGetLocationAndSpeedServiceUnavailableErrorResponseBody",
    "LocationAndSpeedGetLocationAndSpeedTooManyRequestsErrorResponseBody",
    "LocationAndSpeedGetLocationAndSpeedUnauthorizedErrorResponseBody",
    "LocationAndSpeedResponseResponseBody",
    "LocationDataPoint",
    "LocationDataPointGpsLocation",
    "LocationDataPointGpsLocationPlace",
    "LocationObjectRequestBody",
    "LocationObjectRequestBodyAddressTypesItem",
    "LocationObjectResponseBody",
    "LocationObjectResponseBodyAddressTypesItem",
    "LocationResponseBody",
    "LocationResponseResponseBody",
    "LocationType",
    "LogMetaDataObjectResponseBody",
    "Longitude",
    "MaintenanceVendorsListMaintenanceVendorsBadGatewayErrorResponseBody",
    "MaintenanceVendorsListMaintenanceVendorsGatewayTimeoutErrorResponseBody",
    "MaintenanceVendorsListMaintenanceVendorsInternalServerErrorResponseBody",
    "MaintenanceVendorsListMaintenanceVendorsMethodNotAllowedErrorResponseBody",
    "MaintenanceVendorsListMaintenanceVendorsNotFoundErrorResponseBody",
    "MaintenanceVendorsListMaintenanceVendorsNotImplementedErrorResponseBody",
    "MaintenanceVendorsListMaintenanceVendorsResponseBody",
    "MaintenanceVendorsListMaintenanceVendorsServiceUnavailableErrorResponseBody",
    "MaintenanceVendorsListMaintenanceVendorsTooManyRequestsErrorResponseBody",
    "MaintenanceVendorsListMaintenanceVendorsUnauthorizedErrorResponseBody",
    "MaintenanceVendorsListVendorCategoriesBadGatewayErrorResponseBody",
    "MaintenanceVendorsListVendorCategoriesGatewayTimeoutErrorResponseBody",
    "MaintenanceVendorsListVendorCategoriesInternalServerErrorResponseBody",
    "MaintenanceVendorsListVendorCategoriesMethodNotAllowedErrorResponseBody",
    "MaintenanceVendorsListVendorCategoriesNotFoundErrorResponseBody",
    "MaintenanceVendorsListVendorCategoriesNotImplementedErrorResponseBody",
    "MaintenanceVendorsListVendorCategoriesResponseBody",
    "MaintenanceVendorsListVendorCategoriesServiceUnavailableErrorResponseBody",
    "MaintenanceVendorsListVendorCategoriesTooManyRequestsErrorResponseBody",
    "MaintenanceVendorsListVendorCategoriesUnauthorizedErrorResponseBody",
    "MediaObjectResponseBody",
    "MediaObjectResponseBodyCameraRole",
    "MediaObjectResponseBodyInput",
    "MediaObjectResponseBodyMediaType",
    "MediaObjectResponseBodyStatus",
    "MediaRetrievalGetMediaRetrievalBadGatewayErrorResponseBody",
    "MediaRetrievalGetMediaRetrievalGatewayTimeoutErrorResponseBody",
    "MediaRetrievalGetMediaRetrievalInternalServerErrorResponseBody",
    "MediaRetrievalGetMediaRetrievalMethodNotAllowedErrorResponseBody",
    "MediaRetrievalGetMediaRetrievalNotFoundErrorResponseBody",
    "MediaRetrievalGetMediaRetrievalNotImplementedErrorResponseBody",
    "MediaRetrievalGetMediaRetrievalResponseBody",
    "MediaRetrievalGetMediaRetrievalServiceUnavailableErrorResponseBody",
    "MediaRetrievalGetMediaRetrievalTooManyRequestsErrorResponseBody",
    "MediaRetrievalGetMediaRetrievalUnauthorizedErrorResponseBody",
    "MediaRetrievalListUploadedMediaBadGatewayErrorResponseBody",
    "MediaRetrievalListUploadedMediaGatewayTimeoutErrorResponseBody",
    "MediaRetrievalListUploadedMediaInternalServerErrorResponseBody",
    "MediaRetrievalListUploadedMediaMethodNotAllowedErrorResponseBody",
    "MediaRetrievalListUploadedMediaNotFoundErrorResponseBody",
    "MediaRetrievalListUploadedMediaNotImplementedErrorResponseBody",
    "MediaRetrievalListUploadedMediaResponseBody",
    "MediaRetrievalListUploadedMediaServiceUnavailableErrorResponseBody",
    "MediaRetrievalListUploadedMediaTooManyRequestsErrorResponseBody",
    "MediaRetrievalListUploadedMediaUnauthorizedErrorResponseBody",
    "MediaRetrievalPostMediaRetrievalBadGatewayErrorResponseBody",
    "MediaRetrievalPostMediaRetrievalGatewayTimeoutErrorResponseBody",
    "MediaRetrievalPostMediaRetrievalInternalServerErrorResponseBody",
    "MediaRetrievalPostMediaRetrievalMethodNotAllowedErrorResponseBody",
    "MediaRetrievalPostMediaRetrievalNotFoundErrorResponseBody",
    "MediaRetrievalPostMediaRetrievalNotImplementedErrorResponseBody",
    "MediaRetrievalPostMediaRetrievalRequestBodyInputsItem",
    "MediaRetrievalPostMediaRetrievalRequestBodyMediaType",
    "MediaRetrievalPostMediaRetrievalResponseBody",
    "MediaRetrievalPostMediaRetrievalServiceUnavailableErrorResponseBody",
    "MediaRetrievalPostMediaRetrievalTooManyRequestsErrorResponseBody",
    "MediaRetrievalPostMediaRetrievalUnauthorizedErrorResponseBody",
    "MethodNotAllowedError",
    "MinimalRouteAuditLogsResponseBody",
    "MinimalRouteStopAuditLogsResponseBody",
    "MinimalRouteStopAuditLogsResponseBodyState",
    "MinimalRouteStopResponseBody",
    "MinimalRouteStopResponseBodyState",
    "MissingDvirPastDueResponseBody",
    "MissingStateResponseBody",
    "MissingStateResponseBodyUpdateSource",
    "MobileUsageDetectionAlertSettingsObjectResponseBody",
    "MotionDetectedResponseBody",
    "MultipleChoiceFieldTypeMetaDataObjectResponseBody",
    "MultipleChoiceValueObjectRequestBody",
    "MultipleChoiceValueObjectResponseBody",
    "NotFoundError",
    "NotImplementedError",
    "NotificationRecipientRequestBody",
    "NotificationRecipientRequestBodyNotificationTypesItem",
    "NotificationRecipientResponseResponseBody",
    "NotificationRecipientResponseResponseBodyNotificationTypesItem",
    "NumberDataPoint",
    "NumberFieldTypeMetaDataObjectResponseBody",
    "OperationalSettingsObjectRequestBody",
    "OperationalSettingsObjectRequestBodyTimeRangeType",
    "OperationalSettingsObjectResponseBody",
    "OperationalSettingsObjectResponseBodyTimeRangeType",
    "OrderCustomPropertyInputRequestBody",
    "OrderCustomPropertyResponseBody",
    "OrderInputObjectRequestBody",
    "OrderObjectResponseBody",
    "OrderQuantityInputRequestBody",
    "OrderQuantityResponseBody",
    "OrderTaskCustomPropertyObjectResponseBody",
    "OrderTaskObjectResponseBody",
    "OrderTaskRequestBody",
    "OrderTaskRequestBodyPosition",
    "OrderTaskResponseBody",
    "OrderTaskResponseBodyPosition",
    "OrderTaskSkillObjectResponseBody",
    "OrganizationInfoCarrierSettings",
    "OrganizationInfoObject",
    "OrganizationInfoResponse",
    "OutOfRouteDetailsObjectRequestBody",
    "OutOfRouteDetailsObjectResponseBody",
    "OutOfRouteResponseBody",
    "OutsideGeofenceDataResponseBody",
    "OutsideGeofenceTriggerDetailsObjectRequestBody",
    "OutsideGeofenceTriggerDetailsObjectResponseBody",
    "OverSpeedMs",
    "PaginationResponse",
    "PanicButtonDetailsObjectRequestBody",
    "PanicButtonDetailsObjectResponseBody",
    "PanicButtonResponseBody",
    "ParentId",
    "ParentTag",
    "ParentTagId",
    "ParentTagName",
    "PartInstanceInputObjectRequestBody",
    "PartInstanceObjectResponseBody",
    "PatchAssetDataOutputsSingleResponseResponseBody",
    "PatchDriverTrailerAssignmentsResponseBodyResponseBody",
    "PatchDriverVehicleAssignmentsV2RequestBodyMetadataRequestBody",
    "PatchDriverVehicleAssignmentsV2ResponseBodyResponseBody",
    "PatchFunctionDetailResponseBody",
    "PatchFunctionRequestConfigRequestBody",
    "PatchFunctionRequestConfigRequestBodyParams",
    "PatchFunctionRequestConfigRequestBodySecrets",
    "PatchIssueRequestBodyAssignedToRequestBody",
    "PatchIssueRequestBodyAssignedToRequestBodyType",
    "PatchJobObjectRequestBody",
    "PatchJobObjectjobLocationRequestObjectRequestBody",
    "PatchResponseWorkflowConfigurationObjectResponseBody",
    "PatchSafetyEventsDismissalReasonBodyRequestBody",
    "PatchSafetyEventsDismissalReasonBodyRequestBodyCode",
    "PatchSafetyEventsResponseItemDataResponseBody",
    "PatchSafetyEventsResponseItemResponseBody",
    "PatchShippingDocsResponseBodyResponseBody",
    "PendingDutyStatusDurationsObjectResponseBody",
    "PersonDetectedResponseBody",
    "PhotoValueObjectRequestBody",
    "PhotoValueObjectResponseBody",
    "PlanObjectResponseBody",
    "PlanOrdersCreatePlanOrdersBadGatewayErrorResponseBody",
    "PlanOrdersCreatePlanOrdersGatewayTimeoutErrorResponseBody",
    "PlanOrdersCreatePlanOrdersInternalServerErrorResponseBody",
    "PlanOrdersCreatePlanOrdersMethodNotAllowedErrorResponseBody",
    "PlanOrdersCreatePlanOrdersNotFoundErrorResponseBody",
    "PlanOrdersCreatePlanOrdersNotImplementedErrorResponseBody",
    "PlanOrdersCreatePlanOrdersResponseBody",
    "PlanOrdersCreatePlanOrdersServiceUnavailableErrorResponseBody",
    "PlanOrdersCreatePlanOrdersTooManyRequestsErrorResponseBody",
    "PlanOrdersCreatePlanOrdersUnauthorizedErrorResponseBody",
    "PolicyViolationsDetectionAlertSettingsObjectResponseBody",
    "PolicyViolationsDetectionAlertSettingsObjectResponseBodyEventsAvailableForTestingItem",
    "PolicyViolationsDetectionAlertSettingsObjectResponseBodyEventsToCoachItem",
    "PolygonRequestBody",
    "PolygonResponseBody",
    "PostDriverTrailerAssignmentsResponseBodyResponseBody",
    "PostDriverVehicleAssignmentsV2RequestBodyMetadataRequestBody",
    "PostDriverVehicleAssignmentsV2ResponseBodyResponseBody",
    "PostFuelPurchaseRequestBodyDiscountRequestBody",
    "PostFuelPurchaseRequestBodyDiscountRequestBodyCurrency",
    "PostFuelPurchaseRequestBodyPriceRequestBody",
    "PostFuelPurchaseRequestBodyPriceRequestBodyCurrency",
    "PostFuelPurchaseResponseBodyResponseBody",
    "PostInvoiceScanResponseDataResponseBody",
    "PostJobObjectRequestBody",
    "PostJobObjectjobLocationRequestObjectRequestBody",
    "PostMediaRetrievalObjectResponseBody",
    "PostResponseResWorkflowConfigurationObjectResponseBody",
    "PowerTakeOffDurationMs",
    "PrimaryTimeRangeRequestBody",
    "PrimaryTimeRangeResponseBody",
    "PushNotificationOptionsObjectRequestBody",
    "PushNotificationOptionsObjectResponseBody",
    "QrCodeResponseObjectResponseBody",
    "QualificationFieldInputObjectResponseBody",
    "QualificationFieldInputObjectResponseBodyType",
    "QualificationOwnerObjectResponseBody",
    "QualificationOwnerObjectResponseBodyEntityType",
    "QualificationOwnerRequestObjectRequestBody",
    "QualificationOwnerRequestObjectRequestBodyEntityType",
    "QualificationRecordRequestFieldInputObjectRequestBody",
    "QualificationRecordRequestFieldInputObjectRequestBodyType",
    "QualificationRecordResponseObjectResponseBody",
    "QualificationRecordResponseObjectResponseBodyRecordStatus",
    "QualificationTypeReferenceObjectResponseBody",
    "QualificationTypeRequestObjectRequestBody",
    "QualificationTypeResponseObjectResponseBody",
    "QualificationTypeResponseObjectResponseBodyEntityType",
    "QualificationsArchiveQualificationRecordBadGatewayErrorResponseBody",
    "QualificationsArchiveQualificationRecordGatewayTimeoutErrorResponseBody",
    "QualificationsArchiveQualificationRecordInternalServerErrorResponseBody",
    "QualificationsArchiveQualificationRecordMethodNotAllowedErrorResponseBody",
    "QualificationsArchiveQualificationRecordNotFoundErrorResponseBody",
    "QualificationsArchiveQualificationRecordNotImplementedErrorResponseBody",
    "QualificationsArchiveQualificationRecordServiceUnavailableErrorResponseBody",
    "QualificationsArchiveQualificationRecordTooManyRequestsErrorResponseBody",
    "QualificationsArchiveQualificationRecordUnauthorizedErrorResponseBody",
    "QualificationsDeleteQualificationRecordBadGatewayErrorResponseBody",
    "QualificationsDeleteQualificationRecordGatewayTimeoutErrorResponseBody",
    "QualificationsDeleteQualificationRecordInternalServerErrorResponseBody",
    "QualificationsDeleteQualificationRecordMethodNotAllowedErrorResponseBody",
    "QualificationsDeleteQualificationRecordNotFoundErrorResponseBody",
    "QualificationsDeleteQualificationRecordNotImplementedErrorResponseBody",
    "QualificationsDeleteQualificationRecordServiceUnavailableErrorResponseBody",
    "QualificationsDeleteQualificationRecordTooManyRequestsErrorResponseBody",
    "QualificationsDeleteQualificationRecordUnauthorizedErrorResponseBody",
    "QualificationsGetQualificationRecordsBadGatewayErrorResponseBody",
    "QualificationsGetQualificationRecordsGatewayTimeoutErrorResponseBody",
    "QualificationsGetQualificationRecordsInternalServerErrorResponseBody",
    "QualificationsGetQualificationRecordsMethodNotAllowedErrorResponseBody",
    "QualificationsGetQualificationRecordsNotFoundErrorResponseBody",
    "QualificationsGetQualificationRecordsNotImplementedErrorResponseBody",
    "QualificationsGetQualificationRecordsResponseBody",
    "QualificationsGetQualificationRecordsServiceUnavailableErrorResponseBody",
    "QualificationsGetQualificationRecordsStreamBadGatewayErrorResponseBody",
    "QualificationsGetQualificationRecordsStreamGatewayTimeoutErrorResponseBody",
    "QualificationsGetQualificationRecordsStreamInternalServerErrorResponseBody",
    "QualificationsGetQualificationRecordsStreamMethodNotAllowedErrorResponseBody",
    "QualificationsGetQualificationRecordsStreamNotFoundErrorResponseBody",
    "QualificationsGetQualificationRecordsStreamNotImplementedErrorResponseBody",
    "QualificationsGetQualificationRecordsStreamResponseBody",
    "QualificationsGetQualificationRecordsStreamServiceUnavailableErrorResponseBody",
    "QualificationsGetQualificationRecordsStreamTooManyRequestsErrorResponseBody",
    "QualificationsGetQualificationRecordsStreamUnauthorizedErrorResponseBody",
    "QualificationsGetQualificationRecordsTooManyRequestsErrorResponseBody",
    "QualificationsGetQualificationRecordsUnauthorizedErrorResponseBody",
    "QualificationsGetQualificationTypesBadGatewayErrorResponseBody",
    "QualificationsGetQualificationTypesGatewayTimeoutErrorResponseBody",
    "QualificationsGetQualificationTypesInternalServerErrorResponseBody",
    "QualificationsGetQualificationTypesMethodNotAllowedErrorResponseBody",
    "QualificationsGetQualificationTypesNotFoundErrorResponseBody",
    "QualificationsGetQualificationTypesNotImplementedErrorResponseBody",
    "QualificationsGetQualificationTypesResponseBody",
    "QualificationsGetQualificationTypesServiceUnavailableErrorResponseBody",
    "QualificationsGetQualificationTypesTooManyRequestsErrorResponseBody",
    "QualificationsGetQualificationTypesUnauthorizedErrorResponseBody",
    "QualificationsPatchQualificationRecordBadGatewayErrorResponseBody",
    "QualificationsPatchQualificationRecordGatewayTimeoutErrorResponseBody",
    "QualificationsPatchQualificationRecordInternalServerErrorResponseBody",
    "QualificationsPatchQualificationRecordMethodNotAllowedErrorResponseBody",
    "QualificationsPatchQualificationRecordNotFoundErrorResponseBody",
    "QualificationsPatchQualificationRecordNotImplementedErrorResponseBody",
    "QualificationsPatchQualificationRecordResponseBody",
    "QualificationsPatchQualificationRecordServiceUnavailableErrorResponseBody",
    "QualificationsPatchQualificationRecordTooManyRequestsErrorResponseBody",
    "QualificationsPatchQualificationRecordUnauthorizedErrorResponseBody",
    "QualificationsPostQualificationRecordBadGatewayErrorResponseBody",
    "QualificationsPostQualificationRecordGatewayTimeoutErrorResponseBody",
    "QualificationsPostQualificationRecordInternalServerErrorResponseBody",
    "QualificationsPostQualificationRecordMethodNotAllowedErrorResponseBody",
    "QualificationsPostQualificationRecordNotFoundErrorResponseBody",
    "QualificationsPostQualificationRecordNotImplementedErrorResponseBody",
    "QualificationsPostQualificationRecordResponseBody",
    "QualificationsPostQualificationRecordServiceUnavailableErrorResponseBody",
    "QualificationsPostQualificationRecordTooManyRequestsErrorResponseBody",
    "QualificationsPostQualificationRecordUnauthorizedErrorResponseBody",
    "QualificationsUnarchiveQualificationRecordBadGatewayErrorResponseBody",
    "QualificationsUnarchiveQualificationRecordGatewayTimeoutErrorResponseBody",
    "QualificationsUnarchiveQualificationRecordInternalServerErrorResponseBody",
    "QualificationsUnarchiveQualificationRecordMethodNotAllowedErrorResponseBody",
    "QualificationsUnarchiveQualificationRecordNotFoundErrorResponseBody",
    "QualificationsUnarchiveQualificationRecordNotImplementedErrorResponseBody",
    "QualificationsUnarchiveQualificationRecordServiceUnavailableErrorResponseBody",
    "QualificationsUnarchiveQualificationRecordTooManyRequestsErrorResponseBody",
    "QualificationsUnarchiveQualificationRecordUnauthorizedErrorResponseBody",
    "QuantityObjectResponseBody",
    "ReadingDatapointRequestBody",
    "ReadingDatapointRequestBodyEntityType",
    "ReadingDefinitionResponseBody",
    "ReadingHistoryResponseBody",
    "ReadingSnapshotResponseBody",
    "ReadingTriggerContinuousValueObjectRequestBody",
    "ReadingTriggerContinuousValueObjectRequestBodyOperation",
    "ReadingTriggerContinuousValueObjectRequestBodyUnit",
    "ReadingTriggerContinuousValueObjectResponseBody",
    "ReadingTriggerContinuousValueObjectResponseBodyOperation",
    "ReadingTriggerContinuousValueObjectResponseBodyUnit",
    "ReadingTriggerDetailsObjectRequestBody",
    "ReadingTriggerDetailsObjectResponseBody",
    "ReadingTriggerDetailsResponseBody",
    "ReadingTriggerEnumValueObjectRequestBody",
    "ReadingTriggerEnumValueObjectResponseBody",
    "ReadingsGetReadingsHistoryBadGatewayErrorResponseBody",
    "ReadingsGetReadingsHistoryGatewayTimeoutErrorResponseBody",
    "ReadingsGetReadingsHistoryInternalServerErrorResponseBody",
    "ReadingsGetReadingsHistoryMethodNotAllowedErrorResponseBody",
    "ReadingsGetReadingsHistoryNotFoundErrorResponseBody",
    "ReadingsGetReadingsHistoryNotImplementedErrorResponseBody",
    "ReadingsGetReadingsHistoryResponseBody",
    "ReadingsGetReadingsHistoryServiceUnavailableErrorResponseBody",
    "ReadingsGetReadingsHistoryTooManyRequestsErrorResponseBody",
    "ReadingsGetReadingsHistoryUnauthorizedErrorResponseBody",
    "ReadingsGetReadingsSnapshotBadGatewayErrorResponseBody",
    "ReadingsGetReadingsSnapshotGatewayTimeoutErrorResponseBody",
    "ReadingsGetReadingsSnapshotInternalServerErrorResponseBody",
    "ReadingsGetReadingsSnapshotMethodNotAllowedErrorResponseBody",
    "ReadingsGetReadingsSnapshotNotFoundErrorResponseBody",
    "ReadingsGetReadingsSnapshotNotImplementedErrorResponseBody",
    "ReadingsGetReadingsSnapshotResponseBody",
    "ReadingsGetReadingsSnapshotServiceUnavailableErrorResponseBody",
    "ReadingsGetReadingsSnapshotTooManyRequestsErrorResponseBody",
    "ReadingsGetReadingsSnapshotUnauthorizedErrorResponseBody",
    "ReadingsListReadingsDefinitionsBadGatewayErrorResponseBody",
    "ReadingsListReadingsDefinitionsGatewayTimeoutErrorResponseBody",
    "ReadingsListReadingsDefinitionsInternalServerErrorResponseBody",
    "ReadingsListReadingsDefinitionsMethodNotAllowedErrorResponseBody",
    "ReadingsListReadingsDefinitionsNotFoundErrorResponseBody",
    "ReadingsListReadingsDefinitionsNotImplementedErrorResponseBody",
    "ReadingsListReadingsDefinitionsResponseBody",
    "ReadingsListReadingsDefinitionsServiceUnavailableErrorResponseBody",
    "ReadingsListReadingsDefinitionsTooManyRequestsErrorResponseBody",
    "ReadingsListReadingsDefinitionsUnauthorizedErrorResponseBody",
    "ReadingsPostReadingsBadGatewayErrorResponseBody",
    "ReadingsPostReadingsGatewayTimeoutErrorResponseBody",
    "ReadingsPostReadingsInternalServerErrorResponseBody",
    "ReadingsPostReadingsMethodNotAllowedErrorResponseBody",
    "ReadingsPostReadingsNotFoundErrorResponseBody",
    "ReadingsPostReadingsNotImplementedErrorResponseBody",
    "ReadingsPostReadingsServiceUnavailableErrorResponseBody",
    "ReadingsPostReadingsTooManyRequestsErrorResponseBody",
    "ReadingsPostReadingsUnauthorizedErrorResponseBody",
    "RecipientObjectRequestBody",
    "RecipientObjectRequestBodyNotificationTypesItem",
    "RecipientObjectRequestBodyType",
    "RecipientObjectResponseBody",
    "RecipientObjectResponseBodyNotificationTypesItem",
    "RecipientObjectResponseBodyType",
    "RecoveryPhotoResponseBody",
    "RecoveryPhotoResponseBodyStatus",
    "RecoveryStateResponseBody",
    "RecoveryStateResponseBodyUpdateSource",
    "ReeferTemperatureResponseBody",
    "ReportColumnsObjectResponseBody",
    "ReportColumnsObjectResponseBodyDataType",
    "ReportColumnsObjectResponseBodyUnit",
    "ReportConfigObjectResponseBody",
    "ReportRunObjectResponseBody",
    "ReportRunObjectResponseBodyStatus",
    "ReportsCreateReportRunBadGatewayErrorResponseBody",
    "ReportsCreateReportRunGatewayTimeoutErrorResponseBody",
    "ReportsCreateReportRunInternalServerErrorResponseBody",
    "ReportsCreateReportRunMethodNotAllowedErrorResponseBody",
    "ReportsCreateReportRunNotFoundErrorResponseBody",
    "ReportsCreateReportRunNotImplementedErrorResponseBody",
    "ReportsCreateReportRunResponseBody",
    "ReportsCreateReportRunServiceUnavailableErrorResponseBody",
    "ReportsCreateReportRunTooManyRequestsErrorResponseBody",
    "ReportsCreateReportRunUnauthorizedErrorResponseBody",
    "ReportsDatasetFieldResponseBody",
    "ReportsDatasetFieldResponseBodyDataType",
    "ReportsDatasetFieldResponseBodyUnit",
    "ReportsDatasetResponseBody",
    "ReportsGetDatasetsBadGatewayErrorResponseBody",
    "ReportsGetDatasetsGatewayTimeoutErrorResponseBody",
    "ReportsGetDatasetsInternalServerErrorResponseBody",
    "ReportsGetDatasetsMethodNotAllowedErrorResponseBody",
    "ReportsGetDatasetsNotFoundErrorResponseBody",
    "ReportsGetDatasetsNotImplementedErrorResponseBody",
    "ReportsGetDatasetsResponseBody",
    "ReportsGetDatasetsServiceUnavailableErrorResponseBody",
    "ReportsGetDatasetsTooManyRequestsErrorResponseBody",
    "ReportsGetDatasetsUnauthorizedErrorResponseBody",
    "ReportsGetReportConfigsBadGatewayErrorResponseBody",
    "ReportsGetReportConfigsGatewayTimeoutErrorResponseBody",
    "ReportsGetReportConfigsInternalServerErrorResponseBody",
    "ReportsGetReportConfigsMethodNotAllowedErrorResponseBody",
    "ReportsGetReportConfigsNotFoundErrorResponseBody",
    "ReportsGetReportConfigsNotImplementedErrorResponseBody",
    "ReportsGetReportConfigsResponseBody",
    "ReportsGetReportConfigsServiceUnavailableErrorResponseBody",
    "ReportsGetReportConfigsTooManyRequestsErrorResponseBody",
    "ReportsGetReportConfigsUnauthorizedErrorResponseBody",
    "ReportsGetReportRunDataBadGatewayErrorResponseBody",
    "ReportsGetReportRunDataGatewayTimeoutErrorResponseBody",
    "ReportsGetReportRunDataInternalServerErrorResponseBody",
    "ReportsGetReportRunDataMethodNotAllowedErrorResponseBody",
    "ReportsGetReportRunDataNotFoundErrorResponseBody",
    "ReportsGetReportRunDataNotImplementedErrorResponseBody",
    "ReportsGetReportRunDataResponseBody",
    "ReportsGetReportRunDataServiceUnavailableErrorResponseBody",
    "ReportsGetReportRunDataTooManyRequestsErrorResponseBody",
    "ReportsGetReportRunDataUnauthorizedErrorResponseBody",
    "ReportsGetReportRunsBadGatewayErrorResponseBody",
    "ReportsGetReportRunsGatewayTimeoutErrorResponseBody",
    "ReportsGetReportRunsInternalServerErrorResponseBody",
    "ReportsGetReportRunsMethodNotAllowedErrorResponseBody",
    "ReportsGetReportRunsNotFoundErrorResponseBody",
    "ReportsGetReportRunsNotImplementedErrorResponseBody",
    "ReportsGetReportRunsResponseBody",
    "ReportsGetReportRunsServiceUnavailableErrorResponseBody",
    "ReportsGetReportRunsTooManyRequestsErrorResponseBody",
    "ReportsGetReportRunsUnauthorizedErrorResponseBody",
    "ResolveAssignmentByDetailsResolveAssignmentByDetailsBadGatewayErrorResponseBody",
    "ResolveAssignmentByDetailsResolveAssignmentByDetailsGatewayTimeoutErrorResponseBody",
    "ResolveAssignmentByDetailsResolveAssignmentByDetailsInternalServerErrorResponseBody",
    "ResolveAssignmentByDetailsResolveAssignmentByDetailsMethodNotAllowedErrorResponseBody",
    "ResolveAssignmentByDetailsResolveAssignmentByDetailsNotFoundErrorResponseBody",
    "ResolveAssignmentByDetailsResolveAssignmentByDetailsNotImplementedErrorResponseBody",
    "ResolveAssignmentByDetailsResolveAssignmentByDetailsResponseBody",
    "ResolveAssignmentByDetailsResolveAssignmentByDetailsServiceUnavailableErrorResponseBody",
    "ResolveAssignmentByDetailsResolveAssignmentByDetailsTooManyRequestsErrorResponseBody",
    "ResolveAssignmentByDetailsResolveAssignmentByDetailsUnauthorizedErrorResponseBody",
    "ResolveAssignmentByDetailsResponseBodyResponseBody",
    "ResolvedBy",
    "ResolvedByType",
    "ReverseGeo",
    "ReverseGeoObjectResponseBody",
    "RidershipAccountObjectResponseBody",
    "RidershipAccountsCreateRidershipAccountBadGatewayErrorResponseBody",
    "RidershipAccountsCreateRidershipAccountGatewayTimeoutErrorResponseBody",
    "RidershipAccountsCreateRidershipAccountInternalServerErrorResponseBody",
    "RidershipAccountsCreateRidershipAccountMethodNotAllowedErrorResponseBody",
    "RidershipAccountsCreateRidershipAccountNotFoundErrorResponseBody",
    "RidershipAccountsCreateRidershipAccountNotImplementedErrorResponseBody",
    "RidershipAccountsCreateRidershipAccountResponseBody",
    "RidershipAccountsCreateRidershipAccountServiceUnavailableErrorResponseBody",
    "RidershipAccountsCreateRidershipAccountTooManyRequestsErrorResponseBody",
    "RidershipAccountsCreateRidershipAccountUnauthorizedErrorResponseBody",
    "RidershipAccountsDeleteRidershipAccountBadGatewayErrorResponseBody",
    "RidershipAccountsDeleteRidershipAccountGatewayTimeoutErrorResponseBody",
    "RidershipAccountsDeleteRidershipAccountInternalServerErrorResponseBody",
    "RidershipAccountsDeleteRidershipAccountMethodNotAllowedErrorResponseBody",
    "RidershipAccountsDeleteRidershipAccountNotFoundErrorResponseBody",
    "RidershipAccountsDeleteRidershipAccountNotImplementedErrorResponseBody",
    "RidershipAccountsDeleteRidershipAccountServiceUnavailableErrorResponseBody",
    "RidershipAccountsDeleteRidershipAccountTooManyRequestsErrorResponseBody",
    "RidershipAccountsDeleteRidershipAccountUnauthorizedErrorResponseBody",
    "RidershipAccountsGetRidershipAccountBadGatewayErrorResponseBody",
    "RidershipAccountsGetRidershipAccountGatewayTimeoutErrorResponseBody",
    "RidershipAccountsGetRidershipAccountInternalServerErrorResponseBody",
    "RidershipAccountsGetRidershipAccountMethodNotAllowedErrorResponseBody",
    "RidershipAccountsGetRidershipAccountNotFoundErrorResponseBody",
    "RidershipAccountsGetRidershipAccountNotImplementedErrorResponseBody",
    "RidershipAccountsGetRidershipAccountResponseBody",
    "RidershipAccountsGetRidershipAccountServiceUnavailableErrorResponseBody",
    "RidershipAccountsGetRidershipAccountTooManyRequestsErrorResponseBody",
    "RidershipAccountsGetRidershipAccountUnauthorizedErrorResponseBody",
    "RidershipAccountsListRidershipAccountsBadGatewayErrorResponseBody",
    "RidershipAccountsListRidershipAccountsGatewayTimeoutErrorResponseBody",
    "RidershipAccountsListRidershipAccountsInternalServerErrorResponseBody",
    "RidershipAccountsListRidershipAccountsMethodNotAllowedErrorResponseBody",
    "RidershipAccountsListRidershipAccountsNotFoundErrorResponseBody",
    "RidershipAccountsListRidershipAccountsNotImplementedErrorResponseBody",
    "RidershipAccountsListRidershipAccountsResponseBody",
    "RidershipAccountsListRidershipAccountsServiceUnavailableErrorResponseBody",
    "RidershipAccountsListRidershipAccountsTooManyRequestsErrorResponseBody",
    "RidershipAccountsListRidershipAccountsUnauthorizedErrorResponseBody",
    "RidershipAccountsUpdateRidershipAccountBadGatewayErrorResponseBody",
    "RidershipAccountsUpdateRidershipAccountGatewayTimeoutErrorResponseBody",
    "RidershipAccountsUpdateRidershipAccountInternalServerErrorResponseBody",
    "RidershipAccountsUpdateRidershipAccountMethodNotAllowedErrorResponseBody",
    "RidershipAccountsUpdateRidershipAccountNotFoundErrorResponseBody",
    "RidershipAccountsUpdateRidershipAccountNotImplementedErrorResponseBody",
    "RidershipAccountsUpdateRidershipAccountResponseBody",
    "RidershipAccountsUpdateRidershipAccountServiceUnavailableErrorResponseBody",
    "RidershipAccountsUpdateRidershipAccountTooManyRequestsErrorResponseBody",
    "RidershipAccountsUpdateRidershipAccountUnauthorizedErrorResponseBody",
    "RidershipPassengerIdentifierInputRequestBody",
    "RidershipPassengerIdentifierInputRequestBodyStatus",
    "RidershipPassengerIdentifierInputRequestBodyType",
    "RidershipPassengerIdentifierObjectResponseBody",
    "RidershipPassengerIdentifierObjectResponseBodyStatus",
    "RidershipPassengerIdentifierObjectResponseBodyType",
    "RidershipPassengerObjectResponseBody",
    "RidershipPassengerSpecialInstructionsInputRequestBody",
    "RidershipPassengerSpecialInstructionsObjectResponseBody",
    "RidershipPassengersCreateRidershipPassengerBadGatewayErrorResponseBody",
    "RidershipPassengersCreateRidershipPassengerGatewayTimeoutErrorResponseBody",
    "RidershipPassengersCreateRidershipPassengerInternalServerErrorResponseBody",
    "RidershipPassengersCreateRidershipPassengerMethodNotAllowedErrorResponseBody",
    "RidershipPassengersCreateRidershipPassengerNotFoundErrorResponseBody",
    "RidershipPassengersCreateRidershipPassengerNotImplementedErrorResponseBody",
    "RidershipPassengersCreateRidershipPassengerRequestBodyClassification",
    "RidershipPassengersCreateRidershipPassengerResponseBody",
    "RidershipPassengersCreateRidershipPassengerServiceUnavailableErrorResponseBody",
    "RidershipPassengersCreateRidershipPassengerTooManyRequestsErrorResponseBody",
    "RidershipPassengersCreateRidershipPassengerUnauthorizedErrorResponseBody",
    "RidershipPassengersDeleteRidershipPassengerBadGatewayErrorResponseBody",
    "RidershipPassengersDeleteRidershipPassengerGatewayTimeoutErrorResponseBody",
    "RidershipPassengersDeleteRidershipPassengerInternalServerErrorResponseBody",
    "RidershipPassengersDeleteRidershipPassengerMethodNotAllowedErrorResponseBody",
    "RidershipPassengersDeleteRidershipPassengerNotFoundErrorResponseBody",
    "RidershipPassengersDeleteRidershipPassengerNotImplementedErrorResponseBody",
    "RidershipPassengersDeleteRidershipPassengerServiceUnavailableErrorResponseBody",
    "RidershipPassengersDeleteRidershipPassengerTooManyRequestsErrorResponseBody",
    "RidershipPassengersDeleteRidershipPassengerUnauthorizedErrorResponseBody",
    "RidershipPassengersGetRidershipPassengerBadGatewayErrorResponseBody",
    "RidershipPassengersGetRidershipPassengerGatewayTimeoutErrorResponseBody",
    "RidershipPassengersGetRidershipPassengerInternalServerErrorResponseBody",
    "RidershipPassengersGetRidershipPassengerMethodNotAllowedErrorResponseBody",
    "RidershipPassengersGetRidershipPassengerNotFoundErrorResponseBody",
    "RidershipPassengersGetRidershipPassengerNotImplementedErrorResponseBody",
    "RidershipPassengersGetRidershipPassengerResponseBody",
    "RidershipPassengersGetRidershipPassengerServiceUnavailableErrorResponseBody",
    "RidershipPassengersGetRidershipPassengerTooManyRequestsErrorResponseBody",
    "RidershipPassengersGetRidershipPassengerUnauthorizedErrorResponseBody",
    "RidershipPassengersListRidershipPassengersBadGatewayErrorResponseBody",
    "RidershipPassengersListRidershipPassengersGatewayTimeoutErrorResponseBody",
    "RidershipPassengersListRidershipPassengersInternalServerErrorResponseBody",
    "RidershipPassengersListRidershipPassengersMethodNotAllowedErrorResponseBody",
    "RidershipPassengersListRidershipPassengersNotFoundErrorResponseBody",
    "RidershipPassengersListRidershipPassengersNotImplementedErrorResponseBody",
    "RidershipPassengersListRidershipPassengersResponseBody",
    "RidershipPassengersListRidershipPassengersServiceUnavailableErrorResponseBody",
    "RidershipPassengersListRidershipPassengersTooManyRequestsErrorResponseBody",
    "RidershipPassengersListRidershipPassengersUnauthorizedErrorResponseBody",
    "RidershipPassengersUpdateRidershipPassengerBadGatewayErrorResponseBody",
    "RidershipPassengersUpdateRidershipPassengerGatewayTimeoutErrorResponseBody",
    "RidershipPassengersUpdateRidershipPassengerInternalServerErrorResponseBody",
    "RidershipPassengersUpdateRidershipPassengerMethodNotAllowedErrorResponseBody",
    "RidershipPassengersUpdateRidershipPassengerNotFoundErrorResponseBody",
    "RidershipPassengersUpdateRidershipPassengerNotImplementedErrorResponseBody",
    "RidershipPassengersUpdateRidershipPassengerRequestBodyClassification",
    "RidershipPassengersUpdateRidershipPassengerResponseBody",
    "RidershipPassengersUpdateRidershipPassengerServiceUnavailableErrorResponseBody",
    "RidershipPassengersUpdateRidershipPassengerTooManyRequestsErrorResponseBody",
    "RidershipPassengersUpdateRidershipPassengerUnauthorizedErrorResponseBody",
    "RidershipRouteSetupObjectResponseBody",
    "RidershipRouteSetupPassengerInputRequestBody",
    "RidershipRouteSetupPassengerObjectResponseBody",
    "RidershipRouteSetupsCreateRidershipRouteSetupBadGatewayErrorResponseBody",
    "RidershipRouteSetupsCreateRidershipRouteSetupGatewayTimeoutErrorResponseBody",
    "RidershipRouteSetupsCreateRidershipRouteSetupInternalServerErrorResponseBody",
    "RidershipRouteSetupsCreateRidershipRouteSetupMethodNotAllowedErrorResponseBody",
    "RidershipRouteSetupsCreateRidershipRouteSetupNotFoundErrorResponseBody",
    "RidershipRouteSetupsCreateRidershipRouteSetupNotImplementedErrorResponseBody",
    "RidershipRouteSetupsCreateRidershipRouteSetupResponseBody",
    "RidershipRouteSetupsCreateRidershipRouteSetupServiceUnavailableErrorResponseBody",
    "RidershipRouteSetupsCreateRidershipRouteSetupTooManyRequestsErrorResponseBody",
    "RidershipRouteSetupsCreateRidershipRouteSetupUnauthorizedErrorResponseBody",
    "RidershipRouteSetupsDeleteRidershipRouteSetupBadGatewayErrorResponseBody",
    "RidershipRouteSetupsDeleteRidershipRouteSetupGatewayTimeoutErrorResponseBody",
    "RidershipRouteSetupsDeleteRidershipRouteSetupInternalServerErrorResponseBody",
    "RidershipRouteSetupsDeleteRidershipRouteSetupMethodNotAllowedErrorResponseBody",
    "RidershipRouteSetupsDeleteRidershipRouteSetupNotFoundErrorResponseBody",
    "RidershipRouteSetupsDeleteRidershipRouteSetupNotImplementedErrorResponseBody",
    "RidershipRouteSetupsDeleteRidershipRouteSetupServiceUnavailableErrorResponseBody",
    "RidershipRouteSetupsDeleteRidershipRouteSetupTooManyRequestsErrorResponseBody",
    "RidershipRouteSetupsDeleteRidershipRouteSetupUnauthorizedErrorResponseBody",
    "RidershipRouteSetupsGetRidershipRouteSetupBadGatewayErrorResponseBody",
    "RidershipRouteSetupsGetRidershipRouteSetupGatewayTimeoutErrorResponseBody",
    "RidershipRouteSetupsGetRidershipRouteSetupInternalServerErrorResponseBody",
    "RidershipRouteSetupsGetRidershipRouteSetupMethodNotAllowedErrorResponseBody",
    "RidershipRouteSetupsGetRidershipRouteSetupNotFoundErrorResponseBody",
    "RidershipRouteSetupsGetRidershipRouteSetupNotImplementedErrorResponseBody",
    "RidershipRouteSetupsGetRidershipRouteSetupResponseBody",
    "RidershipRouteSetupsGetRidershipRouteSetupServiceUnavailableErrorResponseBody",
    "RidershipRouteSetupsGetRidershipRouteSetupTooManyRequestsErrorResponseBody",
    "RidershipRouteSetupsGetRidershipRouteSetupUnauthorizedErrorResponseBody",
    "RidershipRouteSetupsListRidershipRouteSetupsBadGatewayErrorResponseBody",
    "RidershipRouteSetupsListRidershipRouteSetupsGatewayTimeoutErrorResponseBody",
    "RidershipRouteSetupsListRidershipRouteSetupsInternalServerErrorResponseBody",
    "RidershipRouteSetupsListRidershipRouteSetupsMethodNotAllowedErrorResponseBody",
    "RidershipRouteSetupsListRidershipRouteSetupsNotFoundErrorResponseBody",
    "RidershipRouteSetupsListRidershipRouteSetupsNotImplementedErrorResponseBody",
    "RidershipRouteSetupsListRidershipRouteSetupsResponseBody",
    "RidershipRouteSetupsListRidershipRouteSetupsServiceUnavailableErrorResponseBody",
    "RidershipRouteSetupsListRidershipRouteSetupsTooManyRequestsErrorResponseBody",
    "RidershipRouteSetupsListRidershipRouteSetupsUnauthorizedErrorResponseBody",
    "RidershipRouteSetupsUpdateRidershipRouteSetupBadGatewayErrorResponseBody",
    "RidershipRouteSetupsUpdateRidershipRouteSetupGatewayTimeoutErrorResponseBody",
    "RidershipRouteSetupsUpdateRidershipRouteSetupInternalServerErrorResponseBody",
    "RidershipRouteSetupsUpdateRidershipRouteSetupMethodNotAllowedErrorResponseBody",
    "RidershipRouteSetupsUpdateRidershipRouteSetupNotFoundErrorResponseBody",
    "RidershipRouteSetupsUpdateRidershipRouteSetupNotImplementedErrorResponseBody",
    "RidershipRouteSetupsUpdateRidershipRouteSetupResponseBody",
    "RidershipRouteSetupsUpdateRidershipRouteSetupServiceUnavailableErrorResponseBody",
    "RidershipRouteSetupsUpdateRidershipRouteSetupTooManyRequestsErrorResponseBody",
    "RidershipRouteSetupsUpdateRidershipRouteSetupUnauthorizedErrorResponseBody",
    "RollingStopDetectionAlertSettingsObjectResponseBody",
    "RouteChangesResponseBody",
    "RouteEventDetailsResponseBody",
    "RouteEventResponseResponseBody",
    "RouteEventResponseResponseBodyEventType",
    "RouteEventRouteResponseResponseBody",
    "RouteEventStopResponseResponseBody",
    "RouteFeedObjectResponseBody",
    "RouteFeedObjectResponseBodyOperation",
    "RouteFeedObjectResponseBodySource",
    "RouteFeedObjectResponseBodyType",
    "RouteObjectResponseBody",
    "RouteSettingsRequestBody",
    "RouteSettingsRequestBodyRouteCompletionCondition",
    "RouteSettingsRequestBodyRouteStartingCondition",
    "RouteSettingsRequestBodySequencingMethod",
    "RouteSettingsResponseBody",
    "RouteSettingsResponseBodyRouteCompletionCondition",
    "RouteSettingsResponseBodyRouteStartingCondition",
    "RouteSettingsResponseBodySequencingMethod",
    "RouteStopDetailsObjectResponseBody",
    "RouteStopDetailsObjectResponseBodyOperation",
    "RouteStopDetailsObjectResponseBodyType",
    "RouteStopEstimatedArrivalDetailsObjectRequestBody",
    "RouteStopEstimatedArrivalDetailsObjectResponseBody",
    "RouteStopEtaResponseBody",
    "RouteStopObjectResponseBody",
    "RoutesCreateRouteBadGatewayErrorResponseBody",
    "RoutesCreateRouteGatewayTimeoutErrorResponseBody",
    "RoutesCreateRouteInternalServerErrorResponseBody",
    "RoutesCreateRouteMethodNotAllowedErrorResponseBody",
    "RoutesCreateRouteNotFoundErrorResponseBody",
    "RoutesCreateRouteNotImplementedErrorResponseBody",
    "RoutesCreateRouteResponseBody",
    "RoutesCreateRouteServiceUnavailableErrorResponseBody",
    "RoutesCreateRouteTooManyRequestsErrorResponseBody",
    "RoutesCreateRouteUnauthorizedErrorResponseBody",
    "RoutesDeleteRouteBadGatewayErrorResponseBody",
    "RoutesDeleteRouteGatewayTimeoutErrorResponseBody",
    "RoutesDeleteRouteInternalServerErrorResponseBody",
    "RoutesDeleteRouteMethodNotAllowedErrorResponseBody",
    "RoutesDeleteRouteNotFoundErrorResponseBody",
    "RoutesDeleteRouteNotImplementedErrorResponseBody",
    "RoutesDeleteRouteServiceUnavailableErrorResponseBody",
    "RoutesDeleteRouteTooManyRequestsErrorResponseBody",
    "RoutesDeleteRouteUnauthorizedErrorResponseBody",
    "RoutesFetchRouteBadGatewayErrorResponseBody",
    "RoutesFetchRouteGatewayTimeoutErrorResponseBody",
    "RoutesFetchRouteInternalServerErrorResponseBody",
    "RoutesFetchRouteMethodNotAllowedErrorResponseBody",
    "RoutesFetchRouteNotFoundErrorResponseBody",
    "RoutesFetchRouteNotImplementedErrorResponseBody",
    "RoutesFetchRouteResponseBody",
    "RoutesFetchRouteServiceUnavailableErrorResponseBody",
    "RoutesFetchRouteTooManyRequestsErrorResponseBody",
    "RoutesFetchRouteUnauthorizedErrorResponseBody",
    "RoutesFetchRoutesBadGatewayErrorResponseBody",
    "RoutesFetchRoutesGatewayTimeoutErrorResponseBody",
    "RoutesFetchRoutesInternalServerErrorResponseBody",
    "RoutesFetchRoutesMethodNotAllowedErrorResponseBody",
    "RoutesFetchRoutesNotFoundErrorResponseBody",
    "RoutesFetchRoutesNotImplementedErrorResponseBody",
    "RoutesFetchRoutesResponseBody",
    "RoutesFetchRoutesServiceUnavailableErrorResponseBody",
    "RoutesFetchRoutesTooManyRequestsErrorResponseBody",
    "RoutesFetchRoutesUnauthorizedErrorResponseBody",
    "RoutesGetRouteEventsStreamBadGatewayErrorResponseBody",
    "RoutesGetRouteEventsStreamGatewayTimeoutErrorResponseBody",
    "RoutesGetRouteEventsStreamInternalServerErrorResponseBody",
    "RoutesGetRouteEventsStreamMethodNotAllowedErrorResponseBody",
    "RoutesGetRouteEventsStreamNotFoundErrorResponseBody",
    "RoutesGetRouteEventsStreamNotImplementedErrorResponseBody",
    "RoutesGetRouteEventsStreamResponseBody",
    "RoutesGetRouteEventsStreamServiceUnavailableErrorResponseBody",
    "RoutesGetRouteEventsStreamTooManyRequestsErrorResponseBody",
    "RoutesGetRouteEventsStreamUnauthorizedErrorResponseBody",
    "RoutesGetRoutesFeedBadGatewayErrorResponseBody",
    "RoutesGetRoutesFeedGatewayTimeoutErrorResponseBody",
    "RoutesGetRoutesFeedInternalServerErrorResponseBody",
    "RoutesGetRoutesFeedMethodNotAllowedErrorResponseBody",
    "RoutesGetRoutesFeedNotFoundErrorResponseBody",
    "RoutesGetRoutesFeedNotImplementedErrorResponseBody",
    "RoutesGetRoutesFeedResponseBody",
    "RoutesGetRoutesFeedServiceUnavailableErrorResponseBody",
    "RoutesGetRoutesFeedTooManyRequestsErrorResponseBody",
    "RoutesGetRoutesFeedUnauthorizedErrorResponseBody",
    "RoutesPatchRouteBadGatewayErrorResponseBody",
    "RoutesPatchRouteGatewayTimeoutErrorResponseBody",
    "RoutesPatchRouteInternalServerErrorResponseBody",
    "RoutesPatchRouteMethodNotAllowedErrorResponseBody",
    "RoutesPatchRouteNotFoundErrorResponseBody",
    "RoutesPatchRouteNotImplementedErrorResponseBody",
    "RoutesPatchRouteResponseBody",
    "RoutesPatchRouteServiceUnavailableErrorResponseBody",
    "RoutesPatchRouteTooManyRequestsErrorResponseBody",
    "RoutesPatchRouteUnauthorizedErrorResponseBody",
    "RoutesSingleUseAddressObjectRequestBody",
    "RoutesSingleUseAddressObjectResponseBody",
    "RoutesStopResponseObjectResponseBody",
    "RoutesStopResponseObjectResponseBodyState",
    "SafetyBehaviorTriggerDetailsObjectRequestBody",
    "SafetyBehaviorTriggerDetailsObjectRequestBodyBehaviorsItem",
    "SafetyBehaviorTriggerDetailsObjectRequestBodySeveritiesItem",
    "SafetyBehaviorTriggerDetailsObjectRequestBodyStatusesItem",
    "SafetyBehaviorTriggerDetailsObjectResponseBody",
    "SafetyBehaviorTriggerDetailsObjectResponseBodyBehaviorsItem",
    "SafetyBehaviorTriggerDetailsObjectResponseBodySeveritiesItem",
    "SafetyBehaviorTriggerDetailsObjectResponseBodyStatusesItem",
    "SafetyEvent",
    "SafetyEventActivityFeedItemResponseBody",
    "SafetyEventActivityFeedItemResponseBodyType",
    "SafetyEventBehaviorLabel",
    "SafetyEventBehaviorLabelName",
    "SafetyEventBehaviorLabelSource",
    "SafetyEventBehaviorLabelType",
    "SafetyEventBehaviorLabels",
    "SafetyEventBehaviorLabelsResponseBody",
    "SafetyEventBehaviorLabelsResponseBodyType",
    "SafetyEventCoachingState",
    "SafetyEventDismissalReasonResponseBody",
    "SafetyEventDismissalReasonResponseBodyCode",
    "SafetyEventDownloadForwardVideoUrl",
    "SafetyEventDownloadInwardVideoUrl",
    "SafetyEventDownloadTrackedInwardVideoUrl",
    "SafetyEventDriverObjectResponseBody",
    "SafetyEventId",
    "SafetyEventMaxAccelerationGForce",
    "SafetyEventObjectResponseBody",
    "SafetyEventSpeedingMetadataResponseBody",
    "SafetyEventTime",
    "SafetyEventV2AssetObjectResponseBody",
    "SafetyEventV2AssetObjectResponseBodyType",
    "SafetyEventV2BehaviorLabelsResponseBody",
    "SafetyEventV2BehaviorLabelsResponseBodyLabel",
    "SafetyEventV2BehaviorLabelsResponseBodySource",
    "SafetyEventV2ContextLabelsResponseBody",
    "SafetyEventV2DriverObjectResponseBody",
    "SafetyEventV2MediaResponseBody",
    "SafetyEventV2MediaResponseBodyCameraRole",
    "SafetyEventV2MediaResponseBodyInput",
    "SafetyEventV2ObjectResponseBody",
    "SafetyEventV2ObjectResponseBodyEventState",
    "SafetyEventVehicleObjectResponseBody",
    "SafetyEventsGetSafetyActivityEventFeedBadGatewayErrorResponseBody",
    "SafetyEventsGetSafetyActivityEventFeedGatewayTimeoutErrorResponseBody",
    "SafetyEventsGetSafetyActivityEventFeedInternalServerErrorResponseBody",
    "SafetyEventsGetSafetyActivityEventFeedMethodNotAllowedErrorResponseBody",
    "SafetyEventsGetSafetyActivityEventFeedNotFoundErrorResponseBody",
    "SafetyEventsGetSafetyActivityEventFeedNotImplementedErrorResponseBody",
    "SafetyEventsGetSafetyActivityEventFeedResponseBody",
    "SafetyEventsGetSafetyActivityEventFeedServiceUnavailableErrorResponseBody",
    "SafetyEventsGetSafetyActivityEventFeedTooManyRequestsErrorResponseBody",
    "SafetyEventsGetSafetyActivityEventFeedUnauthorizedErrorResponseBody",
    "SafetyEventsListResponse",
    "SafetyEventsV2GetSafetyEventsV2BadGatewayErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2GatewayTimeoutErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2InternalServerErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2MethodNotAllowedErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2NotFoundErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2NotImplementedErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2ResponseBody",
    "SafetyEventsV2GetSafetyEventsV2ServiceUnavailableErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2StreamBadGatewayErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2StreamGatewayTimeoutErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2StreamInternalServerErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2StreamMethodNotAllowedErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2StreamNotFoundErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2StreamNotImplementedErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2StreamResponseBody",
    "SafetyEventsV2GetSafetyEventsV2StreamServiceUnavailableErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2StreamTooManyRequestsErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2StreamUnauthorizedErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2TooManyRequestsErrorResponseBody",
    "SafetyEventsV2GetSafetyEventsV2UnauthorizedErrorResponseBody",
    "SafetyEventsV2PatchSafetyEventsV2BatchBadGatewayErrorResponseBody",
    "SafetyEventsV2PatchSafetyEventsV2BatchGatewayTimeoutErrorResponseBody",
    "SafetyEventsV2PatchSafetyEventsV2BatchInternalServerErrorResponseBody",
    "SafetyEventsV2PatchSafetyEventsV2BatchMethodNotAllowedErrorResponseBody",
    "SafetyEventsV2PatchSafetyEventsV2BatchNotFoundErrorResponseBody",
    "SafetyEventsV2PatchSafetyEventsV2BatchNotImplementedErrorResponseBody",
    "SafetyEventsV2PatchSafetyEventsV2BatchRequestBodyContextLabelsToAddItem",
    "SafetyEventsV2PatchSafetyEventsV2BatchRequestBodyContextLabelsToRemoveItem",
    "SafetyEventsV2PatchSafetyEventsV2BatchRequestBodyEventState",
    "SafetyEventsV2PatchSafetyEventsV2BatchResponseBody",
    "SafetyEventsV2PatchSafetyEventsV2BatchServiceUnavailableErrorResponseBody",
    "SafetyEventsV2PatchSafetyEventsV2BatchTooManyRequestsErrorResponseBody",
    "SafetyEventsV2PatchSafetyEventsV2BatchUnauthorizedErrorResponseBody",
    "SafetyScoreBehaviorObjectResponseBody",
    "SafetyScoreBehaviorObjectResponseBodyBehaviorType",
    "SafetyScoreConfigurationSettingsObjectResponseBody",
    "SafetyScoreDetailsRequestBody",
    "SafetyScoreDetailsRequestBodyComparison",
    "SafetyScoreDetailsResponseBody",
    "SafetyScoreDetailsResponseBodyComparison",
    "SafetyScoreSpeedingObjectResponseBody",
    "SafetyScoreSpeedingObjectResponseBodySpeedingType",
    "SafetyScoresGetDriverSafetyScoreTripsBadGatewayErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoreTripsGatewayTimeoutErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoreTripsInternalServerErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoreTripsMethodNotAllowedErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoreTripsNotFoundErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoreTripsNotImplementedErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoreTripsResponseBody",
    "SafetyScoresGetDriverSafetyScoreTripsServiceUnavailableErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoreTripsTooManyRequestsErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoreTripsUnauthorizedErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoresBadGatewayErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoresGatewayTimeoutErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoresInternalServerErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoresMethodNotAllowedErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoresNotFoundErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoresNotImplementedErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoresResponseBody",
    "SafetyScoresGetDriverSafetyScoresServiceUnavailableErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoresTooManyRequestsErrorResponseBody",
    "SafetyScoresGetDriverSafetyScoresUnauthorizedErrorResponseBody",
    "SafetyScoresGetTagGroupSafetyScoresBadGatewayErrorResponseBody",
    "SafetyScoresGetTagGroupSafetyScoresGatewayTimeoutErrorResponseBody",
    "SafetyScoresGetTagGroupSafetyScoresInternalServerErrorResponseBody",
    "SafetyScoresGetTagGroupSafetyScoresMethodNotAllowedErrorResponseBody",
    "SafetyScoresGetTagGroupSafetyScoresNotFoundErrorResponseBody",
    "SafetyScoresGetTagGroupSafetyScoresNotImplementedErrorResponseBody",
    "SafetyScoresGetTagGroupSafetyScoresResponseBody",
    "SafetyScoresGetTagGroupSafetyScoresServiceUnavailableErrorResponseBody",
    "SafetyScoresGetTagGroupSafetyScoresTooManyRequestsErrorResponseBody",
    "SafetyScoresGetTagGroupSafetyScoresUnauthorizedErrorResponseBody",
    "SafetyScoresGetTagSafetyScoresBadGatewayErrorResponseBody",
    "SafetyScoresGetTagSafetyScoresGatewayTimeoutErrorResponseBody",
    "SafetyScoresGetTagSafetyScoresInternalServerErrorResponseBody",
    "SafetyScoresGetTagSafetyScoresMethodNotAllowedErrorResponseBody",
    "SafetyScoresGetTagSafetyScoresNotFoundErrorResponseBody",
    "SafetyScoresGetTagSafetyScoresNotImplementedErrorResponseBody",
    "SafetyScoresGetTagSafetyScoresResponseBody",
    "SafetyScoresGetTagSafetyScoresServiceUnavailableErrorResponseBody",
    "SafetyScoresGetTagSafetyScoresTooManyRequestsErrorResponseBody",
    "SafetyScoresGetTagSafetyScoresUnauthorizedErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoreTripsBadGatewayErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoreTripsGatewayTimeoutErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoreTripsInternalServerErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoreTripsMethodNotAllowedErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoreTripsNotFoundErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoreTripsNotImplementedErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoreTripsResponseBody",
    "SafetyScoresGetVehicleSafetyScoreTripsServiceUnavailableErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoreTripsTooManyRequestsErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoreTripsUnauthorizedErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoresBadGatewayErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoresGatewayTimeoutErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoresInternalServerErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoresMethodNotAllowedErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoresNotFoundErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoresNotImplementedErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoresResponseBody",
    "SafetyScoresGetVehicleSafetyScoresServiceUnavailableErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoresTooManyRequestsErrorResponseBody",
    "SafetyScoresGetVehicleSafetyScoresUnauthorizedErrorResponseBody",
    "SafetySettingsGetSafetySettingsBadGatewayErrorResponseBody",
    "SafetySettingsGetSafetySettingsGatewayTimeoutErrorResponseBody",
    "SafetySettingsGetSafetySettingsInternalServerErrorResponseBody",
    "SafetySettingsGetSafetySettingsMethodNotAllowedErrorResponseBody",
    "SafetySettingsGetSafetySettingsNotFoundErrorResponseBody",
    "SafetySettingsGetSafetySettingsNotImplementedErrorResponseBody",
    "SafetySettingsGetSafetySettingsResponseBody",
    "SafetySettingsGetSafetySettingsServiceUnavailableErrorResponseBody",
    "SafetySettingsGetSafetySettingsTooManyRequestsErrorResponseBody",
    "SafetySettingsGetSafetySettingsUnauthorizedErrorResponseBody",
    "SafetySettingsObjectResponseBody",
    "SafetySettingsObjectResponseBodyDefaultVehicleType",
    "Samsara",
    "SamsaraEnvironment",
    "ScannedDocumentValueObjectRequestBody",
    "ScannedDocumentValueObjectResponseBody",
    "ScheduledMaintenanceByEngineHoursDetailsObjectRequestBody",
    "ScheduledMaintenanceByEngineHoursDetailsObjectResponseBody",
    "ScheduledMaintenanceByEngineHoursResponseBody",
    "ScheduledMaintenanceDataResponseBody",
    "ScheduledMaintenanceOdometerDataResponseBody",
    "ScheduledMaintenanceOdometerTriggerDetailsObjectRequestBody",
    "ScheduledMaintenanceOdometerTriggerDetailsObjectResponseBody",
    "ScheduledMaintenanceTriggerDetailsObjectRequestBody",
    "ScheduledMaintenanceTriggerDetailsObjectResponseBody",
    "ScopeObjectRequestBody",
    "ScopeObjectResponseBody",
    "Sensor",
    "SensorResponseBody",
    "Serial",
    "ServiceTaskDefinitionObjectResponseBody",
    "ServiceTaskInstanceInputObjectRequestBody",
    "ServiceTaskInstanceInputObjectRequestBodyStatus",
    "ServiceTaskInstanceObjectResponseBody",
    "ServiceTaskInstanceObjectResponseBodyStatus",
    "ServiceUnavailableError",
    "ServiceWindowObjectResponseBody",
    "SettingsComplianceResponseObjectResponseBody",
    "SettingsGetComplianceSettingsBadGatewayErrorResponseBody",
    "SettingsGetComplianceSettingsGatewayTimeoutErrorResponseBody",
    "SettingsGetComplianceSettingsInternalServerErrorResponseBody",
    "SettingsGetComplianceSettingsMethodNotAllowedErrorResponseBody",
    "SettingsGetComplianceSettingsNotFoundErrorResponseBody",
    "SettingsGetComplianceSettingsNotImplementedErrorResponseBody",
    "SettingsGetComplianceSettingsResponseBody",
    "SettingsGetComplianceSettingsServiceUnavailableErrorResponseBody",
    "SettingsGetComplianceSettingsTooManyRequestsErrorResponseBody",
    "SettingsGetComplianceSettingsUnauthorizedErrorResponseBody",
    "SettingsGetDriverAppSettingsBadGatewayErrorResponseBody",
    "SettingsGetDriverAppSettingsGatewayTimeoutErrorResponseBody",
    "SettingsGetDriverAppSettingsInternalServerErrorResponseBody",
    "SettingsGetDriverAppSettingsMethodNotAllowedErrorResponseBody",
    "SettingsGetDriverAppSettingsNotFoundErrorResponseBody",
    "SettingsGetDriverAppSettingsNotImplementedErrorResponseBody",
    "SettingsGetDriverAppSettingsResponseBody",
    "SettingsGetDriverAppSettingsServiceUnavailableErrorResponseBody",
    "SettingsGetDriverAppSettingsTooManyRequestsErrorResponseBody",
    "SettingsGetDriverAppSettingsUnauthorizedErrorResponseBody",
    "SettingsPatchComplianceSettingsBadGatewayErrorResponseBody",
    "SettingsPatchComplianceSettingsGatewayTimeoutErrorResponseBody",
    "SettingsPatchComplianceSettingsInternalServerErrorResponseBody",
    "SettingsPatchComplianceSettingsMethodNotAllowedErrorResponseBody",
    "SettingsPatchComplianceSettingsNotFoundErrorResponseBody",
    "SettingsPatchComplianceSettingsNotImplementedErrorResponseBody",
    "SettingsPatchComplianceSettingsResponseBody",
    "SettingsPatchComplianceSettingsServiceUnavailableErrorResponseBody",
    "SettingsPatchComplianceSettingsTooManyRequestsErrorResponseBody",
    "SettingsPatchComplianceSettingsUnauthorizedErrorResponseBody",
    "SettingsPatchDriverAppSettingsBadGatewayErrorResponseBody",
    "SettingsPatchDriverAppSettingsGatewayTimeoutErrorResponseBody",
    "SettingsPatchDriverAppSettingsInternalServerErrorResponseBody",
    "SettingsPatchDriverAppSettingsMethodNotAllowedErrorResponseBody",
    "SettingsPatchDriverAppSettingsNotFoundErrorResponseBody",
    "SettingsPatchDriverAppSettingsNotImplementedErrorResponseBody",
    "SettingsPatchDriverAppSettingsResponseBody",
    "SettingsPatchDriverAppSettingsServiceUnavailableErrorResponseBody",
    "SettingsPatchDriverAppSettingsTooManyRequestsErrorResponseBody",
    "SettingsPatchDriverAppSettingsUnauthorizedErrorResponseBody",
    "SettingsResponseBody",
    "SevereSpeedingStartedObjectResponseBody",
    "SevereSpeedingStartedResponseObjectResponseBody",
    "SignatoryUserObjectResponseBody",
    "SignatureFieldTypeMetaDataObjectResponseBody",
    "SignatureValueObjectRequestBody",
    "SignatureValueObjectResponseBody",
    "SingleApprovalRequirementsObjectResponseBody",
    "SingleDriverEfficiencyByDriverDataObjectResponseBody",
    "SingleDriverEfficiencyByVehicleDataObjectResponseBody",
    "SingleUseLocationObjectResponseBody",
    "SiteGatewayDisconnectedResponseBody",
    "SkillObjectResponseBody",
    "SpecificVehicleFaultCodeObjectRequestBody",
    "SpecificVehicleFaultCodeObjectRequestBodyType",
    "SpecificVehicleFaultCodeObjectResponseBody",
    "SpecificVehicleFaultCodeObjectResponseBodyType",
    "SpeedDataResponseBody",
    "SpeedDataResponseBodyOperation",
    "SpeedResponseResponseBody",
    "SpeedTriggerDetailsObjectRequestBody",
    "SpeedTriggerDetailsObjectRequestBodyOperation",
    "SpeedTriggerDetailsObjectResponseBody",
    "SpeedTriggerDetailsObjectResponseBodyOperation",
    "SpeedingIntervalLocationResponseResponseBody",
    "SpeedingIntervalResponseBody",
    "SpeedingIntervalResponseBodySeverityLevel",
    "SpeedingIntervalsGetSpeedingIntervalsBadGatewayErrorResponseBody",
    "SpeedingIntervalsGetSpeedingIntervalsGatewayTimeoutErrorResponseBody",
    "SpeedingIntervalsGetSpeedingIntervalsInternalServerErrorResponseBody",
    "SpeedingIntervalsGetSpeedingIntervalsMethodNotAllowedErrorResponseBody",
    "SpeedingIntervalsGetSpeedingIntervalsNotFoundErrorResponseBody",
    "SpeedingIntervalsGetSpeedingIntervalsNotImplementedErrorResponseBody",
    "SpeedingIntervalsGetSpeedingIntervalsResponseBody",
    "SpeedingIntervalsGetSpeedingIntervalsServiceUnavailableErrorResponseBody",
    "SpeedingIntervalsGetSpeedingIntervalsTooManyRequestsErrorResponseBody",
    "SpeedingIntervalsGetSpeedingIntervalsUnauthorizedErrorResponseBody",
    "SpeedingSettingsObjectResponseBody",
    "SpeedingSettingsObjectResponseBodyUnit",
    "SpeedingSeverityLevelResponseBody",
    "SpeedingSeverityLevelResponseBodySeverityLevel",
    "StartFunctionRunResponseBodyResponseBody",
    "StopEtaUpdatedEventDetailsResponseBody",
    "StopTaskCompletedEventDetailsResponseBody",
    "StopTaskCompletedEventDetailsResponseBodyTaskType",
    "StopTaskSkippedEventDetailsResponseBody",
    "StopTaskSkippedEventDetailsResponseBodyTaskType",
    "StreamWorkOrdersRequestWorkOrderStatusesItem",
    "StringDataPoint",
    "SuddenFuelLevelDropResponseBody",
    "SuddenFuelLevelDropTriggerDetailsObjectRequestBody",
    "SuddenFuelLevelDropTriggerDetailsObjectResponseBody",
    "SuddenFuelLevelRiseResponseBody",
    "SuddenFuelLevelRiseTriggerDetailsObjectRequestBody",
    "SuddenFuelLevelRiseTriggerDetailsObjectResponseBody",
    "TachographActivity",
    "TachographActivityList",
    "TachographActivityListWrapper",
    "TachographActivityState",
    "TachographDriverFile",
    "TachographDriverFileData",
    "TachographDriverFileList",
    "TachographDriverFileListWrapper",
    "TachographDriverFilesResponse",
    "TachographVehicleFile",
    "TachographVehicleFileData",
    "TachographVehicleFileList",
    "TachographVehicleFileListWrapper",
    "TachographVehicleFilesResponse",
    "Tag",
    "TagAllOf",
    "TagAllOfExternalIds",
    "TagGroupSafetyScoreResponseBody",
    "TagId",
    "TagIds",
    "TagName",
    "TagResponse",
    "TagSafetyScoreResponseBody",
    "TagTinyResponse",
    "TaggedObject",
    "TaggedObjectId",
    "TaggedObjectName",
    "TamperingDetectedResponseBody",
    "Time",
    "TimeRangeObjectRequestBody",
    "TimeRangeObjectRequestBodyDaysOfWeekItem",
    "TimeRangeObjectResponseBody",
    "TimeRangeObjectResponseBodyDaysOfWeekItem",
    "TinyAssetObjectRequestBody",
    "TinyAssetObjectRequestBodyAssetType",
    "TinyAssetObjectResponseBody",
    "TinyAssetObjectResponseBodyAssetType",
    "TinyDriverObjectRequestBody",
    "TinyDriverObjectResponseBody",
    "TinyTag",
    "TinyWidgetObjectRequestBody",
    "TinyWidgetObjectResponseBody",
    "TireFaultCodeDetailsObjectRequestBody",
    "TireFaultCodeDetailsObjectRequestBodyManufacturer",
    "TireFaultCodeDetailsObjectRequestBodySpecificTireFaultCodesItem",
    "TireFaultCodeDetailsObjectResponseBody",
    "TireFaultCodeDetailsObjectResponseBodyManufacturer",
    "TireFaultCodeDetailsObjectResponseBodySpecificTireFaultCodesItem",
    "TireFaultsResponseBody",
    "TooManyRequestsError",
    "TotalBrakeEventCount",
    "TrailerAssignmentsCreateDriverTrailerAssignmentBadGatewayErrorResponseBody",
    "TrailerAssignmentsCreateDriverTrailerAssignmentGatewayTimeoutErrorResponseBody",
    "TrailerAssignmentsCreateDriverTrailerAssignmentInternalServerErrorResponseBody",
    "TrailerAssignmentsCreateDriverTrailerAssignmentMethodNotAllowedErrorResponseBody",
    "TrailerAssignmentsCreateDriverTrailerAssignmentNotFoundErrorResponseBody",
    "TrailerAssignmentsCreateDriverTrailerAssignmentNotImplementedErrorResponseBody",
    "TrailerAssignmentsCreateDriverTrailerAssignmentResponseBody",
    "TrailerAssignmentsCreateDriverTrailerAssignmentServiceUnavailableErrorResponseBody",
    "TrailerAssignmentsCreateDriverTrailerAssignmentTooManyRequestsErrorResponseBody",
    "TrailerAssignmentsCreateDriverTrailerAssignmentUnauthorizedErrorResponseBody",
    "TrailerAssignmentsGetDriverTrailerAssignmentsBadGatewayErrorResponseBody",
    "TrailerAssignmentsGetDriverTrailerAssignmentsGatewayTimeoutErrorResponseBody",
    "TrailerAssignmentsGetDriverTrailerAssignmentsInternalServerErrorResponseBody",
    "TrailerAssignmentsGetDriverTrailerAssignmentsMethodNotAllowedErrorResponseBody",
    "TrailerAssignmentsGetDriverTrailerAssignmentsNotFoundErrorResponseBody",
    "TrailerAssignmentsGetDriverTrailerAssignmentsNotImplementedErrorResponseBody",
    "TrailerAssignmentsGetDriverTrailerAssignmentsResponseBody",
    "TrailerAssignmentsGetDriverTrailerAssignmentsServiceUnavailableErrorResponseBody",
    "TrailerAssignmentsGetDriverTrailerAssignmentsTooManyRequestsErrorResponseBody",
    "TrailerAssignmentsGetDriverTrailerAssignmentsUnauthorizedErrorResponseBody",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentBadGatewayErrorResponseBody",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentGatewayTimeoutErrorResponseBody",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentInternalServerErrorResponseBody",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentMethodNotAllowedErrorResponseBody",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentNotFoundErrorResponseBody",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentNotImplementedErrorResponseBody",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentResponseBody",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentServiceUnavailableErrorResponseBody",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentTooManyRequestsErrorResponseBody",
    "TrailerAssignmentsUpdateDriverTrailerAssignmentUnauthorizedErrorResponseBody",
    "TrailerDvirObjectResponseBody",
    "TrailerGoaGatewayTinyResponseResponseBody",
    "TrailerGoaGatewayTinyResponseResponseBodyModel",
    "TrailerObjectResponseBody",
    "TrailerResponseObjectResponseBody",
    "TrailerStatDecorationResponseBody",
    "TrailerStatGpsOdometerMetersTypeResponseBody",
    "TrailerStatGpsOdometerMetersWithDecorationsTypeResponseBody",
    "TrailerStatGpsTypeResponseBody",
    "TrailerStatGpsWithDecorationsTypeResponseBody",
    "TrailerStatReeferAlarmResponseBody",
    "TrailerStatReeferAlarmTypeResponseBody",
    "TrailerStatReeferAlarmWithDecorationsTypeResponseBody",
    "TrailerStatReeferAmbientAirTemperatureMilliCTypeResponseBody",
    "TrailerStatReeferAmbientAirTemperatureWithDecorationsTypeResponseBody",
    "TrailerStatReeferDoorStateZone1TypeResponseBody",
    "TrailerStatReeferDoorStateZone1TypeResponseBodyValue",
    "TrailerStatReeferDoorStateZone1WithDecorationsTypeResponseBody",
    "TrailerStatReeferDoorStateZone1WithDecorationsTypeResponseBodyValue",
    "TrailerStatReeferDoorStateZone2TypeResponseBody",
    "TrailerStatReeferDoorStateZone2TypeResponseBodyValue",
    "TrailerStatReeferDoorStateZone2WithDecorationsTypeResponseBody",
    "TrailerStatReeferDoorStateZone2WithDecorationsTypeResponseBodyValue",
    "TrailerStatReeferDoorStateZone3TypeResponseBody",
    "TrailerStatReeferDoorStateZone3TypeResponseBodyValue",
    "TrailerStatReeferDoorStateZone3WithDecorationsTypeResponseBody",
    "TrailerStatReeferDoorStateZone3WithDecorationsTypeResponseBodyValue",
    "TrailerStatReeferFuelPercentTypeResponseBody",
    "TrailerStatReeferFuelPercentWithDecorationsTypeResponseBody",
    "TrailerStatReeferObdEngineSecondsTypeResponseBody",
    "TrailerStatReeferObdEngineSecondsWithDecorationsTypeResponseBody",
    "TrailerStatReeferReturnAirTemperatureMilliCZone1TypeResponseBody",
    "TrailerStatReeferReturnAirTemperatureMilliCZone1WithDecorationsTypeResponseBody",
    "TrailerStatReeferReturnAirTemperatureMilliCZone2TypeResponseBody",
    "TrailerStatReeferReturnAirTemperatureMilliCZone2WithDecorationsTypeResponseBody",
    "TrailerStatReeferReturnAirTemperatureMilliCZone3TypeResponseBody",
    "TrailerStatReeferReturnAirTemperatureMilliCZone3WithDecorationsTypeResponseBody",
    "TrailerStatReeferRunModeTypeResponseBody",
    "TrailerStatReeferRunModeWithDecorationsTypeResponseBody",
    "TrailerStatReeferSetPointTemperatureMilliCZone1TypeResponseBody",
    "TrailerStatReeferSetPointTemperatureMilliCZone1WithDecorationsTypeResponseBody",
    "TrailerStatReeferSetPointTemperatureMilliCZone2TypeResponseBody",
    "TrailerStatReeferSetPointTemperatureMilliCZone2WithDecorationsTypeResponseBody",
    "TrailerStatReeferSetPointTemperatureMilliCZone3TypeResponseBody",
    "TrailerStatReeferSetPointTemperatureMilliCZone3WithDecorationsTypeResponseBody",
    "TrailerStatReeferStateTypeResponseBody",
    "TrailerStatReeferStateWithDecorationsTypeResponseBody",
    "TrailerStatReeferStateZone1TypeResponseBody",
    "TrailerStatReeferStateZone1WithDecorationsTypeResponseBody",
    "TrailerStatReeferStateZone2TypeResponseBody",
    "TrailerStatReeferStateZone2WithDecorationsTypeResponseBody",
    "TrailerStatReeferStateZone3TypeResponseBody",
    "TrailerStatReeferStateZone3WithDecorationsTypeResponseBody",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone1TypeResponseBody",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone1WithDecorationsTypeResponseBody",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone2TypeResponseBody",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone2WithDecorationsTypeResponseBody",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone3TypeResponseBody",
    "TrailerStatReeferSupplyAirTemperatureMilliCZone3WithDecorationsTypeResponseBody",
    "TrailerStatsGetTrailerStatsFeedBadGatewayErrorResponseBody",
    "TrailerStatsGetTrailerStatsFeedGatewayTimeoutErrorResponseBody",
    "TrailerStatsGetTrailerStatsFeedInternalServerErrorResponseBody",
    "TrailerStatsGetTrailerStatsFeedMethodNotAllowedErrorResponseBody",
    "TrailerStatsGetTrailerStatsFeedNotFoundErrorResponseBody",
    "TrailerStatsGetTrailerStatsFeedNotImplementedErrorResponseBody",
    "TrailerStatsGetTrailerStatsFeedResponseBody",
    "TrailerStatsGetTrailerStatsFeedServiceUnavailableErrorResponseBody",
    "TrailerStatsGetTrailerStatsFeedTooManyRequestsErrorResponseBody",
    "TrailerStatsGetTrailerStatsFeedUnauthorizedErrorResponseBody",
    "TrailerStatsGetTrailerStatsHistoryBadGatewayErrorResponseBody",
    "TrailerStatsGetTrailerStatsHistoryGatewayTimeoutErrorResponseBody",
    "TrailerStatsGetTrailerStatsHistoryInternalServerErrorResponseBody",
    "TrailerStatsGetTrailerStatsHistoryMethodNotAllowedErrorResponseBody",
    "TrailerStatsGetTrailerStatsHistoryNotFoundErrorResponseBody",
    "TrailerStatsGetTrailerStatsHistoryNotImplementedErrorResponseBody",
    "TrailerStatsGetTrailerStatsHistoryResponseBody",
    "TrailerStatsGetTrailerStatsHistoryServiceUnavailableErrorResponseBody",
    "TrailerStatsGetTrailerStatsHistoryTooManyRequestsErrorResponseBody",
    "TrailerStatsGetTrailerStatsHistoryUnauthorizedErrorResponseBody",
    "TrailerStatsGetTrailerStatsSnapshotBadGatewayErrorResponseBody",
    "TrailerStatsGetTrailerStatsSnapshotGatewayTimeoutErrorResponseBody",
    "TrailerStatsGetTrailerStatsSnapshotInternalServerErrorResponseBody",
    "TrailerStatsGetTrailerStatsSnapshotMethodNotAllowedErrorResponseBody",
    "TrailerStatsGetTrailerStatsSnapshotNotFoundErrorResponseBody",
    "TrailerStatsGetTrailerStatsSnapshotNotImplementedErrorResponseBody",
    "TrailerStatsGetTrailerStatsSnapshotResponseBody",
    "TrailerStatsGetTrailerStatsSnapshotServiceUnavailableErrorResponseBody",
    "TrailerStatsGetTrailerStatsSnapshotTooManyRequestsErrorResponseBody",
    "TrailerStatsGetTrailerStatsSnapshotUnauthorizedErrorResponseBody",
    "TrailerStatsObjectResponseBody",
    "TrailerStatsSnapshotObjectResponseBody",
    "TrailerTinyResponse",
    "TrailerWithAttributesResponseObjectResponseBody",
    "TrailersCreateTrailerBadGatewayErrorResponseBody",
    "TrailersCreateTrailerGatewayTimeoutErrorResponseBody",
    "TrailersCreateTrailerInternalServerErrorResponseBody",
    "TrailersCreateTrailerMethodNotAllowedErrorResponseBody",
    "TrailersCreateTrailerNotFoundErrorResponseBody",
    "TrailersCreateTrailerNotImplementedErrorResponseBody",
    "TrailersCreateTrailerResponseBody",
    "TrailersCreateTrailerServiceUnavailableErrorResponseBody",
    "TrailersCreateTrailerTooManyRequestsErrorResponseBody",
    "TrailersCreateTrailerUnauthorizedErrorResponseBody",
    "TrailersDeleteTrailerBadGatewayErrorResponseBody",
    "TrailersDeleteTrailerGatewayTimeoutErrorResponseBody",
    "TrailersDeleteTrailerInternalServerErrorResponseBody",
    "TrailersDeleteTrailerMethodNotAllowedErrorResponseBody",
    "TrailersDeleteTrailerNotFoundErrorResponseBody",
    "TrailersDeleteTrailerNotImplementedErrorResponseBody",
    "TrailersDeleteTrailerServiceUnavailableErrorResponseBody",
    "TrailersDeleteTrailerTooManyRequestsErrorResponseBody",
    "TrailersDeleteTrailerUnauthorizedErrorResponseBody",
    "TrailersGetTrailerBadGatewayErrorResponseBody",
    "TrailersGetTrailerGatewayTimeoutErrorResponseBody",
    "TrailersGetTrailerInternalServerErrorResponseBody",
    "TrailersGetTrailerMethodNotAllowedErrorResponseBody",
    "TrailersGetTrailerNotFoundErrorResponseBody",
    "TrailersGetTrailerNotImplementedErrorResponseBody",
    "TrailersGetTrailerResponseBody",
    "TrailersGetTrailerServiceUnavailableErrorResponseBody",
    "TrailersGetTrailerTooManyRequestsErrorResponseBody",
    "TrailersGetTrailerUnauthorizedErrorResponseBody",
    "TrailersListTrailersBadGatewayErrorResponseBody",
    "TrailersListTrailersGatewayTimeoutErrorResponseBody",
    "TrailersListTrailersInternalServerErrorResponseBody",
    "TrailersListTrailersMethodNotAllowedErrorResponseBody",
    "TrailersListTrailersNotFoundErrorResponseBody",
    "TrailersListTrailersNotImplementedErrorResponseBody",
    "TrailersListTrailersResponseBody",
    "TrailersListTrailersServiceUnavailableErrorResponseBody",
    "TrailersListTrailersTooManyRequestsErrorResponseBody",
    "TrailersListTrailersUnauthorizedErrorResponseBody",
    "TrailersUpdateTrailerBadGatewayErrorResponseBody",
    "TrailersUpdateTrailerGatewayTimeoutErrorResponseBody",
    "TrailersUpdateTrailerInternalServerErrorResponseBody",
    "TrailersUpdateTrailerMethodNotAllowedErrorResponseBody",
    "TrailersUpdateTrailerNotFoundErrorResponseBody",
    "TrailersUpdateTrailerNotImplementedErrorResponseBody",
    "TrailersUpdateTrailerResponseBody",
    "TrailersUpdateTrailerServiceUnavailableErrorResponseBody",
    "TrailersUpdateTrailerTooManyRequestsErrorResponseBody",
    "TrailersUpdateTrailerUnauthorizedErrorResponseBody",
    "TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectRequestBody",
    "TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectRequestBodyAssignmentGroupType",
    "TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectResponseBody",
    "TrainingAssignmentNearDueDateTriggerAssignmentGroupObjectResponseBodyAssignmentGroupType",
    "TrainingAssignmentNearDueDateTriggerDetailsObjectRequestBody",
    "TrainingAssignmentNearDueDateTriggerDetailsObjectRequestBodyConditionUnits",
    "TrainingAssignmentNearDueDateTriggerDetailsObjectResponseBody",
    "TrainingAssignmentNearDueDateTriggerDetailsObjectResponseBodyConditionUnits",
    "TrainingAssignmentPostResponseObjectResponseBody",
    "TrainingAssignmentResponseObjectResponseBody",
    "TrainingAssignmentResponseObjectResponseBodyStatus",
    "TrainingAssignmentsDeleteTrainingAssignmentsBadGatewayErrorResponseBody",
    "TrainingAssignmentsDeleteTrainingAssignmentsGatewayTimeoutErrorResponseBody",
    "TrainingAssignmentsDeleteTrainingAssignmentsInternalServerErrorResponseBody",
    "TrainingAssignmentsDeleteTrainingAssignmentsMethodNotAllowedErrorResponseBody",
    "TrainingAssignmentsDeleteTrainingAssignmentsNotFoundErrorResponseBody",
    "TrainingAssignmentsDeleteTrainingAssignmentsNotImplementedErrorResponseBody",
    "TrainingAssignmentsDeleteTrainingAssignmentsServiceUnavailableErrorResponseBody",
    "TrainingAssignmentsDeleteTrainingAssignmentsTooManyRequestsErrorResponseBody",
    "TrainingAssignmentsDeleteTrainingAssignmentsUnauthorizedErrorResponseBody",
    "TrainingAssignmentsGetTrainingAssignmentsStreamBadGatewayErrorResponseBody",
    "TrainingAssignmentsGetTrainingAssignmentsStreamGatewayTimeoutErrorResponseBody",
    "TrainingAssignmentsGetTrainingAssignmentsStreamInternalServerErrorResponseBody",
    "TrainingAssignmentsGetTrainingAssignmentsStreamMethodNotAllowedErrorResponseBody",
    "TrainingAssignmentsGetTrainingAssignmentsStreamNotFoundErrorResponseBody",
    "TrainingAssignmentsGetTrainingAssignmentsStreamNotImplementedErrorResponseBody",
    "TrainingAssignmentsGetTrainingAssignmentsStreamResponseBody",
    "TrainingAssignmentsGetTrainingAssignmentsStreamServiceUnavailableErrorResponseBody",
    "TrainingAssignmentsGetTrainingAssignmentsStreamTooManyRequestsErrorResponseBody",
    "TrainingAssignmentsGetTrainingAssignmentsStreamUnauthorizedErrorResponseBody",
    "TrainingAssignmentsPatchTrainingAssignmentsBadGatewayErrorResponseBody",
    "TrainingAssignmentsPatchTrainingAssignmentsGatewayTimeoutErrorResponseBody",
    "TrainingAssignmentsPatchTrainingAssignmentsInternalServerErrorResponseBody",
    "TrainingAssignmentsPatchTrainingAssignmentsMethodNotAllowedErrorResponseBody",
    "TrainingAssignmentsPatchTrainingAssignmentsNotFoundErrorResponseBody",
    "TrainingAssignmentsPatchTrainingAssignmentsNotImplementedErrorResponseBody",
    "TrainingAssignmentsPatchTrainingAssignmentsResponseBody",
    "TrainingAssignmentsPatchTrainingAssignmentsServiceUnavailableErrorResponseBody",
    "TrainingAssignmentsPatchTrainingAssignmentsTooManyRequestsErrorResponseBody",
    "TrainingAssignmentsPatchTrainingAssignmentsUnauthorizedErrorResponseBody",
    "TrainingAssignmentsPostTrainingAssignmentsBadGatewayErrorResponseBody",
    "TrainingAssignmentsPostTrainingAssignmentsGatewayTimeoutErrorResponseBody",
    "TrainingAssignmentsPostTrainingAssignmentsInternalServerErrorResponseBody",
    "TrainingAssignmentsPostTrainingAssignmentsMethodNotAllowedErrorResponseBody",
    "TrainingAssignmentsPostTrainingAssignmentsNotFoundErrorResponseBody",
    "TrainingAssignmentsPostTrainingAssignmentsNotImplementedErrorResponseBody",
    "TrainingAssignmentsPostTrainingAssignmentsResponseBody",
    "TrainingAssignmentsPostTrainingAssignmentsServiceUnavailableErrorResponseBody",
    "TrainingAssignmentsPostTrainingAssignmentsTooManyRequestsErrorResponseBody",
    "TrainingAssignmentsPostTrainingAssignmentsUnauthorizedErrorResponseBody",
    "TrainingCategoryObjectResponseBody",
    "TrainingCourseLabelObjectResponseBody",
    "TrainingCourseObjectResponseBody",
    "TrainingCourseResponseObjectResponseBody",
    "TrainingCourseResponseObjectResponseBodyStatus",
    "TrainingCoursesGetTrainingCoursesBadGatewayErrorResponseBody",
    "TrainingCoursesGetTrainingCoursesGatewayTimeoutErrorResponseBody",
    "TrainingCoursesGetTrainingCoursesInternalServerErrorResponseBody",
    "TrainingCoursesGetTrainingCoursesMethodNotAllowedErrorResponseBody",
    "TrainingCoursesGetTrainingCoursesNotFoundErrorResponseBody",
    "TrainingCoursesGetTrainingCoursesNotImplementedErrorResponseBody",
    "TrainingCoursesGetTrainingCoursesResponseBody",
    "TrainingCoursesGetTrainingCoursesServiceUnavailableErrorResponseBody",
    "TrainingCoursesGetTrainingCoursesTooManyRequestsErrorResponseBody",
    "TrainingCoursesGetTrainingCoursesUnauthorizedErrorResponseBody",
    "TrainingLearnerObjectResponseBody",
    "TrainingLearnerObjectResponseBodyType",
    "TriggerParamsObjectRequestBody",
    "TriggerParamsObjectResponseBody",
    "TripAssetResponseBody",
    "TripAssetResponseBodyType",
    "TripResponseBody",
    "TripResponseBodyCompletionStatus",
    "TripSpeedingIntervalsResponseBody",
    "TripsBreakdownResponseBody",
    "TripsGetTripsBadGatewayErrorResponseBody",
    "TripsGetTripsGatewayTimeoutErrorResponseBody",
    "TripsGetTripsInternalServerErrorResponseBody",
    "TripsGetTripsMethodNotAllowedErrorResponseBody",
    "TripsGetTripsNotFoundErrorResponseBody",
    "TripsGetTripsNotImplementedErrorResponseBody",
    "TripsGetTripsResponseBody",
    "TripsGetTripsServiceUnavailableErrorResponseBody",
    "TripsGetTripsTooManyRequestsErrorResponseBody",
    "TripsGetTripsUnauthorizedErrorResponseBody",
    "UnassignedDrivingDataResponseBody",
    "UnassignedDrivingTriggerDetailsObjectRequestBody",
    "UnassignedDrivingTriggerDetailsObjectResponseBody",
    "UnauthorizedError",
    "UpdateAddressRequestAddressTypesItem",
    "UpdateAddressRequestGeofence",
    "UpdateAttributeRequestAttributeType",
    "UpdateAttributeRequestEntityType",
    "UpdateDriverRequestAttributes",
    "UpdateDriverRequestDriverActivationStatus",
    "UpdateDriverRequestHosSetting",
    "UpdateDriverRequestLocale",
    "UpdateEngineImmobilizerRelayStateRequestBodyRequestBody",
    "UpdateEngineImmobilizerRelayStateRequestBodyRequestBodyId",
    "UpdateHubLocationRequestBodyRequestBody",
    "UpdateRoutesStopRequestObjectRequestBody",
    "UpdateUserRequestAuthType",
    "UpdateVehicleRequestAuxInputType1",
    "UpdateVehicleRequestAuxInputType10",
    "UpdateVehicleRequestAuxInputType11",
    "UpdateVehicleRequestAuxInputType12",
    "UpdateVehicleRequestAuxInputType13",
    "UpdateVehicleRequestAuxInputType2",
    "UpdateVehicleRequestAuxInputType3",
    "UpdateVehicleRequestAuxInputType4",
    "UpdateVehicleRequestAuxInputType5",
    "UpdateVehicleRequestAuxInputType6",
    "UpdateVehicleRequestAuxInputType7",
    "UpdateVehicleRequestAuxInputType8",
    "UpdateVehicleRequestAuxInputType9",
    "UpdateVehicleRequestHarshAccelerationSettingType",
    "UploadedMediaObjectResponseBody",
    "UploadedMediaObjectResponseBodyCameraRole",
    "UploadedMediaObjectResponseBodyInput",
    "UploadedMediaObjectResponseBodyMediaType",
    "UploadedMediaObjectResponseBodyTriggerReason",
    "UrlInfoObjectResponseBody",
    "UsDriverRulesetOverride",
    "UsDriverRulesetOverrideCycle",
    "UsDriverRulesetOverrideRestart",
    "UsDriverRulesetOverrideRestbreak",
    "UsDriverRulesetOverrideUsStateToOverride",
    "User",
    "UserAuthType",
    "UserEmail",
    "UserExpireAt",
    "UserId",
    "UserIdentifierSerial",
    "UserName",
    "UserResponse",
    "UserRole",
    "UserRoleAssignment",
    "UserRoles",
    "UserTinyResponse",
    "V1Asset",
    "V1AssetCable",
    "V1AssetCurrentLocation",
    "V1AssetCurrentLocationsResponse",
    "V1AssetLocationResponse",
    "V1AssetLocationResponseItem",
    "V1AssetReeferResponse",
    "V1AssetReeferResponseReeferStats",
    "V1AssetReeferResponseReeferStatsAlarms",
    "V1AssetReeferResponseReeferStatsAlarms1",
    "V1AssetReeferResponseReeferStatsEngineHours",
    "V1AssetReeferResponseReeferStatsFuelPercentage",
    "V1AssetReeferResponseReeferStatsPowerStatus",
    "V1AssetReeferResponseReeferStatsReturnAirTemp",
    "V1AssetReeferResponseReeferStatsSetPoint",
    "V1AssetsReefer",
    "V1AssetsReeferReeferStats",
    "V1AssetsReeferReeferStatsAmbientAirTemperature",
    "V1AssetsReeferReeferStatsDischargeAirTemperature",
    "V1AssetsReeferReeferStatsPowerStatus",
    "V1AssetsReeferReeferStatsPowerStatusStatus",
    "V1CargoResponse",
    "V1CargoResponseSensors",
    "V1DoorResponse",
    "V1DoorResponseSensors",
    "V1DriverSafetyScoreResponse",
    "V1HosAuthenticationLogsResponse",
    "V1HosAuthenticationLogsResponseAuthenticationLogs",
    "V1HumidityResponse",
    "V1HumidityResponseSensors",
    "V1Machine",
    "V1MachineHistoryResponse",
    "V1MachineHistoryResponseMachines",
    "V1MachineHistoryResponseVibrations",
    "V1Message",
    "V1MessageResponse",
    "V1MessageSender",
    "V1Messages",
    "V1MessagesResponse",
    "V1Pagination",
    "V1ProgramsForTheCameraResponse",
    "V1ProgramsForTheCameraResponseItem",
    "V1SafetyReportHarshEvent",
    "V1Sensor",
    "V1SensorHistoryResponse",
    "V1SensorHistoryResponseResults",
    "V1SensorsHistorySeries",
    "V1SensorsHistorySeriesField",
    "V1TemperatureResponse",
    "V1TemperatureResponseSensors",
    "V1TrailerAssignmentResponse",
    "V1TrailerAssignmentsResponse",
    "V1TrailerAssignmentsResponseAllOf",
    "V1TrailerBase",
    "V1TripResponse",
    "V1TripResponseEndAddress",
    "V1TripResponseEndCoordinates",
    "V1TripResponseStartAddress",
    "V1TripResponseStartCoordinates",
    "V1TripResponseTrips",
    "V1VehicleHarshEventResponse",
    "V1VehicleHarshEventResponseLocation",
    "V1VehicleMaintenance",
    "V1VehicleMaintenanceJ1939",
    "V1VehicleMaintenanceJ1939CheckEngineLight",
    "V1VehicleMaintenanceJ1939DiagnosticTroubleCodes",
    "V1VehicleMaintenancePassenger",
    "V1VehicleMaintenancePassengerCheckEngineLight",
    "V1VehicleMaintenancePassengerDiagnosticTroubleCodes",
    "V1VehicleSafetyScoreResponse",
    "V1VisionCamerasResponse",
    "V1VisionCamerasResponseItem",
    "V1VisionRunByCameraResponse",
    "V1VisionRunByCameraResponseInspectionResults",
    "V1VisionRunByCameraResponseProgram",
    "V1VisionRunByCameraResponseRunSummary",
    "V1VisionRunsByCameraAndProgramResponse",
    "V1VisionRunsByCameraResponse",
    "V1VisionRunsByCameraResponseItem",
    "V1VisionRunsByCameraResponseItemProgram",
    "V1VisionRunsByCameraResponseItemReportMetadata",
    "V1VisionRunsResponse",
    "V1VisionRunsResponseReportMetadata",
    "V1VisionRunsResponseVisionRuns",
    "V1VisionStepResults",
    "V1VisionStepResultsItem",
    "V1VisionStepResultsItemAngleCheck",
    "V1VisionStepResultsItemAngleCheckAngleConfigured",
    "V1VisionStepResultsItemBarcodeItem",
    "V1VisionStepResultsItemBooleanLogic",
    "V1VisionStepResultsItemBooleanLogicStepsItem",
    "V1VisionStepResultsItemCaliper",
    "V1VisionStepResultsItemCaliperAngleRange",
    "V1VisionStepResultsItemCaliperContrastRange",
    "V1VisionStepResultsItemCaliperFilterPolarity",
    "V1VisionStepResultsItemCaliperSharpnessRange",
    "V1VisionStepResultsItemCaliperStraightnessRange",
    "V1VisionStepResultsItemContour",
    "V1VisionStepResultsItemDistance",
    "V1VisionStepResultsItemExpirationDate",
    "V1VisionStepResultsItemFindCopies",
    "V1VisionStepResultsItemFindEdge",
    "V1VisionStepResultsItemFindEdgeAngleRange",
    "V1VisionStepResultsItemFindEdgeContrastRange",
    "V1VisionStepResultsItemFindEdgeSharpnessRange",
    "V1VisionStepResultsItemFindEdgeStraightnessRange",
    "V1VisionStepResultsItemFindShapes",
    "V1VisionStepResultsItemFixture",
    "V1VisionStepResultsItemFixtureCoordinates",
    "V1VisionStepResultsItemLabelMatch",
    "V1VisionStepResultsItemPresenceAbsence",
    "V1VisionStepResultsItemPresenceAbsenceBlueRange",
    "V1VisionStepResultsItemPresenceAbsenceGrayscaleRange",
    "V1VisionStepResultsItemPresenceAbsenceGreenRange",
    "V1VisionStepResultsItemPresenceAbsenceHueRange",
    "V1VisionStepResultsItemPresenceAbsenceRedRange",
    "V1VisionStepResultsItemPresenceAbsenceSaturationRange",
    "V1VisionStepResultsItemPresenceAbsenceValueRange",
    "V1VisionStepResultsItemTextMatch",
    "Vehicle",
    "VehicleAssignmentObjectResponseBody",
    "VehicleAssignmentObjectResponseBodyAssignmentType",
    "VehicleAuxInputName",
    "VehicleAuxInputType",
    "VehicleBatterVoltageDetailsObjectRequestBody",
    "VehicleBatterVoltageDetailsObjectRequestBodyOperation",
    "VehicleBatterVoltageDetailsObjectResponseBody",
    "VehicleBatterVoltageDetailsObjectResponseBodyOperation",
    "VehicleBatteryVoltageResponseBody",
    "VehicleDefLevelPercentageResponseBody",
    "VehicleDetectedResponseBody",
    "VehicleDvirObjectResponseBody",
    "VehicleEsn",
    "VehicleExternalIds",
    "VehicleFaultCodeDetailsObjectRequestBody",
    "VehicleFaultCodeDetailsObjectResponseBody",
    "VehicleFaultsResponseBody",
    "VehicleHarshAccelerationSettingType",
    "VehicleId",
    "VehicleLicensePlate",
    "VehicleLocation",
    "VehicleLocationAddress",
    "VehicleLocationHeading",
    "VehicleLocationIsEcuSpeed",
    "VehicleLocationLatitude",
    "VehicleLocationLongitude",
    "VehicleLocationSpeed",
    "VehicleLocationsListResponse",
    "VehicleLocationsListResponseData",
    "VehicleLocationsResponse",
    "VehicleLocationsResponseData",
    "VehicleMake",
    "VehicleModel",
    "VehicleName",
    "VehicleNotes",
    "VehicleRegulationMode",
    "VehicleResponse",
    "VehicleResponseObjectResponseBody",
    "VehicleResponseObjectResponseBodyVehicleRegulationMode",
    "VehicleResponseObjectResponseBodyVehicleType",
    "VehicleResponseResponseBody",
    "VehicleResponseResponseBodyAssetType",
    "VehicleSafetyScoreResponseBody",
    "VehicleSensorConfiguration",
    "VehicleSensorConfigurationArea",
    "VehicleSensorConfigurationAreaPosition",
    "VehicleSensorConfigurationAreaResponseBody",
    "VehicleSensorConfigurationAreaResponseBodyPosition",
    "VehicleSensorConfigurationDoor",
    "VehicleSensorConfigurationDoorPosition",
    "VehicleSensorConfigurationDoorResponseBody",
    "VehicleSensorConfigurationDoorResponseBodyPosition",
    "VehicleSensorConfigurationResponseBody",
    "VehicleStatsAmbientAirTempMilliC",
    "VehicleStatsAmbientAirTempMilliCValue",
    "VehicleStatsAmbientAirTempMilliCWithDecoration",
    "VehicleStatsAuxInput",
    "VehicleStatsAuxInputDecoration",
    "VehicleStatsAuxInputTime",
    "VehicleStatsAuxInputValue",
    "VehicleStatsAuxInputWithDecoration",
    "VehicleStatsBarometricPressurePa",
    "VehicleStatsBarometricPressurePaValue",
    "VehicleStatsBarometricPressurePaWithDecoration",
    "VehicleStatsBatteryMilliVoltsValue",
    "VehicleStatsBatteryVoltage",
    "VehicleStatsBatteryVoltageWithDecoration",
    "VehicleStatsDecorations",
    "VehicleStatsDecorationsAmbientAirTemperatureMilliC",
    "VehicleStatsDecorationsBarometricPressurePa",
    "VehicleStatsDecorationsBatteryMilliVolts",
    "VehicleStatsDecorationsDefLevelMilliPercent",
    "VehicleStatsDecorationsEcuSpeedMph",
    "VehicleStatsDecorationsEngineCoolantTemperatureMilliC",
    "VehicleStatsDecorationsEngineLoadPercent",
    "VehicleStatsDecorationsEngineOilPressureKPa",
    "VehicleStatsDecorationsEngineRpm",
    "VehicleStatsDecorationsEngineStates",
    "VehicleStatsDecorationsEngineStatesValue",
    "VehicleStatsDecorationsFuelConsumedMilliliters",
    "VehicleStatsDecorationsFuelPercents",
    "VehicleStatsDecorationsGps",
    "VehicleStatsDecorationsGpsDistanceMeters",
    "VehicleStatsDecorationsGpsOdometerMeters",
    "VehicleStatsDecorationsIdlingDurationMilliseconds",
    "VehicleStatsDecorationsIntakeManifoldTemperatureMilliC",
    "VehicleStatsDecorationsObdEngineSeconds",
    "VehicleStatsDecorationsObdOdometerMeters",
    "VehicleStatsDefLevelMilliPercent",
    "VehicleStatsDefLevelMilliPercentValue",
    "VehicleStatsDefLevelMilliPercentWithDecoration",
    "VehicleStatsEcuDoorStatus",
    "VehicleStatsEcuDoorStatusValue",
    "VehicleStatsEcuSpeedMph",
    "VehicleStatsEcuSpeedMphValue",
    "VehicleStatsEcuSpeedMphWithDecoration",
    "VehicleStatsEngineCoolantTempMilliC",
    "VehicleStatsEngineCoolantTempMilliCValue",
    "VehicleStatsEngineCoolantTempMilliCWithDecoration",
    "VehicleStatsEngineImmobilizer",
    "VehicleStatsEngineImmobilizerState",
    "VehicleStatsEngineImmobilizerWithDecoration",
    "VehicleStatsEngineImmobilizerWithDecorationState",
    "VehicleStatsEngineLoadPercent",
    "VehicleStatsEngineLoadPercentValue",
    "VehicleStatsEngineLoadPercentWithDecoration",
    "VehicleStatsEngineOilPressureKPa",
    "VehicleStatsEngineOilPressureKPaValue",
    "VehicleStatsEngineOilPressureKPaWithDecoration",
    "VehicleStatsEngineRpm",
    "VehicleStatsEngineRpmValue",
    "VehicleStatsEngineRpmWithDecoration",
    "VehicleStatsEngineState",
    "VehicleStatsEngineStateSetting",
    "VehicleStatsEngineStateWithDecoration",
    "VehicleStatsEvAverageBatteryTemperatureMilliCelsius",
    "VehicleStatsEvBatteryCurrentMilliAmp",
    "VehicleStatsEvBatteryStateOfHealthMilliPercent",
    "VehicleStatsEvBatteryVoltageMilliVolt",
    "VehicleStatsEvChargingCurrentMilliAmp",
    "VehicleStatsEvChargingEnergyMicroWh",
    "VehicleStatsEvChargingStatus",
    "VehicleStatsEvChargingVoltageMilliVolt",
    "VehicleStatsEvConsumedEnergyMicroWh",
    "VehicleStatsEvDistanceDrivenMeters",
    "VehicleStatsEvRegeneratedEnergyMicroWh",
    "VehicleStatsEvStateOfChargeMilliPercent",
    "VehicleStatsFaultCodes",
    "VehicleStatsFaultCodesCanBusType",
    "VehicleStatsFaultCodesIgnitionType",
    "VehicleStatsFaultCodesJ1939",
    "VehicleStatsFaultCodesJ1939Lights",
    "VehicleStatsFaultCodesJ1939TroubleCode",
    "VehicleStatsFaultCodesJ1939TroubleCodes",
    "VehicleStatsFaultCodesObdii",
    "VehicleStatsFaultCodesObdiiTroubleCode",
    "VehicleStatsFaultCodesOem",
    "VehicleStatsFaultCodesOemTroubleCode",
    "VehicleStatsFaultCodesOemTroubleCodes",
    "VehicleStatsFaultCodesPassengerDtc",
    "VehicleStatsFaultCodesPassengerMonitorStatus",
    "VehicleStatsFaultCodesPassengerMonitorStatusValue",
    "VehicleStatsFaultCodesTxId",
    "VehicleStatsFaultCodesValue",
    "VehicleStatsFaultCodesValueJ1939",
    "VehicleStatsFaultCodesValueJ1939CheckEngineLights",
    "VehicleStatsFaultCodesValueJ1939DiagnosticTroubleCodes",
    "VehicleStatsFaultCodesValueJ1939VendorSpecificFields",
    "VehicleStatsFaultCodesValueObdii",
    "VehicleStatsFaultCodesValueObdiiConfirmedDtcs",
    "VehicleStatsFaultCodesValueObdiiDiagnosticTroubleCodes",
    "VehicleStatsFaultCodesValueObdiiDiagnosticTroubleCodesIgnitionType",
    "VehicleStatsFaultCodesValueObdiiMonitorStatus",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusCatalyst",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusComprehensive",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusEgr",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusEvapSystem",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusFuel",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusHeatedCatalyst",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusHeatedO2Sensor",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusIsoSaeReserved",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusMisfire",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusO2Sensor",
    "VehicleStatsFaultCodesValueObdiiMonitorStatusSecondaryAir",
    "VehicleStatsFaultCodesValueOem",
    "VehicleStatsFaultCodesValueOemDiagnosticTroubleCodes",
    "VehicleStatsFaultCodesVendorSpecificFields",
    "VehicleStatsFaultCodesWithDecoration",
    "VehicleStatsFuelConsumedMilliliters",
    "VehicleStatsFuelConsumedMillilitersValue",
    "VehicleStatsFuelConsumedMillilitersWithDecoration",
    "VehicleStatsFuelPercent",
    "VehicleStatsFuelPercentValue",
    "VehicleStatsFuelPercentWithDecoration",
    "VehicleStatsGps",
    "VehicleStatsGpsDistanceMeters",
    "VehicleStatsGpsDistanceMetersValue",
    "VehicleStatsGpsDistanceMetersWithDecoration",
    "VehicleStatsGpsOdometerMeters",
    "VehicleStatsGpsOdometerMetersValue",
    "VehicleStatsGpsOdometerMetersWithDecoration",
    "VehicleStatsIdlingDurationMilliseconds",
    "VehicleStatsIdlingDurationMillisecondsValue",
    "VehicleStatsIdlingDurationMillisecondsWithDecoration",
    "VehicleStatsIntakeManifoldTempMilliC",
    "VehicleStatsIntakeManifoldTempMilliCValue",
    "VehicleStatsIntakeManifoldTempMilliCWithDecoration",
    "VehicleStatsListGps",
    "VehicleStatsListResponse",
    "VehicleStatsListResponseData",
    "VehicleStatsListSyntheticEngineSeconds",
    "VehicleStatsNfcCardScan",
    "VehicleStatsNfcCardScanCard",
    "VehicleStatsNfcCardScanWithDecoration",
    "VehicleStatsObdEngineSeconds",
    "VehicleStatsObdEngineSecondsValue",
    "VehicleStatsObdEngineSecondsWithDecoration",
    "VehicleStatsObdOdometerMeters",
    "VehicleStatsObdOdometerMetersValue",
    "VehicleStatsObdOdometerMetersWithDecoration",
    "VehicleStatsResponse",
    "VehicleStatsResponseData",
    "VehicleStatsResponseEcuDoorStatus",
    "VehicleStatsResponseEcuDoorStatusValue",
    "VehicleStatsResponseEvAverageBatteryTemperatureMilliCelsius",
    "VehicleStatsResponseEvBatteryCurrentMilliAmp",
    "VehicleStatsResponseEvBatteryStateOfHealthMilliPercent",
    "VehicleStatsResponseEvBatteryVoltageMilliVolt",
    "VehicleStatsResponseEvChargingCurrentMilliAmp",
    "VehicleStatsResponseEvChargingEnergyMicroWh",
    "VehicleStatsResponseEvChargingStatus",
    "VehicleStatsResponseEvChargingVoltageMilliVolt",
    "VehicleStatsResponseEvConsumedEnergyMicroWh",
    "VehicleStatsResponseEvDistanceDrivenMeters",
    "VehicleStatsResponseEvRegeneratedEnergyMicroWh",
    "VehicleStatsResponseEvStateOfChargeMilliPercent",
    "VehicleStatsResponseSeatbeltDriver",
    "VehicleStatsResponseSeatbeltDriverValue",
    "VehicleStatsResponseSpreaderActive",
    "VehicleStatsResponseSpreaderActiveValue",
    "VehicleStatsResponseSpreaderAirTemp",
    "VehicleStatsResponseSpreaderBlastState",
    "VehicleStatsResponseSpreaderBlastStateValue",
    "VehicleStatsResponseSpreaderGranularName",
    "VehicleStatsResponseSpreaderGranularRate",
    "VehicleStatsResponseSpreaderLiquidName",
    "VehicleStatsResponseSpreaderLiquidRate",
    "VehicleStatsResponseSpreaderOnState",
    "VehicleStatsResponseSpreaderOnStateValue",
    "VehicleStatsResponseSpreaderPlowStatus",
    "VehicleStatsResponseSpreaderPlowStatusValue",
    "VehicleStatsResponseSpreaderPrewetName",
    "VehicleStatsResponseSpreaderPrewetRate",
    "VehicleStatsResponseSpreaderRoadTemp",
    "VehicleStatsSeatbeltDriver",
    "VehicleStatsSeatbeltDriverValue",
    "VehicleStatsSpreaderActive",
    "VehicleStatsSpreaderActiveValue",
    "VehicleStatsSpreaderAirTemp",
    "VehicleStatsSpreaderBlastState",
    "VehicleStatsSpreaderBlastStateValue",
    "VehicleStatsSpreaderGranularName",
    "VehicleStatsSpreaderGranularRate",
    "VehicleStatsSpreaderLiquidName",
    "VehicleStatsSpreaderLiquidRate",
    "VehicleStatsSpreaderOnState",
    "VehicleStatsSpreaderOnStateValue",
    "VehicleStatsSpreaderPlowStatus",
    "VehicleStatsSpreaderPlowStatusValue",
    "VehicleStatsSpreaderPrewetName",
    "VehicleStatsSpreaderPrewetRate",
    "VehicleStatsSpreaderRoadTemp",
    "VehicleStatsSyntheticEngineSeconds",
    "VehicleStatsSyntheticEngineSecondsValue",
    "VehicleStatsTirePressures",
    "VehicleSummary",
    "VehicleTags",
    "VehicleTinyResponse",
    "VehicleType",
    "VehicleVin",
    "VehicleWithGatewayTinyResponseResponseBody",
    "VehicleWithGatewayTinyResponseResponseBodyAssetType",
    "VehicleYear",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsBadGatewayErrorResponseBody",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsGatewayTimeoutErrorResponseBody",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsInternalServerErrorResponseBody",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsMethodNotAllowedErrorResponseBody",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsNotFoundErrorResponseBody",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsNotImplementedErrorResponseBody",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsResponseBody",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsServiceUnavailableErrorResponseBody",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsTooManyRequestsErrorResponseBody",
    "VehiclesDriverAssignmentsGetVehiclesDriverAssignmentsUnauthorizedErrorResponseBody",
    "VehiclesDriverAssignmentsObjectResponseBody",
    "VehiclesListVehiclesBadGatewayErrorResponseBody",
    "VehiclesListVehiclesGatewayTimeoutErrorResponseBody",
    "VehiclesListVehiclesInternalServerErrorResponseBody",
    "VehiclesListVehiclesMethodNotAllowedErrorResponseBody",
    "VehiclesListVehiclesNotFoundErrorResponseBody",
    "VehiclesListVehiclesNotImplementedErrorResponseBody",
    "VehiclesListVehiclesResponseBody",
    "VehiclesListVehiclesServiceUnavailableErrorResponseBody",
    "VehiclesListVehiclesTooManyRequestsErrorResponseBody",
    "VehiclesListVehiclesUnauthorizedErrorResponseBody",
    "VehiclesLockLockVehicleBadGatewayErrorResponseBody",
    "VehiclesLockLockVehicleGatewayTimeoutErrorResponseBody",
    "VehiclesLockLockVehicleInternalServerErrorResponseBody",
    "VehiclesLockLockVehicleMethodNotAllowedErrorResponseBody",
    "VehiclesLockLockVehicleNotFoundErrorResponseBody",
    "VehiclesLockLockVehicleNotImplementedErrorResponseBody",
    "VehiclesLockLockVehicleServiceUnavailableErrorResponseBody",
    "VehiclesLockLockVehicleTooManyRequestsErrorResponseBody",
    "VehiclesLockLockVehicleUnauthorizedErrorResponseBody",
    "VehiclesLockUnlockVehicleBadGatewayErrorResponseBody",
    "VehiclesLockUnlockVehicleGatewayTimeoutErrorResponseBody",
    "VehiclesLockUnlockVehicleInternalServerErrorResponseBody",
    "VehiclesLockUnlockVehicleMethodNotAllowedErrorResponseBody",
    "VehiclesLockUnlockVehicleNotFoundErrorResponseBody",
    "VehiclesLockUnlockVehicleNotImplementedErrorResponseBody",
    "VehiclesLockUnlockVehicleServiceUnavailableErrorResponseBody",
    "VehiclesLockUnlockVehicleTooManyRequestsErrorResponseBody",
    "VehiclesLockUnlockVehicleUnauthorizedErrorResponseBody",
    "VendorCategoryObjectResponseBody",
    "VendorObjectResponseBody",
    "VertexRequestBody",
    "VertexResponseBody",
    "VoiceCoachingSettingsObjectResponseBody",
    "VoiceCoachingSettingsObjectResponseBodyEventsToCoachItem",
    "VoiceCoachingSettingsObjectResponseBodyLanguage",
    "WalkaroundPhotoObjectResponseBody",
    "WebhookParamsObjectRequestBody",
    "WebhookParamsObjectRequestBodyPayloadType",
    "WebhookParamsObjectResponseBody",
    "WebhookParamsObjectResponseBodyPayloadType",
    "WebhookResponseResponseBody",
    "WebhookResponseResponseBodyEventTypesItem",
    "WebhookResponseResponseBodyVersion",
    "WebhookRouteResponseObjectResponseBody",
    "WebhooksDeleteWebhookBadGatewayErrorResponseBody",
    "WebhooksDeleteWebhookGatewayTimeoutErrorResponseBody",
    "WebhooksDeleteWebhookInternalServerErrorResponseBody",
    "WebhooksDeleteWebhookMethodNotAllowedErrorResponseBody",
    "WebhooksDeleteWebhookNotFoundErrorResponseBody",
    "WebhooksDeleteWebhookNotImplementedErrorResponseBody",
    "WebhooksDeleteWebhookServiceUnavailableErrorResponseBody",
    "WebhooksDeleteWebhookTooManyRequestsErrorResponseBody",
    "WebhooksDeleteWebhookUnauthorizedErrorResponseBody",
    "WebhooksGetWebhookBadGatewayErrorResponseBody",
    "WebhooksGetWebhookGatewayTimeoutErrorResponseBody",
    "WebhooksGetWebhookInternalServerErrorResponseBody",
    "WebhooksGetWebhookMethodNotAllowedErrorResponseBody",
    "WebhooksGetWebhookNotFoundErrorResponseBody",
    "WebhooksGetWebhookNotImplementedErrorResponseBody",
    "WebhooksGetWebhookResponseBody",
    "WebhooksGetWebhookResponseBodyEventTypesItem",
    "WebhooksGetWebhookResponseBodyVersion",
    "WebhooksGetWebhookServiceUnavailableErrorResponseBody",
    "WebhooksGetWebhookTooManyRequestsErrorResponseBody",
    "WebhooksGetWebhookUnauthorizedErrorResponseBody",
    "WebhooksListWebhooksBadGatewayErrorResponseBody",
    "WebhooksListWebhooksGatewayTimeoutErrorResponseBody",
    "WebhooksListWebhooksInternalServerErrorResponseBody",
    "WebhooksListWebhooksMethodNotAllowedErrorResponseBody",
    "WebhooksListWebhooksNotFoundErrorResponseBody",
    "WebhooksListWebhooksNotImplementedErrorResponseBody",
    "WebhooksListWebhooksResponseBody",
    "WebhooksListWebhooksServiceUnavailableErrorResponseBody",
    "WebhooksListWebhooksTooManyRequestsErrorResponseBody",
    "WebhooksListWebhooksUnauthorizedErrorResponseBody",
    "WebhooksPatchWebhookBadGatewayErrorResponseBody",
    "WebhooksPatchWebhookGatewayTimeoutErrorResponseBody",
    "WebhooksPatchWebhookInternalServerErrorResponseBody",
    "WebhooksPatchWebhookMethodNotAllowedErrorResponseBody",
    "WebhooksPatchWebhookNotFoundErrorResponseBody",
    "WebhooksPatchWebhookNotImplementedErrorResponseBody",
    "WebhooksPatchWebhookRequestBodyVersion",
    "WebhooksPatchWebhookResponseBody",
    "WebhooksPatchWebhookResponseBodyEventTypesItem",
    "WebhooksPatchWebhookResponseBodyVersion",
    "WebhooksPatchWebhookServiceUnavailableErrorResponseBody",
    "WebhooksPatchWebhookTooManyRequestsErrorResponseBody",
    "WebhooksPatchWebhookUnauthorizedErrorResponseBody",
    "WebhooksPostWebhooksBadGatewayErrorResponseBody",
    "WebhooksPostWebhooksGatewayTimeoutErrorResponseBody",
    "WebhooksPostWebhooksInternalServerErrorResponseBody",
    "WebhooksPostWebhooksMethodNotAllowedErrorResponseBody",
    "WebhooksPostWebhooksNotFoundErrorResponseBody",
    "WebhooksPostWebhooksNotImplementedErrorResponseBody",
    "WebhooksPostWebhooksRequestBodyEventTypesItem",
    "WebhooksPostWebhooksRequestBodyVersion",
    "WebhooksPostWebhooksResponseBody",
    "WebhooksPostWebhooksResponseBodyEventTypesItem",
    "WebhooksPostWebhooksResponseBodyVersion",
    "WebhooksPostWebhooksServiceUnavailableErrorResponseBody",
    "WebhooksPostWebhooksTooManyRequestsErrorResponseBody",
    "WebhooksPostWebhooksUnauthorizedErrorResponseBody",
    "WorkOrderAttachmentObjectResponseBody",
    "WorkOrderAttachmentObjectResponseBodyProcessingStatus",
    "WorkOrderDiscountObjectRequestBody",
    "WorkOrderDiscountObjectResponseBody",
    "WorkOrderItemObjectRequestBody",
    "WorkOrderItemObjectRequestBodyType",
    "WorkOrderItemObjectResponseBody",
    "WorkOrderItemObjectResponseBodyType",
    "WorkOrderMoneyObjectRequestBody",
    "WorkOrderMoneyObjectRequestBodyCurrency",
    "WorkOrderMoneyObjectResponseBody",
    "WorkOrderMoneyObjectResponseBodyCurrency",
    "WorkOrderObjectResponseBody",
    "WorkOrderObjectResponseBodyPriority",
    "WorkOrderObjectResponseBodyStatus",
    "WorkOrderTaxCreateObjectRequestBody",
    "WorkOrderTaxObjectRequestBody",
    "WorkOrderTaxObjectResponseBody",
    "WorkOrderUnallocatedLaborObjectResponseBody",
    "WorkOrdersDeleteWorkOrdersBadGatewayErrorResponseBody",
    "WorkOrdersDeleteWorkOrdersGatewayTimeoutErrorResponseBody",
    "WorkOrdersDeleteWorkOrdersInternalServerErrorResponseBody",
    "WorkOrdersDeleteWorkOrdersMethodNotAllowedErrorResponseBody",
    "WorkOrdersDeleteWorkOrdersNotFoundErrorResponseBody",
    "WorkOrdersDeleteWorkOrdersNotImplementedErrorResponseBody",
    "WorkOrdersDeleteWorkOrdersServiceUnavailableErrorResponseBody",
    "WorkOrdersDeleteWorkOrdersTooManyRequestsErrorResponseBody",
    "WorkOrdersDeleteWorkOrdersUnauthorizedErrorResponseBody",
    "WorkOrdersGetServiceTasksBadGatewayErrorResponseBody",
    "WorkOrdersGetServiceTasksGatewayTimeoutErrorResponseBody",
    "WorkOrdersGetServiceTasksInternalServerErrorResponseBody",
    "WorkOrdersGetServiceTasksMethodNotAllowedErrorResponseBody",
    "WorkOrdersGetServiceTasksNotFoundErrorResponseBody",
    "WorkOrdersGetServiceTasksNotImplementedErrorResponseBody",
    "WorkOrdersGetServiceTasksResponseBody",
    "WorkOrdersGetServiceTasksServiceUnavailableErrorResponseBody",
    "WorkOrdersGetServiceTasksTooManyRequestsErrorResponseBody",
    "WorkOrdersGetServiceTasksUnauthorizedErrorResponseBody",
    "WorkOrdersGetWorkOrdersBadGatewayErrorResponseBody",
    "WorkOrdersGetWorkOrdersGatewayTimeoutErrorResponseBody",
    "WorkOrdersGetWorkOrdersInternalServerErrorResponseBody",
    "WorkOrdersGetWorkOrdersMethodNotAllowedErrorResponseBody",
    "WorkOrdersGetWorkOrdersNotFoundErrorResponseBody",
    "WorkOrdersGetWorkOrdersNotImplementedErrorResponseBody",
    "WorkOrdersGetWorkOrdersResponseBody",
    "WorkOrdersGetWorkOrdersServiceUnavailableErrorResponseBody",
    "WorkOrdersGetWorkOrdersTooManyRequestsErrorResponseBody",
    "WorkOrdersGetWorkOrdersUnauthorizedErrorResponseBody",
    "WorkOrdersPatchWorkOrdersBadGatewayErrorResponseBody",
    "WorkOrdersPatchWorkOrdersGatewayTimeoutErrorResponseBody",
    "WorkOrdersPatchWorkOrdersInternalServerErrorResponseBody",
    "WorkOrdersPatchWorkOrdersMethodNotAllowedErrorResponseBody",
    "WorkOrdersPatchWorkOrdersNotFoundErrorResponseBody",
    "WorkOrdersPatchWorkOrdersNotImplementedErrorResponseBody",
    "WorkOrdersPatchWorkOrdersRequestBodyPriority",
    "WorkOrdersPatchWorkOrdersRequestBodyStatus",
    "WorkOrdersPatchWorkOrdersResponseBody",
    "WorkOrdersPatchWorkOrdersServiceUnavailableErrorResponseBody",
    "WorkOrdersPatchWorkOrdersTooManyRequestsErrorResponseBody",
    "WorkOrdersPatchWorkOrdersUnauthorizedErrorResponseBody",
    "WorkOrdersPostInvoiceScanBadGatewayErrorResponseBody",
    "WorkOrdersPostInvoiceScanGatewayTimeoutErrorResponseBody",
    "WorkOrdersPostInvoiceScanInternalServerErrorResponseBody",
    "WorkOrdersPostInvoiceScanMethodNotAllowedErrorResponseBody",
    "WorkOrdersPostInvoiceScanNotFoundErrorResponseBody",
    "WorkOrdersPostInvoiceScanNotImplementedErrorResponseBody",
    "WorkOrdersPostInvoiceScanResponseBody",
    "WorkOrdersPostInvoiceScanServiceUnavailableErrorResponseBody",
    "WorkOrdersPostInvoiceScanTooManyRequestsErrorResponseBody",
    "WorkOrdersPostInvoiceScanUnauthorizedErrorResponseBody",
    "WorkOrdersPostWorkOrdersBadGatewayErrorResponseBody",
    "WorkOrdersPostWorkOrdersGatewayTimeoutErrorResponseBody",
    "WorkOrdersPostWorkOrdersInternalServerErrorResponseBody",
    "WorkOrdersPostWorkOrdersMethodNotAllowedErrorResponseBody",
    "WorkOrdersPostWorkOrdersNotFoundErrorResponseBody",
    "WorkOrdersPostWorkOrdersNotImplementedErrorResponseBody",
    "WorkOrdersPostWorkOrdersRequestBodyPriority",
    "WorkOrdersPostWorkOrdersResponseBody",
    "WorkOrdersPostWorkOrdersServiceUnavailableErrorResponseBody",
    "WorkOrdersPostWorkOrdersTooManyRequestsErrorResponseBody",
    "WorkOrdersPostWorkOrdersUnauthorizedErrorResponseBody",
    "WorkOrdersStreamWorkOrdersBadGatewayErrorResponseBody",
    "WorkOrdersStreamWorkOrdersGatewayTimeoutErrorResponseBody",
    "WorkOrdersStreamWorkOrdersInternalServerErrorResponseBody",
    "WorkOrdersStreamWorkOrdersMethodNotAllowedErrorResponseBody",
    "WorkOrdersStreamWorkOrdersNotFoundErrorResponseBody",
    "WorkOrdersStreamWorkOrdersNotImplementedErrorResponseBody",
    "WorkOrdersStreamWorkOrdersResponseBody",
    "WorkOrdersStreamWorkOrdersServiceUnavailableErrorResponseBody",
    "WorkOrdersStreamWorkOrdersTooManyRequestsErrorResponseBody",
    "WorkOrdersStreamWorkOrdersUnauthorizedErrorResponseBody",
    "WorkerSafetySosDataResponseBody",
    "WorkerSafetySosDataResponseBodySourceType",
    "WorkflowAddressEventWithGeofenceObjectResponseBody",
    "WorkflowAuthorSignatureObjectResponseBody",
    "WorkflowAuthorSignatureObjectResponseBodyType",
    "WorkflowCircleResponseBody",
    "WorkflowDvirObjectResponseBody",
    "WorkflowDvirObjectResponseBodySafetyStatus",
    "WorkflowDvirObjectResponseBodyType",
    "WorkflowDvirSubmittedResponseObjectResponseBody",
    "WorkflowGeofenceEventResponseObjectResponseBody",
    "WorkflowGeofenceResponseBody",
    "WorkflowIncidentConditionObjectResponseBody",
    "WorkflowIncidentDetailsObjectResponseBody",
    "WorkflowPolygonResponseBody",
    "WorkflowSignatoryUserObjectResponseBody",
    "WorkflowTriggerObjectRequestBody",
    "WorkflowTriggerObjectResponseBody",
    "__version__",
    "addresses",
    "alerts",
    "assets",
    "attributes",
    "auth_token_for_driver",
    "beta_ap_is",
    "carrier_proposed_assignments",
    "coaching",
    "contacts",
    "documents",
    "driver_qr_codes",
    "driver_trailer_assignments",
    "driver_vehicle_assignments",
    "drivers",
    "equipment",
    "fleet",
    "forms",
    "fuel_and_energy",
    "gateways",
    "hours_of_service",
    "hubs",
    "idling",
    "ifta",
    "industrial",
    "issues",
    "legacy",
    "legacy_ap_is",
    "live_sharing_links",
    "location_and_speed",
    "maintenance",
    "media",
    "messages",
    "organization_info",
    "plans",
    "preview_ap_is",
    "route_events",
    "routes",
    "safety",
    "sensors",
    "settings",
    "speeding_intervals",
    "tachograph_eu_only",
    "tags",
    "trailer_assignments",
    "trailers",
    "training_assignments",
    "training_courses",
    "trips",
    "users",
    "vehicle_locations",
    "vehicle_stats",
    "vehicles",
    "webhooks",
    "work_orders",
]
